/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "applicationsetting.h"
#include <QSettings>

/**
 * @brief 設定ファイルのカテゴリー、キーの名称
 */
static const QString CATEGORY_NAME_TEST = "Test";
static const QString CATEGORY_NAME_POLLOING_INTERVAL = "PolloingInterval";
static const QString CATEGORY_NAME_STUB_DATA_PATH = "StubDataPath";
static const QString CATEGORY_NAME_SINGLE_MEASURE_RESULT = "SingleMeasureResult";
static const QString CATEGORY_NAME_MULTI_MEASURE_RESULT = "MultiMeasureResult";
static const QString CATEGORY_NAME_LOGGER_MEASURE_RESULT = "LoggerMeasureResult";
static const QString CATEGORY_NAME_USER_SETTING = "UserSetting";
static const QString CATEGORY_NAME_USER_SETTING_USB1 = "UserSettingUsb1";
static const QString CATEGORY_NAME_USER_SETTING_USB2 = "UserSettingUsb2";
static const QString CATEGORY_NAME_MEASURE_SETTING = "MeasureSetting";
static const QString CATEGORY_NAME_USER_RESULT = "UserResult";
static const QString CATEGORY_NAME_LOGGER_RESULT = "LoggerResult";
static const QString CATEGORY_NAME_LOGGER_SETTING = "LoggerSetting";
static const QString CATEGORY_NAME_LOGGER_SETTING_USB1 = "LoggerSettingUsb1";
static const QString CATEGORY_NAME_LOGGER_SETTING_USB2 = "LoggerSettingUsb2";
static const QString CATEGORY_NAME_CONSTELLATION_TERM_OF_USE = "ConstellationTermOfUse";
static const QString CATEGORY_NAME_CHANNEL_DEFINITION_PATH = "ChannelDefinitionPath";
static const QString CATEGORY_NAME_ANIMATION_SETTING = "AnimationSetting";
static const QString CATEGORY_NAME_LONG_PRESS_SETTING = "LongPressSetting";
static const QString CATEGORY_NAME_DELAY_SETTING = "DelaySetting";
static const QString CATEGORY_NAME_WAKE_UP_SETTING = "WakeUpSetting";
static const QString CATEGORY_NAME_FIX_TIME_SETTING = "FixTimeSetting";
static const QString CATEGORY_NAME_ZIP_PASSWORD_SETTING = "ZipPasswordSetting";
static const QString CATEGORY_NAME_WAIT_FOR_LOCKING = "WaitForLocking";
static const QString CATEGORY_NAME_BLINKING = "Blinking";
static const QString CATEGORY_NAME_STUB_LOGGER_SETTING = "StubLoggerSetting";
static const QString CATEGORY_NAME_MEASURE_DATA_FILE_LIST = "MeasureDataFileList";

static const QString KEY_NAME_MODE = "Mode";
static const QString KEY_NAME_SINGLE_MEASUREMENT = "SingleMeasurement";
static const QString KEY_NAME_MULTI_MEASUREMENT = "MultiMeasurement";
static const QString KEY_NAME_CONSTELLATION = "Constellation";
static const QString KEY_NAME_DELAY_PROFILE = "DelayProfile";
static const QString KEY_NAME_SCAN = "Scan";
static const QString KEY_NAME_OPTICAL_MEASUREMENT = "OpticalMeasurement";
static const QString KEY_NAME_DC_MEASUREMENT = "DCMeasurement";
static const QString KEY_NAME_FAILURE_DETECTION = "FailureDetection";
static const QString KEY_NAME_COMPASS = "Compass";
static const QString KEY_NAME_ONE_CHANNEL = "OneChannel";
static const QString KEY_NAME_KEY_INPUT = "KeyInput";
static const QString KEY_NAME_DEVICE_STATUS = "DeviceStatus";
static const QString KEY_NAME_DATA = "Data";
static const QString KEY_NAME_COPY = "Copy";
static const QString KEY_NAME_NUMBER_OF_POINTS = "NumberOfPoints";
static const QString KEY_NAME_DATALOGGER = "DataLogger";
static const QString KEY_NAME_METER_UPDATE_INTERVAL = "MeterUpdateInterval";
static const QString KEY_NAME_INVALID_VALUE_SPEED_MAGNIFICATION = "InvalidValueSpeedMagnification";
static const QString KEY_NAME_FIRST_REPEAT_TIME = "FirstRepeatTime";
static const QString KEY_NAME_LOW_REPEAT_COUNT = "LowRepeatCount";
static const QString KEY_NAME_REPEAT_INTERVAL_LOW = "RepeatIntervalLow";
static const QString KEY_NAME_REPEAT_INTERVAL_HIGH = "RepeatIntervalHigh";
static const QString KEY_NAME_DELAY_PROFILE_SKIP_INDEX_LOW = "DelayProfileSkipIndexLow";
static const QString KEY_NAME_DELAY_PROFILE_SKIP_INDEX_HIGH = "DelayProfileSkipIndexHigh";
static const QString KEY_NAME_LOW_REPEAT_COUNT_FOR_FREQUENCY = "LowRepeatCountForFrequency";
static const QString KEY_NAME_REPEAT_INTERVAL_LOW_FOR_FREQUENCY = "RepeatIntervalLowForFrequency";
static const QString KEY_NAME_REPEAT_INTERVAL_HIGH_FOR_FREQUENCY = "RepeatIntervalHighForFrequency";
static const QString KEY_NAME_CHANNEL_CHANGE_DELAY = "ChannelChangeDelay";
static const QString KEY_NAME_WAITING_TIME_FOR_SUB = "WatingTimeForSub";
static const QString KEY_NAME_FIX_TIME_SETTING_LEVEL = "Level";
static const QString KEY_NAME_FIX_TIME_SETTING_MER = "Mer";
static const QString KEY_NAME_FIX_TIME_SETTING_BER = "Ber";
static const QString KEY_NAME_ZIP_PASSWORD_SETTING_PASSWORD = "Password";
static const QString KEY_NAME_METER = "Meter";
static const QString KEY_NAME_PREFFERED_CHANNEL = "PrefferedChannel";
static const QString KEY_NAME_INTERVAL = "Interval";
static const QString KEY_NAME_FILENAME = "FileName";

static constexpr uint32_t INVALID_SETTING_VALUE = 0xFFFFFFFF; //!< 異常値

static constexpr int USER_SETTING_DATA_COUNT = 140;  //!< ユーザー設定データの個数

ApplicationSetting::ApplicationSetting(const QString &settingFilePath, QObject *parent)
    : QObject(parent)
    , _settingFilePath(settingFilePath)
    , _testConfiguration()
    , _pollingInterval()
    , _stubDataPath()
    , _resultDataPath()
    , _settingDataPath()
    , _constellationTermOfUse()
    , _channelDefinition()
    , _animationSetting()
    , _longPressSetting()
    , _wakeUpSetting()
    , _fixTimeSetting()
    , _zipPassword()
    , _measureDataFileList()

{
    // ユーザー設定データの個数を確保
    for (int i = 0; i < USER_SETTING_DATA_COUNT; ++i) {
        _settingDataPath.UserData.append(QString());
    }

    initialize();
}

ApplicationSetting::~ApplicationSetting()
{

}

uint32_t ApplicationSetting::pollingIntervalMultiMeasurement() const
{
    return _pollingInterval.MultiMeasurement;
}

void ApplicationSetting::initialize(void)
{
    // 設定ファイル読込及び値保持
    QSettings settings(_settingFilePath, QSettings::IniFormat);

    // [Test]
    settings.beginGroup(CATEGORY_NAME_TEST);
    _testConfiguration.Mode = settings.value(KEY_NAME_MODE, 0).toUInt();
    settings.endGroup();

    // [PolloingInterval]
    settings.beginGroup(CATEGORY_NAME_POLLOING_INTERVAL);
    _pollingInterval.SingleMeasurement = settings.value(KEY_NAME_SINGLE_MEASUREMENT, 0).toUInt();
    _pollingInterval.MultiMeasurement = settings.value(KEY_NAME_MULTI_MEASUREMENT, 0).toUInt();
    _pollingInterval.Constellation = settings.value(KEY_NAME_CONSTELLATION, 0).toUInt();
    _pollingInterval.DelayProfile = settings.value(KEY_NAME_DELAY_PROFILE, 0).toUInt();
    _pollingInterval.KeyInput = settings.value(KEY_NAME_KEY_INPUT, 0).toUInt();
    _pollingInterval.DeviceStatus = settings.value(KEY_NAME_DEVICE_STATUS, 0).toUInt();
    _pollingInterval.Scan = settings.value(KEY_NAME_SCAN, 0).toUInt();
    _pollingInterval.OpticalMeasurement = settings.value(KEY_NAME_OPTICAL_MEASUREMENT, 0).toUInt();
    _pollingInterval.DCMeasurement = settings.value(KEY_NAME_DC_MEASUREMENT, 0).toUInt();
    _pollingInterval.FailureDetection = settings.value(KEY_NAME_FAILURE_DETECTION, 0).toUInt();
    _pollingInterval.Compass = settings.value(KEY_NAME_COMPASS, 0).toUInt();
    _pollingInterval.OneChannel = settings.value(KEY_NAME_ONE_CHANNEL, 0).toUInt();
    settings.endGroup();

    // [StubDataPath]
    settings.beginGroup(CATEGORY_NAME_STUB_DATA_PATH);
    _stubDataPath.SingleMeasurement = settings.value(KEY_NAME_SINGLE_MEASUREMENT, "").toString();
    _stubDataPath.MultiMeasurement = settings.value(KEY_NAME_MULTI_MEASUREMENT, "").toString();
    _stubDataPath.DataLogger = settings.value(KEY_NAME_DATALOGGER, "").toString();
    settings.endGroup();

    // [SingleMeasureResult]
    settings.beginGroup(CATEGORY_NAME_SINGLE_MEASURE_RESULT);
    _resultDataPath.Single = settings.value(KEY_NAME_DATA, "").toString();
    _resultDataPath.SingleCopy = settings.value(KEY_NAME_COPY, "").toString();
    settings.endGroup();

    // [MultiMeasureResult]
    settings.beginGroup(CATEGORY_NAME_MULTI_MEASURE_RESULT);
    _resultDataPath.Multi = settings.value(KEY_NAME_DATA, "").toString();
    _resultDataPath.MultiCopy = settings.value(KEY_NAME_COPY, "").toString();
    settings.endGroup();

    // [LoggerMeasureResult]
    settings.beginGroup(CATEGORY_NAME_LOGGER_MEASURE_RESULT);
    _resultDataPath.Logger = settings.value(KEY_NAME_DATA, "").toString();
    _resultDataPath.LoggerCopy = settings.value(KEY_NAME_COPY, "").toString();
    settings.endGroup();

    // [UserSetting]
    settings.beginGroup(CATEGORY_NAME_USER_SETTING);
    _settingDataPath.UserData = settings.value(KEY_NAME_DATA, "").toString();
    _settingDataPath.UserSettingFileName = settings.value(KEY_NAME_FILENAME, "").toString();
    settings.endGroup();

    // [UserSettingUsb1]
    settings.beginGroup(CATEGORY_NAME_USER_SETTING_USB1);
    _settingDataPath.UserDataUsb1 = settings.value(KEY_NAME_DATA, "").toString();
    _settingDataPath.UserSettingUsb1FileName = settings.value(KEY_NAME_FILENAME, "").toString();
    settings.endGroup();

    // [UserSettingUsb2]
    settings.beginGroup(CATEGORY_NAME_USER_SETTING_USB2);
    _settingDataPath.UserDataUsb2 = settings.value(KEY_NAME_DATA, "").toString();
    _settingDataPath.UserSettingUsb2FileName = settings.value(KEY_NAME_FILENAME, "").toString();
    settings.endGroup();

    // [UserResult]
    settings.beginGroup(CATEGORY_NAME_USER_RESULT);
    _resultDataPath.List = settings.value(KEY_NAME_DATA, "").toString();
    settings.endGroup();

    // [MeasureSetting]
    settings.beginGroup(CATEGORY_NAME_MEASURE_SETTING);
    _settingDataPath.Measure = settings.value(KEY_NAME_DATA, "").toString();
    settings.endGroup();

    // [LoggerResult]
    settings.beginGroup(CATEGORY_NAME_LOGGER_RESULT);
    _resultDataPath.Logger = settings.value(KEY_NAME_DATA, "").toString();
    settings.endGroup();

    // [LoggerSetting]
    settings.beginGroup(CATEGORY_NAME_LOGGER_SETTING);
    _settingDataPath.Logger = settings.value(KEY_NAME_DATA, "").toString();
    _settingDataPath.LoggerSettingFileName = settings.value(KEY_NAME_FILENAME, "").toString();
    settings.endGroup();

    // [LoggerSettingUsb1]
    settings.beginGroup(CATEGORY_NAME_LOGGER_SETTING_USB1);
    _settingDataPath.LoggerUsb1 = settings.value(KEY_NAME_DATA, "").toString();
    _settingDataPath.LoggerSettingUsb1FileName = settings.value(KEY_NAME_FILENAME, "").toString();
    settings.endGroup();

    // [LoggerSettingUsb2]
    settings.beginGroup(CATEGORY_NAME_LOGGER_SETTING_USB2);
    _settingDataPath.LoggerUsb2 = settings.value(KEY_NAME_DATA, "").toString();
    _settingDataPath.LoggerSettingUsb2FileName = settings.value(KEY_NAME_FILENAME, "").toString();
    settings.endGroup();

    // [ConstellationTermOfUse]
    settings.beginGroup(CATEGORY_NAME_CONSTELLATION_TERM_OF_USE);
    _constellationTermOfUse.NumberOfPoints = settings.value(KEY_NAME_NUMBER_OF_POINTS, 0).toUInt();
    settings.endGroup();

    // [ChannelDefinitionPath]
    settings.beginGroup(CATEGORY_NAME_CHANNEL_DEFINITION_PATH);
    _channelDefinition.Data = settings.value(KEY_NAME_DATA, "").toString();
    settings.endGroup();

    // [AminationSetting]
    settings.beginGroup(CATEGORY_NAME_ANIMATION_SETTING);
    _animationSetting.meterUpdateInterval = settings.value(KEY_NAME_METER_UPDATE_INTERVAL, INVALID_SETTING_VALUE).toUInt();
    _animationSetting.invalidValudSpeed = settings.value(KEY_NAME_INVALID_VALUE_SPEED_MAGNIFICATION, INVALID_SETTING_VALUE).toUInt();
    settings.endGroup();

    // [LongPressSetting]
    settings.beginGroup(CATEGORY_NAME_LONG_PRESS_SETTING);
    _longPressSetting.firstRepeatTime = settings.value(KEY_NAME_FIRST_REPEAT_TIME, INVALID_SETTING_VALUE).toUInt();
    _longPressSetting.lowRepeatCount = settings.value(KEY_NAME_LOW_REPEAT_COUNT, INVALID_SETTING_VALUE).toUInt();
    _longPressSetting.repeatIntervalLow = settings.value(KEY_NAME_REPEAT_INTERVAL_LOW, INVALID_SETTING_VALUE).toUInt();
    _longPressSetting.repeatIntervalHigh = settings.value(KEY_NAME_REPEAT_INTERVAL_HIGH, INVALID_SETTING_VALUE).toUInt();
    _longPressSetting.delayProfileSkipIndexLow = settings.value(KEY_NAME_DELAY_PROFILE_SKIP_INDEX_LOW, INVALID_SETTING_VALUE).toUInt();
    _longPressSetting.delayProfileSkipIndexHigh = settings.value(KEY_NAME_DELAY_PROFILE_SKIP_INDEX_HIGH, INVALID_SETTING_VALUE).toUInt();
    _longPressSetting.lowRepeatCountForFrequency = settings.value(KEY_NAME_LOW_REPEAT_COUNT_FOR_FREQUENCY, INVALID_SETTING_VALUE).toUInt();
    _longPressSetting.repeatIntervalLowForFrequency = settings.value(KEY_NAME_REPEAT_INTERVAL_LOW_FOR_FREQUENCY, INVALID_SETTING_VALUE).toUInt();
    _longPressSetting.repeatIntervalHighForFrequency = settings.value(KEY_NAME_REPEAT_INTERVAL_HIGH_FOR_FREQUENCY, INVALID_SETTING_VALUE).toUInt();
    settings.endGroup();

    // [DelaySetting]
    settings.beginGroup(CATEGORY_NAME_DELAY_SETTING);
    _delaySetting.channelChangeDelay = settings.value(KEY_NAME_CHANNEL_CHANGE_DELAY, INVALID_SETTING_VALUE).toUInt();
    settings.endGroup();

    // [WakeUpSetting]
    settings.beginGroup(CATEGORY_NAME_WAKE_UP_SETTING);
    _wakeUpSetting.waitingTimeForSub = settings.value(KEY_NAME_WAITING_TIME_FOR_SUB, 0).toUInt();
    settings.endGroup();

    // [FixTimeSetting]
    settings.beginGroup(CATEGORY_NAME_FIX_TIME_SETTING);
    _fixTimeSetting.level = settings.value(KEY_NAME_FIX_TIME_SETTING_LEVEL, 0).toUInt();
    _fixTimeSetting.mer = settings.value(KEY_NAME_FIX_TIME_SETTING_MER, 0).toUInt();
    _fixTimeSetting.ber = settings.value(KEY_NAME_FIX_TIME_SETTING_BER, 0).toUInt();
    settings.endGroup();

    // [ZipPasswordSetting]
    settings.beginGroup(CATEGORY_NAME_ZIP_PASSWORD_SETTING);
    _zipPassword.Password = settings.value(KEY_NAME_ZIP_PASSWORD_SETTING_PASSWORD, "").toString();
    settings.endGroup();

    // [WaitForLocking]
    settings.beginGroup(CATEGORY_NAME_WAIT_FOR_LOCKING);
    _waitForLocking.Meter = settings.value(KEY_NAME_METER).toUInt();
    _waitForLocking.Constellation = settings.value(KEY_NAME_CONSTELLATION).toUInt();
    _waitForLocking.DelayProfile = settings.value(KEY_NAME_DELAY_PROFILE).toUInt();
    _waitForLocking.PrefferedChannel = settings.value(KEY_NAME_PREFFERED_CHANNEL).toUInt();
    settings.endGroup();

    // [Blinking]
    settings.beginGroup(CATEGORY_NAME_BLINKING);
    _blinking.Interval = settings.value(KEY_NAME_INTERVAL).toUInt();
    settings.endGroup();

    // [MeasureDataFileList]
    settings.beginGroup(CATEGORY_NAME_MEASURE_DATA_FILE_LIST);
    _measureDataFileList.Path = settings.value(KEY_NAME_DATA).toString();
    _measureDataFileList.FileName = settings.value(KEY_NAME_FILENAME).toString();
    settings.endGroup();

    // [StubLoggerSetting]
    settings.beginGroup(CATEGORY_NAME_STUB_LOGGER_SETTING);
    _settingDataPath.StubLogger = settings.value(KEY_NAME_DATA, "").toString();
    settings.endGroup();}

bool ApplicationSetting::isValidSetting(QString &invalidDataName)
{
    static const QMap<uint32_t *, QPair<QString, QString>> checkDataMap = {
        {&(_animationSetting.meterUpdateInterval), {CATEGORY_NAME_ANIMATION_SETTING, KEY_NAME_METER_UPDATE_INTERVAL}},
        {&(_animationSetting.invalidValudSpeed), {CATEGORY_NAME_ANIMATION_SETTING, KEY_NAME_INVALID_VALUE_SPEED_MAGNIFICATION}},
        {&(_longPressSetting.firstRepeatTime), {CATEGORY_NAME_LONG_PRESS_SETTING, KEY_NAME_FIRST_REPEAT_TIME}},
        {&(_longPressSetting.lowRepeatCount), {CATEGORY_NAME_LONG_PRESS_SETTING, KEY_NAME_LOW_REPEAT_COUNT}},
        {&(_longPressSetting.repeatIntervalLow), {CATEGORY_NAME_LONG_PRESS_SETTING, KEY_NAME_REPEAT_INTERVAL_LOW}},
        {&(_longPressSetting.repeatIntervalHigh), {CATEGORY_NAME_LONG_PRESS_SETTING, KEY_NAME_REPEAT_INTERVAL_HIGH}},
        {&(_longPressSetting.delayProfileSkipIndexLow), {CATEGORY_NAME_LONG_PRESS_SETTING, KEY_NAME_DELAY_PROFILE_SKIP_INDEX_LOW}},
        {&(_longPressSetting.delayProfileSkipIndexHigh), {CATEGORY_NAME_LONG_PRESS_SETTING, KEY_NAME_DELAY_PROFILE_SKIP_INDEX_HIGH}},
        {&(_delaySetting.channelChangeDelay), {CATEGORY_NAME_DELAY_SETTING, KEY_NAME_CHANNEL_CHANGE_DELAY}},
    };

    QMapIterator<uint32_t *, QPair<QString, QString>> iterator(checkDataMap);

    while (iterator.hasNext()) {
        iterator.next();

        if (*(iterator.key()) == INVALID_SETTING_VALUE) {
            invalidDataName = QString("%1 - %2").arg(iterator.value().first).arg(iterator.value().second);
            return false;
        }
    }

    return true;

}
