/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef CHANNELSETTING_H
#define CHANNELSETTING_H

#include <QObject>
extern "C" {
#include "liblc70.h"
}

constexpr uint32_t CHANNEL_NUMBER_STRING_LENGTH = 4;        //!< チャンネル番号の文字列の長さ

/**
 * @brief チャンネル情報構造体
 */
struct Channel {
    uint32_t frequency;                                     //!< 実放送周波数[Hz]
    uint32_t localOscillator;                               //!< 局部発振周波数[Hz]
    uint16_t broadcastSystem;                               //!< 放送方式
    uint16_t band;                                          //!< バンド
    uint16_t modulation;                                    //!< 変調方式
    uint8_t channelNumber[CHANNEL_NUMBER_STRING_LENGTH];    //!< チャンネル番号文字列

    Channel()
    {
        frequency = 0;
        localOscillator = 0;
        broadcastSystem = 0;
        band = 0;
        modulation = 0;
        memset(channelNumber, 0, sizeof(channelNumber));
    }
};

/**
 * @brief チャンネル設定情報
 */
class ChannelSetting : public QObject
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクター
     * @param parent 親オブジェクト
     */
    explicit ChannelSetting(QObject *parent = nullptr);

    /**
     * @brief デストラクター
     */
    ~ChannelSetting();

    /**
     * @brief LC70ライブラリより取得したチャンネル定義情報を設定する
     * @param channelConfiguration チャンネル定義情報
     * @note 構造体定義内容が不明のため不使用
     */
    void setChannel(const LC70_CHAN_CONF_T *channelConfiguration);

    /**
     * @brief チャンネル情報を返す
     * @param channelNumber チャンネル番号(4 文字までの文字列)
     * @return チャンネル情報
     */
    Channel channel(const QString &channelNumber);

signals:

private:
    QList<Channel> _channels;           //!< チャンネル情報のリスト
};

#endif // CHANNELSETTING_H
