/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef LEVELCHECKER_H
#define LEVELCHECKER_H

#include <QObject>
#include <QGuiApplication>
#include <QQuickWindow>
#include "levelcheckermodel.h"
#include "levelcheckerviewmodel.h"

/**
 * @brief pdisp アプリケーション
 */
class LevelChecker : public QObject
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクター
     * @param application Qt アプリケーションクラスのポインター
     * @param engine QML のインスタンスを作成するクラスのポインター
     * @param parent 親オブジェクト
     */
    explicit LevelChecker(QQmlApplicationEngine *engine, QObject *parent = nullptr);

    /**
     * @brief 実行前の準備を行う
     * @param application Qt アプリケーションクラスのポインター
     * @return エラーコード
     */
    LC70_ERR_T prepare(QGuiApplication *application);

    /**
     *  @brief デストラクター
     */
    ~LevelChecker();

signals:

private:
    QQmlApplicationEngine *_engine;             //!< QML のインスタンスを作成するクラスのポインター
    LevelCheckerModel *_model;                  //!< アプリケーションの Model クラスを集約したクラス
    LevelCheckerViewModel *_viewModel;          //!< アプリケーションの ViewModel クラスを集約したクラス
    QQuickWindow *_window;                      //!< アプリケーションを表示するするウィンドウ
};

#endif // LEVELCHECKER_H
