/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include <QApplication>
#include <QQmlApplicationEngine>
#include <QTextCodec>
#include "constant.h"
#include "levelchecker.h"

int main(int argc, char *argv[])
{
    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);

    QApplication app(argc, argv);

    QQmlApplicationEngine engine;

    // 文字列を UTF-8 で表示
    QTextCodec::setCodecForLocale(QTextCodec::codecForName("UTF-8"));

    // アプリケーションのインスタンスを生成
    LevelChecker *levelChecker = new LevelChecker(&engine);

    // アプリケーションの起動
    // MainFrame.qml 及び Home 画面を表示

    LC70_ERR_T errorCode = LC70_OK;
    errorCode = levelChecker->prepare(&app);

    if (errorCode != LC70_OK) {
        delete levelChecker;
        QCoreApplication::exit(errorCode);
        return errorCode;
    }

    // アプリケーションの実行
    int ret = app.exec();

    delete levelChecker;

    return ret;
}
