/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef CONSTANT_H
#define CONSTANT_H

#include <QString>
#include <QList>
#include "typedef.h"

/**
 * @brief 動作モード
 */
enum ActionMode {
    PRODUCTION = 0,     //!< 本番用(ラッパー関数を使用してサブ CPU と連携)
    DEVELOPMENT,        //!< 開発用(スタブからテストデータ使用)

    ACTION_MODE_COUNT
};

/**
 * @brief 測定結果取得対象
 */
enum AcquisitionTarget {
    NOT_ACQUISITION = 0,    //!< 取得なし
    SINGLE,                 //!< シングル測定
    CONSTELLATION,          //!< コンスタレーション
    DELAY_PROFILE,          //!< 遅延プロファイル
    MULTI,                  //!< マルチ測定
    CHANNEL_SCAN,           //!< チャンネルスキャン
    ANTENNA,                //!< アンテナ調整
    ACQUISITION_TARGET_COUNT
};

/**
 * @brief 保存するファイルの種類
 */
enum SaveFileType {
    CSV = 0,                        //!< 測定データ(CSV)
    PNG,                            //!< 測定画面(PNG)
    SAVE_FILE_COUNT
};

/**
 * @brief 給電の種類(ボタンのインデックスに対応)
 */
enum PowerSupplyType {
    FIXED_15V = 0,                  //!< 15v固定 給電
    H15V11,                         //!< 水平15v/垂直11v 給電
    POWER_SUPPLY_COUNT
};

/**
 * @brief 測定種類
 */
enum MeasureType {
    SINGLE_MEASUREMENT = 0,     //!< シングル測定
    MULTI_MEASUREMENT,          //!< マルチ測定
    LIST_MEASUREMNET,           //!< リスト測定
    LOGGER_MESUREMENT,          //!< データロガー
    MEASTURE_TYPE_COUNT
};

/**
 * @brief メニューバーの階層
 */
enum MenuBarFloor {
    FIRST_FLOOR = 0,            //!< 第 1 階層
    SECOND_FLOOR,               //!< 第 2 階層
    THIRD_FLOOR,                //!< 第 3 階層
    FOURTH_FLOOR                //!< 第 4 階層
};

/**
 * @brief シングル測定メニューバーの Band 表示順
 */
enum MenuBarBandIndexSingleMeasurement {
    MENUBAR_UHF_SINGLE = 0,
    MENUBAR_BS_SINGLE,
    MENUBAR_CS_SINGLE,
    MENUBAR_BSCS_SINGLE,
    MENUBAR_CATV_ALL_SINGLE,
    MENUBAR_CATV_90_470_SINGLE,
    MENUBAR_CATV_470_1002_SINGLE,
    MENUBAR_SKYPERFECTV_OPTICAL_SINGLE,
    MENUBAR_PILOT_SINGLE,
    MENUBAR_CATV_UP_STREAM_SINGLE,
    MENUBAR_JCSAT3A_SINGLE,
    MENUBAR_JCSAT4B_SINGLE,
    MENUBAR_ANTENNA_SINGLE,
    MENUBAR_SCCB_SINGLE,
    MENUBAR_SCCC_SINGLE,
    MENUBAR_LTE_SINGLE,
    MENUBAR_FM_SINGLE

};

/**
 * @brief マルチ測定メニューバーの Band 表示順
 */
enum MenuBarBandIndexMultiMeasurement {
    MENUBAR_UHF_MULTI = 0,
    MENUBAR_BS_MULTI,
    MENUBAR_CS_MULTI,
    MENUBAR_BSCS_MULTI,
    MENUBAR_CATV_ALL_MULTI,
    MENUBAR_CATV_90_470_MULTI,
    MENUBAR_CATV_470_1002_MULTI,
    MENUBAR_SKYPERFECTV_OPTICAL_MULTI,
    MENUBAR_PILOT_MULTI,
    MENUBAR_CATV_UP_STREAM_MULTI,
    MENUBAR_JCSAT3A_MULTI,
    MENUBAR_JCSAT4B_MULTI,
    //MENUBAR_ANTENNA_MULTI, // マルチ測定ではアンテナ調整は無
    MENUBAR_SCCB_MULTI,
    MENUBAR_SCCC_MULTI,
    MENUBAR_LTE_MULTI,
    MENUBAR_FM_MULTI
};


enum MenuBarBandIndexopticalMeasurement {
    MENUBAR_UHF_OPT = 0,
    MENUBAR_BS_OPT,
    MENUBAR_CS_OPT,
    MENUBAR_BSCS_OPT,
    MENUBAR_CATV_ALL_OPT,
    MENUBAR_CATV_90_470_OPT,
    MENUBAR_CATV_470_1002_OPT,
    MENUBAR_SKYPERFECTV_OPTICAL_OPT,
    MENUBAR_PILOT_OPT,
    MENUBAR_CATV_UP_STREAM_OPT,
    MENUBAR_JCSAT3A_OPT,
    MENUBAR_JCSAT4B_OPT,
    MENUBAR_SCCB_OPT,
    MENUBAR_SCCC_OPT,
    MENUBAR_LTE_OPT,
    MENUBAR_FM_OPT,

};




/**
 * @brief メニューリストのアイコンインデックス
 */
enum MenuListIconIndex {
    RF_OPTICAL_ICON = 0, //!< 光・同軸
    FUNCTION_ICON,       //!< 機能
    BAND_ICON,           //!< 選択BAND
    SCAN_ICON,           //!< SCAN状態
    POWER_SUPPLY_ICON,   //!< 給電状態
    PREAMP_ICON,            //!<プリアンプ：
    MAX_NUM
};

/**
 * @brief ロック状態
 * @note ラッパーライブラリ V2.00 対応
 */
enum LockStatus {
    UNLOCKED = 0,       //!< アンロック
    LOCKED              //!< ロック
};

/**
 * @brief 遅延プロファイル収集ステータス
 */
enum DelayProfileStatus {
    DATA_NOTHING = 0,   //!< データなし
    DATA_COLLECTING,    //!< データ収集中
    DATA_VALID,         //!< データ有効(全ブロック収集完了)
    NONE_REQUEST,       //!< 収集要求なし
};

/**
 * @brief 変調方式と接頭句をどのように表示するか
 */
enum DisplayModulationAndPrefixMode {
    DISPLAY_MODULATION_PREFIX_TOGETHER = 0,   //!< 変調方式 接頭句を１つのラベルに纏めて表示する
    DISPLAY_MODULATION_PREFIX_SEPARATE = 1    //!< 変調方式 接頭句を別々のラベルに分けて表示する
};

/**
 * @brief Band のタブの一覧のインデックス
 */
enum BandTabIndex {
    BAND_TAB_UHF = 0,
    BAND_TAB_BS_R,
    BAND_TAB_BS_L,
    BAND_TAB_CS_R,
    BAND_TAB_CS_L,
    BAND_TAB_CATV_ALL,
    BAND_TAB_SKY_PERFECTV,
    BAND_TAB_CATV_UPSTREAM,
    BAND_TAB_JCSAT3A_H,
    BAND_TAB_JCSAT3A_V,
    BAND_TAB_JCSAT4B_H,
    BAND_TAB_JCSAT4B_V,
    BAND_TAB_SCCB2_H,
    BAND_TAB_SCCB2_V,
    BAND_TAB_SCCC2_H,
    BAND_TAB_SCCC2_V,
    BAND_TAB_LTE,
    BAND_TAB_FM,
    BAND_TAB_PILOT,
    BAND_TAB_COUNT
};

/**
 * @brief USER データロガー設定チャンネル編集モード
 */
enum ChannelEditMode {
    CHANNEL_EDIT_USER = 0,                  //!< USER 設定
    CHANNEL_EDIT_USER_USB1,                 //!< USB1
    CHANNEL_EDIT_USER_USB2,                 //!< USB2
    CHANNEL_EDIT_DATA_LOGGER,               //!< データロガー設定
    CHANNEL_EDIT_DATA_LOGGER_USB1,          //!< USB1
    CHANNEL_EDIT_DATA_LOGGER_USB2,          //!< USB2
    CHANNEL_EDIT_SELECT_DESTINATION,        //!< 保存先選択
};

/**
 * @brief バッテリー状態
 */
enum BatteryStatus {
    BATTERY_STATUS_UNKNOWN = 0,             //! 不定値
    BATTERY_STATUS_UNCHARGED,               //! 未充電
    BATTERY_STATUS_CHARGING,                //! 充電中
    BATTERY_STATUS_CHARGED,                 //! 満充電
};

/**
 * @brief バッテリーレベル
 */
enum BatteryLevel {
    BATTERY_LEVEL_UNKNOWN = 0,              //!不定値
    BATTERY_LEVEL1,                         //! 0～5%
    BATTERY_LEVEL2,                         //! 6～10%
    BATTERY_LEVEL3,                         //! 11～30%
    BATTERY_LEVEL4,                         //! 31～50%
    BATTERY_LEVEL5,                         //! 51～70%
    BATTERY_LEVEL6,                         //! 71～100%
};

/**
 * @brief USER データロガー設定ファイルの行数
 */
constexpr int USER_DATALOGGER_SETTING_FILE_ROWS = 510;

/**
 * @brief アプリケーションで扱うBANDの総数(チャンネル定義ファイルの数)
 */
constexpr int BAND_TOTAL = 20;

/**
 * @brief エラーコード
 */
constexpr int ERROR_CODE_1 = -1;        //!< MainFrame.qml が表示されなかった

/**
 * @brief 偏波指定時のインデックス
 */
constexpr int INDEX_RIGHT_HAND_HORIZONTAL = 0;        //!< 偏波ID: 右旋、水平
constexpr int INDEX_LEFT_HAND_VERTICAL = 1;         //!< 偏波ID: 左旋、垂直


/**
 * @brief スレッド名
 */
constexpr const char *SYSTEM_WATCHER_THREAD_NAME = "SystemWatcher";
constexpr const char *MEASURER_THREAD_NAME = "Measurer";
constexpr const char *FAULT_DETECTOR_THREAD_NAME = "FaultDetector";

/**
 * @brief スタンバイ実行時に作成するファイル名
 */

constexpr const char *STANDBY_LOCK_FILE_NAME = "./standby";
/**
 * @brief QML オブジェクト名
 */
constexpr const char *MAIN_FRAME_QML_OBJECT_NAME = "MainFrame";             //!< 基本画面
constexpr const char *LOADER_QML_OBJECT_NAME =
    "Loader";                    //!< 個々の画面をロードするためのローダー
constexpr const char *MENU_LIST_QML_OBJECT_NAME = "MenuList";               //!< メニューリストを表す部品
constexpr const char *MACHINE_STATUS_QML_OBJECT_NAME = "MachineStatus";     //!< 機器状態を表す部品
constexpr const char *MENU_BAR_MODEL_QML_OBJECT_NAME = "MenuBarModel";      //!< メニューバーを表す部品
constexpr const char *SINGLE_MEASUREMENT_QML_OBJECT_NAME = "SingleMeasurement"; //!< シングル測定画面
constexpr const char *MULTI_MEASUREMENT_QML_OBJECT_NAME = "MultiMeasurement";   //!< マルチ測定画面

/**
 * @brief QML の画面の種類
 * @note MainFrame.qml での定義と合わせること
 */
constexpr const int SCREEN_TYPE_SINGLE_MEASUREMENT = 0;     // シングル測定画面
constexpr const int SCREEN_TYPE_MULTI_MEASUREMENT = 1;      // マルチ測定画面
constexpr const int SCREEN_TYPE_OTHER = 2;                  // その他の画面

/**
 * @brief 測定種類
 */
constexpr const char *SINGLE_MEASURE_TYPE_NAME  = "SingleMeasurement";       //!< シングル測定
constexpr const char *MULTI_MEASURE_TYPE_NAME   = "MultiMeasurement";        //!< マルチ測定
constexpr const char *ANTENNA_MEASURE_TYPE_NAME = "AntennaAdjustment";       //!< アンテナ調整測定

/**
 * @brief 測定結果初期表示値
 */
static constexpr const char *INITIAL_LEVEL = "---";             //!< 測定入力レベルの初期値
static constexpr const char *INITIAL_MER = "---";               //!< 変調誤差比の初期値
static constexpr const char *INITIAL_BER = "---";               //!< ビット誤り率の初期値
static constexpr const char *INITIAL_MODULATION = "---";        //!< 変調方式の初期値
static constexpr int UNDEFINED_VALUE = -1;                      //!< 不定値 設定すると画面上では---と表示する値
static constexpr int UNLOCKED_VALUE = -2;                       //!< ロックされていない値

/**
 * @brief 測定条件
 */
static constexpr int CHANNEL_NUMBER_LENGTH = 8;                 //!< チャンネル番号の長さ

/**
 * @brief 変調方式の種類
 */
static constexpr const char *OFDM = "OFDM";
static constexpr const char *BPSK = "BPSK";
static constexpr const char *QPSK = "QPSK";
static constexpr const char *TC8PSK = "TC8PSK";
static constexpr const char *THIRTY_TWO_APSK = "32APSK";
static constexpr const char *SIXTEEN_APSK = "16APSK";
static constexpr const char *EIGHT_PSK  = "8PSK ";
static constexpr const char *SIXTY_FOUR_QAM = "64QAM";
static constexpr const char *TWO_HUNDRED_FIFTY_SIX_QAM = "256QAM";
static constexpr const char *CW = "CW";
static constexpr const char *FM = "FM";

/**
 * @brief 放送方式の種類
 */
static constexpr const char *ISDBT    = "ISDBT";
static constexpr const char *ISDBS    = "ISDBS";
static constexpr const char *ISDBS3   = "ISDBS3";
static constexpr const char *ANNEXC   = "ANNEXC";
static constexpr const char *DVBS     = "DVBS";
static constexpr const char *DVBS2    = "DVBS2";
static constexpr const char *OPTICAST = "Opticast";
static constexpr const char *LTE      = "LTE";
static constexpr const char *ANALOG   = "ANALOG";
static constexpr const char *ANNEXB   = "ANNEXB";

/**
 * @brief 偏波面の種類
 */
static constexpr const char *RIGHT_HANDED_POLARIZE = "R-Turn";      //!< 右旋
static constexpr const char *LEFT_HANDED_POLARIZE  = "L-Turn";      //!< 左旋
static constexpr const char *HORIZONTALLY_POLARIZE = "horizontal";  //!< 水平
static constexpr const char *VERTICALLY_POLARIZE   = "vertical";    //!< 垂直

static constexpr int MINIMUM_RANK = 0;                          //!< メニューバーの最下層
static constexpr int MAXIMUM_RANK = 3;                          //!< メニューバーの最上層

/**
 * @brief 閾値
 */
static constexpr float MINIMUM_LEVEL = 20.0;                        //!< LEVEL の最小値
static constexpr float MAXIMUM_LEVEL = 120.0;                       //!< LEVEL の最大値

static constexpr const char *FORMAT_MINIMUM_MER = "<%1.0";        //!< MER の最小値表示フォーマット
static constexpr const char *FORMAT_MAXIMUM_MER = ">%1.0";        //!< MER の最大値表示フォーマット
static const int MINIMUM_BER_EXPONENT = -2;                     //!< BER の最小値の指数
static const int MAXIMUM_BER_EXPONENT = -8;                     //!< BER の最大値の指数
static const int BER_VALUE_EXPONENT =
    2;                        //!< BER の値に付加されている指数(100倍されているので 2)

/**
* @brief 遅延プロファイル
*/
static constexpr int MINIMUM_DELAY_PROFILE_TIME = -84;          //!< 遅延プロファイルの最短時間
static constexpr int MAXIMUM_DELAY_PROFILE_TIME = 252;          //!< 遅延プロファイルの最長時間
static constexpr double DELAY_PROFILE_INITIAL_DECIBEL =
    -100.0f;    //!< 遅延プロファイルの初期値(最小デシベル)
static constexpr int DELAY_PROFILE_DATA_COUNT = 2048;           //!< 遅延プロファイル測定結果数
static constexpr double DELAY_PROFILE_INTERVAL =
    0.1640625;         //!< 遅延プロファイル測定結果の間隔[ns]

/**
 * @brief マルチ測定のグラフ
 */
static constexpr int MAXIMUM_MULTI_GRAPH_BAR_COUNT = 160;      //!< マルチ測定のグラフの最大棒グラフ数


/**
 * @brief ウェイクアップカウンター
 */
static constexpr uint32_t WAKE_UP_COUNTER_LENGTH = 10; //!< ウェイクアップカウンターの長さ

/**
 * @brief 光測定 測定波長
 */
static constexpr uint32_t OPTICAL_MEASUREMENT_WAVE_LENGTH_1300 = 1300;  //!< 光測定で用いる波長
static constexpr uint32_t OPTICAL_MEASUREMENT_WAVE_LENGTH_1310 = 1310;  //!< 光測定で用いる波長
static constexpr uint32_t OPTICAL_MEASUREMENT_WAVE_LENGTH_1490 = 1490;  //!< 光測定で用いる波長
static constexpr uint32_t OPTICAL_MEASUREMENT_WAVE_LENGTH_1550 = 1550;  //!< 光測定で用いる波長
static constexpr uint32_t OPTICAL_MEASUREMENT_WAVE_LENGTH_1625 = 1625;  //!< 光測定で用いる波長
static constexpr const char *FORMAT_MINIMUM_OPTICAST = "<%1";           //!< 光測定の最小表示値よりも下の値を表示する際のフォーマット
static constexpr const char *FORMAT_MAXIMUM_OPTICAST = ">%1";           //!< 光測定の最大表示値よりも上の値を表示する際のフォーマット
static constexpr const int MAXIMUM_OPTICAL_VALUE = 500;                 //!< 光測定の最大表示値 [x0.01dBm]
static constexpr const int MINIMUM_OPTICAL_VALUE = -3000;               //!< 光測定の最小表示値 [x0.01dBm]

/**
 * @brief DC測定
 */
static constexpr const char *FORMAT_MAXIMUM_DC = ">%1";        //!< DC測定の最大表示値よりも上の値を表示する際のフォーマット
static constexpr const int MINIMUM_DC_VALUE = 0;               //!< DC電圧の最小表示値[x0.01V]
static constexpr const int MAXIMUM_DC_VALUE = 3000;            //!< DC電圧の最大表示値[x0.01V]

/**
 * @brief USER データロガー設定
 */
static constexpr int BAND_TYPE_COUNT = 19;                              //!< Band の種類数(偏波別)
static constexpr int USER_DATALOGGER_SETTING_BAND_TYPE_ROWS = 2;        //!< 選択する Band の行数
static constexpr int USER_DATALOGGER_SETTING_BAND_TYPE_COLUMNS = 12;    //!< 選択する Band の列数

/**
 * @brief サブ CPU のリセットを行うまでの連続測定エラー回数の設定
 */
static constexpr int REPEAT_TIMES_TO_RESET = 50;                //!< サブ CPU リセットを行う連続測定エラー回数

/**
 * @brief ロック待ち時間のタイムアウト発生時の表示内容
 */
static constexpr const char *MER_TIMEOUT_VALUE = "<5.0";            //!< タイムアウト時の MER の表示内容
static constexpr const char *BER_TIMEOUT_VALUE = "2.2e-2";          //!< タイムアウト時の BER の表示内容

/**
 * @brief USER データロガー設定
 */
static constexpr uint8_t POWER_SUPPLY_ON = 1;                       //!< 給電 ON
static constexpr uint8_t POWER_SUPPLY_OFF = 0;                      //!< 給電 OFF
static constexpr uint8_t DO_MEASURING = 1;                          //!< 測定する
static constexpr uint8_t DO_NOT_MEASURE = 0;                        //!< 測定しない

/**
 * @brief 測定結果保存データ
 */
struct MeasureResult {
    bool Received;              //!< ラッパー関数からの取得に成功したか否か
    QString Band;               //!< BAND 種別
    QString Channel;            //!< チャンネル番号
    uint32_t Frequency;         //!< 周波数
    uint32_t LocalOscillator;   //!< 局発周波数
    uint8_t Locked;             //!< ロック状態(ラッパーライブラリ V2.00 対応)
    uint16_t Status;            //!< 収集ステータス
    uint16_t BroadcastSystem;   //!< 放送方式
    uint32_t Modulation;        //!< 変調方式
    uint8_t Layer;              //!< 階層、偏波面
    float32_t Level;            //!< 測定入力レベル
    float32_t Mer;              //!< 変調誤差比
    float32_t Cnr;              //!< CNR(ラッパーライブラリ V2.00 対応)
    float32_t Ber;              //!< ビット誤り率
    uint8_t GuardInterval;      //!< ガードインターバル(ラッパーライブラリ V2.00 対応)
    QString Timestamp;          //!< 取得時間

    MeasureResult() : Received(false), Band(), Channel(), Frequency(0), LocalOscillator(0), Locked(0), Status(0),
        BroadcastSystem(0), Modulation(0), Layer(0), Level(0.0f), Mer(0.0f), Ber(0.022), Timestamp() {}
};

/**
 * @brief 測定結果データ(マルチチャンネル測定リスト用)
 * @note 数値のフォーマットを qml 側で行わないため定義
 */
struct MeasureResultRow {
    QString Band;               //!< BAND 種別
    QString BandName;           //!< 表示 Band 名
    QString Channel;            //!< チャンネル番号
    QString BroadcastSystem;    //!< 放送方式
    QString Level;              //!< 測定入力レベル
    QString Mer;                //!< 変調誤差比
    QString Ber;                //!< ビット誤り率
    QString Frequency;          //!< 周波数
    QString Modulation;         //!< 変調方式
    QString Layer;              //!< 階層
    QString Polarization;       //!< 偏波
    QString LocalOscillator;    //!< 局発周波数
    QString Timestamp;          //!< 取得時間

    MeasureResultRow() : Band(), BandName(), Channel(), BroadcastSystem(), Level(), Mer(), Ber(), Frequency(), Modulation(),
        Layer(), Polarization(), LocalOscillator(), Timestamp() {}
};

/**
 * @brief マルチ測定測定結果データ
 */
struct MultiResult {
    bool received;                  //!< ラッパー関数からの取得に成功したか否か
    uint8_t locked;                 //!< ロック状態 0:アンロック 1:ロック
    uint16_t status;                //!< 収集ステータス
    uint8_t readIndex;              //!< 読出データインデックス
    uint8_t currentMeasuringIndex;  //!< カレント測定中インデックス
    MeasureResult result;           //!< 取得した測定結果

    MultiResult() : received(false), locked(UNLOCKED), status(0), readIndex(0), currentMeasuringIndex(0), result() {}
};

/**
 * @brief ユーザー設定データのチャンネル情報
 */
struct UserSettingChannelInformation {
    QString Channel;                            //!< チャンネル番号
    uint8_t Validation;                         //!< 有効フラグ(0: 無効 1: 有効)
    QString Modulation;                         //!< 変調方式

    UserSettingChannelInformation() : Channel(), Validation(0), Modulation() {}
};

/**
 * @brief シングル測定ユーザ設定データ
 */
struct SingleMeasureUserSetting {
    QString Band;                                   //!< BAND 種別
    QList<UserSettingChannelInformation> Channels;  //!< チャンネルデータ

    SingleMeasureUserSetting() : Band(), Channels() {}
};

/**
 * @brief データロガー設定データ
 */
struct DataloggerSetting {
    int BandId;
    int Spec;
    QString ChannelName;
    unsigned int CenterFrequency;
    unsigned int Modulation;
    unsigned int LocalFrequency;
    bool MerCn;
    bool Ber;
    int PowerSupply;        //!< 給電しない...0 11V ... 1 15V...2

    DataloggerSetting() : ChannelName() {}
};

/**
 * @brief マルチチャンネル測定の棒グラフ用のデータ
 */
struct BarGraphData {
    float32_t Level;            //!< 測定入力レベル
    int32_t ColorIndex;         //!< 棒グラフの色のインデックス(閾値以上の判断を QML 外で行うため色の値を持つようにする)
    bool Selection;             //!< 優先測定で本チャンネルを選択中か否か
    bool CurrentMeasuring;      //!< 本チャンネルが現在測定中か否か

    BarGraphData() : Level(0.0f), ColorIndex(0), Selection(false), CurrentMeasuring(false) {}
};

/**
 * @brief USER データロガー設定の Band 一覧のデータ
 */
struct BandTab {
    QString Name;
    int32_t Index;
    uint32_t RecordCount;
    bool Selection;
    bool AllUnselected;

    BandTab() : Name(""), Index(-1), RecordCount(0), Selection(false), AllUnselected(true) {}
    BandTab(QString name, int32_t index, uint32_t recordCount, bool selection, bool allUnselected) :
        Name(name), Index(index), RecordCount(recordCount), Selection(selection), AllUnselected(allUnselected) {}
};

/**
 * @brief Level 測定範囲
 * @note Level のみ
 */
struct MeasureLevelRange {
    BandTabIndex Band;              //!< Band の種類
    float32_t MinimumLevel;         //!< Level 最小値
    float32_t MaximumLevel;         //!< Level 最大値
};

/**
 * @brief USER データロガー設定ファイルの内訳
 */
struct UserDataLoggerSettingFile {
    BandTabIndex band;              //!< BAND の識別
    QString channel;                //!< チャンネル名
    uint32_t frequency;             //!< 実周波数(中心周波数 - 局発周波数)
    uint8_t broadcastsystem;        //!< 放送方式
    uint32_t localFrequency;        //!< 局発周波数
    uint8_t powerSupply;            //!< 給電 ON/OFF
    uint8_t measure;                //!< 測定する/しない
};

/**
 * @brief 実行コマンド
 */
static const QString SYNC_COMMAND = QString("sync");
static const QString USB_POWER_ON_SCRIPT = QString("./usb_power_on.sh");
static const QString USB_POWER_OFF_SCRIPT = QString("./usb_power_off.sh");

/**
 * @brief USBマウント先のパス
 */
static const QString USB_PATH = "/media/sda1/";

/**
 * @brief ユーザー測定設定の保存先のパス
 */
static const QString USER_MEASUREMNET_SETTING_USB_PATH = "/media/sda1/LC70WCS/SETTING/";

/**
 * @brief zip ファイルの拡張子
 */
static const QString ZIP_EXTENSION = QString(".zip");

#endif  // CONSTANT_H
