/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef POPUPID_H
#define POPUPID_H

/**
 * @brief ポップアップID
 */
enum PopupId {
    POPUP_SCAN_CONFIRMATION = 0,                                //!< SCAN 実行確認
    POPUP_SCANNING,                                             //!< SCAN実行中
    POPUP_SCAN_CANCEL,                                          //!< SCAN実行キャンセル
    POPUP_SAVE_USER_SETTING_DATA,                               //!< ユーザ設定データ保存
    POPUP_SAVE_CONFIRMATION,                                    //!< 保存確認
    POPUP_SELECT_SAVE_CONFIRMATION,                             //!< 保存確認(保存先選択)
    POPUP_CANCEL_CONFIRMATION,                                  //!< 変更破棄確認
    POPUP_SELECT_SAVE_DATA,                                     //!< 保存データ選択
    POPUP_SAVE_MEASUREMENT_DATA,                                //!< 測定データ保存
    POPUP_INITIALIZE_CONFIRMATION,                              //!< 初期化処理確認
    POPUP_WRONG_INPUT_DATA,                                     //!< 入力データ誤り
    POPUP_DATA_LOGGER_KEYBOARD,                                 //!< キーボード表示
    POPUP_DATA_LOGGER_DELETE_CONFIRMATION,                      //!< 削除操作確認
    POPUP_DATA_LOGGER_DELETE_FILELIST_CONFIRMATION,             //!< ファイルリスト削除操作確認
    POPUP_DELETE_ALL_MEASUREMENT_CONFIRMATION,                  //!< 測定データ一括削除確認
    POPUP_DELETE_ALL_DATA_LOGGER_CONFIRMATION,                  //!< データロガー情報一括削除確認
    POPUP_COPY_ALL_TO_USB_USER_SETTING_DATA_CONFIRMATION,       //!< ユーザ設定データ書き込み確認(本体->USB)
    POPUP_COPY_ALL_TO_BODY_USER_SETTING_DATA_CONFIRMATION,      //!< ユーザ設定データ書き込み確認(USB->本体)
    POPUP_COPY_ALL_TO_BODY_SELECT_USER_SETTING_DATA_CONFIRMATION,   //!< ユーザ設定データ書き込み場所選択(取り込みデータ1 or 取り込みデータ2)
    POPUP_DELETE_ALL_USER_SETTING_DATA_CONFIRMATION,            //!< ユーザ設定データ書き込み一括削除確認
    POPUP_USB_FORMAT_CONFIRMATION,                              //!< USBフォーマット実行確認
    POPUP_INPUT_FILENAME,                                       //!< ファイル名入力用キーボード表示
    POPUP_USB_FORMAT_RUNNING,                                   //!< USBフォーマット実行中
    POPUP_FAILURE_COPY_EXECUTE,                                 //!< コピー失敗
    POPUP_NOTHING_COPY_FILE,                                    //!< コピー元ファイル無し
    POPUP_FAILURE_DELETE_EXECUTE,                               //!< 削除失敗
    POPUP_FAILURE_FORMAT_EXECUTE,                               //!< USBフォーマット失敗
    POPUP_USB_NO_SPACE,                                         //!< USB容量なし
    POPUP_POWER_SUPPLY_SELECT3,                                 //!< 給電選択(JCSAT, SCC)
    POPUP_POWER_SUPPLY_SELECT2,                                 //!< 給電選択(その他)
    POPUP_MEASUREMENT_CANCEL,                                   //!< 測定キャンセル
    POPUP_WRONG_LOCAL_OSCILLATOION_DATA,                        //!< 局部発振周波数データ誤り
    POPUP_FAILURE_NO_USB_CONFIRMATION,                          //!< USB接続依頼ダイアログ
    POPUP_CONFIRM_UPDATE,                                       //!< アップデート確認
    POPUP_UPDATING,                                             //!< アップデート中
    POPUP_CONFLICT_POWER_SUPPLY_SETTING,                        //!< 給電設定競合
    POPUP_POWER_SUPPLY_ERROR_MANUAL_MEASURING,                  //!< 給電異常(マニュアル測定中)
    POPUP_POWER_SUPPLY_ERROR_USER_MEASURING,                    //!< 給電異常(USER測定中)
    POPUP_SCAN_RESULT,                                          //!< スキャン結果
    POPUP_CONFIRM_DELETE_SELECTED_FILE,                         //!< 選択ファイル削除確認ダイアログ
    POPUP_CONFIRM_DELETE,                                       //!< 削除中ダイアログ
    POPUP_CONFIRM_COPY_SELECTED_FILE,                           //!< 選択ファイルコピー確認ダイアログ
    POPUP_CONFIRM_COPY,                                         //!< コピー中ダイアログ
    POPUP_CONFIRM_ALL_DELETE_FILE,                              //!< 選択データ場所のファイル一括削除
    POPUP_CONFIRM_OVERWRITE_USER_LOGGER_DATA,                   //!< ユーザデータロガー上書き確認ダイアログ
    POPUP_CONFIRM_REGIST_SCAN_RESULT,                           //!< スキャン結果保存確認ダイアログ
    POPUP_DATA_LOGGER_USB_REMOVE_ERROR,                         //!< データロガー測定中にUSBが抜かれたことを示すダイアログ
    POPUP_FAILURE_SETTING_RANGE_WRONG,                          //!< 設定範囲が異なることを示すダイアログ
    POPUP_CONFIRM_EXECUTE_WITH_AUTO_POWER_OFF,                  //!< オートパワーオフありでデータロガーを実行するか確認
    POPUP_CONFIRM_ACQUIRE_MEASURE_DATA,                         //!< 測定データ取得確認(マニュアル マルチ測定)
    POPUP_MEASURING,                                            //!< 測定データ取得中
    POPUP_MEASURE_CANCEL,                                       //!< 測定データ取得キャンセル
    POPUP_SCAN_NOT_APPLICABLE,                                  //!< スキャン対象外
    POPUP_FAILURE_DATE_SETTING,                                 //!< 時刻設定失敗
    POPUP_MEASURE_COMPLETE,                                     //!< 測定データ取得完了
    POPUP_CONFIRM_CHANGE_BAND,                                  //!< Band 変更確認
    POPUP_WRITE_ERROR,                                          //!< ファイル出力失敗
    POPUP_USER_SETTING_EXCEED_UPPER_LIMIT,                      //!< ユーザ設定のチャンネル数の上限超過
    POPUP_DATA_LOGGER_SETTING_EXCEED_UPPER_LIMIT,               //!< データロガー設定のチャンネル数の上限超過
    POPUP_SAME_FREQUENCY_CHANNEL,                               //!< 同一周波数のチャンネル検知
    POPUP_UNEXPECTED_ERROR,                                     //!< 予期しないエラー通知(静電試験で qml を指すポインターが nullptr に鳴った場合など。個々の画面でこの POPUP_ID を受け取らないこと)
    POPUP_MEASURE_CATV_UPSTREAM_NOT_APPLICABLE,                 //!< 光入力設定のとき CATV 上りは測定不可
    POPUP_DISABLE_POWER_SUPPLY,                                 //!< バッテリーレベルが 10% 以下で給電不可
    POPUP_DATA_LOGGER_MESUREMENT_COMLETE,                       //!< データロガー取得完了
    POPUP_DATA_LOGGER_MAX_SAVE_FILE,                            //!< データロガー測定データ保存上限
    POPUP_FAILURE_READ_USER_SETTING_FILE,                       //!< ユーザ設定ファイル読み込みエラー
    POPUP_DATA_SINGLE_MAX_SAVE_FILE,                            //!< シングル測定データ保存上限
    POPUP_DATA_MULTI_MAX_SAVE_FILE,                             //!< マルチ測定データ保存上限
    POPUP_ID_COUNT
};

/**
 * @brief 保存先
 */
enum SaveLocation {
    SAVE_MEASUREMENT_DATA = 0,      //! 測定データ
    SAVE_USER_SETTING,              //! ユーザー設定1(不使用）
};

#endif // POPUPID_H
