/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SCREENID_H
#define SCREENID_H

/**
 * @brief 画面ID
 */
enum ScreenId {
    SCREEN_MAINFRAME = 0,                           //!< 全画面表示枠
    SCREEN_HOME,                                    //!< HOME
    SCREEN_BAND,                                    //!< シングル／マルチ測定
    SCREEN_LOCAL_OSCILLATOR_SETTING,                //!< 局部発振周波数選択
    SCREEN_MODULATION,                              //!< 変調方式選択
    SCREEN_SCAN_SELECTION,                          //!< SCAN選択
    SCREEN_USER_DATA_LOGGER_MENU,                   //!< ユーザ／データロガーメニュー
    SCREEN_USER,                                    //!< ユーザ（SINGLE/MULTI）
    SCREEN_USER_SETTING_SELECTION,                  //!< ユーザ設定呼び出し（SINGLE/MULTI）
    SCREEN_USER_SETTING,                            //!< ユーザ設定
    SCREEN_MANUAL_AUTO_SELECTION,                   //!< 手動／自動選択
    SCREEN_MANUAL_SETTING,                          //!< 手動設定
    SCREEN_AUTO_SETTING,                            //!< 自動設定
    SCREEN_SCAN_RESULT,                             //!< SCAN結果
    SCREEN_FILE_SELECTION,                          //!< 登録ファイル選択
    SCREEN_SINGLE_MEASUREMENT,                      //!< シングルチャンネル測定
    SCREEN_CONSTELLATION,                           //!< コンスタレーション(不使用)
    SCREEN_DELAY_PROFILE,                           //!< 遅延プロファイル(不使用)
    SCREEN_MULTI_MEASUREMENT,                       //!< マルチチャンネル測定
    SCREEN_MEASUREMENT_LIST,                        //!< マルチチャンネル測定リスト(不使用)
    SCREEN_SPECTRUM_ANALYZER_MENU,                  //!< スペアナメニュー
    SCREEN_FIXED_SPAN,                              //!< 固定SPAN
    SCREEN_CHANNEL_SELECTION,                       //!< CH指定
    SCREEN_FIXED_SPAN_SPECTRUM_ANALYZER,            //!< スペアナ（固定SPAN）
    SCREEN_CHANNEL_SELECTION_SPECTRUM_ANALYZER,     //!< スペアナ（CH指定）
    SCREEN_DC_MEASUREMENT,                          //!< DC測定
    SCREEN_WAVELENGTH_SELECT,                       //!< 波長選択
    SCREEN_OPTICAL_MEASUREMENT,                     //!< 光測定
    SCREEN_SYSTEM_SETTING_MENU,                     //!< システム設定メニュー
    SCREEN_AUTO_POWER_OFF_SETTING,                  //!< オートパワーオフ設定
    SCREEN_DATE_TIME_SETTING,                       //!< 日時設定
    SCREEN_VOLUME_SETTING,                          //!< 音量設定
    SCREEN_INITIALIZATION,                          //!< 初期化（工場出荷状態）
    SCREEN_MEASUREMENT_SETTING_MENU,                //!< 測定設定メニュー
    SCREEN_CABLE_OFFSET,                            //!< ケーブルオフセット
    SCREEN_LOCAL_OSCILLATOR,                        //!< 局部発振周波数
    SCREEN_THRESHOLD,                               //!< 閾値（BAND選択）
    SCREEN_THRESHOLD_SETTING,                       //!< 閾値設定
    SCREEN_SWITCH_MER_CN,                           //!< MER/CN切り替え
    SCREEN_CATV_CHANNEL_FREQUENCY,                  //!< CATVチャンネル周波数
    SCREEN_CONSTELLATION_SETTING,                   //!< コンスタレーション表示設定
    SCREEN_SWITCH_OPTICAL_COAXIAL_CABLE,            //!< 光同軸切替え設定
    SCREEN_DATA_LOGGER,                             //!< データロガー
    SCREEN_LOGGING_SETTING,                         //!< 取得設定
    SCREEN_START_SELECTION,                         //!< 取得開始
    SCREEN_DATALOGGER_MEASUREMENT_LIST,             //!< データロガー測定リスト
    SCREEN_DATA_MANAGEMENT_MENU,                    //!< データ管理メニュー
    SCREEN_MEASUREMENT_DATA_MENU,                   //!< 測定データメニュー
    SCREEN_MEDIA_SELECTION,                         //!< メディア選択
    SCREEN_SAVED_DATA_LIST,                         //!< 保存データの呼び出し
    SCREEN_ALL_DELETION,                            //!< 保存データの全消去
    SCREEN_ALL_COPY,                                //!< 保存データの全コピー
    SCREEN_DATA_LOGGER_MENU,                        //!< データロガー取得データメニュー
    SCREEN_POPUP_FRAME,                             //!< ポップアップ表示枠
    SCREEN_POLARIZATION,                            //!< 偏波面選択
    SCREEN_MENULIST,                                //!< メニューリスト
    SCREEN_BRIGHTNESS_SETTING,                      //!< 明るさ設定
    SCREEN_BROADCAST_SETTING,                       //!< 放送方式選択
    SCREEN_USER_MEASUREMENT_SETTING_MENU,           //!< ユーザ測定設定メニュー
    SCREEN_MEASUREMENT_RESURT_DATA_LIST,            //!< 測定結果一覧表示
    SCREEN_DATA_LOGGER_LIST,                        //!< データロガー取得データ一覧表示
    SCREEN_MEASUREMENT_RESURT_DATA_PNG,             //!< 測定結果データ表示(PNG)
    SCREEN_MEASUREMENT_RESURT_DATA_CSV,             //!< 測定結果データ表示(CSV)
    SCREEN_DATA_LOGGER_DETAILS_DATA,                //!< データロガー取得データ表示(詳細)
    SCREEN_ANTENNA_ADJUSTMENT,                      //!< アンテナ調整
    SCREEN_CATV_MENU,                               //!< CATV メニュー
    SCREEN_MODEL_INFORMATION,                       //!< バージョン情報
    SCREEN_MEASUREMENT_RESULT_DATA_COPY,            //!< 測定データコピー
    SCREEN_MEASUREMENT_RESULT_DATA_DELETION,        //!< 測定データ削除
    SCREEN_MEASUREMENT_RESULT_DATA_COPY_DELETION,   //!< 測定データコピー削除
    SCREEN_COMPASS,                                 //!< コンパス
#ifdef NEW_USER_SETTING
    SCREEN_USER_DATALOGGER_SETTING,                 //!< USER データロガー設定
    SCREEN_USER_MEASUREMENT_SELECTION,              //!< 測定メニュー選択
    SCREEN_DATALOGGER_SETTING,                      //!< データロガー設定
#endif
    SCREEN_OTHER,                                   //!< その他メニュー
    SCREEN_BATTERY_INFO,                            //!< バッテリー情報
    SCREEN_MANUAL,                                  //!< 取扱説明書
    SCREEN_ID_COUNT
};

#endif // SCREENID_H
