/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef USBDEFS_H
#define USBDEFS_H

#include <QString>
#include "constant.h"
/**
 * @brief The USB内で取り扱うデータタイプ
 */
enum UsbDataType {
    MEASUREMENT_RESULT_SINGLE = 0,    //!< 測定結果データ(SINGLE)
    MEASUREMENT_RESULT_MULTI,         //!< 測定結果データ(MULTI)
    DATA_LOGGER_RESULT,               //!< データロガーデータ取得結果
    USER_MEASUREMENT_SETTING,         //!< ユーザ測定設定
    DATALOGGER_MEASUREMENT_SETTING,   //!< データロガー設定
};

/**
 * @brief The エラータイプ
 */
enum UsbErrorType {
    NON_ERROR = 0,          //!< エラーなし
    COPY_EXEC_ERROR,        //!< コピー実施中エラー
    COPY_FILE_ERROR,        //!< コピー元ファイル無しエラー
    FORMAT_ERROR,           //!< フォーマットエラー
    DELETE_ERROR,           //!< 削除エラー
    SPACE_ERROR,            //!< 容量なしエラー
};


// 結果ファイル保存先パス(USB)
static const QString RESULT_DATA_PATH = USB_PATH + "LC70WCS/DATA";
// 設定ファイル保存先パス(USB)
static const QString SETTING_DATA_PATH = USB_PATH + "LC70WCS/SETTING";
// ユーザ測定設定ファイル保存先パス(USB)
static const QString USER_MEASUREMENT_PATH = SETTING_DATA_PATH + "/user_set";
// データロガー設定ファイル保存先パス(USB)
static const QString DATALOGGER_MEASUREMENT_PATH = SETTING_DATA_PATH + "/logger_set";
// 作業用パス
static const QString TMP_PATH = "/tmp";
// mountコマンド
static const QString USB_MOUNT_COMMAND = "/bin/mount /dev/sda1 " + USB_PATH;
// umountコマンド
static const QString USB_UMOUNT_COMMAND = "/bin/umount -l " + USB_PATH;
// mkdosfsコマンド
static const QString USB_FORMAT_COMMAND = "/usr/sbin/mkdosfs -F32 -nUSBMEMORY /dev/sda1";
// rmコマンド
static const QString DELETE_DIR_COMMAND = "rm -r ";
// cpコマンド
static const QString COPY_DIR_COMMAND = "cp -rf ";
// mkdirコマンド
static const QString CREATE_DIR_COMMAND = "mkdir -p ";
// zipコマンド
static const QString CREATE_ZIP_COMMAND = "zip -r -e --password=";
// unzipコマンド
static const QString EXTRACT_ZIP_COMMAND = "unzip -P ";
// mv コマンド
static const QString MV_FILE_COMMAND = "mv -f ";
// USB空き容量の閾値
static const qint64 THRESHOLD_USB_FREE_SPACE = 10000; // TBD


#endif // USBDEFS_H
