/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef VALUEID_H
#define VALUEID_H


/**
 * @brief The ValueId enum
 * 設定値等の情報の識別ID
 * ModelOperator を使用する場合に指定を行う
 *
 * @see ModelOperator
 */
enum ValueId {
    INVALID_VALUE_ID = (-1),
    VALUE_DATETIME,                     // 1
    VALUE_AUTOPOWEROFF,                 // 2
    VALUE_SOUNDVOLUME,                  // 3
    VALUE_MER_CN,                       // 4
    VALUE_CATVCHANNEL_FREQ,             // 5
    VALUE_RF_OPTICAL,                   // 6   同軸・光選択
    VALUE_OPTION_OPTICAL,               // 7   光測定オプション有無
    VALUE_THRESHOLD,                    // 8   閾値
    VALUE_CONSTELLATION,                // 9   コンスタレーション表示ポイント
    VALUE_LEVEL_OFFSET,                 // 10  ケーブル損失
    VALUE_BRIGHTNESS,                   // 11  明るさ設定
    VALUE_USERSETTING_FILELIST,         // 12  USER 設定ファイルリスト、
    VALUE_USERSETTING_SETTINGLIST,      // 13  USER 設定チャンネルリスト
    VALUE_LOCAL_FREQUENCY,              // 14  局部発振周波数
    VALUE_LEVEL_OFFSET_ENABLE,          // 15  ケーブル損失有効
    VALUE_BROADBANDSYSTEM_MODULATION,   // 16  マニュアル測定 放送方式、変調方式選択
    VALUE_MERCNR_LIMITS,                // 17  MERの上限 下限値
    VALUE_DATALOGGERSETTING_FILELIST,   // 18  データロガー設定ファイルリスト、
    VALUE_DATALOGGERSETTING_SETTINGLIST,// 19  データロガー設定チャンネルリスト
    VALUE_USERSETTING_FILELIST_USB1,    // 20  USER 設定ファイルリストUSB1、
    VALUE_USERSETTING_SETTINGLIST_USB1, // 21  USER 設定チャンネルリストUSB1
    VALUE_USERSETTING_FILELIST_USB2,    // 22  USER 設定ファイルリストUSB2、
    VALUE_USERSETTING_SETTINGLIST_USB2, // 23  USER 設定チャンネルリストUSB2
    VALUE_DATALOGGERSETTING_FILELIST_USB1,   // 24  データロガー設定ファイルリストUSB1、
    VALUE_DATALOGGERSETTING_SETTINGLIST_USB1,// 25  データロガー設定チャンネルリストUSB1
    VALUE_DATALOGGERSETTING_FILELIST_USB2,   // 26  データロガー設定ファイルリストUSB2、
    VALUE_DATALOGGERSETTING_SETTINGLIST_USB2 // 27  データロガー設定チャンネルリストUSB2
};

constexpr int THRESHOLD_ITEM_COUNT = 9; //!< 閾値の要素数
constexpr int LEVEL_OFFSET_ITEM_COUNT = 4; //!< ケーブルオフセット画面の設定値の数

#endif // VALUEID_H
