/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "bandmodel.h"

BandModel::BandModel(QObject *parent) : QAbstractTableModel(parent)
{
    _table.append({
                      { "地デジ", BAND_TAB_UHF, 0, false, true },
                      { "BS 右旋", BAND_TAB_BS_R, 0, false, true },
                      { "BS 左旋", BAND_TAB_BS_L, 0, false, true },
                      { "CS 右旋", BAND_TAB_CS_R, 0, false, true },
                      { "CS 左旋", BAND_TAB_CS_L, 0, false, true },
                      { "CATV\n  ALL", BAND_TAB_CATV_ALL, 0, false, true },
                      { " スカパー！\n　　 光", BAND_TAB_SKY_PERFECTV, 0, false, true },
                      { "CATV\n  上り", BAND_TAB_CATV_UPSTREAM, 0, false, true },
                      { " JCSAT\n3A 水平", BAND_TAB_JCSAT3A_H, 0, false, true },
                      { " JCSAT\n3A 垂直", BAND_TAB_JCSAT3A_V, 0, false, true },
                  });
    _table.append({
                      { " JCSAT\n4B 水平", BAND_TAB_JCSAT4B_H, 0, false, true },
                      { " JCSAT\n4B 垂直", BAND_TAB_JCSAT4B_V, 0, false, true },
                      { "SCC-B\n  水平", BAND_TAB_SCCB2_H, 0, false, true },
                      { "SCC-B\n  垂直", BAND_TAB_SCCB2_V, 0, false, true },
                      { "SCC-C\n  水平", BAND_TAB_SCCC2_H, 0, false, true },
                      { "SCC-C\n  垂直", BAND_TAB_SCCC2_V, 0, false, true },
                      { "LTE", BAND_TAB_LTE, 0, false, true },
                      { "FM", BAND_TAB_FM, 0, false, true },
                      { "PILOT", BAND_TAB_PILOT, 0, false, true },
                      { "", -1, 0, false, true },   // ダミー

                  });
}


BandModel::~BandModel()
{

}

int BandModel::rowCount(const QModelIndex &) const
{
    return _table.size();
}

int BandModel::columnCount(const QModelIndex &) const
{
    if (_table.size() > 0) {
        return _table.at(0).size();
    } else {
        return 0;
    }
}

QVariant BandModel::data(const QModelIndex &index, int role) const
{
    switch (role) {
    case BandNameRole:
    {
        return _table.at(index.row()).at(index.column()).Name;
    }
        break;
    case BandIndexRole:
    {
        return _table.at(index.row()).at(index.column()).Index;
    }
        break;
    case BandRecordCountRole:
    {
        return _table.at(index.row()).at(index.column()).RecordCount;
    }
        break;
    case BandSelectionRole:
    {
        return _table.at(index.row()).at(index.column()).Selection;
    }
        break;
    case BandAllUnselectedRole:
    {
        return _table.at(index.row()).at(index.column()).AllUnselected;
    }
        break;
    default:
        break;
    }

    return QVariant();
}

QHash<int, QByteArray> BandModel::roleNames() const
{
    QHash<int, QByteArray> roles;
    roles[BandNameRole] = "bandName";
    roles[BandIndexRole] = "bandIndex";
    roles[BandRecordCountRole] = "recordCount";
    roles[BandSelectionRole] = "selection";
    roles[BandAllUnselectedRole] = "allUnselected";
    return roles;
}

void BandModel::initialize()
{
    for (int i = 0; i < _table.size(); ++i) {
        for (int j = 0; j < _table[i].size(); ++j) {
            _table[i][j].RecordCount = 0;
            _table[i][j].Selection = false;
            _table[i][j].AllUnselected = true;
        }
    }

    emit dataChanged(index(0, 0), index(_table.size() - 1, _table[0].size() - 1), { BandRecordCountRole, BandSelectionRole, BandAllUnselectedRole });
}

void BandModel::select(BandTabIndex)
{
    for (int i = 0; i < _table.size(); ++i) {
        for (int j = 0; j < _table[i].size(); ++j) {
            if (_table[i][j].Selection == true) {
                _table[i][j].Selection = false;
                emit dataChanged(index(i, j), index(i, j), { BandSelectionRole });
                break;
            }
        }
    }
}

void BandModel::update(BandTabIndex bandIndex, uint32_t recordCount, bool selection)
{
    for (int i = 0; i < _table.size(); ++i) {
        for (int j = 0; j < _table[i].size(); ++j) {
            if (_table[i][j].Index == bandIndex) {
                _table[i][j].RecordCount = recordCount;
                _table[i][j].Selection = selection;

                emit dataChanged(index(i, j), index(i, j), { BandRecordCountRole, BandSelectionRole });
                break;
            }
        }
    }
}

void BandModel::unselectAll(bool select)
{
    for (int i = 0; i < _table.size(); ++i) {
        for (int j = 0; j < _table[i].size(); ++j) {
            _table[i][j].AllUnselected = select;
        }
    }

    emit dataChanged(index(0, 0), index(_table.size() - 1, _table[0].size() - 1), { BandAllUnselectedRole });
}
