/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef BANDMODEL_H
#define BANDMODEL_H

#include <QAbstractTableModel>
#include "constant.h"

class BandModel : public QAbstractTableModel
{
    Q_OBJECT
    enum BandRoles {
        BandNameRole = Qt::UserRole + 30,
        BandIndexRole,
        BandRecordCountRole,
        BandSelectionRole,
        BandAllUnselectedRole
    };

public:
    /**
     * @brief コンストラクター
     * @param parent 親オブジェクト
     */
    explicit BandModel(QObject *parent = nullptr);

    /**
     *  @brief デストラクター
     */
    ~BandModel();

    /**
     * @brief 行数を返す
     * @return 行数
     * @note 2 行固定
     */
    int rowCount(const QModelIndex & = QModelIndex()) const override;

    /**
     * @brief 列数を返す
     * @return 列数
     * @note 12 列固定
     */
    int columnCount(const QModelIndex & = QModelIndex()) const override;

    /**
     * @brief Band タブのデータを返す
     * @param index データの位置
     * @param role ロール
     * @return Band タブのデータ
     */
    QVariant data(const QModelIndex &index, int role) const override;

    /**
     * @brief ロール名を返す
     * @return ロール名
     */
    QHash<int, QByteArray> roleNames() const override;

    /**
     * @brief Band の状態を初期化
     */
    void initialize(void);

    /**
     * @brief Band タブの選択
     * @param index 選択する Band のインデックス
     */
    void select(BandTabIndex bandIndex);

    /**
     * @brief タブの更新
     * @param index 選択する Band のインデックス
     * @param recordCount Band から選択されたチャンネル数
     * @param selection 選択中か否か
     */
    void update(BandTabIndex bandIndex, uint32_t recordCount = 0, bool selection = false);

    /**
     * @brief 全未選択状態を設定
     * @param select true: 全未選択状態 false: 全未選択状態ではない
     * @note 設定ファイルにデータがない場合はどの Band も未選択とする
     */
    void unselectAll(bool select);

private:
    QVector<QVector<BandTab>> _table;
};

#endif // BANDMODEL_H
