/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef CHANNELDEFINITIONITEM_H
#define CHANNELDEFINITIONITEM_H

#include <QString>

/**
 * @brief チャンネル情報を格納する構造体
 *
 */
struct ChannelDefinitionItem {
    /**
     * @brief band
     * LC70_BAND_T の情報を格納する
     */
    int band;

    /**
     * @brief channelNumber
     * チャンネル番号
     */
    QString channelNumber;

    /**
     * @brief polarization
     * 偏波種別
     *
     * 偏波種別なしの場合には(-1)
     */
    int polarization;

    /**
     * @brief centerFrequency1
     * 中心周波数１
     * 数値は KHz で表現
     */
    int centerFrequency1;

    /**
     * @brief centerFrequency2
     * 中心周波数２
     * 数値は KHz で表現
     *
     * 複数の変調方式を持つ場合に設定
     * 設定なしの場合は（-1)
     */
    int centerFrequency2;

    /**
     * @brief bandWidth
     * 帯域幅
     * 数値は KHz で表現
     *
     * 設定なしの場合は（-1)
     */
    int bandWidth;

    /**
     * @brief 有効
     * @note スキャン結果の有効/無効
     */
    bool valid;

    ChannelDefinitionItem() : band(-1), channelNumber(), polarization(-1), centerFrequency1(-1), centerFrequency2(-1),
        bandWidth(-1), valid(true) {}

    ChannelDefinitionItem(int band, QString channelNumber, int polarization, int centerFrequency1, int centerFrequency2,
                          int bandWidth) : band(band), channelNumber(channelNumber), polarization(polarization),
        centerFrequency1(centerFrequency1), centerFrequency2(centerFrequency2), bandWidth(bandWidth), valid(true) {}

    bool operator<(const ChannelDefinitionItem& otherChannelDefinition) const
    {
        QString one = QString::number(band) + channelNumber;
        QString other = QString::number(otherChannelDefinition.band) + otherChannelDefinition.channelNumber;
        return one < other;
    }
};

#endif // CHANNELDEFINITIONITEM_H
