/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "delayprofilelineseriesmodel.h"

DelayProfileLineSeriesModel::DelayProfileLineSeriesModel(QObject *parent)
    : QObject(parent)
    , _lineSeries()
    , _xySeries(nullptr)
{
    qRegisterMetaType<QAbstractSeries *>();
    qRegisterMetaType<QAbstractAxis *>();

    double x = MINIMUM_DELAY_PROFILE_TIME + DELAY_PROFILE_INTERVAL;

    for (int i = 0; i < DELAY_PROFILE_DATA_COUNT; ++i) {
        _lineSeries.append(QPointF(x, DELAY_PROFILE_INITIAL_DECIBEL));
        x += DELAY_PROFILE_INTERVAL;
    }
}

DelayProfileLineSeriesModel::~DelayProfileLineSeriesModel()
{

}

void DelayProfileLineSeriesModel::setLineSeries(const QVector<QPointF> &lineSeries)
{
    for (int i = 0; i < lineSeries.count(); ++i) {
        _lineSeries[i] = lineSeries[i];
    }

    if (_xySeries) {
        _xySeries->replace(_lineSeries);
    }
}

int DelayProfileLineSeriesModel::count() const
{
    return _lineSeries.count();
}

QPointF DelayProfileLineSeriesModel::lineSeries(int index) const
{
    if (index < 0 || index >= _lineSeries.count()) {
        return QPointF();
    }

    return _lineSeries[index];
}

void DelayProfileLineSeriesModel::update(QAbstractSeries *series)
{
    if (series) {
        _xySeries = static_cast<QXYSeries *>(series);

        _xySeries->replace(_lineSeries);
    }
}
