/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef DELAYPROFILELINESERIESD_H
#define DELAYPROFILELINESERIESD_H

#include <QObject>
#include <QVector>
#include <QPointF>
#include <QtCharts/QXYSeries>
#include "constant.h"

QT_CHARTS_USE_NAMESPACE

class DelayProfileLineSeriesModel : public QObject
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクター
     * @param parent 親オブジェクト
     */
    explicit DelayProfileLineSeriesModel(QObject *parent = nullptr);

    /**
     * @brief デストラクター
     */
    ~DelayProfileLineSeriesModel();

    /**
     * @brief 時間軸に対応するデータを設定
     * @param lineSeries 時間軸に対応するデータ
     */
    void setLineSeries(const QVector<QPointF> &lineSeries);

    /**
     * @brief 配列の要素数を返す
     * @return 配列の要素数
     */
    int count(void) const;

    /**
     * @brief 指定したインデックスの時間軸の座標を返す
     * @param index 配列のインデックス
     * @return 指定したインデックスの時間軸の座標
     */
    QPointF lineSeries(int index) const;

public slots:
    /**
     * @brief 折れ線グラフの更新
     * @param series 時間軸に対応するデータ
     */
    Q_INVOKABLE void update(QAbstractSeries *series);

private:
    QVector<QPointF> _lineSeries;       //!< 時間軸に対応するデータ
    QXYSeries *_xySeries;               //!< ChartView の折れ線
};

#endif // DELAYPROFILELINESERIESD_H
