/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef DISPLAYFILESYSTEMMODEL_H
#define DISPLAYFILESYSTEMMODEL_H

#include <QFileSystemModel>

enum DisplayFileSystemRoles  {
    SizeRole = Qt::UserRole + 100,
    UrlStringRole = Qt::UserRole
};

/**
 * @brief 測定データ管理でのファイルのツリー表示用
 */
class DisplayFileSystemModel : public QFileSystemModel
{
    Q_OBJECT
    Q_ENUM(DisplayFileSystemRoles)
public:
    /**
     * @brief コンストラクター
     * @param parent 親オブジェクト
     */
    explicit DisplayFileSystemModel(QObject *parent = nullptr);

    /**
     * @brief デストラクター
     */
    ~DisplayFileSystemModel();

    /**
     * @brief ロール名を返す
     * @return ロール名
     */
    QHash<int, QByteArray> roleNames() const override;

    /**
     * @brief ファイルの情報を返す
     * @param index データの位置
     * @param role ロール
     * @return ファイルの情報
     */
    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
};

#endif // DISPLAYFILESYSTEMMODEL_H
