/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "channeldefinitionhelper.h"
#include <QDebug>
extern "C" {
#include "liblc70.h"
}

// コンストラクタ
ChannelDefinitionItemHelper::ChannelDefinitionItemHelper(QObject *parent)
    : QObject(parent)
{
}

// ラッパークラスから取得した値を本プログラムで使うChannelDefinitionItemデータ型変換する
QList<ChannelDefinitionItem> ChannelDefinitionItemHelper::convertChannelDefinitionItem(void *data, int fileId)
{
    QList<ChannelDefinitionItem> channelDefinitionList;

    if (data == nullptr) {
        return channelDefinitionList;
    }

    switch (fileId) {
    case LC70_FILE_ID_CH_SET_UHF: {     // 地デジ
        LC70_CH_SET_UHF_T *uhf = static_cast<LC70_CH_SET_UHF_T *>(data);

        for (int i = 0; i < LC70_CH_SET_UHF_IDX_MAX; ++i) {
            ChannelDefinitionItem item(LC70_BAND_UHF,                       // BAND
                                       QString(uhf->chSetRow[i].cStrChNo),  // チャンネル番号
                                       -1,                                  // 偏波種別
                                       uhf->chSetRow[i].ulCentFreq,         // 中心周波数 1
                                       -1,                                  // 中心周波数 2
                                       -1                                   // 帯域幅
                                      );

            channelDefinitionList.append(item);
        }

        break;
    }

    case LC70_FILE_ID_CH_SET_BS: {      // BS
        LC70_CH_SET_BS_T *bs = static_cast<LC70_CH_SET_BS_T *>(data);

        for (int i = 0; i < LC70_CH_SET_BS_IDX_MAX; ++i) {

            ChannelDefinitionItem item(LC70_BAND_BS,                        // BAND
                                       QString(bs->chSetRow[i].cStrChNo),   // チャンネル番号
                                       bs->chSetRow[i].ucWave,              // 偏波種別
                                       bs->chSetRow[i].ulCentFreq,          // 中心周波数 1
                                       -1,                                  // 中心周波数 2
                                       -1                                   // 帯域幅
                                      );

            channelDefinitionList.append(item);
        }

        break;
    }

    case LC70_FILE_ID_CH_SET_CS: {      // CS
        LC70_CH_SET_CS_T *cs = static_cast<LC70_CH_SET_CS_T *>(data);

        for (int i = 0; i < LC70_CH_SET_CS_IDX_MAX; ++i) {

            ChannelDefinitionItem item(LC70_BAND_CS,                        // BAND
                                       QString(cs->chSetRow[i].cStrChNo),   // チャンネル番号
                                       cs->chSetRow[i].ucWave,              // 偏波種別
                                       cs->chSetRow[i].ulCentFreq,          // 中心周波数 1
                                       -1,                                  // 中心周波数 2
                                       -1                                   // 帯域幅
                                      );

            channelDefinitionList.append(item);
        }

        break;
    }

    case LC70_FILE_ID_CH_SET_SCCB: {      // SCC-B
        LC70_CH_SET_SCCB_T *sccb = static_cast<LC70_CH_SET_SCCB_T *>(data);

        for (int i = 0; i < LC70_CH_SET_SCCB_IDX_MAX; ++i) {

            ChannelDefinitionItem item(LC70_BAND_SCCB,                        // BAND
                                       QString(sccb->chSetRow[i].cStrChNo),   // チャンネル番号
                                       sccb->chSetRow[i].ucWave,              // 偏波種別
                                       sccb->chSetRow[i].ulCentFreq,          // 中心周波数 1
                                       -1,                                    // 中心周波数 2
                                       -1                                     // 帯域幅
                                      );

            channelDefinitionList.append(item);
        }

        break;
    }

    case LC70_FILE_ID_CH_SET_SCCC: {      // SCC-C
        LC70_CH_SET_SCCC_T *sccc = static_cast<LC70_CH_SET_SCCC_T *>(data);

        for (int i = 0; i < LC70_CH_SET_SCCC_IDX_MAX; ++i) {

            ChannelDefinitionItem item(LC70_BAND_SCCC,                        // BAND
                                       QString(sccc->chSetRow[i].cStrChNo),   // チャンネル番号
                                       sccc->chSetRow[i].ucWave,              // 偏波種別
                                       sccc->chSetRow[i].ulCentFreq,          // 中心周波数 1
                                       -1,                                    // 中心周波数 2
                                       -1                                     // 帯域幅
                                      );

            channelDefinitionList.append(item);
        }

        break;
    }

    case LC70_FILE_ID_CH_SET_JSAT3A: {      // JSAT-3A
        LC70_CH_SET_JSAT3A_T *jsat3a = static_cast<LC70_CH_SET_JSAT3A_T *>(data);

        for (int i = 0; i < LC70_CH_SET_JSAT3A_IDX_MAX; ++i) {

            ChannelDefinitionItem item(LC70_BAND_JCSAT3,                        // BAND
                                       QString(jsat3a->chSetRow[i].cStrChNo),   // チャンネル番号
                                       jsat3a->chSetRow[i].ucWave,              // 偏波種別
                                       jsat3a->chSetRow[i].ulCentFreq,          // 中心周波数 1
                                       -1,                                      // 中心周波数 2
                                       -1                                       // 帯域幅
                                      );

            channelDefinitionList.append(item);
        }

        break;
    }

    case LC70_FILE_ID_CH_SET_JSAT4B: {      // JSAT-4B
        LC70_CH_SET_JSAT4B_T *jsat4b = static_cast<LC70_CH_SET_JSAT4B_T *>(data);

        for (int i = 0; i < LC70_CH_SET_JSAT4B_IDX_MAX; ++i) {

            ChannelDefinitionItem item(LC70_BAND_JCSAT4,                        // BAND
                                       QString(jsat4b->chSetRow[i].cStrChNo),   // チャンネル番号
                                       jsat4b->chSetRow[i].ucWave,              // 偏波種別
                                       jsat4b->chSetRow[i].ulCentFreq,          // 中心周波数 1
                                       -1,                                      // 中心周波数 2
                                       -1                                       // 帯域幅
                                      );

            channelDefinitionList.append(item);
        }

        break;
    }

    // ラッパーライブラリ V2.00 対応
    case LC70_FILE_ID_CH_SET_CATV_ALL: {      // CATV_ALL
        LC70_CH_SET_CATV_ALL_T *catv = static_cast<LC70_CH_SET_CATV_ALL_T *>(data);

        for (int i = 0; i < LC70_CH_SET_CATV_ALL_IDX_MAX; ++i) {

            ChannelDefinitionItem item(LC70_BAND_CATV_ALL,                      // BAND
                                       QString(catv->chSetRow[i].cStrChNo),     // チャンネル番号
                                       -1,                                      // 偏波種別
                                       catv->chSetRow[i].ulCentFreqQam,         // 中心周波数 1
                                       catv->chSetRow[i].ulCentFreqOfdm,        // 中心周波数 2
                                       -1                                       // 帯域幅
                                      );

            channelDefinitionList.append(item);
        }

        break;
    }

    // ラッパーライブラリ V2.00 対応
    case LC70_FILE_ID_CH_SET_CATV_90_470MHZ: {      // CATV　90〜470MHz
        LC70_CH_SET_CATV_90_470MHZ_T *catv = static_cast<LC70_CH_SET_CATV_90_470MHZ_T *>(data);

        for (int i = 0; i < LC70_CH_SET_CATV_90_470MHZ_IDX_MAX; ++i) {

            ChannelDefinitionItem item(LC70_BAND_CATV_90_470MHZ,                // BAND
                                       QString(catv->chSetRow[i].cStrChNo),     // チャンネル番号
                                       -1,                                      // 偏波種別
                                       catv->chSetRow[i].ulCentFreqQam,         // 中心周波数 1
                                       catv->chSetRow[i].ulCentFreqOfdm,        // 中心周波数 2
                                       -1                                       // 帯域幅
                                      );

            channelDefinitionList.append(item);
        }

        break;
    }

    // ラッパーライブラリ V2.00 対応
    case LC70_FILE_ID_CH_SET_CATV_470_1002MHZ: {      // CATV 470〜1002MHz
        LC70_CH_SET_CATV_470_1002MHZ_T *catv = static_cast<LC70_CH_SET_CATV_470_1002MHZ_T *>(data);

        for (int i = 0; i < LC70_CH_SET_CATV_470_1002MHZ_IDX_MAX; ++i) {

            ChannelDefinitionItem item(LC70_BAND_CATV_470_1002MHZ,              // BAND
                                       QString(catv->chSetRow[i].cStrChNo),     // チャンネル番号
                                       -1,                                      // 偏波種別
                                       catv->chSetRow[i].ulCentFreqQam,         // 中心周波数 1
                                       catv->chSetRow[i].ulCentFreqOfdm,        // 中心周波数 2
                                       -1                                       // 帯域幅
                                      );

            channelDefinitionList.append(item);
        }

        break;
    }

    case LC70_FILE_ID_CH_SET_SKYP: {      // スカパー光
        LC70_CH_SET_SKYP_T *skyp = static_cast<LC70_CH_SET_SKYP_T *>(data);

        for (int i = 0; i < LC70_CH_SET_SKYP_IDX_MAX; ++i) {

            ChannelDefinitionItem item(LC70_BAND_SKYP,                          // BAND
                                       QString(skyp->chSetRow[i].cStrChNo),     // チャンネル番号
                                       -1,                                      // 偏波種別
                                       skyp->chSetRow[i].ulCentFreq,            // 中心周波数 1
                                       -1,                                      // 中心周波数 2
                                       -1                                       // 帯域幅
                                      );

            channelDefinitionList.append(item);
        }

        break;
    }

    case LC70_FILE_ID_CH_SET_PILOT: {      // PILOT
        LC70_CH_SET_PILOT_T *pilot = static_cast<LC70_CH_SET_PILOT_T *>(data);

        for (int i = 0; i < LC70_CH_SET_PILOT_IDX_MAX; ++i) {

            ChannelDefinitionItem item(LC70_BAND_PILOT,                         // BAND
                                       QString(pilot->chSetRow[i].cStrChNo),    // チャンネル番号
                                       -1,                                      // 偏波種別
                                       pilot->chSetRow[i].ulCentFreq,           // 中心周波数 1
                                       -1,                                      // 中心周波数 2
                                       -1                                       // 帯域幅
                                      );

            channelDefinitionList.append(item);
        }

        break;
    }

    case LC70_FILE_ID_CH_SET_LTE: {      // LTE
        LC70_CH_SET_LTE_T *lte = static_cast<LC70_CH_SET_LTE_T *>(data);

        for (int i = 0; i < LC70_CH_SET_LTE_IDX_MAX; ++i) {

            ChannelDefinitionItem item(LC70_BAND_LTE,                          // BAND
                                       QString(lte->chSetRow[i].cStrChNo),     // チャンネル番号
                                       -1,                                     // 偏波種別
                                       lte->chSetRow[i].ulCentFreq,            // 中心周波数 1
                                       -1,                                     // 中心周波数 2
                                       lte->chSetRow[1].ulBandWide             // 帯域幅
                                      );

            channelDefinitionList.append(item);
        }

        break;
    }

    case LC70_FILE_ID_CH_SET_FM: {      // FM
        LC70_CH_SET_FM_T *fm = static_cast<LC70_CH_SET_FM_T *>(data);

        for (int i = 0; i < LC70_CH_SET_FM_IDX_MAX; ++i) {

            ChannelDefinitionItem item(LC70_BAND_FM,                           // BAND
                                       QString(fm->chSetRow[i].cStrChNo),      // チャンネル番号
                                       -1,                                     // 偏波種別
                                       fm->chSetRow[i].ulCentFreq,             // 中心周波数 1
                                       -1,                                     // 中心周波数 2
                                       -1                                      // 帯域幅
                                      );

            channelDefinitionList.append(item);
        }

        break;
    }

    case LC70_FILE_ID_CH_SET_CATV_UP_STREAM :{    // CATV_UP_STREAM
        LC70_CH_SET_CATV_UP_STREAM_T *catv_upstream = static_cast<LC70_CH_SET_CATV_UP_STREAM_T *>(data);

        for (int i = 0; i < LC70_CH_SET_CATV_UP_STREAM_IDX_MAX; ++i) {
            ChannelDefinitionItem item(LC70_BAND_CATV_UP_STREAM,                      // BAND
                                       QString(catv_upstream->chSetRow[i].cStrChNo),  // チャンネル番号
                                       -1,                                            // 偏波種別
                                       catv_upstream->chSetRow[i].ulCentFreq,         // 中心周波数 1
                                       -1,                                            // 中心周波数 2
                                       -1                                             // 帯域幅
                                       );

            channelDefinitionList.append(item);
        }

        break;
    }

    case LC70_FILE_ID_CH_SET_JSAT3A_ANTENNA: {  // アンテナ調整(JSAT-3A)
        LC70_CH_SET_JSAT3A_ANTENNA_T *jsat3a = static_cast<LC70_CH_SET_JSAT3A_ANTENNA_T *>(data);

        for (int i = 0; i < LC70_CH_SET_JSAT3A_ANTENNA_IDX_MAX; ++i) {

            ChannelDefinitionItem item(LC70_BAND_JCSAT3,                        // BAND
                                       QString(jsat3a->chSetRow[i].cStrChNo),   // チャンネル番号
                                       jsat3a->chSetRow[i].ucWave,              // 偏波種別
                                       jsat3a->chSetRow[i].ulCentFreq,          // 中心周波数 1
                                       -1,                                      // 中心周波数 2
                                       -1                                       // 帯域幅
                                      );

            channelDefinitionList.append(item);
        }

        break;
    }

    case LC70_FILE_ID_CH_SET_JSAT4B_ANTENNA: {  // アンテナ調整(JSAT-4B)
        LC70_CH_SET_JSAT4B_ANTENNA_T *jsat4b = static_cast<LC70_CH_SET_JSAT4B_ANTENNA_T *>(data);

        for (int i = 0; i < LC70_CH_SET_JSAT4B_ANTENNA_IDX_MAX; ++i) {

            ChannelDefinitionItem item(LC70_BAND_JCSAT4,                        // BAND
                                       QString(jsat4b->chSetRow[i].cStrChNo),   // チャンネル番号
                                       jsat4b->chSetRow[i].ucWave,              // 偏波種別
                                       jsat4b->chSetRow[i].ulCentFreq,          // 中心周波数 1
                                       -1,                                      // 中心周波数 2
                                       -1                                       // 帯域幅
                                      );

            channelDefinitionList.append(item);
        }

        break;
    }

    case LC70_FILE_ID_CH_SET_FM_DEF: {      // FM Default
        LC70_CH_SET_FM_DEF_T *fm = static_cast<LC70_CH_SET_FM_DEF_T *>(data);

        for (int i = 0; i < LC70_CH_SET_FM_DEF_IDX_MAX; ++i) {

            ChannelDefinitionItem item(LC70_BAND_FM,                           // BAND
                                       QString(fm->chSetRow[i].cStrChNo),      // チャンネル番号
                                       -1,                                     // 偏波種別
                                       fm->chSetRow[i].ulCentFreq,             // 中心周波数 1
                                       -1,                                     // 中心周波数 2
                                       -1                                      // 帯域幅
                                      );

            channelDefinitionList.append(item);
        }

        break;
    }
    case LC70_FILE_ID_CH_SET_CATV_UP_STREAM_DEF :{    // CATV_UP_STREAM
        LC70_CH_SET_CATV_UP_STREAM_DEF_T *catv_upstream = static_cast<LC70_CH_SET_CATV_UP_STREAM_DEF_T *>(data);

        for (int i = 0; i < LC70_CH_SET_CATV_UP_STREAM_DEF_IDX_MAX; ++i) {
            ChannelDefinitionItem item(LC70_BAND_CATV_UP_STREAM,                      // BAND
                                       QString(catv_upstream->chSetRow[i].cStrChNo),  // チャンネル番号
                                       -1,                                            // 偏波種別
                                       catv_upstream->chSetRow[i].ulCentFreq,         // 中心周波数 1
                                       -1,                                            // 中心周波数 2
                                       -1                                             // 帯域幅
                                       );

            channelDefinitionList.append(item);
        }

        break;
	}

    case LC70_FILE_ID_CH_SET_BS_CS: {      // BS_CS統合
        LC70_CH_SET_BS_CS_T *bs_cs = static_cast<LC70_CH_SET_BS_CS_T *>(data);
        ChannelDefinitionItem item;

        int i = 0;
        for (; i < 12; ++i) {
            ChannelDefinitionItem item(LC70_BAND_BS,                           // BAND
                                       QString(bs_cs->chSetRow[i].cStrChNo),   // チャンネル番号
                                       bs_cs->chSetRow[i].ucWave,              // 偏波種別
                                       bs_cs->chSetRow[i].ulCentFreq,          // 中心周波数 1
                                       -1,                                     // 中心周波数 2
                                       -1                                      // 帯域幅
                                      );
            channelDefinitionList.append(item);
        }

        for (; i < 25; ++i) {
            ChannelDefinitionItem item(LC70_BAND_CS,                           // BAND
                                       QString(bs_cs->chSetRow[i].cStrChNo),   // チャンネル番号
                                       bs_cs->chSetRow[i].ucWave,              // 偏波種別
                                       bs_cs->chSetRow[i].ulCentFreq,          // 中心周波数 1
                                       -1,                                     // 中心周波数 2
                                       -1                                      // 帯域幅
                                      );
            channelDefinitionList.append(item);
        }
        for (; i < 37; ++i) {
            ChannelDefinitionItem item(LC70_BAND_BS,                           // BAND
                                       QString(bs_cs->chSetRow[i].cStrChNo),   // チャンネル番号
                                       bs_cs->chSetRow[i].ucWave,              // 偏波種別
                                       bs_cs->chSetRow[i].ulCentFreq,          // 中心周波数 1
                                       -1,                                     // 中心周波数 2
                                       -1                                      // 帯域幅
                                      );
            channelDefinitionList.append(item);
        }
        for (; i < LC70_CH_SET_BS_CS_IDX_MAX; ++i) {
            ChannelDefinitionItem item(LC70_BAND_CS,                           // BAND
                                       QString(bs_cs->chSetRow[i].cStrChNo),   // チャンネル番号
                                       bs_cs->chSetRow[i].ucWave,              // 偏波種別
                                       bs_cs->chSetRow[i].ulCentFreq,          // 中心周波数 1
                                       -1,                                     // 中心周波数 2
                                       -1                                      // 帯域幅
                                      );
            channelDefinitionList.append(item);
        }

        break;
    }

    default:
        break;
    }

    return channelDefinitionList;
}
