/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef CHANNELDEFINITIONHELPER_H
#define CHANNELDEFINITIONHELPER_H

#include <QObject>
#include "constant.h"
#include "channeldefinitionitem.h"

/**
 * @brief チャンネル定義情報用の静的メソッドを定義したクラス
 */
class ChannelDefinitionItemHelper : public QObject
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクタ
     */
    explicit ChannelDefinitionItemHelper(QObject *parent = nullptr);

    /**
     * @brief ラッパークラス(Lc70)から取得したチャンネル定義情報を
     *        本アプリケーションで使うデータ構造に変換
     * @param data ラッパークラス(lc70)から取得したデータ
     * @param fileId ファイルID
     * @return チャンネルを定義した CSV ファイルを読み込んでチャンネル定義のリスト
     */
    static QList<ChannelDefinitionItem> convertChannelDefinitionItem(void *data, int fileId);
};

#endif // CHANNELDEFINITIONHELPER_H
