/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "objectsearcher.h"
#include "constant.h"
#include <QDebug>

ObjectSearcher::ObjectSearcher(QObject *parent)
    : QObject(parent)
{

}

ObjectSearcher::~ObjectSearcher()
{

}

QObject *ObjectSearcher::search(QQmlApplicationEngine *engine, const QString &objectName)
{
    if (engine->rootObjects().count() == 0) {
        return nullptr;
    }

    QObject *rootObject = engine->rootObjects().first();

    if (rootObject == nullptr) {
        return nullptr;
    }

    // ルートオブジェクトの評価
    if (rootObject->objectName() == objectName) {
        return rootObject;
    }

    // 子オブジェクトの検索
    QObject *resultObject = nullptr;
    QObjectList rootObjectList = rootObject->children();

    // ポップアップ用
    QObjectList objectList = rootObjectList[0]->children();

    for (QObject *object : objectList) {
        if (object->objectName() == objectName) {
            return object;
        }
    }

    // 画面用
    for (QObject *rootObject : rootObjectList) {
        if (rootObject->objectName() == QString(LOADER_QML_OBJECT_NAME)) {
            QObjectList objectList = rootObject->children();

            for (QObject *object : objectList) {
                if (object->objectName() == objectName) {
                    resultObject = object;
                    break;
                } else {
                    QObjectList childrenList = object->children();

                    for (QObject *child : childrenList) {
                        if (child->objectName() == objectName) {
                            return child;
                        }
                    }
                }
            }

            break;
        } else if (rootObject->objectName() == QString(MENU_LIST_QML_OBJECT_NAME) ||
                   rootObject->objectName() == QString(MACHINE_STATUS_QML_OBJECT_NAME) ||
                   rootObject->objectName() == QString(MENU_BAR_MODEL_QML_OBJECT_NAME)) {
            // MainFrame.qml に配置された基本部品
            if (rootObject->objectName() == objectName) {
                resultObject = rootObject;
                break;
            }
        }
    }

    return resultObject;
}
