/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "systemlog.h"
#include <QDebug>

static SystemLog *instance_ = nullptr;

SystemLog &SystemLog::instance(QObject *parent)
{
    if (instance_ == nullptr) {
        instance_ = new SystemLog(parent);
    }

    return *instance_;
}

SystemLog::~SystemLog()
{
    closelog();
}

void SystemLog::prepare(const ActionMode &actionMode, const QString &logFileName)
{
    // 初回設定のみ有効
    if (_actionMode != ACTION_MODE_COUNT) {
        return;
    }

    _actionMode = actionMode;

    openlog(logFileName.toLocal8Bit().constData(), LOG_CONS | LOG_PID, LOG_USER);
}

void SystemLog::write(const QString &sender, const QString &message, int priority)
{
    if (_actionMode == ACTION_MODE_COUNT) {
        return;
    }

    if (_actionMode == PRODUCTION) {
        if (priority < LOG_INFO) {
            syslog(priority, "[%s] %s", sender.toLocal8Bit().constData(), message.toLocal8Bit().constData());
            qDebug() << QString("[%1] %2").arg(sender).arg(message);
        }
    } else {
        qDebug() << QString("[%1] %2").arg(sender).arg(message);
    }
}

SystemLog::SystemLog(QObject *parent)
    : QObject(parent)
    , _actionMode(ACTION_MODE_COUNT)
{

}
