/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SYSTEMLOG_H
#define SYSTEMLOG_H

#include <QObject>
#include <QString>
#include <syslog.h>
#include <constant.h>

/**
 * @brief システムロガーからログを出力
 */
class SystemLog : public QObject
{
    Q_OBJECT
public:
    static SystemLog &instance(QObject *parent = nullptr);
    SystemLog(const SystemLog &) = delete;
    void operator = (const SystemLog &) = delete;

    /**
     * @brief デストラクター
     */
    ~SystemLog();

    /**
     * @brief 動作モードの設定
     * @param actionMode 動作モード
     * @param logFileName ログファイル名
     * @note 初回呼び出し時のみ使用する
     */
    void prepare(const ActionMode &actionMode, const QString &logFileName);

    /**
     * @brief ログ出力する
     * @param sender ログ出力したクラス名
     * @param message ログに出力する文字列
     * @param priority メッセージの優先度
     * @note メッセージの優先度は syslog の level と同じ
     */
    void write(const QString &sender, const QString &message, int priority = LOG_DEBUG);

private:
    /**
     * @brief コンストラクター
     * @param parent 親オブジェクト
     */
    explicit SystemLog(QObject *parent = nullptr);

    QString _actionMode;    //!< 動作モード
};

#endif // SYSTEMLOG_H
