/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef ZIPHELPER_H
#define ZIPHELPER_H

#include <QString>
#include <QStringRef>
#include <QVector>

extern "C" {
#include "zip.h"
}

/**
 * @brief libzip を使用するためのヘルパー関数群
 */
class ZipHelper
{
public:
    ZipHelper();

    /**
     * @brief zip ファイルに圧縮
     * @param archiveFile zip ファイル名
     * @param fileList 圧縮するファイルのリスト
     * @param destination 圧縮先のパス
     * @param password パスワード
     * @return
     */
    static bool create(const QString& archiveFile, const QVector<QStringRef> &fileList, const QString &destination, const QString &password);

    /**
     * @brief zip ファイルを展開
     * @param archiveFile zip ファイル名
     * @param destination 展開先のパス
     * @param password パスワード
     * @return
     */
    static bool extract(const QString& archiveFile, const QString &destination, const QString &password);
};

#endif // ZIPHELPER_H
