//------------------------------------------------------------------------------
//	libipc.h
//	プロセス間通信ライブラリヘッダ
//	
//	変更履歴
//	・2020/03/05 S.Iwamatsu 新規作成
//	
//	(c) 2020 DX ANTENNA CO.,LTD.
//------------------------------------------------------------------------------
#ifndef _LIBIPC_H_
#define _LIBIPC_H_

//-----------------------------------------------------------------------------
//	include
//-----------------------------------------------------------------------------
#include <semaphore.h>

#include "typedef.h"

//-----------------------------------------------------------------------------
//	define
//-----------------------------------------------------------------------------
// メッセージキューキー名
#define MQ_KEY_PSYS				"/mq_key_psys"				// システム管理
#define MQ_KEY_PSYS_2ND			"/mq_key_psys_2nd"			// システム管理	(自身発用)
#define MQ_KEY_PDISP			"/mq_key_pdisp"				// 描画(Qt)
#define MQ_KEY_PDISP_2ND		"/mq_key_pdisp_2nd"			// 描画(Qt)		(自身発用)
#define MQ_KEY_PDISPMNG			"/mq_key_pdispmng"			// 描画管理
#define MQ_KEY_PDISPMNG_2ND		"/mq_key_pdispmng_2nd"		// 描画管理		(自身発用)
#define MQ_KEY_PDEV				"/mq_key_pdev"				// デバイス監視
#define MQ_KEY_PDEV_2ND			"/mq_key_pdev_2nd"			// デバイス監視	(自身発用)
#define MQ_KEY_PKEY				"/mq_key_pkey"				// キー入力
#define MQ_KEY_PKEY_2ND			"/mq_key_pkey_2nd"			// キー入力		(自身発用)
#define MQ_KEY_PBUZ				"/mq_key_pbuz"				// ブザー制御
#define MQ_KEY_PBUZ_2ND			"/mq_key_pbuz_2nd"			// ブザー制御	(自身発用)
#define MQ_KEY_PMEAS			"/mq_key_pmeas"				// 測定制御
#define MQ_KEY_PMEAS_2ND		"/mq_key_pmeas_2nd"			// 測定制御		(自身発用)
#define MQ_KEY_PDISP_SYS		"/mq_key_pdisp_sys"			// 描画(Qt) システム監視用
#define MQ_KEY_PDISP_SYS_2ND	"/mq_key_pdisp_sys_2nd"		// 描画(Qt)	システム監視用	(自身発用)
#define MQ_KEY_PDISP_MEAS		"/mq_key_pdisp_meas"		// 描画(Qt) 測定用
#define MQ_KEY_PDISP_MEAS_2ND	"/mq_key_pdisp_meas_2nd"	// 描画(Qt)	測定用			(自身発用)

// メッセージキュー数定義 (上限はlibipc_conf.hのLIPC_MQ_MAX_MSG参照)
#define MQ_QUENUM_PSYS		32				// システム管理
#define MQ_QUENUM_PDISP		32				// 描画(Qt)
#define MQ_QUENUM_PDISPMNG	32				// 描画管理
#define MQ_QUENUM_PDEV		32				// デバイス監視
#define MQ_QUENUM_PKEY		32				// キー入力
#define MQ_QUENUM_PBUZ		32				// ブザー制御
#define MQ_QUENUM_PMEAS		32				// 測定制御

// メッセージバイトサイズ定義(上限はlibipc_conf.hのLIPC_MQ_MAX_MSG_SIZE参照)
#define MQ_MSGSIZE_PSYS		1300			// システム管理
#define MQ_MSGSIZE_PDISP	1300			// 描画(Qt)
#define MQ_MSGSIZE_PDISPMNG	1300			// 描画管理
#define MQ_MSGSIZE_PDEV		1300			// デバイス監視
#define MQ_MSGSIZE_PKEY		1300			// キー入力
#define MQ_MSGSIZE_PBUZ		1300			// ブザー制御
#define MQ_MSGSIZE_PMEAS	1300			// 測定制御

// プロセスID定義
typedef enum proc_id_t{
	PROC_ID_PSYS		= 0,	// システム管理
	PROC_ID_PSYS_2ND,			// システム管理	(応答受信用)
	PROC_ID_PDISP,				// 描画(Qt)
	PROC_ID_PDISP_2ND,			// 描画(Qt)		(応答受信用)
	PROC_ID_PDISPMNG,			// 描画管理
	PROC_ID_PDISPMNG_2ND,		// 描画管理		(応答受信用)
	PROC_ID_PDEV,				// デバイス監視
	PROC_ID_PDEV_2ND,			// デバイス監視	(応答受信用)
	PROC_ID_PKEY,				// キー入力
	PROC_ID_PKEY_2ND,			// キー入力		(応答受信用)
	PROC_ID_PBUZ,				// ブザー制御
	PROC_ID_PBUZ_2ND,			// ブザー制御	(応答受信用)
	PROC_ID_PMEAS,				// 測定制御
	PROC_ID_PMEAS_2ND,			// 測定制御		(応答受信用)
	PROC_ID_PDISP_SYS,			// 描画(Qt)	システム監視用
	PROC_ID_PDISP_SYS_2ND,		// 描画(Qt)	システム監視用	(応答受信用)
	PROC_ID_PDISP_MEAS,			// 描画(Qt) 測定用
	PROC_ID_PDISP_MEAS_2ND,		// 描画(Qt)	測定用	(応答受信用)
	PROC_ID_MAX
} PROC_ID_T;

// メッセージキューテーブル構造体
typedef struct lipc_mq_tbl_t{
	const char *pcKey;		// キー名
	int32_t lMqcnt;			// キュー数
	int32_t	lMqsz;			// メッセージバイトサイズ
	const char *pcName;		// 表示名
} LIPC_MQ_TBL_T;


#define LIPC_MQ_KEY(x)		g_mqTbl[x].pcKey
#define LIPC_MQ_COUNT(x)	g_mqTbl[x].lMqcnt
#define LIPC_MQ_SIZE(x)		g_mqTbl[x].lMqsz
#define LIPC_MQ_NAME(x)		g_mqTbl[x].pcName

//-----------------------------------------------------------------------------
//	typedef
//-----------------------------------------------------------------------------
// 関数エラーコード型
typedef enum lipc_err_t{
	LIPC_OK				   =  0,  /* 正常終了 */

	/* 継続不可エラー */
	LIPC_ERR			   = -1,  /* 異常終了 */
	LIPC_ERR_KEY_EXIST	   = -2,  /* 既に存在するキー名を指定した */
	LIPC_ERR_KEY_NOT_EXIST = -3,  /* 存在しないキー名を指定した */
	LIPC_ERR_BAD_ID		   = -4,  /* 有効ではないIDを指定した */
	LIPC_ERR_NOMEM		   = -5,  /* メモリ不足 */
	LIPC_ERR_ARG		   = -6,  /* 引数異常 */

	/* 継続可能エラー */
	LIPC_ERR_TIMEOUT	   =  1,  /* タイムアウト */
	LIPC_ERR_OVERFLOW	   =  2,  /* セマフォ値がすでに最大値である */
}LIPC_ERR_T;

// 共有メモリ関連 
typedef struct lipc_shm_id_t{
	// (構造体の中身はライブラリ内部で使用する。ライブラリ使用者が意識する必要はない)
	void *pvShm;	/* 共有メモリアドレス */
	int32_t lSize;	/* 共有メモリサイズ[byte] */
	int32_t lFd;	/* 共有メモリFD */
}LIPC_SHM_ID_T;					/* 共有メモリID型 */

// セマフォ関連
typedef sem_t *LIPC_SEM_ID_T;	/* セマフォID型 */

// メッセージキュー関連
typedef int32_t LIPC_MQ_ID_T;	/* メッセージキューID型 */

// メモリプール関連
typedef struct lipc_mpl_id_t{
	// (構造体の中身はライブラリ内部で使用する。ライブラリ使用者が意識する必要はない)
	LIPC_SHM_ID_T shmId;	/* 共有メモリID格納 */
	LIPC_SEM_ID_T semId;	/* セマフォID格納 */
}LIPC_MPL_ID_T;					/* メモリプールID型 */

//-----------------------------------------------------------------------------
//	prototype
//-----------------------------------------------------------------------------
// 共有メモリ関連
LIPC_ERR_T lipc_initShm(const char *pcKey, int32_t lSize);
LIPC_ERR_T lipc_openShm(const char *pcKey, LIPC_SHM_ID_T *pShmId);
LIPC_ERR_T lipc_getShm(const LIPC_SHM_ID_T *pShmId, void **ppvShm, int32_t *plSize);

// セマフォ関連
LIPC_ERR_T lipc_initSem(const char *pcKey, uint32_t ulSemVal);
LIPC_ERR_T lipc_openSem(const char *pcKey, LIPC_SEM_ID_T *pSemId);
LIPC_ERR_T lipc_takeSem(const LIPC_SEM_ID_T *pSemId);
LIPC_ERR_T lipc_ptakeSem(const LIPC_SEM_ID_T *pSemId);
LIPC_ERR_T lipc_ttakeSem(const LIPC_SEM_ID_T *pSemId, int32_t lTimOut);
LIPC_ERR_T lipc_giveSem(const LIPC_SEM_ID_T *pSemId);
LIPC_ERR_T lipc_refSem(const LIPC_SEM_ID_T *pSemId, int32_t *piSemVal);


// メッセージキュー関連
LIPC_ERR_T lipc_initMq(const char *pcKey, int32_t lMqcnt, int32_t lMqsz);
LIPC_ERR_T lipc_openMq(const char *pcKey, LIPC_MQ_ID_T *pMqId);
LIPC_ERR_T lipc_closeMq(const LIPC_MQ_ID_T *pMqId);
LIPC_ERR_T lipc_sndMq(const LIPC_MQ_ID_T *pMqId, const char *pcMsg, size_t ulMsgLen);
LIPC_ERR_T lipc_psndMq(const LIPC_MQ_ID_T *pMqId, const char *pcMsg, size_t ulMsgLen);
LIPC_ERR_T lipc_tsndMq(const LIPC_MQ_ID_T *pMqId, const char *pcMsg, size_t ulMsgLen, int32_t lTimOut);
LIPC_ERR_T lipc_rcvMq(const LIPC_MQ_ID_T *pMqId, char *pcMsg, size_t ulMsgLen, size_t *pulRcvLen);
LIPC_ERR_T lipc_prcvMq(const LIPC_MQ_ID_T *pMqId, char *pcMsg, size_t ulMsgLen, size_t *pulRcvLen);
LIPC_ERR_T lipc_trcvMq(const LIPC_MQ_ID_T *pMqId, char *pcMsg, size_t ulMsgLen, size_t *pulRcvLen,int32_t lTimOut);
LIPC_ERR_T lipc_refMq(const LIPC_MQ_ID_T *pMqId, int32_t *plMaxMsg, int32_t *plCurMsg);

// メモリプール関連
LIPC_ERR_T lipc_initMpl(const char *pcKey, int32_t lBlkcnt, int32_t lBlksz);
LIPC_ERR_T lipc_openMpl(const char *pcKey, LIPC_MPL_ID_T *pMplId);
LIPC_ERR_T lipc_getMpl(const LIPC_MPL_ID_T *pMplId, void **ppvMpl, int32_t *plMplBlkId);
LIPC_ERR_T lipc_getMplRetry(const LIPC_MPL_ID_T *pMplId, void **ppvMpl, int32_t *plMplBlkId,int32_t lRetryNum,int32_t lRetryWait);
LIPC_ERR_T lipc_relMpl (const LIPC_MPL_ID_T *pMplId, int32_t lMplBlkId);

//-----------------------------------------------------------------------------
//	exetern variable
//-----------------------------------------------------------------------------
// メッセージキューテーブル (実体はlibipc_mq.cにて定義)
extern const LIPC_MQ_TBL_T g_mqTbl[PROC_ID_MAX];

#endif /* _LIBIPC_H_ */

