/*******************************************************************************
	liblc70.h
	LC70WS アプリケーションライブラリヘッダ
	
	変更履歴
	・2020/05/29 M.Shinmura 新規作成
	
	(c) 2020 DX ANTENNA CO.,LTD.
*******************************************************************************/
#ifndef	_LIBLC70_H_
#define	_LIBLC70_H_

/*******************************************************************************
	include
*******************************************************************************/
#include "typedef.h"
#include "libipc.h"

/*******************************************************************************
	define
*******************************************************************************/


/* リソース数 */
#define	LC70_MAX_REG_CH			(LC70_CH_SET_CATV_ALL_IDX_MAX)		/* 最大設定チャンネル数(FM, CATV 上りを除き一番チャンネル数が多いCATV ALLを参照) */
#define	LC70_MAX_CONSTA_RD_NUM	(200)		/* コンスタレーション最大読出数 */
#define	LC70_MIN_THR_BLK		(1)			/* 最小有効閾値ブロック数 */
#define	LC70_MAX_THR_BLK		(48)		/* 最大有効閾値ブロック数 */

/* 測定条件／収集ステータス(bit0-5) */
/* 補足:測定条件指定時、下記CNR,MERのbitが両方1の場合、MERは0とみなす */
#define	LC70_DATA_MSK_NONE		(0x0000)	/* 測定なし */
#define	LC70_DATA_MSK_LEVEL		(0x0001)	/* LEVEL */
#define	LC70_DATA_MSK_CNR		(0x0002)	/* CNR */
#define	LC70_DATA_MSK_BER		(0x0004)	/* BER */
#define	LC70_DATA_MSK_CONSTA	(0x0008)	/* コンスタレーション */
#define	LC70_DATA_MSK_DLY_PRF	(0x0010)	/* 遅延プロファイル */
#define	LC70_DATA_MSK_MER		(0x0020)	/* MER */


/* 放送方式 */
#define LC70_BD_SYS_ISDBT			((uint8_t)0)
#define LC70_BD_SYS_ISDBS			((uint8_t)1)
#define LC70_BD_SYS_ISDBS3			((uint8_t)2)
#define LC70_BD_SYS_ANNEXC			((uint8_t)3)
#define LC70_BD_SYS_DVBS			((uint8_t)4)
#define LC70_BD_SYS_DVBS2			((uint8_t)5)
#define LC70_BD_SYS_OPTICAST		((uint8_t)6)
#define LC70_BD_SYS_LTE				((uint8_t)7)
#define LC70_BD_SYS_ANALOG			((uint8_t)8)
#define LC70_BD_SYS_ANNEXB			((uint8_t)9)
#define LC70_BD_SYS_NONE			((uint8_t)10)   /* 放送方式指定なし */


#ifndef MES_DF_SETMOD_OFDM	/* @@@ msgdef_mes.hと定義重複 暫定措置 */
/* 変調方式ビット 本APIのパラメータ指定はLC70_SETMOD_XXX定義を使用すること(本定義は直接使用しないこと) */
#define	MES_DF_SETMOD_OFDM		((uint32_t)1<<0)
#define	MES_DF_SETMOD_TC8PSK	((uint32_t)1<<1)
#define	MES_DF_SETMOD_DQPSK		((uint32_t)1<<2)
#define	MES_DF_SETMOD_QPSK		((uint32_t)1<<3)
#define	MES_DF_SETMOD_BPSK		((uint32_t)1<<4)
#define	MES_DF_SETMOD_8PSK		((uint32_t)1<<5)
#define	MES_DF_SETMOD_16APSK	((uint32_t)1<<6)
#define	MES_DF_SETMOD_32APSK	((uint32_t)1<<7)
#define	MES_DF_SETMOD_16QAM		((uint32_t)1<<8)
#define	MES_DF_SETMOD_32QAM		((uint32_t)1<<9)
#define	MES_DF_SETMOD_64QAM		((uint32_t)1<<10)
#define	MES_DF_SETMOD_128QAM	((uint32_t)1<<11)
#define	MES_DF_SETMOD_256QAM	((uint32_t)1<<12)
#define	MES_DF_SETMOD_CW		((uint32_t)1<<13)
#define	MES_DF_SETMOD_8APSKL	((uint32_t)1<<14)
#define	MES_DF_SETMOD_16APSKL	((uint32_t)1<<15)
#define	MES_DF_SETMOD_32APSKL	((uint32_t)1<<16)
#define	MES_DF_SETMOD_FM		((uint32_t)1<<17)
#define	MES_DF_SETMOD_UNDEF		((uint32_t)0)		/* 定義なし */
#endif	/* MES_DF_SETMOD_OFDM */

/* 変調方式ビット */
#define LC70_SETMOD_OFDM		(MES_DF_SETMOD_OFDM)
#define LC70_SETMOD_BPSK		(MES_DF_SETMOD_BPSK)
#define LC70_SETMOD_QPSK		(MES_DF_SETMOD_QPSK)
#define LC70_SETMOD_TC8PSK		(MES_DF_SETMOD_TC8PSK)
#define LC70_SETMOD_32APSK		(MES_DF_SETMOD_32APSK)
#define LC70_SETMOD_16APSK		(MES_DF_SETMOD_16APSK)
#define LC70_SETMOD_8PSK		(MES_DF_SETMOD_8PSK)
#define LC70_SETMOD_64QAM		(MES_DF_SETMOD_64QAM)
#define LC70_SETMOD_256QAM		(MES_DF_SETMOD_256QAM)
#define LC70_SETMOD_CW			(MES_DF_SETMOD_CW)
#define LC70_SETMOD_FM			(MES_DF_SETMOD_FM)
#define LC70_SETMOD_UNDEF		(MES_DF_SETMOD_UNDEF)

/* 測定状態 */
#define	LC70_MSTAT_MSK_NONE		(0x0000)	/* 測定停止中 */
#define	LC70_MSTAT_MSK_SINGLE	(0x0001)	/* シングル測定中 */
#define	LC70_MSTAT_MSK_MULTI	(0x0002)	/* マルチ測定中 */

/* サブCPU動作状態 */
#define	LC70_SUB_STAT_OK		(0)			/* 正常状態 */
#define	LC70_SUB_STAT_WAIT_REST	(1)			/* リセット待ち */

/* 測定チャンネル有効／無効 */
#define	LC70_CH_DISABLE			(0)			/* 測定チャンネル有効 */
#define	LC70_CH_ENABLE			(1)			/* 測定チャンネル無効 */

/* 故障コード  */
#define LC70_FAIL_NONE    			(0x0000)	/* 故障なし */
#define LC70_FAIL_FILE_ERR    		(0x0100)	/* システム設定ファイル読み出しエラー */
												/* 測定設定ファイル読み出しエラー */
												/* ユーザ設定ファイル読み出しエラー */
												/* チャンネル設定ファイル読み出しエラー */
												/* キャリブレーション設定ファイル読み出しエラー */
												/* SDマウント異常 */
												/* ファイル書き込みエラー */
#define LC70_FAIL_DEV_MAG_ERR		(0x0300)	/* 磁気センサ異常 */
#define LC70_FAIL_DEV_MAG_I2C_ERR	(0x0301)	/* I2C通信エラー(for 磁気センサ） */
#define LC70_FAIL_MODEL_GAUGE_ERR	(0x0304)	/* モデルゲージのI2C通信異常(I2C-0) */
												/* モデルゲージのI2C通信異常(I2C-3) */
#define LC70_FAIL_DCDC_ERR    		(0x0308)	/* 給電(DCDC)アクセス異常(I2C異常) */
												/* 給電(DCDC)のAD値が読めない(AD値を格納したファイルが無い) */
#define LC70_FAIL_SUB_ERR			(0x0400)	/* サブCPUシステムエラー */
												/*（タイマドライバ） */
												/*（IRQドライバ）*/
												/*（SPIドライバ）など */
												/* SPI通信エラー */
												/* 要求エラー */
#define LC70_FAIL_PARAM_ERR			(0x7FFF)	/* 関数引数エラー */
												/* ブザー制御エラー */
												/* GPIO制御エラー */
#define LC70_FAIL_MSG_SD_FULL		(0x8101)	/* SD容量オーバ */
#define LC70_FAIL_MSG_RTC_ERR		(0x8200)	/* RTC異常 */
												/* 時刻設定エラー */
												/* I2C通信エラー（for RTC) */
#define LC70_FAIL_MSG_OVER_CURR_ERR	(0x8305)	/* 給電(DCDC)の過電流異常エラー */
#define LC70_FAIL_MSG_DCDC_TEMP_ERR	(0x8306)	/* 給電(DCDC)の温度異常エラー */
#define LC70_FAIL_USBC_PD_ERR		(0x8307)	/* USB TYPE-C 非対応PD接続エラー */
#define LC70_FAIL_MEAS_PARAM_ERR	(0x8401)	/* 測定管理パラメータエラー */
#define LC70_FAIL_MSG_PRGUPDATE		(0x9000)	/* プログラム更新ファイルあり(SDカード消去なし) */
#define LC70_FAIL_MSG_PRGSDUPDATE	(0x9001)	/* プログラム更新ファイルあり(SDカード消去(コンバート)あり) */
#define LC70_FAIL_MSG_PRGUPDATE_COMPLATE	(0x9002)	/* プログラムアップデート正常終了 */
#define LC70_FAIL_MSG_PRGUPDATE_ERR	(0x9003)	/* プログラムアップデート異常終了 */

/* 故障状態 */
#define	LC70_FAIL_STAT_NORMAL	((uint8_t)0)			/* 故障なし(復旧) */
#define	LC70_FAIL_STAT_FAIL		((uint8_t)1)			/* 故障あり(発生) */

/* 故障時の動作 */
#define	LC70_FAIL_CTL_NONE			((uint8_t)0)			/* なし(継続) */
#define	LC70_FAIL_CTL_MSGDISP		((uint8_t)1)			/* メッセージ表示 */
#define	LC70_FAIL_CTL_REBOOT		((uint8_t)2)			/* 再起動 */
#define	LC70_FAIL_CTL_SHUTDOWN		((uint8_t)3)			/* シャットダウン */
#define	LC70_FAIL_CTL_UPDATE		((uint8_t)4)			/* アップデート */
#define	LC70_FAIL_CTL_MSGDISP_CLR	((uint8_t)5)			/* メッセージ表示(故障状態取得時に自動復旧) */

/* 追加情報数 */
#define LC70_FAIL_ADD_INFO_NUM	(32)

/* プロダクト情報バイトサイズ */
#define LC70_MODELCODE_SIZE		(8)		/* 機種コード バイトサイズ */
#define LC70_OPTINFO_SIZE		(5)		/* オプション情報 バイトサイズ */
#define LC70_SERIALNO_SIZE		(12)	/* シリアル番号 バイトサイズ */
#define LC70_VERSION_SIZE		(16)	/* バージョン情報 バイトサイズ */

/* チャンネル番号文字列長 */
#define	STR_CHAN_LEN			(8)

/* 遅延プロファイルデータ最大読み出し点数 */
#define LC70_DLY_PRF_NUM		(2048)

/* バッテリ状態(bit0-2) */
#define LC70_BATT_LVL_MSK_RED0   ((uint8_t)0x00) /* 0～5%    赤(Empty) */
#define LC70_BATT_LVL_MSK_RED1   ((uint8_t)0x01) /* 6～10%   赤1本線 */
#define LC70_BATT_LVL_MSK_GREEN1 ((uint8_t)0x02) /* 11～30%  緑1本線 */
#define LC70_BATT_LVL_MSK_GREEN2 ((uint8_t)0x03) /* 31～50%  緑2本線 */
#define LC70_BATT_LVL_MSK_GREEN3 ((uint8_t)0x04) /* 51～70%  緑3本線 */
#define LC70_BATT_LVL_MSK_GREEN4 ((uint8_t)0x05) /* 71～100% 緑4本線 */
#define LC70_BATT_LVL_MSK_RSV    ((uint8_t)0x06) /* 予備 */
#define LC70_BATT_LVL_MSK_ERR    ((uint8_t)0x07) /* 不定値(I2C異常含む) */

#define LC70_BATT_LVL_MSK        ((uint8_t)0x07) /* バッテリ残量マスク */

/* バッテリ状態(bit3-4) */
#define LC70_BATT_STS_MSK_UNCHG  ((uint8_t)0x00) /* 未充電 */
#define LC70_BATT_STS_MSK_CHGING ((uint8_t)0x08) /* 充電中 */
#define LC70_BATT_STS_MSK_FULL   ((uint8_t)0x10) /* 満充電 */
#define LC70_BATT_STS_MSK_INDEF  ((uint8_t)0x18) /* 不定値 */

#define LC70_BATT_STS_MSK        ((uint8_t)0x18) /* バッテリ状態マスク */


/* 測定状態 */
#define LC70_MEAS_STAT_DIS				(0) /* 測定不可 */
#define LC70_MEAS_STAT_ENB				(1) /* 測定可 */

/* (光/同軸)入力切替状態 */
#define LC70_INPUT_RF					(0)       /* 同軸 */
#define LC70_INPUT_OPT					(1)       /* 光 */
#define LC70_INPUT_PROCESSING			(0xFFFF)  /* 入力切替中 */

/* スタンバイ状態 */
#define LC70_STANDBY_STAT_STANDBY			(0) /* スタンバイ状態 */
#define LC70_STANDBY_STAT_WAKEUP			(1) /* ウェイクアップ状態 */
#define LC70_STANDBY_STAT_STANDBY_BUSY		(2) /* スタンバイ状態切替中 */
#define LC70_STANDBY_STAT_WAKEUP_BUSY		(3) /* ウェイクアップ状態切替中 */

/* キャリブレーション状態 */
#define ANGLE_CAL_STAT_IDLE        ((int32_t)0)  /* 処理なし */
#define ANGLE_CAL_STAT_CALC1       ((int32_t)1)  /* 中心点1計算中 */
#define ANGLE_CAL_STAT_CALC2       ((int32_t)2)  /* 中心点2計算中 */
#define ANGLE_CAL_STAT_CALC3       ((int32_t)3)  /* 中心点3計算中 */
#define ANGLE_CAL_STAT_OK          ((int32_t)4)  /* キャリブレーションOK */
#define ANGLE_CAL_STAT_NG          ((int32_t)5)  /* キャリブレーションNG */



/*============================================================
	システム設定ファイル関連
============================================================*/
/*----------------------------------------
	POWER OFF時間(分)
----------------------------------------*/
/* システム設定(POWER OFF時間(分))データ配列数定義 */
#define LC70_SYS_SET_POWOFF_IDX_MAX (1)

/* POWER OFF時間設定配列数 */
#define LC70_SYS_SET_POWOFF_SELECT_NUM	(6)

/* POWER OFF時間設定定義 */
#define LC70_SYS_SET_POWOFF_OFF		((uint8_t)0)	/* OFF  */
#define LC70_SYS_SET_POWOFF_5MIN	((uint8_t)5)	/*  5分 */
#define LC70_SYS_SET_POWOFF_10MIN	((uint8_t)10)	/* 10分 */
#define LC70_SYS_SET_POWOFF_15MIN	((uint8_t)15)	/* 15分 */
#define LC70_SYS_SET_POWOFF_30MIN	((uint8_t)30)	/* 30分 */
#define LC70_SYS_SET_POWOFF_60MIN	((uint8_t)60)	/* 60分 */

/*----------------------------------------
	音量設定
----------------------------------------*/
/* システム設定(音量設定)データ配列数定義 */
#define LC70_SYS_SET_VOLUME_IDX_MAX (1)

/* 音量設定配列数 */
#define LC70_SYS_SET_VOLUME_SELECT_NUM	(4)

/* 音量設定定義 */
#define LC70_SYS_SET_VOLUME_OFF	((uint8_t)0)	/* OFF */
#define LC70_SYS_SET_VOLUME_MIN	((uint8_t)1)	/* 小 */
#define LC70_SYS_SET_VOLUME_MID	((uint8_t)2)	/* 中 */
#define LC70_SYS_SET_VOLUME_MAX	((uint8_t)3)	/* 大 */

/*----------------------------------------
	明るさ設定
----------------------------------------*/
/* システム設定(明るさ設定)データ配列数定義 */
#define LC70_SYS_SET_BRIGHTNESS_IDX_MAX (1)

/* 明るさ設定配列数 */
#define LC70_SYS_SET_BRIGHTNESS_SELECT_NUM	(3)

/* 明るさ設定定義 */
#define LC70_SYS_SET_BRIGHTNESS_MIN	((uint8_t)1)	/* 暗 */
#define LC70_SYS_SET_BRIGHTNESS_MID	((uint8_t)2)	/* 普 */
#define LC70_SYS_SET_BRIGHTNESS_MAX	((uint8_t)3)	/* 明 */

/*============================================================
	測定設定ファイル関連
============================================================*/
/*----------------------------------------
	局部発信周波数設定
----------------------------------------*/
/* 局部発信周波数無効値定義 */
#define LC70_MEAS_SET_FREQ_NULL		((uint32_t)-1)	/* 無効な値  */

/* 偏波定義 */
#define LC70_MEAS_SET_WAVE_R	((uint8_t)0)	/* 右旋(R) */
#define LC70_MEAS_SET_WAVE_L	((uint8_t)1)	/* 左旋(L) */
#define LC70_MEAS_SET_WAVE_H	((uint8_t)2)	/* 水平(H) */
#define LC70_MEAS_SET_WAVE_V	((uint8_t)3)	/* 垂直(V) */

/*----------------------------------------
	閾値設定
----------------------------------------*/
/* 規格定義 */
/* LC70_BD_SYS_XXX定義を参照 */

/* 変調方式ビット */
/* LC70_SETMOD_XXX定義を参照 */

/*----------------------------------------
	CNR/MER切替設定
----------------------------------------*/
/* CNR/MER切替設定配列数 */
#define LC70_MEAS_SET_CNRMER_SELECT_NUM		(2)

/* Select CNR/MER 定義 */
#define LC70_MEAS_SET_SEL_CNR	((uint8_t)0)	/* CNR選択 */
#define LC70_MEAS_SET_SEL_MER	((uint8_t)1)	/* MER選択 */
#define LC70_MEAS_SET_SEL_UNUSE ((uint8_t)255)  /* 未使用 */

/*----------------------------------------
	CATVチャンネル周波数設定
----------------------------------------*/
/* なし */

/*----------------------------------------
	ケーブル損失設定
----------------------------------------*/
/* なし */

/*----------------------------------------
	入力切替設定
----------------------------------------*/
/* 入力切替設定データ配列数定義 */
#define LC70_MEAS_SET_INPUT_IDX_MAX		(1)

/* 入力切替設定配列数 */
#define LC70_MEAS_SET_INPUT_SELECT_NUM	(2)

/* 入力切替定義 */
#define LC70_MEAS_SET_INPUT_RF	((uint8_t)0)	/* 同軸 */
#define LC70_MEAS_SET_INPUT_OPT	((uint8_t)1)	/* 光 */

/*----------------------------------------
	CATVの変調方式選択
----------------------------------------*/
/* CATVの変調方式選択データ配列数定義 */
#define LC70_MEAS_SET_CATV_MOD_IDX_MAX		(1)

/* CATVの変調方式選択配列数 */
#define LC70_MEAS_SET_CATV_MOD_SELECT_NUM	(3)

/* CATVの変調方式選択定義 */
#define LC70_MEAS_SET_CATV_MOD_OFDM		LC70_SETMOD_OFDM		/* OFDM */
#define LC70_MEAS_SET_CATV_MOD_64QAM	LC70_SETMOD_64QAM		/* 64QAM */
#define LC70_MEAS_SET_CATV_MOD_256QAM	LC70_SETMOD_256QAM		/* 256QAM */

/*----------------------------------------
	給電電圧(DC OUT)設定
----------------------------------------*/
/* DC OUT選択定義 */
#define LC70_MEAS_SET_DC_OUT_VAL_NONE		((uint8_t)0)	/* 給電なし */
#define LC70_MEAS_SET_DC_OUT_VAL_11V		((uint8_t)1)	/* 11V */
#define LC70_MEAS_SET_DC_OUT_VAL_15V		((uint8_t)2)	/* 15V */
#define LC70_MEAS_SET_DC_OUT_VAL_11V_P		((uint8_t)3)	/* 11V+P */
#define LC70_MEAS_SET_DC_OUT_VAL_15V_P		((uint8_t)4)	/* 15V+P */

/*============================================================
	ユーザー測定/データロガー設定ファイル関連
============================================================*/
/* ユーザー測定データ配列数定義 */
#define LC70_USER_SET_USER_SAVE_FM_NUM			(12) /* FM情報記憶数 */
#define LC70_USER_SET_USER_SAVE_UP_STREAM_NUM	(12) /* CATV上り情報記憶数 */

/* 一番CHの多いCATV ALL分、FMとCATV上りとCATV ALLの情報記憶用を考慮 */
#define LC70_USER_SET_USER_IDX_MAX (LC70_CH_SET_CATV_ALL_IDX_MAX + LC70_USER_SET_USER_SAVE_FM_NUM + LC70_USER_SET_USER_SAVE_UP_STREAM_NUM + LC70_CH_SET_CATV_ALL_IDX_MAX)
#define LC70_USER_SET_USER_FLIST_IDX_MAX LC70_USER_SET_USER_FILE_MAX

/* ユーザー測定データファイル数定義 */
#define LC70_USER_SET_USER_FILE_MAX (140)

/* ユーザー測定ファイル名文字列長定義 */
#define LC70_USER_USER_FNAME_STRLEN (12 + 1)	/* +1は終端文字を考慮 */


/* データロガー設定データ配列数定義 */
#define LC70_LOGGER_SET_LOGGER_SAVE_FM_NUM			(12) /* FM情報記憶数 */
#define LC70_LOGGER_SET_LOGGER_SAVE_UP_STREAM_NUM	(12) /* CATV上り情報記憶数 */

/* 一番CHの多いCATV ALL分、FMとCATV上りとCATV ALLの情報記憶用を考慮 */
#define LC70_LOGGER_SET_LOGGER_IDX_MAX (LC70_CH_SET_CATV_ALL_IDX_MAX + LC70_LOGGER_SET_LOGGER_SAVE_FM_NUM + LC70_LOGGER_SET_LOGGER_SAVE_UP_STREAM_NUM + LC70_CH_SET_CATV_ALL_IDX_MAX)
#define LC70_LOGGER_SET_LOGGER_FLIST_IDX_MAX LC70_LOGGER_SET_LOGGER_FILE_MAX

/* データロガー設定データファイル数定義 */
#define LC70_LOGGER_SET_LOGGER_FILE_MAX (140)

/* データロガー設定ファイル名文字列長定義 */
#define LC70_LOGGER_LOGGER_FNAME_STRLEN (12 + 1)	/* +1は終端文字を考慮 */

/*============================================================
	チャンネル定義ファイル関連
============================================================*/
/* 注意:チャンネル定義データ配列数定義LC70_CH_SET_XXX_IDX_MAX変更時は
        データロガー設定データ配列数定義LC70_LOGGER_SET_LOGGER_IDX_MAXも変更すること 
		全チャンネル数(FM, CATV上りは12とみなす)の合計としているため。 */

/* チャンネル番号文字列長定義 */
#define LC70_CH_SET_CH_STRLEN	(8)

/* 偏波定義 */
#define LC70_CH_SET_WAVE_R	LC70_MEAS_SET_WAVE_R	/* 右旋(R) */
#define LC70_CH_SET_WAVE_L	LC70_MEAS_SET_WAVE_L	/* 左旋(L) */
#define LC70_CH_SET_WAVE_H	LC70_MEAS_SET_WAVE_H	/* 水平(H) */
#define LC70_CH_SET_WAVE_V	LC70_MEAS_SET_WAVE_V	/* 垂直(V) */

/*----------------------------------------
	地デジ(帯域幅6MHz)
----------------------------------------*/
/* チャンネル定義(地デジ(帯域幅6MHz))データ配列数定義 */
#define LC70_CH_SET_UHF_IDX_MAX (40)

/*----------------------------------------
	BS(帯域幅34.5MHz)
----------------------------------------*/
/* チャンネル定義(BS(帯域幅34.5MHz))データ配列数定義 */
#define LC70_CH_SET_BS_IDX_MAX (24)

/*----------------------------------------
	CS(帯域幅34.5MHz)
----------------------------------------*/
/* チャンネル定義(CS(帯域幅34.5MHz))データ配列数定義 */
#define LC70_CH_SET_CS_IDX_MAX (26)

/*----------------------------------------
	SCC-B(帯域幅27MHz)
----------------------------------------*/
/* チャンネル定義(SCC-B(帯域幅27MHz))データ配列数定義 */
#define LC70_CH_SET_SCCB_IDX_MAX (23)

/*----------------------------------------
	SCC-C(帯域幅27MHz)
----------------------------------------*/
/* チャンネル定義(SCC-C(帯域幅27MHz))データ配列数定義 */
#define LC70_CH_SET_SCCC_IDX_MAX (24)

/*----------------------------------------
	JSAT-3A(帯域幅27MHz)
----------------------------------------*/
/* チャンネル定義(JSAT-3A(帯域幅27MHz))データ配列数定義 */
#define LC70_CH_SET_JSAT3A_IDX_MAX (28)

/*----------------------------------------
	JSAT-4B(帯域幅27MHz)
----------------------------------------*/
/* チャンネル定義(JSAT-4B(帯域幅27MHz))データ配列数定義 */
#define LC70_CH_SET_JSAT4B_IDX_MAX (32)

/*----------------------------------------
	CATV ALL(帯域幅6MHz)
----------------------------------------*/
/* チャンネル定義(CATV ALL(帯域幅6MHz))データ配列数定義  */
#define LC70_CH_SET_CATV_ALL_IDX_MAX (150)

/*----------------------------------------
	CATV 90-470MHz(帯域幅6MHz)
----------------------------------------*/
/* チャンネル定義(CATV 90-470MHz(帯域幅6MHz))データ配列数定義 */
#define LC70_CH_SET_CATV_90_470MHZ_IDX_MAX (62)

/*----------------------------------------
	CATV 470-1002MHz(帯域幅6MHz)
----------------------------------------*/
/* チャンネル定義(CATV 470-1002MHz(帯域幅6MHz))データ配列数定義 */
#define LC70_CH_SET_CATV_470_1002MHZ_IDX_MAX (88)

/*----------------------------------------
	スカパー光
----------------------------------------*/
/* チャンネル定義(スカパー光(帯域幅6MHz))データ配列数定義 */
#define LC70_CH_SET_SKYP_IDX_MAX (113)

/*----------------------------------------
	PILOT
----------------------------------------*/
/* チャンネル定義(PILOT)データ配列数定義 */
#define LC70_CH_SET_PILOT_IDX_MAX (20)

/*----------------------------------------
	LTE
----------------------------------------*/
/* チャンネル定義(LTE)データ配列数定義 */
#define LC70_CH_SET_LTE_IDX_MAX (6)

/*----------------------------------------
	FM
----------------------------------------*/
/* チャンネル定義(FM)データ配列数定義 */
#define LC70_CH_SET_FM_IDX_MAX (251)

/*----------------------------------------
	CATV上り
----------------------------------------*/
/* チャンネル定義(CATV 上り)データ配列数定義 */
#define LC70_CH_SET_CATV_UP_STREAM_IDX_MAX (1001)

/*----------------------------------------
	アンテナ調整用 JSAT-3A
----------------------------------------*/
/* チャンネル定義(アンテナ調整用 JSAT-3A(帯域幅27MHz))データ配列数定義 */
#define LC70_CH_SET_JSAT3A_ANTENNA_IDX_MAX (16)

/*----------------------------------------
	アンテナ調整用 JSAT-4B
----------------------------------------*/
/* チャンネル定義(アンテナ調整用 JSAT-4B(帯域幅27MHz))データ配列数定義 */
#define LC70_CH_SET_JSAT4B_ANTENNA_IDX_MAX (16)

/*----------------------------------------
	FM(デフォルト)
----------------------------------------*/
/* チャンネル定義(FM)データ配列数定義 */
#define LC70_CH_SET_FM_DEF_IDX_MAX (12)

/*----------------------------------------
	CATV上り(デフォルト)
----------------------------------------*/
/* チャンネル定義(CATV 上り)データ配列数定義 */
#define LC70_CH_SET_CATV_UP_STREAM_DEF_IDX_MAX (12)

/*----------------------------------------
	BS/CS(帯域幅34.5MHz)
----------------------------------------*/
/* チャンネル定義(BS(帯域幅34.5MHz))データ配列数定義 */
#define LC70_CH_SET_BS_CS_IDX_MAX (LC70_CH_SET_BS_IDX_MAX + LC70_CH_SET_CS_IDX_MAX)

/*******************************************************************************
	typedef
*******************************************************************************/
/* 関数戻り値 */
typedef enum lc70_err_t {
	LC70_OK					= 0,	/* 正常終了 */
	LC70_ERR 				= -1,	/* 異常終了 */
	LC70_ERR_PARAM			= -2,	/* パラメータエラー */
	LC70_ERR_FILE			= -3,	/* ファイルアクセスエラー */
	LC70_ERR_BUSY			= -4,	/* ビジー状態 */
	LC70_ERR_PORT			= -5,	/* ポートアクセスエラー */
	LC70_ERR_BUZZ_REPEATING	= -6,	/* リピート鳴動中 */
	LC70_ERR_POWERSUPPLY	= -7,	/* 給電エラー */
	LC70_ERR_BUZZ_PRIO_BUSY	= -8,	/* 優先鳴動中 */
} LC70_ERR_T;

/* 遷移先画面種別型 */
typedef enum lc70_disp_type_t {
	LC70_DISP_TYPE_NOT_MEAS = 0,	/* 測定画面以外 */
	LC70_DISP_TYPE_METER,			/* メータ画面 */
	LC70_DISP_TYPE_CONSTA,			/* コンスタ画面 */
	LC70_DISP_TYPE_DLY_PRF,			/* 遅延プロファイル画面 */
	LC70_DISP_TYPE_GRAPH,			/* グラフ画面 */
	LC70_DISP_TYPE_LIST_MULTI,		/* リスト画面(マルチ) */
	LC70_DISP_TYPE_LIST_LOGGER,		/* リスト画面(データロガー) */
	LC70_DISP_TYPE_ANTENNA_ADJUST	/* JCSAT アンテナ調整(メータ) */
} LC70_DISP_TYPE_T;

/* プロダクト情報 */
typedef struct lc70_product_info_t{
	char cModelCode[LC70_MODELCODE_SIZE];	/* 機種コード ヌル終端文字列 */
	char cOptInfo[LC70_OPTINFO_SIZE];		/* オプション情報 ヌル終端文字列 */
	char cSerialNo[LC70_SERIALNO_SIZE];		/* シリアル番号 ヌル終端文字列 */
	char cBootPrgVer[LC70_VERSION_SIZE];	/* ブートプログラムバージョン ヌル終端文字列 */
	char cMainPrgVer[LC70_VERSION_SIZE];	/* メインプログラムバージョン ヌル終端文字列 */
	char cSubPrgVer[LC70_VERSION_SIZE];		/* サブプログラムバージョン ヌル終端文字列 */
	char cQtVer[LC70_VERSION_SIZE];			/* Qtバージョン ヌル終端文字列 */
	char cProductVer[LC70_VERSION_SIZE];	/* プロダクトバージョン ヌル終端文字列 */
}LC70_PRODUCT_INFO_T;

/* 故障情報 */
typedef struct lc70_fail_info_t {
	uint16_t			usCode;		/* 故障コード */
	uint8_t				ucStat;		/* 故障状態 発生/復旧 */
	uint8_t				ucCtl;		/* 故障時の動作 */
	uint16_t			usWait;		/* メッセージの再表示までの待機時間[秒] 0の時は再表示しない */
	uint16_t			usDummy;	/* 予備 */
	uint8_t				ucAddInfo[LC70_FAIL_ADD_INFO_NUM];	/* 追加情報 */
} LC70_FAIL_INFO_T;

/* USB TypeA、 SDカード状態 */
typedef enum lc70_strage_t {
	LC70_STRAGE_NONE					= 0,	/* 未装着 */
	LC70_STRAGE_NON_SUPPORT_FORMAT		= 1,	/* 装着(未対応フォーマット) */
	LC70_STRAGE_FORMAT					= 2,	/* 装着(フォーマット済) フォーマット形式:vfat */
	LC70_STRAGE_UNFORMAT				= 3,	/* 装着(未フォーマット) */
	LC70_STRAGE_UNACQ					= 0xFF,	/* ストレージ状態未取得 */
} LC70_STRAGE_T;

/* USB TypeC 給電状態 */
typedef enum lc70_usbc_t {
	LC70_USBC_DISCONNECT		= 0,	/* 未装着 */
	LC70_USBC_CONNECT			= 1,	/* 装着 */
	LC70_USBC_POWERED			= 2,	/* 駆動中 */
	LC70_USBC_UNACQ				= 0xFF,	/* ストレージ状態未取得 */
} LC70_USBC_T;


/* デバイス状態 */
typedef struct lc70_dev_stat_t {
	uint16_t		usAngle;		/* 方位 (0～359) 0:北 90:東 180:南 270:西 FFFEh:測定停止中 FFFFh:無効データ */
	uint8_t			ucBatt;			/* バッテリ状態(LC70_BATT_XX定義参照) */
	uint8_t			ucBatv;			/* バッテリ残量値(%) 
									     正常値 : 0〜100
									     不定値(I2C異常含める) : FFh
									   不定値の場合、バッテリ状態(ucBatt)の値は1Fhとなる*/
	LC70_STRAGE_T	usba;			/* USB TypeA状態 */
	LC70_STRAGE_T	sd;				/* SDカード状態 */
	LC70_USBC_T		usbc;			/* USB TypeC 給電状態 */
	uint8_t			ucBatempH;		/* バッテリ使用可能時間(時)
										正常値:00～11
										測定結果なし(I2C異常、測定結果異常):FFh
									*/
	uint8_t			ucBatempM;		/* バッテリ使用可能時間(分)
										正常値:00～59
										測定結果なし(I2C異常、測定結果異常):FFh
									*/
} LC70_DEV_STAT_T;

/* キー(ボタン)ID */
typedef enum lc70_key_id_t {
	LC70_KEY_ID_MENU			= 0,	/* MENU */
	LC70_KEY_ID_BAND			,		/* BAND */
	LC70_KEY_ID_HOME			,		/* HOME */
	LC70_KEY_ID_USER			,		/* USER */
	LC70_KEY_ID_ESCAPE			,		/* ESCAPE */
	LC70_KEY_ID_SCAN			,		/* SCAN */
	LC70_KEY_ID_UP				,		/* UP */
	LC70_KEY_ID_DOWN			,		/* DOWN */
	LC70_KEY_ID_RIGHT			,		/* RIGHT */
	LC70_KEY_ID_LEFT			,		/* LEFT */
	LC70_KEY_ID_ENTER			,		/* ENTER */
	LC70_KEY_ID_CH_DOWN			,		/* DOWN */
	LC70_KEY_ID_CH_UP			,		/* UP */
	LC70_KEY_ID_SCR_SAVE		,		/* 画面SAVE */
	LC70_KEY_ID_DATA_SAVE		,		/* データSAVE */
	LC70_KEY_ID_POWER_SUPPLY	,		/* 給電 */
	LC70_KEY_ID_POWER			,		/* 電源 */
	LC70_KEY_ID_MAX				,		/* キー数 */
} LC70_KEYID_T;

/* キー(ボタン) ON/OFF */
typedef enum lc70_key_t {
	LC70_KEY_ON					= 0,	/* ON */
	LC70_KEY_OFF				= 1,	/* OFF */
} LC70_KEY_T;

/* キー(ボタン) 入力状態 */
typedef struct lc70_key_stat_t {
	LC70_KEY_T	stat[LC70_KEY_ID_MAX];
} LC70_KEY_STAT_T;

/* 入力信号 */
typedef enum lc70_input_t {
   LC70_INPUT_COAXIAL 			= 0,  /* 同軸ケーブル */
   LC70_INPUT_OPTICAL 			= 1,  /* 光ケーブル */
} LC70_INPUT_T;

/* 給電設定 */
typedef enum lc70_power_supply_t {
   LC70_POWER_SUPPLY_OFF = 0,	/* 給電なし */
   LC70_POWER_SUPPLY_11V,		/* 11V */
   LC70_POWER_SUPPLY_15V,		/* 15V */
   LC70_POWER_SUPPLY_11V_P,		/* 11V+P */
   LC70_POWER_SUPPLY_15V_P,		/* 15V+P */
} LC70_POWER_SUPPLY_T;

/* 有効閾値設定ブロック */
typedef struct lc70_data_thr_t {
	uint16_t	usBdSys;			/* 放送方式 */
	uint16_t	usBand;				/* バンド */
	float32_t	fLevel;				/* レベル閾値 */
	float32_t	fCNR;				/* CNR */
	float32_t	fBER;				/* BER */
} LC70_DATA_THR_T;

/* 測定状態 */
typedef struct lc70_meas_stat_t {
	uint32_t	ulMeasStat;			/* 測定状態 0:測定不可 1:測定可 */
	uint16_t	usInputStat;		/* (光/同軸)入力切替状態 0:同軸 1:光 0xffff:入力切替中 */
	uint8_t		ucRsv[6];			/* 予備 */
} LC70_MEAS_STAT_T;

/* スタンバイ状態 */
typedef struct lc70_standby_stat_t {
	uint32_t	ulStandbyStat;		/* スタンバイ状態 0:スタンバイ状態 1:ウェイクアップ状態 2:要求処理中 */
	uint8_t		ucRsv[4];			/* 予備 */
} LC70_STANDBY_STAT_T;

/* ガードインターバル長列挙型 */
typedef enum lc70_isdbt_gi_t {
	LC70_ISDBT_GI_1_32 = 0,	/* 1/32  31.5us */
	LC70_ISDBT_GI_1_16,		/* 1/16  63.0us */
	LC70_ISDBT_GI_1_8,		/* 1/8  126.0us */
	LC70_ISDBT_GI_1_4,		/* 1/4  252.0us */
} LC70_ISDBT_GI_T;

/* チャンネル別測定条件 */
typedef struct lc70_meas_single_t {
	uint32_t	ulFreq;						/* 実放送周波数[kHz] */
	uint32_t	ulLoFreq;					/* 局部発信周波数[kHz] */
	uint16_t	usBdSys;					/* 放送方式 */
											/* BS/CS/JCSAT/SCCの場合は、放送方式指定無し
											  （LC70_BD_SYS_NONE)の設定が可能。
				  							  （ISDBS/ISDBS3、DVBS/DVBS2を自動選択する） */
	uint16_t	usBand;						/* バンド */
	uint16_t	usMod;						/* 変調方式 */
	uint16_t	usCondition;				/* 測定条件 */
	uint8_t		ucStrChan[STR_CHAN_LEN];	/* チャンネル番号文字列(NULL終端なし、8文字に足りない場合はスペースで埋める) */
	uint8_t		ucOutputEnb;				/* 給電有効/無効 0:無効(マニュアル測定) 
															 1:有効(ユーザー/ロガー、及びユーザー/ロガー設定のSCAN時) */
	LC70_POWER_SUPPLY_T		powerSupply;	/* 給電設定 */
} LC70_MEAS_SINGLE_T;

/* コンスタレーション収集件数 */
typedef enum lc70_consta_num_t {
	LC70_CONSTA_1000 = 1000,		/* 1000点 */
	LC70_CONSTA_2000 = 2000,		/* 2000点 */
	LC70_CONSTA_4000 = 4000,		/* 4000点 */
} LC70_CONSTA_NUM_T;

/* コンスタレーションデータ  */
struct lc70_consta_t {
	int8_t		x;
	int8_t		y;
}  __attribute__((__packed__));

typedef struct lc70_consta_t LC70_CONSTA_T;

/* シングルチャンネル測定結果 */
typedef struct lc70_meas_single_result_t {
	uint8_t			ucLock;							/* ロック状態 0:アンロック 1:ロック */
	uint8_t			ucDummy[3];						/* 予備 */
	uint16_t		usStat;							/* 収集ステータス LC70_DATA_MSK_XX定義参照 */
	uint16_t		usMesCondision;					/* 測定条件設定値 LC70_DATA_MSK_XX定義参照(bit0～4まで) */
	uint8_t			ucDummy2[2];					/* 予備 */
	uint16_t		usBdSys;						/* 放送方式 LC70_BD_SYS_XX定義参照 */
	uint32_t		ulLevel;						/* LEVEL [x1/10] */
	uint32_t		ulCnr;							/* CNR or MER [x1/10] どちらかは収集ステータスで判断 */
	uint32_t		ulBerTotalBitNum;				/* 総データ数 BER=エラー数/総データ数 */
	uint32_t		ulBerErrBitNum;					/* エラー数   BER=エラー数/総データ数 */
	uint16_t		usTsId;							/* TS-ID (未使用 0xFFFF) */
	uint8_t			ucGi;							/* ガードインターバル長 LC70_ISDBT_GI_T型参照 */
	uint8_t			ucLayer;						/* 64QAMのレイヤ（ISDBTのみ有効）0:レイヤなし 1Layer:A 2:LayerB 3:LayerC */
	uint32_t		ulModBitPtrn;					/* 変調方式 LC70_SETMOD_XX定義参照 */
	int16_t			sConstaNum;						/* コンスタレーションデータ読出点数 */
	uint8_t			ucDummy3[2];					/* 予備 */
	LC70_CONSTA_T	consta[LC70_MAX_CONSTA_RD_NUM];	/* コンスタレーションデータ */
} LC70_MEAS_SINGLE_RESULT_T;

/* マルチチャンネル測定条件 */
typedef struct lc70_meas_multi_t {
	int16_t					sRegNum;					/* 登録件数(1～120) */
	uint8_t					ucDummy[2];					/* 予備(0固定) */
	LC70_MEAS_SINGLE_T		single[LC70_MAX_REG_CH];	/* 測定インデックス毎の測定条件 */
} LC70_MEAS_MULTI_T;

/* マルチチャンネル測定結果 */
typedef struct lc70_meas_multi_result_t {
	uint8_t			ucLock;							/* ロック状態 0:アンロック 1:ロック */
	uint8_t			ucDummy[3];						/* 予備 */
	uint16_t		usStat;							/* 収集ステータス LC70_DATA_MSK_XX定義参照 */
	uint16_t		usCondition;					/* 測定条件設定値 LC70_DATA_MSK_XX定義参照(bit0～4まで) */
	uint8_t			ucReadIdx;						/* 読出データインデックス */
	uint8_t			ucCurrIdx;						/* カレント測定中インデックス  */
													/*   0xFF : 全測定完了(SCAN時) */
	uint16_t		usBdSys;						/* 放送方式 LC70_BD_SYS_XX定義参照 */
	uint32_t		ulLevel;						/* LEVEL [x1/10] */
	uint32_t		ulCnr;							/* CNR or MER [x1/10] どちらかは収集ステータスで判断 */
	uint32_t		ulBerTotalBitNum;				/* 総データ数 BER=エラー数/総データ数 */
	uint32_t		ulBerErrBitNum;					/* エラー数   BER=エラー数/総データ数 */
	uint16_t		usTsId;							/* TS-ID (未使用 0xFFFF) */
	uint8_t			ucGi;							/* ガードインターバル長 LC70_ISDBT_GI_T型参照 */
	uint8_t			ucLayer;						/* 64QAMのレイヤ（ISDBTのみ有効）0:レイヤなし 1Layer:A 2:LayerB 3:LayerC */
	uint32_t		ulModBitPtrn;					/* 変調方式 LC70_SETMOD_XX定義参照  */	
} LC70_MEAS_MULTI_RESULT_T;

/* 遅延プロファイル測定結果 */
typedef struct lc70_meas_dly_prf_result_t {
	uint16_t		usStat;							/* 収集ステータス */
													/* 0:データなし 
													   1:データ収集中 
													   2:データ有効(全ブロック収集完了)
													   3:収集要求なし
													 */
	int8_t			ucDlyPrfData[LC70_DLY_PRF_NUM]; /* 遅延プロファイルデータ 0～-100(db) (インデックスxt時間のデータ) t=0.1640625 
													       [0] : 時刻(512 - 0)		* -tのパワー(-84us)
													       [1] : 時刻(512 - 1)		* -tのパワー(-83.8359375us)
														   ..途中省略..
													     [510] : 時刻(512 - 510)	* -tのパワー(-0.328125us)
														 [511] : 時刻(512 - 511)	* -tのパワー(-0.1640625us)
													     [512] : 時刻(0) 			* -tのパワー(0.0us))
													     [513] : 時刻(1)			* -tのパワー(0.1640625us)
														   ..途中省略..
													    [2046] : 時刻(1535)			* -tのパワー(251.8359375us)
													    [2047] : 時刻(1536)			* -tのパワー(252us)
													*/
} LC70_MEAS_DLY_PRF_RESULT_T;

/* マルチチャンネルフォーカスチャンネル優先測定モード */
typedef enum lc70_fmode_t {
	LC70_FMODE_REALTIME 	= 0,					/* 即時測定実施 */
	LC70_FMODE_CHGCOND  	= 1						/* 測定条件変更 */
} LC70_FMODE_T;

/* 光測定結果 */
typedef struct lc70_meas_opt_result_t {
	int32_t		lOptPow;							/* 光パワー[x0.01dBm] 例:-650 → -6.50dBm */
} LC70_MEAS_OPT_RESULT_T;

/* DC測定結果 */
typedef struct lc70_meas_dc_result_t {
	uint32_t		ulDcV;							/* DC電圧[x0.01V] */
} LC70_MEAS_DC_RESULT_T;

/* プログラムアップデート情報 */
typedef struct lc70_prg_update_t {
	uint8_t		ucMainVer[LC70_VERSION_SIZE];		/* メインプログラムバージョン */
	uint8_t		ucSubVer[LC70_VERSION_SIZE];		/* サブプログラムバージョン */
} LC70_PRG_UPDATE_T;

/* ブザー鳴動パターン */
typedef enum lc70_buzz_t {
	LC70_BUZZ_OFF = 0,					/* 音なし(強制ブザー音量制御で音量変更のみする場合) */
	LC70_BUZZ_VOL_CHG,					/* 音量変更時、
										   受信良好時 : シングル測定中(リピート鳴動を想定)
										   のブザー出力 */
	LC70_BUZZ_ALL_CH_SCAN,				/* 全ch scan終了時のブザー出力 */
	LC70_BUZZ_ERR,						/* エラー時のブザー出力 */
	LC70_BUZZ_1CH_SCAN,					/*  1ch scan終了時のブザー出力(受信良好時) */

	LC70_BUZZ_MAX,						/* 終端 */
} LC70_BUZZ_T;

/* ブザーモード */
typedef enum lc70_buzz_mode_t {
	LC70_BUZZ_MODE_ONESHOT = 0,					/* 1回だけ鳴動 */
	LC70_BUZZ_MODE_REPEAT,						/* リピート鳴動 */
	LC70_BUZZ_MODE_STOP,						/* 鳴動停止 */
} LC70_BUZZ_MODE_T;

/* ブザー音量 */
typedef enum lc70_buzz_vol_t {
	LC70_BUZZ_VOL_MUTE = 0,				/* ミュート */
	LC70_BUZZ_VOL_MIN,					/* ボリューム小 */	
	LC70_BUZZ_VOL_MID,					/* ボリューム中 */	
	LC70_BUZZ_VOL_MAX,					/* ボリューム大 */	
} LC70_BUZZ_VOL_T;

/* 明るさパターン */
typedef enum lc70_brightness_t {
	LC70_BRIGHTNESS_MIN		= 1,					/* 暗 */
	LC70_BRIGHTNESS_MID		= 2,					/* 普 */
	LC70_BRIGHTNESS_MAX		= 3,					/* 明 */
} LC70_BRIGHTNESS_T;

/* キャリブレーション中心点型 */
typedef struct lc70_angle_cal_center_point_t {
	float32_t flX;	/* x軸の値 */
	float32_t flY;	/* y軸の値 */
	float32_t flZ; 	/* z軸の値 */
} LC70_ANGLE_CAL_CENTER_POINT_T;

/* 方位キャリブレーション状態構造体型 */
typedef struct lc70_angle_cal_stat_t {
	int32_t		lStatus;						/* キャリブレーション状態 */
												/* ANGLE_CAL_STAT_XXXの値が入る*/
	LC70_ANGLE_CAL_CENTER_POINT_T centerPoint1;	/* 中心点1 (予備) */
	LC70_ANGLE_CAL_CENTER_POINT_T centerPoint2;	/* 中心点2 (予備) */
	LC70_ANGLE_CAL_CENTER_POINT_T centerPoint3;	/* 中心点3 (予備) */
} LC70_ANGLE_CAL_STAT_T;


/* 方位キャリブレーション詳細情報 */
typedef struct lc70_angle_cal_info_detail_t {
	float32_t		flRoll;		/* ロール[°] */
	float32_t		flPitch;	/* ピッチ[°] */
	float32_t		flAx;		/* 加速度データ x軸 */
	float32_t		flAy;		/* 加速度データ y軸 */
	float32_t		flAz;		/* 加速度データ z軸 */
	float32_t		flMx;		/* 磁気データ x軸 */
	float32_t		flMy;		/* 磁気データ y軸 */
	float32_t		flMz;		/* 磁気データ z軸 */
	float32_t		flAxRot;	/* 回転後加速度データ x軸 */
	float32_t		flAyRot;	/* 回転後加速度データ y軸 */
	float32_t		flAzRot;	/* 回転後加速度データ z軸 */
	float32_t		flMxRot;	/* 回転後磁気データ x軸 */
	float32_t		flMyRot;	/* 回転後磁気データ y軸 */
	float32_t		flMzRot;	/* 回転後磁気データ z軸 */
} LC70_ANGLE_CAL_INFO_DETAIL_T;


/* 給電情報 */
typedef struct lc70_powersupply_info_t {
	uint8_t		ucPowerSupply;		/* 給電状態(LC70_MEAS_SET_DC_OUT_VAL_XXX定義参照) */
	uint8_t		ucVolt;				/* 電圧(V) */
	uint16_t	usAdVal;			/* 電流AD値(生値) */
	uint32_t	ulCurrentM;			/* 電流(mA) */
	uint32_t	ulElecPowerM;		/* 電力(mW) */
} LC70_POWERSUPPLY_INFO_T;

/*============================================================
	設定ファイル関連全般
============================================================*/
/* 設定ファイルID 列挙型 */
typedef enum lc70_file_id_t {
	LC70_FILE_ID_SYS_SET_POWOFF = 0,		/* システム設定ファイル(POWER OFF時間(分)) */
	LC70_FILE_ID_SYS_SET_VOLUME,			/* システム設定ファイル(音量設定) */
	LC70_FILE_ID_SYS_SET_BRIGHTNESS,		/* システム設定ファイル(明るさ設定) */

	LC70_FILE_ID_MEAS_SET_LOCAL_FREQ,		/* 測定設定ファイル(局部発信周波数) */
	LC70_FILE_ID_MEAS_SET_THRD,				/* 測定設定ファイル(閾値) */
	LC70_FILE_ID_MEAS_SET_CNRMER,			/* 測定設定ファイル(CNR/MER切替) */
	LC70_FILE_ID_MEAS_SET_CATV_FREQ,		/* 測定設定ファイル(CATVチャンネル周波数) */
	LC70_FILE_ID_MEAS_SET_CABLE_LOSS,		/* 測定設定ファイル(ケーブル損失) */
	LC70_FILE_ID_MEAS_SET_CABLE_LOSS_ENB,	/* 測定設定ファイル(ケーブル損失有効) */
	LC70_FILE_ID_MEAS_SET_INPUT,			/* 測定設定ファイル(入力切替) */
	LC70_FILE_ID_MEAS_SET_CATV_MOD,			/* 測定設定ファイル(CATVの変調方式選択) */
	LC70_FILE_ID_MEAS_SET_DC_OUT,			/* 測定設定ファイル(給電電圧) */
	LC70_FILE_ID_MEAS_SET_OPT_MEAS,			/* 測定設定ファイル(光測定選択範囲) */
	LC70_FILE_ID_MEAS_SET_CONSTA_NUM,		/* 測定設定ファイル(コンスタレーション表示ポイント数選択範囲) */

	LC70_FILE_ID_USER_SET_USER,				/* ユーザー測定ファイル */
	LC70_FILE_ID_USER_SET_USER_FLIST,		/* ユーザー測定ファイル名リストファイル */

	LC70_FILE_ID_CH_SET_UHF,				/* チャンネル定義(地デジ(帯域幅6MHz))ファイル */
	LC70_FILE_ID_CH_SET_BS,					/* チャンネル定義(CS(帯域幅34.5MHz))ファイル */
	LC70_FILE_ID_CH_SET_CS,					/* チャンネル定義(BS(帯域幅34.5MHz))ファイル */
	LC70_FILE_ID_CH_SET_SCCB,				/* チャンネル定義(SCC-B(帯域幅27MHz))ファイル */
	LC70_FILE_ID_CH_SET_SCCC,				/* チャンネル定義(SCC-C(帯域幅27MHz))ファイル */
	LC70_FILE_ID_CH_SET_JSAT3A,				/* チャンネル定義(JSAT-3A(帯域幅27MHz))ファイル */
	LC70_FILE_ID_CH_SET_JSAT4B,				/* チャンネル定義(JSAT-4B(帯域幅27MHz))ファイル */
	LC70_FILE_ID_CH_SET_CATV_ALL,			/* チャンネル定義(CATV ALL(帯域幅6MHz))ファイル */
	LC70_FILE_ID_CH_SET_CATV_90_470MHZ,		/* チャンネル定義(CATV 90-470MHZ(帯域幅6MHz))ファイル */
	LC70_FILE_ID_CH_SET_CATV_470_1002MHZ,	/* チャンネル定義(CATV 470-1002(帯域幅6MHz))ファイル */
	LC70_FILE_ID_CH_SET_SKYP,				/* チャンネル定義(スカパー光(帯域幅6MHz))ファイル */
	LC70_FILE_ID_CH_SET_PILOT,				/* チャンネル定義(PILOT)ファイル */
	LC70_FILE_ID_CH_SET_LTE,				/* チャンネル定義(LTE)ファイル */
	LC70_FILE_ID_CH_SET_FM,					/* チャンネル定義(FM)ファイル */

	LC70_FILE_ID_MEAS_SET_MANU_BDSYS_MOD,	/* 測定設定ファイル(マニュアル測定 放送方式、変調方式選択) */
	LC70_FILE_ID_MEAS_SET_BDSYS_CONV,		/* 測定設定ファイル(放送方式チューナ部変換) */
	LC70_FILE_ID_MEAS_SET_CATV_BDSYS_CONV,	/* 測定設定ファイル(CATV放送方式チューナ部変換) */

	LC70_FILE_ID_CH_SET_CATV_UP_STREAM,		/* チャンネル定義(CATV上り)ファイル */

	LC70_FILE_ID_PMEAS_SET_PMEAS_MNG,		/* 測定管理プロセス設定(測定管理テーブル)ファイル */
	LC70_FILE_ID_LOGGER_SET_LOGGER,			/* データロガー設定ファイル */
	LC70_FILE_ID_LOGGER_SET_LOGGER_FLIST,	/* データロガー設定ファイル名リストファイル */

	LC70_FILE_ID_CH_SET_JSAT3A_ANTENNA,		/* チャンネル定義(アンテナ調整用 JSAT-3A(帯域幅27MHz))ファイル */
	LC70_FILE_ID_CH_SET_JSAT4B_ANTENNA,		/* チャンネル定義(アンテナ調整用 JSAT-4B(帯域幅27MHz))ファイル */

	LC70_FILE_ID_CH_SET_FM_DEF,				/* チャンネル定義(FM(デフォルト))ファイル */
	LC70_FILE_ID_CH_SET_CATV_UP_STREAM_DEF,	/* チャンネル定義(CATV上り(デフォルト))ファイル */

	LC70_FILE_ID_CH_SET_BS_CS,				/* チャンネル定義(BS/CS(帯域幅34.5MHz))ファイル */

	LC70_FILE_ID_USER_SET_USER_USB1,			/* ユーザー測定ファイル                 取込みデータ1用 */
	LC70_FILE_ID_USER_SET_USER_USB1_FLIST,		/* ユーザー測定ファイル名リストファイル 取込みデータ1用 */
	LC70_FILE_ID_USER_SET_USER_USB2,			/* ユーザー測定ファイル                 取込みデータ2用 */
	LC70_FILE_ID_USER_SET_USER_USB2_FLIST,		/* ユーザー測定ファイル名リストファイル 取込みデータ2用 */
	LC70_FILE_ID_LOGGER_SET_LOGGER_USB1,		/* データロガー設定ファイル                 取込みデータ1用 */
	LC70_FILE_ID_LOGGER_SET_LOGGER_USB1_FLIST,	/* データロガー設定ファイル名リストファイル 取込みデータ1用 */
	LC70_FILE_ID_LOGGER_SET_LOGGER_USB2,		/* データロガー設定ファイル                 取込みデータ2用 */
	LC70_FILE_ID_LOGGER_SET_LOGGER_USB2_FLIST,	/* データロガー設定ファイル名リストファイル 取込みデータ2用 */

	LC70_FILE_ID_MAX,						/* 定義数 */
} LC70_FILE_ID_T;


/*============================================================
	システム設定ファイル関連
============================================================*/
/*----------------------------------------
	POWER OFF時間(分)
----------------------------------------*/
/* システム設定(POWER OFF時間(分))の1行分データ構造体 */
typedef struct lc70_sys_set_powoff_row_t{
	uint8_t ucPowerOffSelect[LC70_SYS_SET_POWOFF_SELECT_NUM];		/* POWER OFF時間(分) 選択範囲 ※0はOFFとして扱う */
	uint8_t ucPowerOff;												/* POWER OFF時間(分)          ※0はOFFとして扱う */
}LC70_SYS_SET_POWOFF_ROW_T;	/* 8byte */

/* システム設定(POWER OFF時間(分))データ構造体 */
typedef struct lc70_sys_set_powoff_t{
	LC70_SYS_SET_POWOFF_ROW_T sysSetPowoffRow[LC70_SYS_SET_POWOFF_IDX_MAX];
}LC70_SYS_SET_POWOFF_T;		/* 8byte */

/*----------------------------------------
	音量設定
----------------------------------------*/
/* システム設定(音量設定)の1行分データ構造体 */
typedef struct lc70_sys_set_volume_row_t{
	uint8_t ucVolumeSelect[LC70_SYS_SET_VOLUME_SELECT_NUM];		/* 音量設定 選択範囲 */
	uint8_t ucVolume;											/* 音量設定 */
}LC70_SYS_SET_VOLUME_ROW_T;	/* 8byte */

/* システム設定(音量設定)データ構造体 */
typedef struct lc70_sys_set_volume_t{
	LC70_SYS_SET_VOLUME_ROW_T sysSetVolumeRow[LC70_SYS_SET_VOLUME_IDX_MAX];
}LC70_SYS_SET_VOLUME_T;		/* 8byte */

/*----------------------------------------
	明るさ設定
----------------------------------------*/
/* システム設定(明るさ設定)の1行分データ構造体 */
typedef struct lc70_sys_set_brightness_row_t{
	uint8_t ucBrightnessSelect[LC70_SYS_SET_BRIGHTNESS_SELECT_NUM];		/* 明るさ設定 選択範囲 */
	uint8_t ucBrightness;												/* 明るさ設定 */
}LC70_SYS_SET_BRIGHTNESS_ROW_T;	/* 4byte */

/* システム設定(明るさ設定)データ構造体 */
typedef struct lc70_sys_set_brightness_t{
	LC70_SYS_SET_BRIGHTNESS_ROW_T sysSetBrightnessRow[LC70_SYS_SET_BRIGHTNESS_IDX_MAX];
}LC70_SYS_SET_BRIGHTNESS_T;		/* 4byte */

/*============================================================
	測定設定ファイル関連
============================================================*/
/* バンド定義列挙型 */
typedef enum {
	LC70_BAND_UNDEF=0,
	LC70_BAND_UHF,
	LC70_BAND_BS,
	LC70_BAND_CS,
	LC70_BAND_JCSAT3,
	LC70_BAND_JCSAT4,
	LC70_BAND_SCCB,
	LC70_BAND_SCCC,
	LC70_BAND_CATV_ALL,
	LC70_BAND_CATV_90_470MHZ,
	LC70_BAND_CATV_470_1002MHZ,
	LC70_BAND_PILOT,
	LC70_BAND_SKYP,
	LC70_BAND_LTE,
	LC70_BAND_FM,
	LC70_BAND_CATV_UP_STREAM,
	LC70_BAND_FM_DEF,
	LC70_BAND_CATV_UP_STREAM_DEF,
	LC70_BAND_BS_CS,
	LC70_BAND_END
} LC70_BAND_T;

/*----------------------------------------
	局部発信周波数設定
----------------------------------------*/
/* 測定設定(局部発信周波数)の1行分データ構造体 */
typedef struct lc70_meas_set_local_freq_row_t{
	uint8_t ucBand;				/* band 値はLC70_BAND_T型を参照 */
	uint8_t ucWave;				/* 偏波 */
	uint8_t ucDummy[2];			/* ダミー */
	uint32_t ulLocalFreq1;		/* 局部発信周波数1[kHz] */
	uint32_t ulLocalFreq2;		/* 局部発信周波数2[kHz] */
	uint32_t ulLocalFreq3;		/* 局部発信周波数3[kHz] */
	uint32_t ulLocalFreq4;		/* 局部発信周波数4[kHz] */
	uint32_t ulLocalFreq5;		/* 局部発信周波数5[kHz] */
	uint32_t ulLocalFreqUser;	/* 局部発信周波数ユーザ設定[kHz] */
}LC70_MEAS_SET_LOCAL_FREQ_ROW_T;	/* 28byte */

/* 測定設定(局部発信周波数)データインデックス 列挙型 */
typedef enum {
	LC70_MEAS_SET_LOCAL_FREQ_IDX_BS_R = 0,		/*  0: BS 右旋(R) */
	LC70_MEAS_SET_LOCAL_FREQ_IDX_BS_L,			/*  1: BS 右旋(L) */
	LC70_MEAS_SET_LOCAL_FREQ_IDX_CS_R,			/*  2: CS(N-SAT110) 右旋(R) */
	LC70_MEAS_SET_LOCAL_FREQ_IDX_CS_L,			/*  3: CS(N-SAT110) 左旋(L) */
	LC70_MEAS_SET_LOCAL_FREQ_IDX_JCSAT3_H,		/*  4: JCSAT3 水平(H) */
	LC70_MEAS_SET_LOCAL_FREQ_IDX_JCSAT3_V,		/*  5: JCSAT3 垂直(V) */
	LC70_MEAS_SET_LOCAL_FREQ_IDX_JCSAT4_H,		/*  6: JCSAT4 水平(H) */
	LC70_MEAS_SET_LOCAL_FREQ_IDX_JCSAT4_V,		/*  7: JCSAT4 垂直(V) */
	LC70_MEAS_SET_LOCAL_FREQ_IDX_SCCB_H,		/*  8: SCC-B 水平(H) */
	LC70_MEAS_SET_LOCAL_FREQ_IDX_SCCB_V,		/*  9: SCC-B 垂直(V) */
	LC70_MEAS_SET_LOCAL_FREQ_IDX_SCCC_H,		/* 10: SCC-C 水平(H) */
	LC70_MEAS_SET_LOCAL_FREQ_IDX_SCCC_V,		/* 11: SCC-C 垂直(V) */
	
	LC70_MEAS_SET_LOCAL_FREQ_IDX_MAX
} LC70_MEAS_SET_LOCAL_FREQ_IDX_T;

/* 測定設定(局部発信周波数)データ構造体 */
typedef struct lc70_meas_set_local_freq_t{
	LC70_MEAS_SET_LOCAL_FREQ_ROW_T measSetLocalFreqRow[LC70_MEAS_SET_LOCAL_FREQ_IDX_MAX];
}LC70_MEAS_SET_LOCAL_FREQ_T;		/* 504(28 * 18)byte */

/*----------------------------------------
	閾値設定
----------------------------------------*/
/* 測定設定(閾値)データ構造体(LEVEL) */
typedef struct lc70_meas_set_thrd_dat_level_t{
	int32_t lMin;		/* 閾値 最小値 */
	int32_t lLow;		/* 閾値 受信不可 */
	int32_t lHigh;		/* 閾値 受信可 */
	int32_t lMax;		/* 閾値 最大値 */
}LC70_MEAS_SET_THRD_DAT_LEVEL_T;	/* 16byte */

/* 測定設定(閾値)データ構造体(MER,CN) */
typedef struct lc70_meas_set_thrd_dat_mer_t{
	uint32_t ulMin;		/* 閾値 最小値   【x1/10】 */
	uint32_t ulLow;		/* 閾値 余裕度低 【x1/10】 */
	uint32_t ulHigh;	/* 閾値 余裕度高 【x1/10】 */
	uint32_t ulMax;		/* 閾値 最大値   【x1/10】 */
}LC70_MEAS_SET_THRD_DAT_MER_T;		/* 16byte */

/* 測定設定(閾値)データ浮動小数点構成 構造体(BER) */
typedef struct lc70_meas_set_thrd_float_t{
	uint32_t ulMantissa;				/* 仮数部 【x1/100】*/
	int32_t lExponent;					/* 指数部 【x100】  */
}LC70_MEAS_SET_THRD_FLOAT_T;		/*  8byte */

/* 測定設定(閾値)データ構造体(BER) */
typedef struct lc70_meas_set_thrd_dat_ber_t{
	LC70_MEAS_SET_THRD_FLOAT_T min;		/* 閾値 最小値 */
	LC70_MEAS_SET_THRD_FLOAT_T low;		/* 閾値 余裕度低 */
	LC70_MEAS_SET_THRD_FLOAT_T high;	/* 閾値 余裕度高 */
	LC70_MEAS_SET_THRD_FLOAT_T max;		/* 閾値 最大値 */
}LC70_MEAS_SET_THRD_DAT_BER_T;		/* 32byte */

/* 測定設定(閾値)の1行分データ構造体 */
typedef struct lc70_meas_set_thrd_row_t{
	uint8_t ucBand;							/* band 値はLC70_BAND_T型を参照 */
	uint8_t ucSpec;							/* 規格 値はLC70_BD_SYS_XXX定義を参照 */
	uint8_t ucDummy[2];						/* ダミー */
	uint32_t ulModBit;						/* 変調方式 ビットパターン ビット値はLC70_SETMOD_XXX定義を参照 */
	LC70_MEAS_SET_THRD_DAT_LEVEL_T level;	/* 閾値 LEVEL */
	LC70_MEAS_SET_THRD_DAT_MER_T mer;		/* 閾値 MER */
	LC70_MEAS_SET_THRD_DAT_BER_T ber;		/* 閾値 BER */
	LC70_MEAS_SET_THRD_DAT_MER_T cn;		/* 閾値 CN */
}LC70_MEAS_SET_THRD_ROW_T;			/* 88byte */

/* 測定設定(閾値)データインデックス 列挙型 */
typedef enum {
	LC70_MEAS_SET_THRD_IDX_UHF_ISDBT = 0,		/*  0: UHF(地デジ) */
	LC70_MEAS_SET_THRD_IDX_BS_ISDBS,			/*  1: BS ISDBS */
	LC70_MEAS_SET_THRD_IDX_BS_ISDBS3,			/*  2: BS ISDBS3 */
	LC70_MEAS_SET_THRD_IDX_CS_ISDBS,			/*  3: CS ISDBS */
	LC70_MEAS_SET_THRD_IDX_CS_ISDBS3,			/*  4: CS ISDBS3 */
	LC70_MEAS_SET_THRD_IDX_JCSAT3_DVBS,			/*  5: JCSAT3 DVBS */
	LC70_MEAS_SET_THRD_IDX_JCSAT3_DVBS2,		/*  6: JCSAT3 DVBS2 */
	LC70_MEAS_SET_THRD_IDX_JCSAT4_DVBS,			/*  7: JCSAT4 DVBS */
	LC70_MEAS_SET_THRD_IDX_JCSAT4_DVBS2,		/*  8: JCSAT4 DVBS2 */
	LC70_MEAS_SET_THRD_IDX_SCCB_DVBS,			/*  9: SCC-B DVBS */
	LC70_MEAS_SET_THRD_IDX_SCCB_DVBS2,			/* 10: SCC-B DVBS2 */
	LC70_MEAS_SET_THRD_IDX_SCCC_DVBS,			/* 11: SCC-C DVBS */
	LC70_MEAS_SET_THRD_IDX_SCCC_DVBS2,			/* 12: SCC-C DVBS2 */
	LC70_MEAS_SET_THRD_IDX_CATV_ISDBT_OFDM,		/* 13: CATV ISDBT OFDM */
	LC70_MEAS_SET_THRD_IDX_CATV_ANNEXC_64QAM,	/* 14: CATV ANNEXC 64QAM */
	LC70_MEAS_SET_THRD_IDX_CATV_ANNEXC_256QAM,	/* 15: CATV ANNEXC 256QAM */
	LC70_MEAS_SET_THRD_IDX_CATV_ANNEXB_64QAM,	/* 16: CATV ANNEXB 64QAM */
	LC70_MEAS_SET_THRD_IDX_CATV_ANNEXB_256QAM,	/* 17: CATV ANNEXB 256QAM */
	LC70_MEAS_SET_THRD_IDX_CATV_PILOT,			/* 18: CATV PILOT */
	LC70_MEAS_SET_THRD_IDX_CATV_SKYP_OFDM,		/* 19: CATV スカパー光 OFDM */
	LC70_MEAS_SET_THRD_IDX_CATV_SKYP_256QAM,	/* 20: CATV スカパー光 256QAM */
	LC70_MEAS_SET_THRD_IDX_LTE,					/* 21: LTE */
	LC70_MEAS_SET_THRD_IDX_FM,					/* 22: FM */
	LC70_MEAS_SET_THRD_IDX_CATV_UP_STREAM,		/* 23: CATV 上り */

	LC70_MEAS_SET_THRD_IDX_MAX
} LC70_MEAS_SET_THRD_IDX_T;


/* 測定設定(閾値)データ構造体 */
typedef struct lc70_meas_set_thrd_t{
	LC70_MEAS_SET_THRD_ROW_T measSetThrdRow[LC70_MEAS_SET_THRD_IDX_MAX];
}LC70_MEAS_SET_THRD_T;			/* 1932(92 * 21)byte */

/*----------------------------------------
	CNR/MER切替設定
----------------------------------------*/
/* 測定設定(CNR/MER切替)の1行分データ構造体 */
typedef struct lc70_meas_set_cnrmer_row_t{
	uint8_t ucSelCnMerSelect[LC70_MEAS_SET_CNRMER_SELECT_NUM];	/* Select CNR/MER CNR=0 MER=1 選択範囲 */
	uint8_t ucSelCnMer;											/* Select CNR/MER CNR=0 MER=1 */
}LC70_MEAS_SET_CNRMER_ROW_T;			/* 4byte */

/* 測定設定(CNR/MER切替)データインデックス 列挙型 */
typedef enum {
	LC70_MEAS_SET_CNRMER_IDX_UHF = 0,          /*  0: 地上デジタル */
	LC70_MEAS_SET_CNRMER_IDX_BS,               /*  1: BS */
	LC70_MEAS_SET_CNRMER_IDX_CS,               /*  2: CS */
	LC70_MEAS_SET_CNRMER_IDX_CATV_ALL,         /*  3: CATV ALL */
	LC70_MEAS_SET_CNRMER_IDX_CATV_90_470MHZ,   /*  4: CATV 90-470MHz */
	LC70_MEAS_SET_CNRMER_IDX_CATV_470_1002MHZ, /*  5: CATV 470-1002MHz */
	LC70_MEAS_SET_CNRMER_IDX_SKYP,             /*  6: スカパー光 */
	LC70_MEAS_SET_CNRMER_IDX_JCSAT3A,          /*  7: JCSAT3A */
	LC70_MEAS_SET_CNRMER_IDX_JCSAT4B,          /*  8: JCSAT4B */
	LC70_MEAS_SET_CNRMER_IDX_SCCB2,            /*  9: SCC-B2 */
	LC70_MEAS_SET_CNRMER_IDX_SCCC2,            /* 10: SCC-C2 */
	LC70_MEAS_SET_CNRMER_IDX_PILOT,            /* 11: PILOT */
	LC70_MEAS_SET_CNRMER_IDX_LTE,              /* 12: LTE */
	LC70_MEAS_SET_CNRMER_IDX_FM,               /* 13: FM */
	LC70_MEAS_SET_CNRMER_IDX_CATV_UP_STREAM,   /* 14: CATV 上り */

	LC70_MEAS_SET_CNRMER_IDX_MAX
} LC70_MEAS_SET_CNRMER_IDX_T;

/* 測定設定(CNR/MER切替)データ構造体 */
typedef struct lc70_meas_set_cnrmer_t{
	LC70_MEAS_SET_CNRMER_ROW_T measSetCnrmerRow[LC70_MEAS_SET_CNRMER_IDX_MAX];
}LC70_MEAS_SET_CNRMER_T;			/* 56(4 * 14)byte */

/*----------------------------------------
	CATVチャンネル周波数設定
----------------------------------------*/
/* 測定設定(CATVチャンネル周波数)の1行分データ構造体 */
typedef struct lc70_meas_set_catv_freq_row_t{
	uint8_t ucSetNo;		/* 設定番号 1:設定1 2:設定2 */
	uint8_t ucDummy[3];		/* ダミー */
	uint32_t ulModBit;		/* 変調方式 ビットパターン ビット値はLC70_SETMOD_XXX定義を参照 */
	uint32_t ulFreqC24;		/* C24 周波数[kHz] */
	uint32_t ulFreqC25;		/* C25 周波数[kHz] */
	uint32_t ulFreqC26;		/* C26 周波数[kHz] */
	uint32_t ulFreqC27;		/* C27 周波数[kHz] */
	uint8_t ucIsDisp;		/* 設定画面表示有無 0:非表示 1:表示 */
	uint8_t ucUse;			/* 実設定 0:未設定 1:設定 */
}LC70_MEAS_SET_CATV_FREQ_ROW_T;	/* 28byte */

/* 測定設定(CATVチャンネル周波数)データインデックス 列挙型 */
typedef enum {
	LC70_MEAS_SET_CATV_FREQ_IDX_SET1_QAM = 0,		/*  0: 設定1 QAM */
	LC70_MEAS_SET_CATV_FREQ_IDX_SET1_OFDM,			/*  1: 設定1 OFDM */
	LC70_MEAS_SET_CATV_FREQ_IDX_SET2_QAM,			/*  2: 設定2 QAM */
	LC70_MEAS_SET_CATV_FREQ_IDX_SET2_OFDM,			/*  3: 設定2 OFDM */
	
	LC70_MEAS_SET_CATV_FREQ_IDX_MAX
} LC70_MEAS_SET_CATV_FREQ_IDX_T;

/* 測定設定(CATVチャンネル周波数)データ構造体 */
typedef struct lc70_meas_set_catv_freq_t{
	LC70_MEAS_SET_CATV_FREQ_ROW_T measSetCatvFreqRow[LC70_MEAS_SET_CATV_FREQ_IDX_MAX];
}LC70_MEAS_SET_CATV_FREQ_T;		/* 112(28 * 4)byte */

/*----------------------------------------
	ケーブル損失設定
----------------------------------------*/
/* 測定設定(ケーブル損失)の1行分データ構造体 */
typedef struct lc70_meas_set_cable_loss_row_t{
	uint32_t ulFreq;				/* 周波数[kHz] */
	uint32_t ulCorrectionValue;		/* 補正値[0.1dB] 0～300 */
}LC70_MEAS_SET_CABLE_LOSS_ROW_T;		/* 8byte */

/* 測定設定(ケーブル損失)データインデックス 列挙型 */
typedef enum {
	LC70_MEAS_SET_CABLE_LOSS_IDX_70000KHZ = 0,		/*  0: 70000kHz */
	LC70_MEAS_SET_CABLE_LOSS_IDX_770000KHZ,			/*  1: 770000kHz */
	LC70_MEAS_SET_CABLE_LOSS_IDX_950000KHZ,			/*  2: 950000kHz */
	LC70_MEAS_SET_CABLE_LOSS_IDX_2600000KHZ,		/*  3: 2600000kHz */
	
	LC70_MEAS_SET_CABLE_LOSS_IDX_MAX
} LC70_MEAS_SET_CABLE_LOSS_IDX_T;


/* 測定設定(ケーブル損失)データ構造体 */
typedef struct lc70_meas_set_cable_loss_t{
	LC70_MEAS_SET_CABLE_LOSS_ROW_T measSetCableLossRow[LC70_MEAS_SET_CABLE_LOSS_IDX_MAX];
}LC70_MEAS_SET_CABLE_LOSS_T;	/* 32(8 * 4)byte */

/*----------------------------------------
	ケーブル損失有効設定
----------------------------------------*/
/* 測定設定(ケーブル損失有効)データ配列数定義 */
#define LC70_MEAS_SET_CABLE_LOSS_ENB_IDX_MAX	(1)

/* 測定設定(ケーブル損失有効)の1行分データ構造体 */
typedef struct lc70_meas_set_cable_loss_enb_row_t{
	uint8_t ucCorrectionEnbFlg;			/* 補正有無 0:無効 1:有効 */
}LC70_MEAS_SET_CABLE_LOSS_ENB_ROW_T;		/* 8byte */


/* 測定設定(ケーブル損失有効)データ構造体 */
typedef struct lc70_meas_set_cable_loss_enb_t{
	LC70_MEAS_SET_CABLE_LOSS_ENB_ROW_T measSetCableLossEnbRow[LC70_MEAS_SET_CABLE_LOSS_ENB_IDX_MAX];
}LC70_MEAS_SET_CABLE_LOSS_ENB_T;	/* 32(8 * 4)byte */


/*----------------------------------------
	入力切替設定
----------------------------------------*/
/* 測定設定(入力切替)の1行分データ構造体 */
typedef struct lc70_meas_set_input_row_t{
	uint8_t ucInputSelect[LC70_MEAS_SET_INPUT_SELECT_NUM];	/* 入力 0:同軸 1:光 選択範囲 */
	uint8_t ucInput;										/* 入力 0:同軸 1:光 */
}LC70_MEAS_SET_INPUT_ROW_T;		/* 4byte */

/* 測定設定(入力切替)データ構造体 */
typedef struct lc70_meas_set_input_t{
	LC70_MEAS_SET_INPUT_ROW_T measSetInputRow[LC70_MEAS_SET_INPUT_IDX_MAX];
}LC70_MEAS_SET_INPUT_T;			/* 4byte */

/*----------------------------------------
	CATVの変調方式選択
----------------------------------------*/
/* 測定設定(CATVの変調方式選択)の1行分データ構造体 */
typedef struct lc70_meas_set_catv_mod_row_t{
	uint32_t ulCatvModSelect[LC70_MEAS_SET_CATV_MOD_SELECT_NUM];	/* CATVの変調方式 ビットパターン 選択範囲 */
}LC70_MEAS_SET_CATV_MOD_ROW_T;	/* 12byte */

/* 測定設定(CATVの変調方式選択)データ構造体 */
typedef struct lc70_meas_set_catv_mod_t{
	LC70_MEAS_SET_CATV_MOD_ROW_T measSetCatvModRow[LC70_MEAS_SET_CATV_MOD_IDX_MAX];
}LC70_MEAS_SET_CATV_MOD_T;		/* 12byte */

/*----------------------------------------
	給電電圧(DC OUT)設定
----------------------------------------*/
/* 測定設定(給電電圧(DC OUT))の1行分データ構造体 */
typedef struct lc70_meas_set_dc_out_row_t{
	uint8_t ucStat;				/* DC OUT状態 LC70_MEAS_SET_DC_OUT_IDX_T型を参照 */
	uint8_t ucDcOutJcsat3H;		/* DC OUT JCSAT3 水平 LC70_MEAS_SET_DC_OUT_VAL_XXX定義値を参照 */
	uint8_t ucDcOutJcsat3V;		/* DC OUT JCSAT3 垂直 LC70_MEAS_SET_DC_OUT_VAL_XXX定義値を参照 */
	uint8_t ucDcOutJcsat4H;		/* DC OUT JCSAT4 水平 LC70_MEAS_SET_DC_OUT_VAL_XXX定義値を参照 */
	uint8_t ucDcOutJcsat4V;		/* DC OUT JCSAT4 垂直 LC70_MEAS_SET_DC_OUT_VAL_XXX定義値を参照 */
	uint8_t ucDcOutSccbH;		/* DC OUT SCC-B 水平 LC70_MEAS_SET_DC_OUT_VAL_XXX定義値を参照 */
	uint8_t ucDcOutSccbV;		/* DC OUT SCC-B 垂直 LC70_MEAS_SET_DC_OUT_VAL_XXX定義値を参照 */
	uint8_t ucDcOutScccH;		/* DC OUT SCC-C 水平 LC70_MEAS_SET_DC_OUT_VAL_XXX定義値を参照 */
	uint8_t ucDcOutScccV;		/* DC OUT SCC-C 垂直 LC70_MEAS_SET_DC_OUT_VAL_XXX定義値を参照 */
	uint8_t ucDcOutOther;		/* DC OUT その他 LC70_MEAS_SET_DC_OUT_VAL_XXX定義値を参照 */
}LC70_MEAS_SET_DC_OUT_ROW_T;		/* 12byte */

/* 測定設定(給電電圧(DC OUT))データインデックス 列挙型 */
typedef enum {
	LC70_MEAS_SET_DC_OUT_IDX_H15V_V11V = 0,		/*  0: H15V/V11V */
	LC70_MEAS_SET_DC_OUT_IDX_15V_CONST,			/*  1: 15V固定 */
	LC70_MEAS_SET_DC_OUT_IDX_DC_OUT_NONE,		/*  2: 給電しない */
	
	LC70_MEAS_SET_DC_OUT_IDX_MAX
} LC70_MEAS_SET_DC_OUT_IDX_T;

/* 測定設定(給電電圧(DC OUT))データ構造体 */
typedef struct lc70_meas_set_dc_out_t{
	LC70_MEAS_SET_DC_OUT_ROW_T measSetDcOutRow[LC70_MEAS_SET_DC_OUT_IDX_MAX];
}LC70_MEAS_SET_DC_OUT_T;			/* 36(12 * 3)byte */

/*----------------------------------------
	光測定設定
----------------------------------------*/
/* 光測定の波長選択データ配列数定義 */
#define LC70_MEAS_SET_OPT_MEAS_IDX_MAX	(1)

/* 光測定の波長選択配列数 */
#define LC70_MEAS_SET_OPT_MEAS_SELECT_NUM	(3)

/* 光測定の波長選択定義 */
#define LC70_MEAS_SET_OPT_MEAS_1300	(1300)		/* 波長 1300[nm] */
#define LC70_MEAS_SET_OPT_MEAS_1310	(1310)		/* 波長 1310[nm] */
#define LC70_MEAS_SET_OPT_MEAS_1490	(1490)		/* 波長 1490[nm] */

/* 測定設定(光測定の波長選択)の1行分データ構造体 */
typedef struct lc70_meas_set_opt_meas_row_t{
	uint32_t ulOptMeasSelect[LC70_MEAS_SET_OPT_MEAS_SELECT_NUM];	/* 光測定の波長選択範囲 LC70_MEAS_SET_OPT_MEAS_XXの定義値 */
}LC70_MEAS_SET_OPT_MEAS_ROW_T;

/* 測定設定(光測定の波長選択)データ構造体 */
typedef struct lc70_meas_set_opt_meas_t{
    LC70_MEAS_SET_OPT_MEAS_ROW_T measSetOptMeasRow[LC70_MEAS_SET_OPT_MEAS_IDX_MAX];
}LC70_MEAS_SET_OPT_MEAS_T;

/*----------------------------------------
	コンスタレーション表示ポイント数設定
----------------------------------------*/
/* コンスタレーションの表示ポイント数選択データ配列数定義 */
#define LC70_MEAS_SET_CONSTA_NUM_IDX_MAX		(1)

/* コンスタレーションの表示ポイント数選択配列数 */
#define LC70_MEAS_SET_CONSTA_NUM_SELECT_NUM		(3)

/* コンスタレーションの表示ポイント数選択定義 */
#define LC70_MEAS_SET_CONSTA_NUM_1000	(1000)		/* 1000 ポイント */
#define LC70_MEAS_SET_CONSTA_NUM_2000	(2000)		/* 2000 ポイント */
#define LC70_MEAS_SET_CONSTA_NUM_4000	(4000)		/* 4000 ポイント */

/* 測定設定(コンスタレーションの表示ポイント数選択)の1行分データ構造体 */
typedef struct lc70_meas_set_consta_num_row_t{
	uint32_t ulConstaNumSelect[LC70_MEAS_SET_CONSTA_NUM_SELECT_NUM]; /* コンスタレーションの表示ポイント数選択範囲 LC70_MEAS_SET_CONSTA_NUM_XXの定義値 */
	uint32_t ulConstaNum; /* コンスタレーションの表示ポイント数設定 LC70_MEAS_SET_CONSTA_NUM_XXの定義値 */
}LC70_MEAS_SET_CONSTA_NUM_ROW_T;

/* 測定設定(コンスタレーションの表示ポイント数選択)データ構造体 */
typedef struct lc70_meas_set_consta_num_t{
	LC70_MEAS_SET_CONSTA_NUM_ROW_T measSetConstaNumRow[LC70_MEAS_SET_CONSTA_NUM_IDX_MAX];
}LC70_MEAS_SET_CONSTA_NUM_T;

/*----------------------------------------
    マニュアル 放送方式、変調方式(pdisp -> pmeas)
----------------------------------------*/
/* 測定設定(マニュアル 放送方式、変調方式)の1行分データ構造体 */
typedef struct lc70_meas_set_manu_bdsys_mod_row_t{
	uint16_t usBdSys;          /* 放送方式 LC70_BD_SYS_XX定義を参照 */
	uint32_t ulMod;            /* 変調方式 LC70_SETMOD_XX定義を参照 */
}LC70_MEAS_SET_MANU_BDSYS_MOD_ROW_T;

/* 測定設定(マニュアル 放送方式、変調方式)データインデックス 列挙型 */
typedef enum {
	LC70_MEAS_SET_MANU_BDSYS_MOD_IDX_UHF = 0,         /*  0: 地デジ */
	LC70_MEAS_SET_MANU_BDSYS_MOD_IDX_BS_R,            /*  1: BS 右旋(L) */
	LC70_MEAS_SET_MANU_BDSYS_MOD_IDX_BS_L,            /*  2: BS 右旋(L) */
	LC70_MEAS_SET_MANU_BDSYS_MOD_IDX_CS_R,            /*  3: CS(N-SAT110) 右旋(R) */
	LC70_MEAS_SET_MANU_BDSYS_MOD_IDX_CS_L,            /*  4: CS(N-SAT110) 左旋(L) */
	LC70_MEAS_SET_MANU_BDSYS_MOD_IDX_CATV_OFDM,       /*  5: CATV OFDM */
	LC70_MEAS_SET_MANU_BDSYS_MOD_IDX_CATV_QAM,        /*  6: CATV QAM */
	LC70_MEAS_SET_MANU_BDSYS_MOD_IDX_SKYP_ISDBT,      /*  7: SKYP ISDBT */
	LC70_MEAS_SET_MANU_BDSYS_MOD_IDX_SKYP_OPTICAST,   /*  8: SKYP OPTICAST */
	LC70_MEAS_SET_MANU_BDSYS_MOD_IDX_PILOT,           /*  9: PILOT */
	LC70_MEAS_SET_MANU_BDSYS_MOD_IDX_JCSAT3_H,        /* 10: JCSAT3 水平(H) */
	LC70_MEAS_SET_MANU_BDSYS_MOD_IDX_JCSAT3_V,        /* 11: JCSAT3 垂直(V) */
	LC70_MEAS_SET_MANU_BDSYS_MOD_IDX_JCSAT4_H,        /* 12: JCSAT4 水平(H) */
	LC70_MEAS_SET_MANU_BDSYS_MOD_IDX_JCSAT4_V,        /* 13: JCSAT4 垂直(V) */
	LC70_MEAS_SET_MANU_BDSYS_MOD_IDX_JCSAT_ANTENNA_H, /* 14: JCSATアンテナ調整 水平(H) */
	LC70_MEAS_SET_MANU_BDSYS_MOD_IDX_JCSAT_ANTENNA_V, /* 15: JCSATアンテナ調整 垂直(V) */
	LC70_MEAS_SET_MANU_BDSYS_MOD_IDX_SCCB_H,          /* 16: SCC-B 水平(H) */
	LC70_MEAS_SET_MANU_BDSYS_MOD_IDX_SCCB_V,          /* 17: SCC-B 垂直(V) */
	LC70_MEAS_SET_MANU_BDSYS_MOD_IDX_SCCC_H,          /* 18: SCC-C 水平(H) */
	LC70_MEAS_SET_MANU_BDSYS_MOD_IDX_SCCC_V,          /* 19: SCC-C 垂直(V) */
	LC70_MEAS_SET_MANU_BDSYS_MOD_IDX_LTE,             /* 20: LTE */
	LC70_MEAS_SET_MANU_BDSYS_MOD_IDX_FM,              /* 21: FM */
	LC70_MEAS_SET_MANU_BDSYS_MOD_IDX_CATV_UP_STREAM,  /* 22: CATV 上り */

	LC70_MEAS_SET_MANU_BDSYS_MOD_IDX_MAX
} LC70_MEAS_SET_MANU_BDSYS_MOD_IDX_T;

/* 測定設定(マニュアル 放送方式、変調方式)データ構造体 */
typedef struct lc70_meas_set_manu_bdsys_mod_t{
	LC70_MEAS_SET_MANU_BDSYS_MOD_ROW_T measSetManuBdSysMod[LC70_MEAS_SET_MANU_BDSYS_MOD_IDX_MAX];
}LC70_MEAS_SET_MANU_BDSYS_MOD_T;

/*----------------------------------------
    放送方式チューナ部変換(pmeas -> サブCPU)
----------------------------------------*/
/* 測定設定(放送方式チューナ部変換)の1行分データ構造体 */
typedef struct lc70_meas_set_bdsys_conv_row_t{
	uint16_t usBdSys;          /* 放送方式 LC70_BD_SYS_XX定義を参照 */
	uint16_t usBdSysCnv;       /* 放送方式(チューナー部) */
	uint8_t  ucBand;           /* バンド LC70_BAND_T型を参照 */
}LC70_MEAS_SET_BDSYS_CONV_ROW_T;

/* 測定設定(放送方式チューナ部変換)データインデックス 列挙型 */
typedef enum {
	LC70_MEAS_SET_BDSYS_CONV_IDX_UHF_ISDBT = 0,           /*  0: 地デジ ISDBT */
	LC70_MEAS_SET_BDSYS_CONV_IDX_BS_ISDBS,                /*  1: BS ISDBS */
	LC70_MEAS_SET_BDSYS_CONV_IDX_BS_ISDBS3,               /*  2: BS ISDBS3 */
	LC70_MEAS_SET_BDSYS_CONV_IDX_CS_ISDBS,                /*  3: CS(N-SAT110) ISDBS */
	LC70_MEAS_SET_BDSYS_CONV_IDX_CS_ISDBS3,               /*  4: CS(N-SAT110) ISDBS3 */
	LC70_MEAS_SET_BDSYS_CONV_IDX_JCSAT3_DVBS,             /*  5: JCSAT3 DVBS */
	LC70_MEAS_SET_BDSYS_CONV_IDX_JCSAT3_DVBS2,            /*  6: JCSAT3 DVBS2 */
	LC70_MEAS_SET_BDSYS_CONV_IDX_JCSAT4_DVBS,             /*  7: JCSAT4 DVBS */
	LC70_MEAS_SET_BDSYS_CONV_IDX_JCSAT4_DVBS2,            /*  8: JCSAT4 DVBS2 */
	LC70_MEAS_SET_BDSYS_CONV_IDX_SCCB_DVBS,               /*  9: SCC-B DVBS */
	LC70_MEAS_SET_BDSYS_CONV_IDX_SCCB_DVBS2,              /* 10: SCC-B DVBS2 */
	LC70_MEAS_SET_BDSYS_CONV_IDX_SCCC_DVBS,               /* 11: SCC-C DVBS */
	LC70_MEAS_SET_BDSYS_CONV_IDX_SCCC_DVBS2,              /* 12: SCC-C DVBS2 */
	LC70_MEAS_SET_BDSYS_CONV_IDX_CATV_ALL_ISDBT,          /* 13: CATV ALL ISDBT */
	LC70_MEAS_SET_BDSYS_CONV_IDX_CATV_ALL_ANNEXC,         /* 14: CATV ALL ANNEXC */
	LC70_MEAS_SET_BDSYS_CONV_IDX_CATV_ALL_ANNEXB,         /* 15: CATV ALL ANNEXB */
	LC70_MEAS_SET_BDSYS_CONV_IDX_CATV_90_470MHZ_ISDBT,    /* 16: CATV 90-470MHZ ISDBT */
	LC70_MEAS_SET_BDSYS_CONV_IDX_CATV_90_470MHZ_ANNEXC,   /* 17: CATV 90-470MHZ ANNEXC */
	LC70_MEAS_SET_BDSYS_CONV_IDX_CATV_90_470MHZ_ANNEXB,   /* 18: CATV 90-470MHZ ANNEXB */
	LC70_MEAS_SET_BDSYS_CONV_IDX_CATV_470_1002MHZ_ISDBT,  /* 19: CATV 470-1002MHZ ISDBT */
	LC70_MEAS_SET_BDSYS_CONV_IDX_CATV_470_1002MHZ_ANNEXC, /* 20: CATV 470-1002MHZ ANNEXC */
	LC70_MEAS_SET_BDSYS_CONV_IDX_CATV_470_1002MHZ_ANNEXB, /* 21: CATV 470-1002MHZ ANNEXB */
	LC70_MEAS_SET_BDSYS_CONV_IDX_PILOT_NONE,              /* 22: PILOT 指定なし */
	LC70_MEAS_SET_BDSYS_CONV_IDX_SKYP_ISDBT,              /* 23: SKYP ISDBT */
	LC70_MEAS_SET_BDSYS_CONV_IDX_SKYP_OPTICAST,           /* 24: SKYP OPTICAST */
	LC70_MEAS_SET_BDSYS_CONV_IDX_LTE_NONE,                /* 25: LTE 指定なし */
	LC70_MEAS_SET_BDSYS_CONV_IDX_FM_NONE,                 /* 26: FM 指定なし */
	LC70_MEAS_SET_BDSYS_CONV_IDX_CATV_UP_STREAM_NONE,     /* 27: CATV 上り 指定なし */

	LC70_MEAS_SET_BDSYS_CONV_IDX_MAX
} LC70_MEAS_SET_BDSYS_CONV_IDX_T;

/* 測定設定(放送方式チューナ部変換)データ構造体 */
typedef struct lc70_meas_set_bdsys_conv_t{
	LC70_MEAS_SET_BDSYS_CONV_ROW_T measSetBdSysConv[LC70_MEAS_SET_BDSYS_CONV_IDX_MAX];
}LC70_MEAS_SET_BDSYS_CONV_T;

/*----------------------------------------
    CATV放送方式チューナ部変換(pmeas -> サブCPU)
----------------------------------------*/
/* 測定設定(CATV放送方式チューナ部変換)の1行分データ構造体 */
typedef struct lc70_meas_set_catv_bdsys_conv_row_t{
	uint32_t ulMod;            /* 変調方式 LC70_SETMOD_XX定義を参照 */
	uint16_t usBdSys;          /* 放送方式 LC70_BD_SYS_XX定義を参照 */
	uint16_t usBdSysCnv;       /* 放送方式(チューナー部) */
}LC70_MEAS_SET_CATV_BDSYS_CONV_ROW_T;

/* 測定設定(CATV放送方式チューナ部変換)データインデックス 列挙型 */
typedef enum {
	LC70_MEAS_SET_CATV_BDSYS_CONV_IDX_ISDBT_OFDM,          /*  0: ISDBT OFDM */
	LC70_MEAS_SET_CATV_BDSYS_CONV_IDX_ANNEXC_64QAM,        /*  1: ANNEXC 64QAM */
	LC70_MEAS_SET_CATV_BDSYS_CONV_IDX_ANNEXC_256QAM,       /*  2: ANNEXC 256QAM */
	LC70_MEAS_SET_CATV_BDSYS_CONV_IDX_ANNEXB_64QAM,        /*  3: ANNEXB 64QAM */
	LC70_MEAS_SET_CATV_BDSYS_CONV_IDX_ANNEXB_256QAM,       /*  4: ANNEXB 256QAM */

	LC70_MEAS_SET_CATV_BDSYS_CONV_IDX_MAX
} LC70_MEAS_SET_CATV_BDSYS_CONV_IDX_T;

/* 測定設定(放送方式チューナ部変換)データ構造体 */
typedef struct lc70_meas_set_catv_bdsys_conv_t{
	LC70_MEAS_SET_CATV_BDSYS_CONV_ROW_T measSetCatvBdSysConv[LC70_MEAS_SET_CATV_BDSYS_CONV_IDX_MAX];
}LC70_MEAS_SET_CATV_BDSYS_CONV_T;


/*============================================================
	ユーザー測定/データロガー設定ファイル関連
============================================================*/
/* ユーザー測定の1行分データ構造体 */
typedef struct lc70_user_set_user_row_t{
	uint8_t ucNo;											/* 要素番号 1～LC70_USER_SET_USER_IDX_MAX */
	uint8_t ucEnbFlg;										/* 有効フラグ 1:有効行 0:無効行 */
	uint8_t ucBand;											/* band 値はLC70_BAND_T型を参照 */
	uint8_t ucSpec;											/* 規格 値はLC70_BD_SYS_XXX定義を参照 */
	char	cStrChNo[LC70_CH_SET_CH_STRLEN];				/* チャンネル番号文字列 */
	uint32_t ulCenterFreq;									/* 中心周波数[kHz] */
	uint32_t ulModBit;										/* 変調方式 ビットパターン ビット値はLC70_SETMOD_XXX定義を参照 */
	uint32_t ulLocalFreq;									/* 局部発信周波数[kHz] */
	uint8_t ucGetDataFlg;									/* 取得データフラグ bit0:LEVEL bit1:CN/MER bit2:BER */
	uint8_t ucDcOut;										/* 給電有無 LC70_MEAS_SET_DC_OUT_VAL_XXX定義値を参照 */
}LC70_USER_SET_USER_ROW_T;	/* 28byte */

/* ユーザー測定データ構造体 */
typedef struct lc70_user_set_user_t{
	LC70_USER_SET_USER_ROW_T userSet[LC70_USER_SET_USER_IDX_MAX];	/* ユーザー測定の1行分データ */
}LC70_USER_SET_USER_T;		/* 4228(28 * 151)byte */

/* ユーザー測定ファイル名リストの1行分データ構造体 */
typedef struct lc70_user_set_user_flist_row_t{
	uint8_t ucNo;											/* 要素番号 1～LC70_USER_SET_USER_FLIST_IDX_MAX */
	uint8_t ucEnbFlg;										/* 有効フラグ 1:有効行 0:無効行 */
	char	cFileName[LC70_USER_USER_FNAME_STRLEN];			/* ファイル名文字列(拡張子は除く) */
}LC70_USER_SET_USER_FLIST_ROW_T;	/* 14byte */

/* ユーザー測定ファイル名リストデータ構造体 */
typedef struct lc70_user_set_user_flist_t{
	LC70_USER_SET_USER_FLIST_ROW_T userSetFlist[LC70_USER_SET_USER_FLIST_IDX_MAX];	/* ユーザー測定の1行分データ */
}LC70_USER_SET_USER_FLIST_T;		/* 1960(14 * 140)byte */


/* データロガー設定の1行分データ構造体 */
typedef struct lc70_logger_set_logger_row_t{
	uint8_t ucNo;											/* 要素番号 1～LC70_LOGGER_SET_LOGGER_IDX_MAX */
	uint8_t ucEnbFlg;										/* 有効フラグ 1:有効行 0:無効行 */
	uint8_t ucBand;											/* band 値はLC70_BAND_T型を参照 */
	uint8_t ucSpec;											/* 規格 値はLC70_BD_SYS_XXX定義を参照 */
	char	cStrChNo[LC70_CH_SET_CH_STRLEN];				/* チャンネル番号文字列 */
	uint32_t ulCenterFreq;									/* 中心周波数[kHz] */
	uint32_t ulModBit;										/* 変調方式 ビットパターン ビット値はLC70_SETMOD_XXX定義を参照 */
	uint32_t ulLocalFreq;									/* 局部発信周波数[kHz] */
	uint8_t ucGetDataFlg;									/* 取得データフラグ bit0:LEVEL bit1:CN/MER bit2:BER */
	uint8_t ucDcOut;										/* 給電有無 LC70_MEAS_SET_DC_OUT_VAL_XXX定義値を参照 */
}LC70_LOGGER_SET_LOGGER_ROW_T;	/* 28byte */

/* データロガー設定データ構造体 */
typedef struct lc70_logger_set_logger_t{
	LC70_LOGGER_SET_LOGGER_ROW_T loggerSet[LC70_LOGGER_SET_LOGGER_IDX_MAX];	/* データロガー設定の1行分データ */
}LC70_LOGGER_SET_LOGGER_T;		/* 4228(28 * 151)byte */

/* データロガー設定ファイル名リストの1行分データ構造体 */
typedef struct lc70_logger_set_logger_flist_row_t{
	uint8_t ucNo;											/* 要素番号 1～LC70_LOGGER_SET_LOGGER_FLIST_IDX_MAX */
	uint8_t ucEnbFlg;										/* 有効フラグ 1:有効行 0:無効行 */
	char	cFileName[LC70_LOGGER_LOGGER_FNAME_STRLEN];	/* ファイル名文字列(拡張子は除く) */
}LC70_LOGGER_SET_LOGGER_FLIST_ROW_T;	/* 14byte */

/* データロガー設定ファイル名リストデータ構造体 */
typedef struct lc70_logger_set_logger_flist_t{
	LC70_LOGGER_SET_LOGGER_FLIST_ROW_T loggerSetFlist[LC70_LOGGER_SET_LOGGER_FLIST_IDX_MAX];	/* データロガー設定の1行分データ */
}LC70_LOGGER_SET_LOGGER_FLIST_T;		/* 980(14 * 70)byte */


/*============================================================
	チャンネル定義ファイル関連
============================================================*/

/*----------------------------------------
	地デジ(帯域幅6MHz)
----------------------------------------*/
/* チャンネル定義(地デジ(帯域幅6MHz))の1行分データ構造体 */
typedef struct lc70_ch_set_uhf_row_t{
	char cStrChNo[LC70_CH_SET_CH_STRLEN];				/* チャンネル番号文字列 */
	uint32_t ulCentFreq;								/* 中心周波数[kHz] */
}LC70_CH_SET_UHF_ROW_T;	/* 12byte */

/* チャンネル定義(地デジ(帯域幅6MHz))データ構造体 */
typedef struct lc70_ch_set_uhf_t{
	LC70_CH_SET_UHF_ROW_T chSetRow[LC70_CH_SET_UHF_IDX_MAX];
}LC70_CH_SET_UHF_T;		/* 480byte(12 * 40) */

/*----------------------------------------
	BS,CS,SCCB,SCCC共通
----------------------------------------*/
/* チャンネル定義(BS,CS,SCC)の1行分データ構造体 */
typedef struct lc70_ch_set_bs_cs_scc_row_t{
	uint8_t ucWave;										/* 偏波番号 */
	uint8_t ucDummy[3];									/* ダミー */
	char cStrChNo[LC70_CH_SET_CH_STRLEN];				/* チャンネル番号文字列 */
	uint32_t ulCentFreq;								/* 中心周波数[kHz] */
}LC70_CH_SET_BS_CS_SCC_ROW_T;	/* 16byte */

/*----------------------------------------
	BS(帯域幅34.5MHz)
----------------------------------------*/
/* チャンネル定義(BS(帯域幅34.5MHz))データ構造体 */
typedef struct lc70_ch_set_bs_t{
	LC70_CH_SET_BS_CS_SCC_ROW_T chSetRow[LC70_CH_SET_BS_IDX_MAX];
}LC70_CH_SET_BS_T;		/* 384(16 * 24)byte */

/*----------------------------------------
	CS(帯域幅34.5MHz)
----------------------------------------*/
/* チャンネル定義(CS(帯域幅34.5MHz))データ構造体 */
typedef struct lc70_ch_set_cs_t{
	LC70_CH_SET_BS_CS_SCC_ROW_T chSetRow[LC70_CH_SET_CS_IDX_MAX];
}LC70_CH_SET_CS_T;		/* 416(16 * 26)byte */

/*----------------------------------------
	SCC-B(帯域幅27MHz)
----------------------------------------*/
/* チャンネル定義(SCC-B(帯域幅27MHz))データ構造体 */
typedef struct lc70_ch_set_sccb_t{
	LC70_CH_SET_BS_CS_SCC_ROW_T chSetRow[LC70_CH_SET_SCCB_IDX_MAX];
}LC70_CH_SET_SCCB_T;	/* 368(16 * 23)byte */

/*----------------------------------------
	SCC-C(帯域幅27MHz)
----------------------------------------*/
/* チャンネル定義(SCC-C(帯域幅27MHz))データ構造体 */
typedef struct lc70_ch_set_sccc_t{
	LC70_CH_SET_BS_CS_SCC_ROW_T chSetRow[LC70_CH_SET_SCCC_IDX_MAX];
}LC70_CH_SET_SCCC_T;	/* 384(16 * 24)byte */

/*----------------------------------------
	JSAT-3A(帯域幅27MHz)
----------------------------------------*/
/* チャンネル定義(JSAT-3A(帯域幅27MHz))データ構造体 */
typedef struct lc70_ch_set_jsat3a_t{
	LC70_CH_SET_BS_CS_SCC_ROW_T chSetRow[LC70_CH_SET_JSAT3A_IDX_MAX];
}LC70_CH_SET_JSAT3A_T;	/* 448(16 * 28)byte */

/*----------------------------------------
	JSAT-4B(帯域幅27MHz)
----------------------------------------*/
/* チャンネル定義(JSAT-4B(帯域幅27MHz))データ構造体 */
typedef struct lc70_ch_set_jsat4b_t{
	LC70_CH_SET_BS_CS_SCC_ROW_T chSetRow[LC70_CH_SET_JSAT4B_IDX_MAX];
}LC70_CH_SET_JSAT4B_T;	/* 256(16 * 16)byte */

/*----------------------------------------
	CATV, CATV VHF, CATV UHF共通
----------------------------------------*/
/* チャンネル定義(CATV, CATV VHF, CATV UHF共通))の1行分データ構造体 */
typedef struct lc70_ch_set_catv_row_t{
	char cStrChNo[LC70_CH_SET_CH_STRLEN];				/* チャンネル番号文字列 */
	uint32_t ulCentFreqQam;								/* QAM 中心周波数[kHz] */
	uint32_t ulCentFreqOfdm;							/* OFDM 中心周波数[kHz] */
}LC70_CH_SET_CATV_ROW_T;	/* 16byte */

/*----------------------------------------
	CATV ALL(帯域幅6MHz)
----------------------------------------*/
/* チャンネル定義(CATV ALL(帯域幅6MHz))データ構造体 */
typedef struct lc70_ch_set_catv_all_t{
	LC70_CH_SET_CATV_ROW_T chSetRow[LC70_CH_SET_CATV_ALL_IDX_MAX];
}LC70_CH_SET_CATV_ALL_T;		/* 2432(16 * 152)byte */

/*----------------------------------------
	CATV 90-470MHZ(帯域幅6MHz)
----------------------------------------*/
/* チャンネル定義(CATV 90-470MHZ(帯域幅6MHz))データ構造体 */
typedef struct lc70_ch_set_catv_90_470mhz_t{
	LC70_CH_SET_CATV_ROW_T chSetRow[LC70_CH_SET_CATV_90_470MHZ_IDX_MAX];
}LC70_CH_SET_CATV_90_470MHZ_T;		/* 1008(16 * 63)byte */

/*----------------------------------------
	CATV 470-1002MHZ(帯域幅6MHz)
----------------------------------------*/
/* チャンネル定義(CATV 470-1002MHZ(帯域幅6MHz))データ構造体 */
typedef struct lc70_ch_set_catv_470_1002mhz_t{
	LC70_CH_SET_CATV_ROW_T chSetRow[LC70_CH_SET_CATV_470_1002MHZ_IDX_MAX];
}LC70_CH_SET_CATV_470_1002MHZ_T;		/* 1424(16 * 89)byte */

/*----------------------------------------
	スカパー光
----------------------------------------*/
/* チャンネル定義(スカパー光(帯域幅6MHz))の1行分データ構造体 */
typedef struct lc70_ch_set_skyp_row_t{
	char cStrChNo[LC70_CH_SET_CH_STRLEN];			/* チャンネル番号文字列 */
	uint32_t ulCentFreq;							/* 中心周波数[kHz] */
}LC70_CH_SET_SKYP_ROW_T;	/* 12byte */

/* チャンネル定義(スカパー光(帯域幅6MHz))データ構造体 */
typedef struct lc70_ch_set_skyp_t{
	LC70_CH_SET_SKYP_ROW_T chSetRow[LC70_CH_SET_SKYP_IDX_MAX];
}LC70_CH_SET_SKYP_T;		/* 1356(12 * 113)byte */

/*----------------------------------------
	PILOT
----------------------------------------*/
/* チャンネル定義(PILOT)の1行分データ構造体 */
typedef struct lc70_ch_set_pilot_row_t{
	char cStrChNo[LC70_CH_SET_CH_STRLEN];			/* チャンネル番号文字列 */
	uint32_t ulCentFreq;							/* 中心周波数[kHz] */
}LC70_CH_SET_PILOT_ROW_T;	/* 4byte */

/* チャンネル定義(PILOT)データ構造体 */
typedef struct lc70_ch_set_pilot_t{
	LC70_CH_SET_PILOT_ROW_T chSetRow[LC70_CH_SET_PILOT_IDX_MAX];
}LC70_CH_SET_PILOT_T;		/* 80(4 * 20)byte */

/*----------------------------------------
	LTE
----------------------------------------*/
/* チャンネル定義(LTE)の1行分データ構造体 */
typedef struct lc70_ch_set_lte_row_t{
	char cStrChNo[LC70_CH_SET_CH_STRLEN];			/* チャンネル番号文字列 */
	uint32_t ulCentFreq;							/* 中心周波数[kHz] */
	uint32_t ulBandWide;							/* 帯域幅[kHz] */
}LC70_CH_SET_LTE_ROW_T;		/* 16byte */

/* チャンネル定義(LTE)データ構造体 */
typedef struct lc70_ch_set_lte_t{
	LC70_CH_SET_LTE_ROW_T chSetRow[LC70_CH_SET_LTE_IDX_MAX];
}LC70_CH_SET_LTE_T;			/* 128(16 * 8)byte */ 

/*----------------------------------------
	FM
----------------------------------------*/
/* チャンネル定義(FM)の1行分データ構造体 */
typedef struct lc70_ch_set_fm_row_t{
	char cStrChNo[LC70_CH_SET_CH_STRLEN];			/* チャンネル番号文字列 */
	uint32_t ulCentFreq;							/* 中心周波数[kHz] */
}LC70_CH_SET_FM_ROW_T;		/* 16byte */

/* チャンネル定義(FM)データ構造体 */
typedef struct lc70_ch_set_fm_t{
	LC70_CH_SET_FM_ROW_T chSetRow[LC70_CH_SET_FM_IDX_MAX];
}LC70_CH_SET_FM_T;			/* 128(16 * 8)byte */ 

/*----------------------------------------
	CATV上り
----------------------------------------*/
/* チャンネル定義(CATV 上り)の1行分データ構造体 */
typedef struct lc70_ch_set_catv_up_stream_row_t{
    char cStrChNo[LC70_CH_SET_CH_STRLEN];           /* チャンネル番号文字列 */
    uint32_t ulCentFreq;                            /* 中心周波数[kHz] */
}LC70_CH_SET_CATV_UP_STREAM_ROW_T;

/* チャンネル定義(CATV 上り)データ構造体 */
typedef struct lc70_ch_set_catv_up_stream_t{
    LC70_CH_SET_CATV_UP_STREAM_ROW_T chSetRow[LC70_CH_SET_CATV_UP_STREAM_IDX_MAX];
}LC70_CH_SET_CATV_UP_STREAM_T;


/*----------------------------------------
	アンテナ調整用 JSAT-3A
----------------------------------------*/
/* チャンネル定義(アンテナ調整用 JSAT-3A(帯域幅27MHz))データ構造体 */
typedef struct lc70_ch_set_jsat3a_antenna_t{
    LC70_CH_SET_BS_CS_SCC_ROW_T chSetRow[LC70_CH_SET_JSAT3A_ANTENNA_IDX_MAX];
}LC70_CH_SET_JSAT3A_ANTENNA_T;

/*----------------------------------------
	アンテナ調整用 JSAT-4B
----------------------------------------*/
/* チャンネル定義(アンテナ調整用 JSAT-4B(帯域幅27MHz))データ構造体 */
typedef struct lc70_ch_set_jsat4b_antenna_t{
    LC70_CH_SET_BS_CS_SCC_ROW_T chSetRow[LC70_CH_SET_JSAT4B_ANTENNA_IDX_MAX];
}LC70_CH_SET_JSAT4B_ANTENNA_T;

/*----------------------------------------
	FM(デフォルト)
----------------------------------------*/
/* チャンネル定義(FM(デフォルト))の1行分データ構造体 */
typedef struct lc70_ch_set_fm_def_row_t{
	char cStrChNo[LC70_CH_SET_CH_STRLEN];			/* チャンネル番号文字列 */
	uint32_t ulCentFreq;							/* 中心周波数[kHz] */
}LC70_CH_SET_FM_DEF_ROW_T;		/* 16byte */

/* チャンネル定義(FM(デフォルト))データ構造体 */
typedef struct lc70_ch_set_fm_def_t{
	LC70_CH_SET_FM_DEF_ROW_T chSetRow[LC70_CH_SET_FM_DEF_IDX_MAX];
}LC70_CH_SET_FM_DEF_T;			/* 128(16 * 8)byte */ 

/*----------------------------------------
	CATV上り(デフォルト)
----------------------------------------*/
/* チャンネル定義(CATV 上り(デフォルト))の1行分データ構造体 */
typedef struct lc70_ch_set_catv_up_stream_def_row_t{
    char cStrChNo[LC70_CH_SET_CH_STRLEN];           /* チャンネル番号文字列 */
    uint32_t ulCentFreq;                            /* 中心周波数[kHz] */
}LC70_CH_SET_CATV_UP_STREAM_DEF_ROW_T;

/* チャンネル定義(CATV 上り(デフォルト))データ構造体 */
typedef struct lc70_ch_set_catv_up_stream_def_t{
    LC70_CH_SET_CATV_UP_STREAM_DEF_ROW_T chSetRow[LC70_CH_SET_CATV_UP_STREAM_DEF_IDX_MAX];
}LC70_CH_SET_CATV_UP_STREAM_DEF_T;

/*----------------------------------------
	BS/CS(帯域幅34.5MHz)
----------------------------------------*/
/* チャンネル定義(BS/CS(帯域幅34.5MHz))データ構造体 */
typedef struct lc70_ch_set_bs_cs_t{
	LC70_CH_SET_BS_CS_SCC_ROW_T chSetRow[LC70_CH_SET_BS_CS_IDX_MAX];
}LC70_CH_SET_BS_CS_T;		/* 384(16 * 24)byte */


/*============================================================
	測定管理プロセス設定ファイル関連
============================================================*/
/* 測定管理プロセス設定(測定管理テーブル)データインデックス 列挙型 */
typedef enum {
	LC70_PMEAS_SET_PMEAS_MNG_IDX_SINGLE_METER_SAT = 0,            /*   0: シングル(メータ) 衛星 */
	LC70_PMEAS_SET_PMEAS_MNG_IDX_SINGLE_METER_FM,                 /*   1: シングル(メータ) FM */
	LC70_PMEAS_SET_PMEAS_MNG_IDX_SINGLE_METER_PILOT_LTE,          /*   2: シングル(メータ) PILOT/LTE */
	LC70_PMEAS_SET_PMEAS_MNG_IDX_SINGLE_METER_UHF,                /*   3: シングル(メータ) 地デジ */
	LC70_PMEAS_SET_PMEAS_MNG_IDX_SINGLE_METER_SKYP,               /*   4: シングル(メータ) スカパー光 */
	LC70_PMEAS_SET_PMEAS_MNG_IDX_SINGLE_METER_OTHER,              /*   5: シングル(メータ) その他 */

	LC70_PMEAS_SET_PMEAS_MNG_IDX_SINGLE_CONSTA_SAT,               /*   6: シングル(コンスタ) 衛星 */      
	LC70_PMEAS_SET_PMEAS_MNG_IDX_SINGLE_CONSTA_FM,                /*   7: シングル(コンスタ) FM */        
	LC70_PMEAS_SET_PMEAS_MNG_IDX_SINGLE_CONSTA_PILOT_LTE,         /*   8: シングル(コンスタ) PILOT/LTE */ 
	LC70_PMEAS_SET_PMEAS_MNG_IDX_SINGLE_CONSTA_UHF,               /*   9: シングル(コンスタ) 地デジ */    
	LC70_PMEAS_SET_PMEAS_MNG_IDX_SINGLE_CONSTA_SKYP,              /*  10: シングル(コンスタ) スカパー光 */    
	LC70_PMEAS_SET_PMEAS_MNG_IDX_SINGLE_CONSTA_OTHER,             /*  11: シングル(コンスタ) その他 */    

	LC70_PMEAS_SET_PMEAS_MNG_IDX_SINGLE_DLYPRF_SAT,               /*  12: シングル(遅延プロファイル) 衛星 */       
	LC70_PMEAS_SET_PMEAS_MNG_IDX_SINGLE_DLYPRF_FM,                /*  13: シングル(遅延プロファイル) FM */         
	LC70_PMEAS_SET_PMEAS_MNG_IDX_SINGLE_DLYPRF_PILOT_LTE,         /*  14: シングル(遅延プロファイル) PILOT/LTE */  
	LC70_PMEAS_SET_PMEAS_MNG_IDX_SINGLE_DLYPRF_UHF,               /*  15: シングル(遅延プロファイル) 地デジ */     
	LC70_PMEAS_SET_PMEAS_MNG_IDX_SINGLE_DLYPRF_SKYP,              /*  16: シングル(遅延プロファイル) スカパー光 */     
	LC70_PMEAS_SET_PMEAS_MNG_IDX_SINGLE_DLYPRF_OTHER,             /*  17: シングル(遅延プロファイル) その他 */     

	LC70_PMEAS_SET_PMEAS_MNG_IDX_MULTI_GRAPH_SAT,                 /*  18: マルチ(グラフ) 衛星 */        
	LC70_PMEAS_SET_PMEAS_MNG_IDX_MULTI_GRAPH_FM,                  /*  19: マルチ(グラフ) FM */          
	LC70_PMEAS_SET_PMEAS_MNG_IDX_MULTI_GRAPH_PILOT_LTE,           /*  20: マルチ(グラフ) PILOT/LTE */   
	LC70_PMEAS_SET_PMEAS_MNG_IDX_MULTI_GRAPH_UHF,                 /*  21: マルチ(グラフ) 地デジ */      
	LC70_PMEAS_SET_PMEAS_MNG_IDX_MULTI_GRAPH_SKYP,                /*  22: マルチ(グラフ) スカパー光 */      
	LC70_PMEAS_SET_PMEAS_MNG_IDX_MULTI_GRAPH_OTHER,               /*  23: マルチ(グラフ) その他 */      

	LC70_PMEAS_SET_PMEAS_MNG_IDX_MULTI_LIST_SAT,                  /*  24: マルチ(リスト 単一) 衛星 */         
	LC70_PMEAS_SET_PMEAS_MNG_IDX_MULTI_LIST_FM,                   /*  25: マルチ(リスト 単一) FM */           
	LC70_PMEAS_SET_PMEAS_MNG_IDX_MULTI_LIST_PILOT_LTE,            /*  26: マルチ(リスト 単一) PILOT/LTE */    
	LC70_PMEAS_SET_PMEAS_MNG_IDX_MULTI_LIST_UHF,                  /*  27: マルチ(リスト 単一) 地デジ */       
	LC70_PMEAS_SET_PMEAS_MNG_IDX_MULTI_LIST_SKYP,                 /*  28: マルチ(リスト 単一) スカパー光 */       
	LC70_PMEAS_SET_PMEAS_MNG_IDX_MULTI_LIST_OTHER,                /*  29: マルチ(リスト 単一) その他 */       

	LC70_PMEAS_SET_PMEAS_MNG_IDX_MULTI_LIST2_SAT,                 /*  30: マルチ(リスト 複数) 衛星 */          
	LC70_PMEAS_SET_PMEAS_MNG_IDX_MULTI_LIST2_FM,                  /*  31: マルチ(リスト 複数) FM */            
	LC70_PMEAS_SET_PMEAS_MNG_IDX_MULTI_LIST2_PILOT_LTE,           /*  32: マルチ(リスト 複数) PILOT/LTE */     
	LC70_PMEAS_SET_PMEAS_MNG_IDX_MULTI_LIST2_UHF,                 /*  33: マルチ(リスト 複数) 地デジ */        
	LC70_PMEAS_SET_PMEAS_MNG_IDX_MULTI_LIST2_SKYP,                /*  34: マルチ(リスト 複数) スカパー光 */        
	LC70_PMEAS_SET_PMEAS_MNG_IDX_MULTI_LIST2_OTHER,               /*  35: マルチ(リスト 複数) その他 */        

#if 1  /* 20210607 makito add アンテナ調整時間変更 >> */
	LC70_PMEAS_SET_PMEAS_MNG_IDX_ANT_ADJUST_SAT,                  /*  36: アンテナ調整 衛星(対象JCSAT3A/4B) */
	LC70_PMEAS_SET_PMEAS_MNG_IDX_ANT_ADJUST_FM,                   /*  37: アンテナ調整 FM 			不使用	*/
	LC70_PMEAS_SET_PMEAS_MNG_IDX_ANT_ADJUST_PILOT_LTE,            /*  38: アンテナ調整 PILOT/LTE 	不使用	*/
	LC70_PMEAS_SET_PMEAS_MNG_IDX_ANT_ADJUST_UHF,                  /*  39: アンテナ調整 地デジ 		不使用	*/
	LC70_PMEAS_SET_PMEAS_MNG_IDX_ANT_ADJUST_SKYP,                 /*  40: アンテナ調整 スカパー光	不使用	*/
	LC70_PMEAS_SET_PMEAS_MNG_IDX_ANT_ADJUST_OTHER,                /*  41: アンテナ調整 その他		不使用	*/
#endif /* 20210607 makito add アンテナ調整時間変更 << */

	LC70_PMEAS_SET_PMEAS_MNG_IDX_SCAN_SAT,                        /*  42: スキャン 衛星 */           
	LC70_PMEAS_SET_PMEAS_MNG_IDX_SCAN_FM,                         /*  43: スキャン FM */             
	LC70_PMEAS_SET_PMEAS_MNG_IDX_SCAN_PILOT_LTE,                  /*  44: スキャン PILOT/LTE */      
	LC70_PMEAS_SET_PMEAS_MNG_IDX_SCAN_UHF,                        /*  45: スキャン 地デジ */         
	LC70_PMEAS_SET_PMEAS_MNG_IDX_SCAN_SKYP,                       /*  46: スキャン スカパー光 */         
	LC70_PMEAS_SET_PMEAS_MNG_IDX_SCAN_OTHER,                      /*  47: スキャン その他 */         

	LC70_PMEAS_SET_PMEAS_MNG_IDX_MAX
} LC70_PMEAS_SET_PMEAS_MNG_IDX_T;

/* CH ID */
/* pmeasのPMEAS_MEAS_CH_Tと同じ定義(先頭にLC70_を付加) */
typedef enum lc70_pmeas_meas_ch_t {
	LC70_PMEAS_MEAS_CH1	 	= 0,			/* CH1 */
	LC70_PMEAS_MEAS_CH2,					/* CH2 */
	LC70_PMEAS_MEAS_CH_MAX,					/* CH最大 */
} LC70_PMEAS_MEAS_CH_T;

/* CH設定定義 */
/* pmeasのPMEAS_MEAS_CH_MNG_Tと同じ定義(先頭にLC70_を付加) */
typedef struct lc70_pmeas_meas_ch_mng_t
{
	uint8_t				ucIsMes;				/* 測定対象	*/
	uint8_t				ucMesData;				/* 測定項目	*/
	uint8_t				ucSaveMethod;			/* 測定テーブルへの保存方法 */
	uint32_t			ulTmNoSignal;			/* No Sigal タイムアウト時間[ms] */
	uint32_t			ulTmLock;				/* Lock タイムアウト時間[ms] */
	uint16_t			ucJudgeMesData;
	uint16_t			ucJudgeStatus;
} LC70_PMEAS_MEAS_CH_MNG_T;

/* 測定管理プロセス設定(測定管理テーブル)の1行分データ構造体 */
/* pmeasのPMEAS_MEAS_MNG_TBL_Tと同じ定義 */
typedef struct lc70_pmeas_set_pmeas_mng_row_t{
	BOOL							isNextChSync;
	LC70_PMEAS_MEAS_CH_MNG_T		single[LC70_PMEAS_MEAS_CH_MAX];
	LC70_PMEAS_MEAS_CH_MNG_T		multi[LC70_PMEAS_MEAS_CH_MAX];
}LC70_PMEAS_SET_PMEAS_MNG_ROW_T; 

/* 測定管理プロセス設定(測定管理テーブル)データ構造体 */
typedef struct lc70_pmeas_set_pmeas_mng_t{
    LC70_PMEAS_SET_PMEAS_MNG_ROW_T chSetRow[LC70_PMEAS_SET_PMEAS_MNG_IDX_MAX];
}LC70_PMEAS_SET_PMEAS_MNG_T;


/* 設定ファイルデータ型共用体 ※LC70_FILE_ID_T型修正に合わせて修正が必要 */
typedef union{
	LC70_SYS_SET_POWOFF_T			sysPowoff;			/* システム設定 POWER OFF時間(分) */
	LC70_SYS_SET_VOLUME_T			sysVolume;			/* システム設定 音量設定 */
	LC70_SYS_SET_BRIGHTNESS_T		sysBrightness;		/* システム設定 明るさ設定 */
	LC70_MEAS_SET_LOCAL_FREQ_T		measLocalFreq;		/* 測定設定 局部発信周波数 */
	LC70_MEAS_SET_THRD_T			measThrd;			/* 測定設定 閾値 */
	LC70_MEAS_SET_CATV_FREQ_T		measCatvFreq;		/* 測定設定 CATVチャンネル周波数設定 */
	LC70_MEAS_SET_CABLE_LOSS_T		measCableLoss;		/* 測定設定 ケーブル損失設定 */
	LC70_MEAS_SET_CABLE_LOSS_ENB_T	measCableLossEnb;	/* 測定設定 ケーブル損失有効設定 */
	LC70_MEAS_SET_INPUT_T			measInput;			/* 測定設定 入力切替設定 */
	LC70_MEAS_SET_CATV_MOD_T		measCatvMod;		/* 測定設定 CATVの変調方式選択 */
	LC70_MEAS_SET_DC_OUT_T			measDcOut;			/* 測定設定 給電電圧(DC OUT)設定 */
	LC70_MEAS_SET_OPT_MEAS_T		measOptMeas;		/* 測定設定 光測定設定 */
	LC70_MEAS_SET_CONSTA_NUM_T		measConstaNum;		/* 測定設定 コンスタレーション表示ポイント数設定 */
	LC70_USER_SET_USER_T			userUser;			/* ユーザー測定 */
	LC70_USER_SET_USER_FLIST_T		userUserFlist;		/* ユーザー測定 ファイル名リスト */
	LC70_CH_SET_UHF_T				chUhf;				/* チャンネル定義 地デジ(帯域幅6MHz) */
	LC70_CH_SET_BS_T				chBs;				/* チャンネル定義 BS(帯域幅34.5MHz) */
	LC70_CH_SET_CS_T				chCs;				/* チャンネル定義 CS(帯域幅34.5MHz) */
	LC70_CH_SET_SCCB_T				chSccb;				/* チャンネル定義 SCC-B(帯域幅27MHz) */
	LC70_CH_SET_SCCC_T				chSccc;				/* チャンネル定義 SCC-C(帯域幅27MHz) */
	LC70_CH_SET_JSAT3A_T			chJsat3a;			/* チャンネル定義 JSAT-3A(帯域幅27MHz) */
	LC70_CH_SET_JSAT4B_T			chJsat4b;			/* チャンネル定義 JSAT-4B(帯域幅27MHz) */
	LC70_CH_SET_CATV_ALL_T			chCatvAll;			/* チャンネル定義 CATV ALL(帯域幅6MHz) */
	LC70_CH_SET_CATV_90_470MHZ_T	chCatv90_470mhz;	/* チャンネル定義 CATV 90-470MHz(帯域幅6MHz) */
	LC70_CH_SET_CATV_470_1002MHZ_T	chCatv470_1002mhz;	/* チャンネル定義 CATV 470-1002MHz(帯域幅6MHz) */
	LC70_CH_SET_SKYP_T				chSkyp;				/* チャンネル定義 スカパー光 */
	LC70_CH_SET_PILOT_T				chPilot;			/* チャンネル定義 PILOT */
	LC70_CH_SET_LTE_T				chLte;				/* チャンネル定義 LTE */
	LC70_CH_SET_FM_T				chFm;				/* チャンネル定義 FM */

	LC70_MEAS_SET_MANU_BDSYS_MOD_T	measManuBdsysMod;	/* 測定設定ファイル(マニュアル測定 放送方式、変調方式選択) */
	LC70_MEAS_SET_BDSYS_CONV_T		measBdsysConv;		/* 測定設定ファイル(放送方式チューナ部変換) */
	LC70_MEAS_SET_CATV_BDSYS_CONV_T	measCatvBdsysConv;	/* 測定設定ファイル(CATV放送方式チューナ部変換) */

	LC70_CH_SET_CATV_UP_STREAM_T	chCatvUpStream;		/* チャンネル定義 CATV上り */
	LC70_LOGGER_SET_LOGGER_T		loggerLogger;		/* データロガー設定 */
	LC70_LOGGER_SET_LOGGER_FLIST_T	loggerLoggerFlist;	/* データロガー設定 ファイル名リスト */

	LC70_PMEAS_SET_PMEAS_MNG_T		pmeasPmeasMng;		/* 測定管理プロセス 測定管理テーブル */

	LC70_CH_SET_JSAT3A_ANTENNA_T	chJsat3aAntenna;	/* チャンネル定義 アンテナ調整用JSAT-3A(帯域幅27MHz) */
	LC70_CH_SET_JSAT4B_ANTENNA_T	chJsat4bAntenna;	/* チャンネル定義 アンテナ調整用JSAT-4B(帯域幅27MHz) */
	LC70_CH_SET_FM_DEF_T				chFmDef;		/* チャンネル定義 FM(デフォルト) */
	LC70_CH_SET_CATV_UP_STREAM_DEF_T	chCatvUpStreamDef;	/* チャンネル定義 CATV上り(デフォルト) */
	LC70_CH_SET_BS_CS_T				chBsCs;				/* チャンネル定義 BS/CS(帯域幅34.5MHz) */
	LC70_USER_SET_USER_T			userUserUsb1;			/* ユーザー測定                  取込みデータ1用 */
	LC70_USER_SET_USER_FLIST_T		userUserUsb1Flist;		/* ユーザー測定 ファイル名リスト 取込みデータ1用 */
	LC70_USER_SET_USER_T			userUserUsb2;			/* ユーザー測定                  取込みデータ2用 */
	LC70_USER_SET_USER_FLIST_T		userUserUsb2Flist;		/* ユーザー測定 ファイル名リスト 取込みデータ2用 */
	LC70_LOGGER_SET_LOGGER_T		loggerLoggerUsb1;		/* データロガー設定                  取込みデータ1用 */
	LC70_LOGGER_SET_LOGGER_FLIST_T	loggerLoggerUsb1Flist;	/* データロガー設定 ファイル名リスト 取込みデータ1用 */
	LC70_LOGGER_SET_LOGGER_T		loggerLoggerUsb2;		/* データロガー設定                  取込みデータ2用 */
	LC70_LOGGER_SET_LOGGER_FLIST_T	loggerLoggerUsb2Flist;	/* データロガー設定 ファイル名リスト 取込みデータ2用 */
}LC70_SET_FILE_UNION_T;

/* 放送方式(チューナが解釈できる値) */
typedef enum {
	DMD_E_ISDBT=0,
	DMD_E_ISDBS,
	DMD_E_DVBT,
	DMD_E_DVBT2,
	DMD_E_DVBS,
	DMD_E_DVBS2,
	DMD_E_DVBS2X,
	DMD_E_DVBC,
	DMD_E_DVBC2,
	DMD_E_ATSC,
	DMD_E_QAMB_64QAM,
	DMD_E_QAMB_256QAM,
	DMD_E_QAMC_64QAM,
	DMD_E_QAMC_256QAM,
	DMD_E_ISDBT_BRAZIL,
	DMD_E_ISDBT_SB,
	DMD_E_ISDBT2,
	DMD_E_ISDBS3,
	DMD_E_CB_BIND_256QAM,
	DMD_E_CB_BIND_64QAM,
	DMD_E_CB_BRANCH_256QAM,
	DMD_E_CB_BRANCH_64QAM,
	DMD_E_ANALOG,
	DMD_E_NTSC_M_BTSC,
	DMD_E_PAL_M_BTSC,
	DMD_E_PAL_N_BTSC,
	DMD_E_PAL_B_G_NICAM,
	DMD_E_PAL_I_NiCAM,
	DMD_E_PAL_D_NiCAM,
	DMD_E_PAL_B_G_A2,
	DMD_E_SECAM_L_NiCAM,
	DMD_E_SECAM_L1_NiCAM,
	DMD_E_SECAM_D_K_A2,
	DMD_E_SECAM_BG_NICAM,
	DMD_E_END_OF_SYSTEM,
	DMD_E_NOT_DEFINED,
	// add
	DMD_E_FM,
	DMD_E_PILOT,
	DMD_E_LTE,
	DMD_E_QAMB_64QAM_SKP,
	DMD_E_QAMB_256QAM_SKP,
} DMD_SYSTEM_t;

/*******************************************************************************
	prototype
*******************************************************************************/
LC70_ERR_T lc70_init(PROC_ID_T procId);
LC70_ERR_T lc70_getProductInfo(LC70_PRODUCT_INFO_T *pProductInfo);
LC70_ERR_T lc70_getFailinfo(LC70_FAIL_INFO_T *pFail);
LC70_ERR_T lc70_getKeyStatus(LC70_KEY_STAT_T *pKeyStat);
LC70_ERR_T lc70_startAngleMeas(void);
LC70_ERR_T lc70_stopAngleMeas(void);
LC70_ERR_T lc70_getDeviceStatus(LC70_DEV_STAT_T *pDevStat);
LC70_ERR_T lc70_reqPowerSupply(LC70_POWER_SUPPLY_T powerSupply);
LC70_ERR_T lc70_getMeasStatus(LC70_MEAS_STAT_T *pMeasStat);
LC70_ERR_T lc70_startSingleMeas(LC70_DISP_TYPE_T dispType, LC70_MEAS_SINGLE_T *pCondition);
LC70_ERR_T lc70_stopSingleMeas(LC70_DISP_TYPE_T dispType);
LC70_ERR_T lc70_startConstaMeas(LC70_DISP_TYPE_T dispType, LC70_CONSTA_NUM_T collectNum);
LC70_ERR_T lc70_stopConstaMeas(LC70_DISP_TYPE_T dispType);
LC70_ERR_T lc70_getSingleMeasResult(int16_t sConstaNum, LC70_MEAS_SINGLE_RESULT_T *pResult);
LC70_ERR_T lc70_startDlyPrfMeas(LC70_DISP_TYPE_T dispType, LC70_MEAS_SINGLE_T *pCondition);
LC70_ERR_T lc70_stopDlyPrfMeas(LC70_DISP_TYPE_T dispType);
LC70_ERR_T lc70_getDlyPrfResult(LC70_MEAS_DLY_PRF_RESULT_T *pResult);
LC70_ERR_T lc70_startMultiMeas(LC70_DISP_TYPE_T dispType, LC70_MEAS_MULTI_T *pCondition);
LC70_ERR_T lc70_stopMultiMeas(LC70_DISP_TYPE_T dispType);
LC70_ERR_T lc70_setMultiMeasChannel(uint8_t *pMeasEnb);										/* 未使用 */
LC70_ERR_T lc70_getMultiMeasResult(int16_t sIndex, LC70_MEAS_MULTI_RESULT_T *pResult);
LC70_ERR_T lc70_startMultiChPrioMeas(LC70_DISP_TYPE_T dispType, LC70_MEAS_SINGLE_T *pCondition);
LC70_ERR_T lc70_stopMultiChPrioMeas(LC70_DISP_TYPE_T dispType);
LC70_ERR_T lc70_getMultiChPrioMeas(LC70_MEAS_SINGLE_RESULT_T *pResult);
LC70_ERR_T lc70_startScan(LC70_DISP_TYPE_T dispType, LC70_MEAS_MULTI_T *pCondition);
LC70_ERR_T lc70_stopScan(LC70_DISP_TYPE_T dispType);
LC70_ERR_T lc70_getScanResult(int16_t sIndex, LC70_MEAS_MULTI_RESULT_T *pResult);
LC70_ERR_T lc70_startOptMeas(uint32_t ulWaveLength);
LC70_ERR_T lc70_stopOptMeas(void);
LC70_ERR_T lc70_getOptMeasResult(LC70_MEAS_OPT_RESULT_T *pResult);
LC70_ERR_T lc70_startDcMeas(void);
LC70_ERR_T lc70_stopDcMeas(void);
LC70_ERR_T lc70_getDcMeasResult(LC70_MEAS_DC_RESULT_T *pResult);
LC70_ERR_T lc70_reboot(void);
LC70_ERR_T lc70_shutdown(void);
LC70_ERR_T lc70_standby(uint8_t ucMode);
LC70_ERR_T lc70_wakeup(uint8_t ucMode);
LC70_ERR_T lc70_prgUpdate(LC70_PRG_UPDATE_T *pPrgUpdate);
LC70_ERR_T lc70_buzzer(LC70_BUZZ_T buzz, LC70_BUZZ_MODE_T buzzMode);
LC70_ERR_T lc70_forceBuzzerVolume(LC70_BUZZ_T buzz, LC70_BUZZ_VOL_T buzzVol);
LC70_ERR_T lc70_forceBrightness(LC70_BRIGHTNESS_T brightness);
LC70_ERR_T lc70_setFailStat(uint16_t usCode, uint8_t ucStat, const uint8_t *pucAddInfo);
LC70_ERR_T lc70_ntfUpdateFile(LC70_FILE_ID_T fileId);
LC70_ERR_T lc70_ntfUpdateFileIdx(LC70_FILE_ID_T fileId, uint32_t ulIdx);
LC70_ERR_T lc70_calibration(uint8_t ucMode);
LC70_ERR_T lc70_getStandbyStat(LC70_STANDBY_STAT_T *pStandbyStat);
LC70_ERR_T lc70_ntfLowBattStatChg(uint8_t ucLowBattStat);
LC70_ERR_T lc70_initFactoryDefault(void);
LC70_ERR_T lc70_setDeveloperMode(uint8_t ucOnOff);
LC70_ERR_T lc70_setPowerSupplyMultiMeasMixBand(uint8_t ucOnOff); /* (マルチ測定複数バンド用)給電要求 */
LC70_ERR_T lc70_force_standby(void);
LC70_ERR_T lc70_force_wakeup(void);
LC70_ERR_T lc70_startAngleCal(void);
LC70_ERR_T lc70_getAngleCalStat(LC70_ANGLE_CAL_STAT_T *pStat);
LC70_ERR_T lc70_getAngleCalInfoDetail(LC70_ANGLE_CAL_INFO_DETAIL_T *pInfo);
LC70_ERR_T lc70_getPowerSupplyInfo(LC70_POWERSUPPLY_INFO_T *pInfo);

int32_t lc70_readSetFile(LC70_FILE_ID_T fileId, void *pDat, const char *pcUserFileName, BOOL bDefault);
int32_t lc70_writeSetFile(LC70_FILE_ID_T fileId, void *pDat, const char *pcUserFileName, uint32_t ulUserLine);
LC70_ERR_T lc70_deleteSetFileUser(const char *pcUserFileName);
LC70_ERR_T lc70_deleteSetFileUserUsb1(const char *pcUserFileName);
LC70_ERR_T lc70_deleteSetFileUserUsb2(const char *pcUserFileName);
LC70_ERR_T lc70_deleteSetFileLogger(const char *pcUserFileName);
LC70_ERR_T lc70_deleteSetFileLoggerUsb1(const char *pcLoggerFileName);
LC70_ERR_T lc70_deleteSetFileLoggerUsb2(const char *pcLoggerFileName);
LC70_ERR_T lc70_deleteAllSetFile(void);
LC70_ERR_T lc70_deleteSetFileUserBulk(LC70_FILE_ID_T fileId);
LC70_ERR_T lc70_deleteSetFileLoggerBulk(LC70_FILE_ID_T fileId);
int32_t lc70_readSetFileIdx(LC70_FILE_ID_T fileId, void *pDat, uint32_t ulIdx, const char *pcUserFileName, BOOL bDefault);
int32_t lc70_writeSetFileIdx(LC70_FILE_ID_T fileId, void *pDat, uint32_t ulIdx, const char *pcUserFileName);

int32_t lc70_isFileIdUserSet(LC70_FILE_ID_T fileId);
int32_t lc70_isFileIdUserSetFlist(LC70_FILE_ID_T fileId);
int32_t lc70_isFileIdLoggerSet(LC70_FILE_ID_T fileId);
int32_t lc70_isFileIdLoggerSetFlist(LC70_FILE_ID_T fileId);

/* --> @@削除予定 */
/* ユーザ設定情報 */
typedef struct lc70_user_set_t {
	int32_t 	lDummy;
} LC70_USER_SET_T;

/* チャンネル定義情報 */
typedef struct lc70_chan_conf_t {
	int32_t 	lDummy;
} LC70_CHAN_CONF_T;

/* キャリブレーション設定情報 */
typedef struct lc70_cal_set_t {
	int32_t 	lDummy;
} LC70_CAL_SET_T;

LC70_ERR_T lc70_setMeasInput(LC70_INPUT_T input);
//LC70_ERR_T lc70_setDataThreshold(int32_t lBlkNum, LC70_DATA_THR_T *pThrBlk);
/* <-- @@削除予定 */

/*******************************************************************************
	extern  variable
*******************************************************************************/
extern const LC70_MEAS_SET_MANU_BDSYS_MOD_T g_measSetManuBdsysModDef;

#endif /* _LIBLC70_H_ */

