/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "scanlockmodel.h"

ScanLockModel::ScanLockModel(QObject *parent)
    : QAbstractListModel(parent)
    , _roleNames()
    , _scanLockList()
{
    _roleNames[GroupChannelRole] = "channel";
}

ScanLockModel::~ScanLockModel()
{
    _scanLockList.clear();
}

int ScanLockModel::rowCount(const QModelIndex &parent) const
{
    if (parent.isValid()) {
        return 0;
    }

    return _scanLockList.size();
}

QHash<int, QByteArray> ScanLockModel::roleNames() const
{
    return _roleNames;
}

QVariant ScanLockModel::data(const QModelIndex &index, int role) const
{
    if (!hasIndex(index.row(), index.column(), index.parent())) {
        return QVariant();
    }

    switch (role) {
    case GroupChannelRole:
        return QVariant(_scanLockList[index.row()].channel);
    default:
        break;
    }

    return {};
}

void ScanLockModel::append(const ScanLockData &scanLock)
{
    int position = _scanLockList.size();
    QModelIndex modelIndex = QModelIndex();
    beginInsertRows(modelIndex, position, position);
    _scanLockList.append(scanLock);
    endInsertRows();
}

void ScanLockModel::clear()
{
    _scanLockList.clear();
}

