/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SCANLOCKMODEL_H
#define SCANLOCKMODEL_H

#include <QAbstractListModel>

/**
 * @brief スキャンロックデータのメンバーに対応するロール
 */
enum ScanLockRoles {
    GroupChannelRole = Qt::UserRole + 120,     //!< チャンネル
};


/**
 * @brief スキャンロックデータ
 */
struct ScanLockData {
    QString channel;                        //!< チャンネル

    ScanLockData(QString paramChannel = "") {
        channel = paramChannel;
    }
};

/**
 * @brief スキャンロックデータ
 */
class ScanLockModel : public QAbstractListModel
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクター
     * @param parent 親オブジェクト
     */
    explicit ScanLockModel(QObject *parent = nullptr);

    /**
     * @brief デストラクター
     */
    ~ScanLockModel();

    /**
     * @brief スキャンロック(グループ)数を返す
     * @return スキャンロック(グループ)数
     */
    int rowCount(const QModelIndex &parent = QModelIndex()) const override;

    /**
     * @brief ロール名を返す
     * @return ロール名
     */
    QHash<int, QByteArray> roleNames() const override;

    /**
     * @brief スキャン結果を返す
     * @param index データの位置
     * @param role ロール
     * @return スキャン結果
     */
    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;

    /**
     * @brief スキャンロックの追加
     * @param scanLock スキャンロック
     */
    void append(const ScanLockData &scanLock);

    /**
     * @brief データをクリアー
     */
    void clear(void);

private:
    QHash<int, QByteArray> _roleNames;       //!< ロール名
    QList<ScanLockData>    _scanLockList;    //!< スキャンロック
};

#endif // SCANLOCKMODEL_H
