/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "scanresultgroupmodel.h"

ScanResultGroupModel::ScanResultGroupModel(QObject *parent)
    : QAbstractListModel(parent)
    , _roleNames()
    , _groupList()
{
    _roleNames[ChannelNumberRole] = "channelNumber";
    _roleNames[ChannelColorRole] = "channelColor";
}

ScanResultGroupModel::~ScanResultGroupModel()
{
}

int ScanResultGroupModel::rowCount(const QModelIndex &parent) const
{
    if (parent.isValid()) {
        return 0;
    }

    return _groupList.size();
}

QHash<int, QByteArray> ScanResultGroupModel::roleNames() const
{
    return _roleNames;
}

QVariant ScanResultGroupModel::data(const QModelIndex &index, int role) const
{
    if (!hasIndex(index.row(), index.column(), index.parent())) {
        return QVariant();
    }

    switch (role) {
    case ChannelNumberRole:
        return QVariant(_groupList[index.row()].channel);
        break;

    case ChannelColorRole:
        return QVariant(_groupList[index.row()].colorType);
    default:
        break;
    }

    return {};
}

void ScanResultGroupModel::append(const ScanResultGroupData &groupList)
{
    int pos = _groupList.size();
    QModelIndex index = QModelIndex();
    beginInsertRows(index, pos, pos);
    _groupList.append(groupList);
    endInsertRows();
}

void ScanResultGroupModel::clear()
{
    _groupList.clear();
}
