/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SCANRESULTGROUPMODEL_H
#define SCANRESULTGROUPMODEL_H

#include <QAbstractListModel>
#include "constant.h"

/**
 * @brief スキャン結果データのメンバーに対応するロール
 */
enum ScanResultGroupRoles {
    ChannelNumberRole = Qt::UserRole + 40,  //!< チャンネル番号
    ChannelColorRole,                       //!< チャンネルエリアの色
};

/**
 * @brief スキャン結果グループデータ
 */
struct ScanResultGroupData {
    QString channel;                        //!< チャンネル
    int colorType;                 //!< 色

    ScanResultGroupData(QString paramChannel = "", int paramColorType = 0) {
        channel = paramChannel;
        colorType = paramColorType;
    }
};

class ScanResultGroupModel : public QAbstractListModel
{
    Q_OBJECT
    Q_ENUMS(ScanResultGroupRoles)
public:
    /**
     * @brief コンストラクター
     * @param parent 親オブジェクト
     */
    explicit ScanResultGroupModel(QObject *parent = nullptr);

    /**
     * @brief デストラクター
     */
    virtual ~ScanResultGroupModel();

    /**
     * @brief スキャン結果(チャンネル)数を返す
     * @return スキャン結果(チャンネル)数
     */
    virtual int rowCount(const QModelIndex &parent = QModelIndex()) const override;

    /**
     * @brief ロール名を返す
     * @return ロール名
     */
    virtual QHash<int, QByteArray> roleNames() const override;

    /**
     * @brief スキャン結果を返す
     * @param index データの位置
     * @param role ロール
     * @return スキャン結果
     */
    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;

    /**
     * @brief スキャン結果の追加
     * @param grouplList スキャン結果(グループ)
     */
    void append(const ScanResultGroupData &groupList);

    /**
     * @brief データをクリアー
     */
    void clear(void);

private:
    QHash<int, QByteArray> _roleNames;              //!< ロール名
    QList<ScanResultGroupData> _groupList;

};

#endif
