/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "scanresultmodel.h"

ScanResultModel::ScanResultModel(QObject *parent)
    : QAbstractListModel(parent)
    , _roleNames()
    , _scanResultGroup()
{
    _roleNames[GroupNameRole] = "groupName";
    _roleNames[GroupModelRole] = "groupModel";
    _roleNames[TitleRowColorRole] = "titleRowColor";
}

ScanResultModel::~ScanResultModel()
{
}

int ScanResultModel::rowCount(const QModelIndex &parent) const
{
    if (parent.isValid()) {
        return 0;
    }

    return _scanResultGroup.size();
}

QHash<int, QByteArray> ScanResultModel::roleNames() const
{
    return _roleNames;
}

QVariant ScanResultModel::data(const QModelIndex &index, int role) const
{
    if (!hasIndex(index.row(), index.column(), index.parent())) {
        return QVariant();
    }

    switch (role) {
    case GroupNameRole:
        return QVariant(_scanResultGroup[index.row()].groupName);

    case GroupModelRole:
        return QVariant::fromValue(_scanResultGroup[index.row()].groupModel);

    case TitleRowColorRole:
        return QVariant(_scanResultGroup[index.row()].colorType);
        break;

    default:
        break;
    }

    return {};
}

void ScanResultModel::append(const ScanResultData &scanResult)
{
    int pos = _scanResultGroup.size();
    QModelIndex index = QModelIndex();
    beginInsertRows(index, pos, pos);
    _scanResultGroup.append(scanResult);
    endInsertRows();
}

void ScanResultModel::clear()
{
    for (int i = 0; i < _scanResultGroup.size(); ++i) {
        if (_scanResultGroup[i].groupModel != nullptr) {
            delete _scanResultGroup[i].groupModel;
            _scanResultGroup[i].groupModel = nullptr;
        }
    }
    emit dataChanged(index(0), index(_scanResultGroup.count() - 1), { GroupNameRole, GroupModelRole, TitleRowColorRole } );
    _scanResultGroup.clear();
}
