/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SCANRESULTMODEL_H
#define SCANRESULTMODEL_H

#include <QAbstractListModel>
#include "constant.h"
#include "scanresultgroupmodel.h"

/**
 * @brief スキャン結果データのメンバーに対応するロール
 */
enum ScanResultRoles {
    GroupNameRole = Qt::UserRole + 50,      //!< グループ名
    GroupModelRole,                         //!< グループデータ
    TitleRowColorRole,                      //!< グループエリアの色
};

/**
 * @brief スキャン結果行の色種別
 */
enum RowColorType {
    BrightColor = 0,                        //!< 明るめの色
    DarkColor,                              //!< 暗めの色
};

/**
 * @brief スキャン結果データ
 */
struct ScanResultData {
    QString groupName;                      //!< グループ名
    ScanResultGroupModel *groupModel;       //!< グループデータ
    int colorType;                          //!< 色

    ScanResultData(QString paramGroupName = "", ScanResultGroupModel *paramGroupModel = nullptr, int paramColorType = 0) {
        groupName = paramGroupName;
        if (paramGroupModel == nullptr) {
            groupModel = new ScanResultGroupModel();
        } else {
            groupModel = paramGroupModel;
        }
        colorType = paramColorType;
    }
};

/**
 * @brief スキャン結果データ
 */
class ScanResultModel : public QAbstractListModel
{
    Q_OBJECT
    Q_ENUMS(ScanResultRoles)
public:
    /**
     * @brief コンストラクター
     * @param parent 親オブジェクト
     */
    explicit ScanResultModel(QObject *parent = nullptr);

    /**
     * @brief デストラクター
     */
    ~ScanResultModel();

    /**
     * @brief スキャン結果(グループ)数を返す
     * @return スキャン結果(グループ)数
     */
    int rowCount(const QModelIndex &parent = QModelIndex()) const override;

    /**
     * @brief ロール名を返す
     * @return ロール名
     */
    QHash<int, QByteArray> roleNames() const override;

    /**
     * @brief スキャン結果を返す
     * @param index データの位置
     * @param role ロール
     * @return スキャン結果
     */
    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;

    /**
     * @brief スキャン結果の追加
     * @param scanResult スキャン結果
     */
    void append(const ScanResultData &scanResult);

    /**
     * @brief データをクリアー
     */
    void clear(void);

private:
    QHash<int, QByteArray> _roleNames;          //!< ロール名
    QList<ScanResultData> _scanResultGroup;     //!< スキャン結果
};

#endif
