/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include <QDir>
#include <QFile>
#include <QTextStream>
#include <QImage>
#include <QDebug>
#include "lc70dummy.h"

static constexpr int USER_LIT_COLUMN_COUNT = 3; //!< ユーザー設定ファイル名リストの列数
static constexpr const char *USER_LIST_FILENAME =
    "user_setting_file_list.csv";               //!< USER 設定ファイル名リストのファイル名
static constexpr const char *DATALOGGER_LIST_FILENAME =
    "logger_setting_file_list.csv";             //!< データロガー設定ファイル名リストのファイル名
static constexpr const char *IGNORE_ELEMENTS[] = { "1.0.0", "NO,ENBFLG,FILE_NAME", "End Of File" };   //!< ユーザー設定ファイル名リストの中の無視する要素

LC70Dummy::LC70Dummy(QObject *parent) : QObject(parent)
{

}

LC70_ERR_T LC70Dummy::initialize(PROC_ID_T processId)
{
    Q_UNUSED(processId)
    return LC70_OK;
    testValue = 0;
}

LC70_ERR_T LC70Dummy::readMeasureSettingFile(LC70_FILE_ID_T fileId, void *data, bool isDefault)
{
    Q_UNUSED(fileId)
    Q_UNUSED(data)
    Q_UNUSED(isDefault)
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::readSystemSettingFile(LC70_FILE_ID_T fileId, void *data, bool isDefault)
{
    Q_UNUSED(fileId)
    Q_UNUSED(data)
    Q_UNUSED(isDefault)
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::readUserSettingFile(const char *fileName, LC70_USER_SET_T *userSetting)
{
    Q_UNUSED(fileName)
    Q_UNUSED(userSetting)
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::readChannelConfigurationFile(LC70_FILE_ID_T fileId, void *data, bool isDefault)
{
    Q_UNUSED(fileId)
    Q_UNUSED(data)
    Q_UNUSED(isDefault)
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::readCalibrationSettingFile(const char *fileName,
        LC70_CAL_SET_T *calibrationSetting)
{
    Q_UNUSED(fileName)
    Q_UNUSED(calibrationSetting)
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::writeMeasureSettingFile(LC70_FILE_ID_T fileId, void *data)
{
    Q_UNUSED(fileId)
    Q_UNUSED(data)
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::writeSystemSettingFile(LC70_FILE_ID_T fileId, void *data)
{
    Q_UNUSED(fileId)
    Q_UNUSED(data)
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::writeUserSettingFile(const char *fileName, LC70_USER_SET_T *userSetting)
{
    Q_UNUSED(fileName)
    Q_UNUSED(userSetting)
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::writeChannelConfigurationFile(LC70_FILE_ID_T fileId, void *data)
{
    Q_UNUSED(fileId)
    Q_UNUSED(data)
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::writeCalibrationSettingFile(const char *fileName,
        LC70_CAL_SET_T *calibrationSetting)
{
    Q_UNUSED(fileName)
    Q_UNUSED(calibrationSetting)
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::failureInformation(LC70_FAIL_INFO_T *failureInformation)
{
    Q_UNUSED(failureInformation)
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::keyStatus(LC70_KEY_STAT_T *keyStatus)
{
    Q_UNUSED(keyStatus)
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::deviceStatus(LC70_DEV_STAT_T *deviceStatus)
{
    Q_UNUSED(deviceStatus)
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::setMeasuringInputSignal(LC70_INPUT_T inputSignal)
{
    Q_UNUSED(inputSignal)
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::setPowerSupply(LC70_POWER_SUPPLY_T outputVoltage)
{
    qDebug() << QString("setPowerSupply(%1)").arg(static_cast<int>(outputVoltage));
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::setDataThreshold(int32_t dataThresholdBlockNumber,
                                       LC70_DATA_THR_T *dataThresholdBlock)
{
    Q_UNUSED(dataThresholdBlockNumber)
    Q_UNUSED(dataThresholdBlock)
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::measuringStatus(LC70_MEAS_STAT_T *measuringStatus)
{
    Q_UNUSED(measuringStatus)
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::startSingleMeasuring(LC70_MEAS_SINGLE_T *measuringCondition)
{
    Q_UNUSED(measuringCondition)
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::stopSingleMeasuring()
{
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::startConstellationMeasuring(LC70_CONSTA_NUM_T collectionPoints)
{
    Q_UNUSED(collectionPoints)
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::stopConstellationMeasuring()
{
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::singleMeasuringResult(int16_t constellationPoints,
        LC70_MEAS_SINGLE_RESULT_T *measuringResult)
{
    Q_UNUSED(constellationPoints)
    Q_UNUSED(measuringResult)
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::startDelayProfileMeasuring()
{
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::stopDelayProfileMeasuring()
{
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::delayProfileMeasuring()
{
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::startMultiMeasuring(LC70_MEAS_MULTI_T *measuringCondition)
{
    Q_UNUSED(measuringCondition)
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::stopMultiMeasuring()
{
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::setMultiMeasuringChannel(uint8_t *measureEnabled)
{
    Q_UNUSED(measureEnabled)
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::multiMeasuringResult(int16_t index,
        LC70_MEAS_MULTI_RESULT_T *measuringResult)
{
    Q_UNUSED(index)
    Q_UNUSED(measuringResult)
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::multiMeasuringFocus(LC70_FMODE_T mode, int16_t index,
        uint16_t measuringCondition)
{
    Q_UNUSED(mode)
    Q_UNUSED(index)
    Q_UNUSED(measuringCondition)
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::systemReboot()
{
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::systemShutdown()
{
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::systemSleep()
{
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::systemWakeup()
{
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::buzzer(LC70_BUZZ_T buzzerPattern, LC70_BUZZ_MODE_T buzzerMode)
{
    qDebug() << __FUNCTION__;
    qDebug("buzzerPattern : %d", static_cast<int>(buzzerPattern));
    qDebug("buzzerMode : %d", static_cast<int>(buzzerMode));
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::fourceBuzzerVolume(LC70_BUZZ_T buzzerPattern, int buzzerVolume)
{
    qDebug() << __FUNCTION__;
    qDebug("buzzerPattern : %d", static_cast<int>(buzzerPattern));
    qDebug("set BuzzerVolume : %d", buzzerVolume);
    return LC70_OK;
}

int LC70Dummy::setDateTime(int yyyy, int mm, int dd, int week, int hour, int minutes)
{
    qDebug("setDateTime: %d-%d-%d %d %d:%d", yyyy, mm, dd, week, hour, minutes);
    return 0;
}

LC70_ERR_T LC70Dummy::setAutoPowerOffTime(int offTime)
{
    qDebug("AutoPowerOffTime : %d", offTime);
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::deleteUserlogSetFile(const char *fileName)
{
    QFile file(fileName);

    LC70_ERR_T ret = LC70_OK;

    qDebug("remove file : %s", fileName);

    if (file.remove()) {
        ret = LC70_OK;
    } else {
        ret = LC70_ERR;
    }

    return ret;
}

int LC70Dummy::readSetFile(const char *fileName, LC70_LOGGER_SET_LOGGER_T &loggerSet)
{

    // initialize
    for (int i = 0; i < LC70_LOGGER_SET_LOGGER_IDX_MAX; i++) {
        memset(&(loggerSet.loggerSet[i]), 0, sizeof(LC70_LOGGER_SET_LOGGER_ROW_T));
    }

    QFile file(fileName);

    if (!file.open(QIODevice::ReadOnly)) {
        return LC70_ERR;
    }

    QTextStream in(&file);

    int idx = 0;

    while (!in.atEnd()) {
        QStringList line = in.readLine().split(",");
        loggerSet.loggerSet[idx].ucNo = line.at(0).toInt();
        loggerSet.loggerSet[idx].ucEnbFlg = line.at(1).toInt();
        loggerSet.loggerSet[idx].ucBand = line.at(2).toInt();
        loggerSet.loggerSet[idx].ucSpec = line.at(3).toInt();
        strncpy(loggerSet.loggerSet[idx].cStrChNo, line.at(4).toUtf8().constData(), line.at(4).toUtf8().size());
        loggerSet.loggerSet[idx].ulCenterFreq = line.at(5).toULong();
        loggerSet.loggerSet[idx].ulModBit = line.at(6).toUInt();
        loggerSet.loggerSet[idx].ulLocalFreq = line.at(7).toULong();
        loggerSet.loggerSet[idx].ucGetDataFlg = line.at(8).toInt(nullptr, 16);
        loggerSet.loggerSet[idx].ucDcOut = line.at(9).toInt();
        idx++;
    }

    return idx;
}

LC70_ERR_T LC70Dummy::writeSetFile(const char *fileName, const LC70_LOGGER_SET_LOGGER_T &loggerSet, int lines)
{
    QFile file(fileName);

    if (!file.open(QIODevice::WriteOnly)) {
        return LC70_ERR;
    }

    QTextStream out(&file);

    for (int idx = 0; idx < lines; idx++) {
        out << loggerSet.loggerSet[idx].ucNo << ",";
        out << loggerSet.loggerSet[idx].ucEnbFlg << ",";
        out << loggerSet.loggerSet[idx].ucBand << ",";
        out << loggerSet.loggerSet[idx].ucSpec << ",";
        out << loggerSet.loggerSet[idx].cStrChNo << ",";
        out << loggerSet.loggerSet[idx].ulCenterFreq << ",";
        out << loggerSet.loggerSet[idx].ulModBit << ",";
        out << loggerSet.loggerSet[idx].ulLocalFreq << ",";
        out << loggerSet.loggerSet[idx].ucGetDataFlg << ",";
        out << loggerSet.loggerSet[idx].ucDcOut << "\n";
    }

    return LC70_OK;
}

LC70_ERR_T LC70Dummy::readSetFileList(const QString &dirname, QList<LC70_LOGGER_SET_LOGGER_FLIST_ROW_T> &userlogSetFileList, ChannelEditMode mode)
{
    QFile file(dirname + QString("/") + (mode == CHANNEL_EDIT_USER ? USER_LIST_FILENAME : DATALOGGER_LIST_FILENAME));

    if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
        return LC70_ERR;
    }

    int index = 0;

    QTextStream in(&file);

    while (!in.atEnd()) {
        QString line = in.readLine();
        QVector<QStringRef> values = line.splitRef(",");

        // 列の数と異なる行はスキップする
        if (values.count() != USER_LIT_COLUMN_COUNT) {
            continue;
        }

        // 無視する行(PILOT 用)
        if (line == QString(IGNORE_ELEMENTS[0]) ||
                line == QString(IGNORE_ELEMENTS[1]) ||
                line == QString(IGNORE_ELEMENTS[2])) {
            continue;
        }

        LC70_LOGGER_SET_LOGGER_FLIST_ROW_T item;
        item.ucNo = values.at(0).toInt();
        item.ucEnbFlg = values.at(1).toInt();
        strncpy(item.cFileName, values.at(2).toUtf8().constData(), LC70_LOGGER_LOGGER_FNAME_STRLEN);
        item.cFileName[LC70_LOGGER_LOGGER_FNAME_STRLEN - 1] = '\0';
        userlogSetFileList.append(item);

        index++;
    }

    return LC70_OK;
}

LC70_ERR_T LC70Dummy::writeSetFileList(const QString &dirname, QList<LC70_LOGGER_SET_LOGGER_FLIST_ROW_T> &userlogSetFileList, ChannelEditMode mode)
{
    QFile file(dirname + QString("/") + (mode == CHANNEL_EDIT_USER ? USER_LIST_FILENAME : DATALOGGER_LIST_FILENAME));

    if (!file.open(QIODevice::WriteOnly | QIODevice::Text)) {
        return LC70_ERR;
    }

    QTextStream out(&file);

    int lines = 0;

    // ヘッダー
    out << "1.0.0" << endl;
    out << "NO,ENBFLG,FILE_NAME" << endl;

    foreach (const LC70_LOGGER_SET_LOGGER_FLIST_ROW_T &item, userlogSetFileList) {
        out << item.ucNo << ",";
        out << item.ucEnbFlg << ",";
        out << QString(item.cFileName) << "\n";
        lines++;
    }

    // フッター
    out << "End Of File" << endl;

    qDebug("writeSetFileList() lines:%d", lines);
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::setThresholdData(QVariantList thresholdData)
{
    for (int i = 0; i < LC70_BAND_END; i++) {
        qDebug() << thresholdData.at(i);
    }

    return LC70_OK;
}

LC70_ERR_T LC70Dummy::setConstellationShowPoint(int constellationSelectNum)
{
    qDebug() << "setConstellationShowPoint" << constellationSelectNum;
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::setLebelOffsetData(QVariantList levelOffsetDataList)
{
    for (int i = 0; i < LC70_MEAS_SET_CABLE_LOSS_IDX_MAX; i++) {
        qDebug() << levelOffsetDataList.at(i);
    }

    return LC70_OK;
}
LC70_ERR_T LC70Dummy::setSoundVolume(int soundVolume)
{
    qDebug("setSoundVolume : %d", soundVolume);
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::setBrightness(int brightness)
{
    qDebug("setBrightness : %d", brightness);
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::setScreenBrightness(int brightness)
{
    qDebug("set Test Brightness : %d", brightness);
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::setLocalFrequency(QVariantList localFrequency)
{
    for (int i = 0; i < LC70_MEAS_SET_LOCAL_FREQ_IDX_MAX; i++) {
        qDebug() << localFrequency.at(i);
    }

    return LC70_OK;
}

LC70_ERR_T LC70Dummy::setIsEnableCableLoss(int isEnableCableLoss)
{
    qDebug("setIsEnableCableLoss : %d", isEnableCableLoss);

    return LC70_OK;
}

LC70_ERR_T LC70Dummy::setMERCN(int mercnValue)
{
    qDebug("setBrightness : %d", mercnValue);
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::setCATVChannelFrequency(int settingNo)
{
    qDebug("setCATVChannelFrequency : %d", settingNo);
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::startOpticalMeasurement(uint32_t ulWaveLength)
{
    qDebug("start Optical Measurement : %d", ulWaveLength);
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::stopOpticalMeasurement()
{
    qDebug("stop Optical Measurement");
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::getOpticalMeasurementResult(QVariant &result)
{
    //qDebug("get Optical Measurement result");
    result = QVariant(-650);
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::startDCMeasurement()
{
    qDebug("start DC Measurement");
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::stopDCMeasurement()
{
    qDebug("stop DC Measurement");
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::getDCMeasurementResult(QVariant &result)
{
    result = QVariant(12345);
    return LC70_OK;
}

LC70_ERR_T LC70Dummy::getModelInformation(LC70_PRODUCT_INFO_T &result)
{
    Q_UNUSED(result);
    return  LC70_OK;
}

LC70_ERR_T LC70Dummy::resetSubCpu(void)
{
    return LC70_OK;
}
