/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "paralleltask.h"

ParallelTask::ParallelTask(SystemLog &systemLog, QObject *parent)
    : QObject(parent)
    , _systemLog(systemLog)
    , _initialized(false)
    , _thread(nullptr)
    , _working(false)
{

}

ParallelTask::~ParallelTask()
{
    if (this->_thread == nullptr) {
        return;
    }

    if (this->_thread->isRunning()) {
        this->_thread->suspend();
    }

    delete _thread;
    _thread = nullptr;
}

bool ParallelTask::attach(ThreadBase *thread, const QString &name)
{
    if (thread == nullptr) {
        return false;
    }

    if (this->_thread != nullptr) {
        return false;
    }

    this->_thread = thread;
    this->_thread->setObjectName(name);

    // スレッド開始後、タイマーの指定間隔経過後に発火する
    connect(this->_thread, &ThreadBase::alarm, this, &ParallelTask::work);

    // 処理をスレッドに割り当てる
    this->moveToThread(_thread);

    // スレッド開始
    _thread->start();

    return true;
}

bool ParallelTask::detach()
{
    if (this->_thread == nullptr) {
        return false;
    }

    disconnect(_thread, SIGNAL(started()), this, SLOT(work()));
    _thread = nullptr;

    return true;
}

bool ParallelTask::resume(void)
{
    if (this->_thread == nullptr) {
        return false;
    }

    _working = true;
    this->_thread->resume();

    return true;
}

bool ParallelTask::suspend(void)
{
    if (this->_thread == nullptr) {
        return false;
    }

    this->_thread->suspend();
    _working = false;

    return true;
}

void ParallelTask::setPriority(const QThread::Priority &priority)
{
    if (this->_thread == nullptr) {
        return;
    }

    this->_thread->setPriority(priority);
}

ThreadBase *ParallelTask::usingThread()
{
    return this->_thread;
}

bool ParallelTask::isWorking() const
{
    return _working;
}
