/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "threadbase.h"

ThreadBase::ThreadBase(uint32_t interval)
    : _priority(InheritPriority)
    , _timer(nullptr)
    , _interval(interval)
{
}

ThreadBase::~ThreadBase()
{
    if (_timer) {
        delete _timer;
        _timer = nullptr;
    }
}

bool ThreadBase::resume()
{
    if (this->isRunning()) {
        return false;
    }

    this->start(this->_priority);

    return true;
}

bool ThreadBase::suspend()
{
    if (!this->isRunning()) {
        return false;
    }

    // タイムアウトのsignalを受け取らないようにする
    QObject::disconnect(_timer, &QTimer::timeout, this, &ThreadBase::alarm);

    this->requestInterruption();
    this->quit();
    this->wait();

    return true;
}

void ThreadBase::run()
{
    if (!_timer) {
        _timer = new QTimer;
    }

    _timer->setInterval(this->_interval);
    QObject::connect(_timer, &QTimer::timeout, this, &ThreadBase::alarm);
    _timer->start();
    this->QThread::exec();
    _timer->stop();
}

void ThreadBase::setPriority(const QThread::Priority &priority)
{
    _priority = priority;
}

void ThreadBase::setInterval(const uint32_t &interval)
{
    if (!_timer) {
        return;
    }

    _timer->setInterval(interval);
}
