/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef THREADBASE_H
#define THREADBASE_H

#include <QThread>
#include <QTimer>
/**
 * @brief スレッドの基底クラス
 */
class ThreadBase : public QThread
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクター
     * @param interval タイマーの間隔
     */
    explicit ThreadBase(uint32_t interval);

    /**
     * @brief デストラクター
     */
    virtual ~ThreadBase() override;

    /**
     * @brief スレッドの優先度を設定する
     * @param priority スレッドの優先度
     */
    void setPriority(const Priority &priority);

    /**
     * @brief 定周期の間隔を設定する
     * @param interval 定周期の間隔
     */
    void setInterval(const uint32_t &interval);

    /**
     * @brief 開始、再開処理を行う
     */
    bool resume(void);

    /**
     * @brief 中断処理を行う
     * @note 本メソッドを呼び出してから中断を開始するので即中断にはなるわけではない
     */
    bool suspend(void);

signals:
    /**
     * @brief タイマーの指定間隔が経過したことを通知
     */
    void alarm(void);

protected:
    /**
     * @brief run
     */
    virtual void run() override;

private:
    Priority _priority;           //!< スレッドの優先度
    QTimer *_timer;               //!< タイマー
    uint32_t _interval;           //!< タイマーの間隔
};
#endif  // THREADBASE_H
