/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "valueelement.h"

ValueElement::ValueElement():
    _isUpdate(false)
{
}

ValueElement::~ValueElement()
{

}

void ValueElement::setInitialValue(const QVariant &v)
{
    _value.setValue(v);
    _dirtyValue.clear();
    _isUpdate = false;
}

QVariant ValueElement::getValue()
{
    return _isUpdate ? _dirtyValue : _value;
}

void ValueElement::setValue(const QVariant &v)
{
    // 同値であった場合は更新とはしない
    if (_value != v) {
        _dirtyValue.setValue(v);
        _isUpdate = true;
    } else {
        _isUpdate = false;
    }
}

void ValueElement::commit()
{
    if (_isUpdate == false) {
        qDebug("commit is wrong");
        return;
    }

    _value.setValue(_dirtyValue);
    _dirtyValue.clear();
    _isUpdate = false;
}

void ValueElement::rollback()
{
    _dirtyValue.clear();
    _isUpdate = false;
}

bool ValueElement::isUpdate()
{
    return _isUpdate;
}
