/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
import QtQuick.Controls 2.12
import "../parts"

/**
 * @brief データロガー View
 */
Item {
    id:root
    objectName: "DataLogger"
    implicitWidth: 800
    implicitHeight: 480
    property string trashIcon: "trash_disable.png"
    property bool noDownArrow: false                // 測定開始の下矢印を見せない

    signal request(int condition)

    // 前画面の設定値を受け取るための仕組み
    // ここから
    function backup(key, value) {
        var temporary = attributes.takeOver
        temporary[key] = value
        attributes.takeOver = temporary
    }
    Item {
        id: takeOverData
        objectName: "takeOverData"
        property int dataloggerFunction: 0
    }

    Rectangle {
        id: background
        objectName: "background"
        width: 700
        height: 313
        color: "#30333A"
        x: 25
        y: 0
    }

    // ユーザデータ選択用リスト
    Image {
        objectName: "userSelectListBg"
        source: "qrc:/resource/png/datalogger_userlist_base.png"
        y: userdataPage.height
        x: userSelectList.x
    }

    // USERファイルページ数
    Text {
        id: userdataPage
        objectName: "userfilelistpage"
        text: "1/10"
        anchors {
            top: parent.top
            left: parent.left
        }

        width: 173
        height: 33
        verticalAlignment: Text.AlignVCenter
        horizontalAlignment: Text.AlignRight
        color: "white"
        font.pixelSize: 16
        font.family: defaultFontName
    }

    Column {
        id:userSelectList
        objectName: "userSelectList"

        Item {
            id: userDataPagePadding
            height: 33
            width: 10
        }

        ListItem {
            id: userdata0
            objectName: "userdata0"
            activebg: "datalogger_userlist_btn_active_rd.png"
            idlebg: ""
            width:183
            height:40
            fontsize:12
        }
        ListItem {
            id: userdata1
            objectName: "userdata1"
            activebg: "datalogger_userlist_btn_active_urd.png"
            idlebg: ""
            width:183
            height:40
            fontsize:12
        }
        ListItem {
            id: userdata2
            objectName: "userdata2"
            activebg: "datalogger_userlist_btn_active_urd.png"
            idlebg: ""
            width:183
            height:40
            fontsize:12
        }
        ListItem {
            id: userdata3
            objectName: "userdata3"
            activebg: "datalogger_userlist_btn_active_urd.png"
            idlebg: ""
            width:183
            height:40
            fontsize:12
        }
        ListItem {
            id: userdata4
            objectName: "userdata4"
            activebg: "datalogger_userlist_btn_active_urd.png"
            idlebg: ""
            width:183
            height:40
            fontsize:12
        }
        ListItem {
            id: userdata5
            objectName: "userdata5"
            activebg: "datalogger_userlist_btn_active_urd.png"
            idlebg: ""
            width:183
            height:40
            fontsize:12
        }
        ListItem {
            id: userdata6
            objectName: "userdata6"
            activebg: "datalogger_userlist_btn_active_urd.png"
            idlebg: ""
            width:183
            height:40
            fontsize:12
        }
        ListItem {
            id: userdata7
            objectName: "userdata7"
            activebg: "datalogger_userlist_btn_active_urd.png"
            idlebg: ""
            width:183
            height:40
            fontsize:12
        }
        ListItem {
            id: userdata8
            objectName: "userdata8"
            activebg: "datalogger_userlist_btn_active_urd.png"
            idlebg: ""
            width:183
            height:40
            fontsize:12
        }
        ListItem {
            id: userdata9
            objectName: "userdata9"
            activebg: "datalogger_userlist_btn_active_ur.png"
            idlebg: ""
            width:183
            height:40
            fontsize:12
        }
    }
    // チャンネルリスト
    // 6つのアイテム
    Item {
        id: channelListBase
        objectName: "channelListBase"
        anchors.top: userSelectList.top
        anchors.left: userSelectList.right

        Image {
            id: channelListBg
            objectName: "channelListBg"
            source: "qrc:/resource/png/datalogger_channellist_bg.png"
        }

        Column {
            id: channelList
            Row {
                width: 550
                anchors.horizontalCenter: parent.horizontalCenter

                Text {
                    id:channelNumDisp
                    objectName: "channelNumDisp"
                    text: "CH登録数: 300/max120"
                    horizontalAlignment: Text.AlignLeft
                    verticalAlignment: Text.AlignVCenter
                    color: "white"
                    font.pixelSize: 16
                    font.family: defaultFontName
                    width: parent.width/2
                    visible: false
                    height: 33
                }
                Text {
                    id:channelListPage
                    objectName: "channelListPage"
                    text: "ページ 1/20"
                    horizontalAlignment: Text.AlignRight
                    verticalAlignment: Text.AlignVCenter
                    color: "white"
                    font.pixelSize: 16
                    font.family: defaultFontName
                    width: parent.width/2
                    visible: false
                    height: 33
                }
            }
            Text {
                id:channelInfoDisp
                objectName: "channelInfoDisp"
                text: "1: xxxxx に登録されているCH: 1/34 ページ"
                anchors {
                    left: listHeader.left
                    right: listHeader.right
                }
                horizontalAlignment: Text.AlignRight
                verticalAlignment: Text.AlignVCenter
                color: "white"
                font.pixelSize: 16
                font.family: defaultFontName
                visible: false
                height: 33
            }
            Row {
                id: listHeader
                height:34
                spacing:2

                Text {
                    objectName: "row1"
                    text: "No."
                    height:listHeader.height
                    width: 40
                    horizontalAlignment: Text.AlignHCenter
                    verticalAlignment: Text.AlignVCenter
                    color: "skyblue"
                    font.pixelSize: 13
                    font.family: defaultFontName
                }
                Text {
                    objectName: "row2"
                    text: "BAND"
                    height:listHeader.height
                    width: 63
                    horizontalAlignment: Text.AlignHCenter
                    verticalAlignment: Text.AlignVCenter
                    color: "skyblue"
                    font.pixelSize: 13
                    font.family: defaultFontName
                }
                Text {
                    objectName: "row3"
                    text: "放送規格"
                    height:listHeader.height
                    width: 63
                    horizontalAlignment: Text.AlignHCenter
                    verticalAlignment: Text.AlignVCenter
                    color: "skyblue"
                    font.pixelSize: 13
                    font.family: defaultFontName
                }
                Text {
                    objectName: "row4"
                    text: "CH"
                    height:listHeader.height
                    width: 63
                    horizontalAlignment: Text.AlignHCenter
                    verticalAlignment: Text.AlignVCenter
                    color: "skyblue"
                    font.pixelSize: 13
                    font.family: defaultFontName
                }
                Text {
                    objectName: "row5"
                    text: "変調方式"
                    height:listHeader.height
                    width: 63
                    horizontalAlignment: Text.AlignHCenter
                    verticalAlignment: Text.AlignVCenter
                    color: "skyblue"
                    font.pixelSize: 13
                    font.family: defaultFontName
                }
                Text {
                    objectName: "row6"
                    text: "局発"
                    height:listHeader.height
                    width: 63
                    horizontalAlignment: Text.AlignHCenter
                    verticalAlignment: Text.AlignVCenter
                    color: "skyblue"
                    font.pixelSize: 13
                    font.family: defaultFontName
                }
                Text {
                    objectName: "row7"
                    text: "MER\n/CN"
                    height:listHeader.height
                    width: 38
                    horizontalAlignment: Text.AlignHCenter
                    verticalAlignment: Text.AlignVCenter
                    color: "skyblue"
                    font.pixelSize: 13
                    font.family: defaultFontName
                }
                Text {
                    objectName: "row8"
                    text: "BER"
                    height:listHeader.height
                    width: 38
                    horizontalAlignment: Text.AlignHCenter
                    verticalAlignment: Text.AlignVCenter
                    color: "skyblue"
                    font.pixelSize: 13
                    font.family: defaultFontName
                }
                Text {
                    objectName: "row9"
                    text: "給電"
                    height:listHeader.height
                    width: 63
                    horizontalAlignment: Text.AlignHCenter
                    verticalAlignment: Text.AlignVCenter
                    color: "skyblue"
                    font.pixelSize: 13
                    font.family: defaultFontName
                }
                Text {
                    objectName: "row10"
                    text: "削除"
                    height:listHeader.height
                    width: 39
                    horizontalAlignment: Text.AlignHCenter
                    verticalAlignment: Text.AlignVCenter
                    color: "skyblue"
                    font.pixelSize: 13
                    font.family: defaultFontName
                }
            }

            ChannelListEdit {
                id:list0
                objectName: "list0"
                activebg: "datalogger_channellist_cur_d.png"
                idlebg:""
                editbg: "datalogger_channellist_cur_edit.png"
                trashIcon: root.trashIcon
            }
            ChannelListEdit {
                id:list1
                objectName: "list1"
                activebg: "datalogger_channellist_cur_ud.png"
                idlebg:""
                editbg: "datalogger_channellist_cur_edit.png"
                trashIcon: root.trashIcon
            }
            ChannelListEdit {
                id:list2
                objectName: "list2"
                activebg: "datalogger_channellist_cur_ud.png"
                idlebg:""
                editbg: "datalogger_channellist_cur_edit.png"
                trashIcon: root.trashIcon
            }
            ChannelListEdit {
                id:list3
                objectName: "list3"
                activebg: "datalogger_channellist_cur_ud.png"
                idlebg:""
                editbg: "datalogger_channellist_cur_edit.png"
                trashIcon: root.trashIcon
            }
            ChannelListEdit {
                id:list4
                objectName: "list4"
                activebg: "datalogger_channellist_cur_ud.png"
                idlebg:""
                editbg: "datalogger_channellist_cur_edit.png"
                trashIcon: root.trashIcon
            }
            ChannelListEdit {
                id:list5
                objectName: "list5"
                activebg: "datalogger_channellist_cur_u.png"
                idlebg:""
                editbg: "datalogger_channellist_cur_edit.png"
                trashIcon: root.trashIcon
            }
        }
    }

    Item {
        id: operationKey
        objectName: "operationKey"
        width: 800
        y: 330
        property bool visibleDownUP: false
        Row {
            anchors.horizontalCenter: parent.horizontalCenter

            height:20
            spacing:10
            Image {
                source:"qrc:/resource/png/icon_key_menu.png"
                width:20
                height:parent.height
                visible: operationKey.visibleDownUP
            }
            Text {
                text:"DOWN・UP：ページ移動"
                horizontalAlignment: Text.AlignRight
                verticalAlignment: Text.AlignVCenter
                color: "skyblue"
                font.pixelSize: 12
                font.family: defaultFontName
                anchors.verticalCenter: parent.verticalCenter
                visible: operationKey.visibleDownUP
            }
            Item {
                width: 10
                height: parent.height
            }

            Image {
                source:"qrc:/resource/png/icon_key_cross.png"
                width:20
                height:parent.height
            }
            Text {
                text:"十字キー：カーソル移動"
                horizontalAlignment: Text.AlignRight
                verticalAlignment: Text.AlignVCenter
                color: "skyblue"
                font.pixelSize: 12
                font.family: defaultFontName
                anchors.verticalCenter: parent.verticalCenter
            }
            Item {
                width: 10
                height: parent.height
            }
            Image {
                source:"qrc:/resource/png/icon_key_enter.png"
                width:20
                height:parent.height
            }
            Text {
                text:"決定キー"
                horizontalAlignment: Text.AlignRight
                verticalAlignment: Text.AlignVCenter
                color: "skyblue"
                font.pixelSize: 12
                font.family: defaultFontName
                anchors.verticalCenter: parent.verticalCenter
            }
            Item {
                width: 10
                height: parent.height
            }
            Image {
                source:"qrc:/resource/png/icon_key_esc.png"
                width:20
                height:parent.height
            }
            Text {
                text:"ESCキー"
                horizontalAlignment: Text.AlignRight
                verticalAlignment: Text.AlignVCenter
                color: "skyblue"
                font.pixelSize: 12
                font.family: defaultFontName
                anchors.verticalCenter: parent.verticalCenter
            }
        }
    }

    //　実行ボタンリスト
    Column {
        id: executeList
        width:children.width
        anchors.right:root.right
        y:listHeader.y

        SelectButton {
            id: execute1
            objectName: "execute1"
            message: ""
            width:63
            height:176
            activebg: (!noDownArrow) ? "datalogger_action_btn_active_ld.png" : "datalogger_action_btn_active_ld2.png"
            idlebg: "datalogger_action_btn.png"
            pressbg: "datalogger_action_btn_p.png"
        }
        Item {
            width: 55
            height: 20
        }
        SelectButton {
            id: execute2
            objectName: "execute2"
            message: "削\n除"
            width:63
            height:176
            activebg:"datalogger_action_btn_active_ul.png"
            idlebg: "datalogger_action_btn.png"
            pressbg: "datalogger_action_btn_p.png"
        }
    }

    ScreenName {
        objectName: "screenName"
        name: ""
    }

    Item {
        id:dgPopup
        objectName:"dgPopup"
        width:root.width
        height:root.height + 50
        y: -50
        visible: false

        // type 0 ... 取得開始POPUP
        // type 1 ... 日時設定POPUP
        // type 2 ... 取得間隔POPUP
        // type 3 ... 待機中POPUP
        property int popupType: -1
        property string rightButtonMessage: ""
        property string leftButtonMessage: ""

        property string message:""
        property int interval: 0

        onPopupTypeChanged: {
            bg.popupType = popupType
        }

        onIntervalChanged: {
            datetimeintervaldata.interval = interval
            intervaldata.interval = interval
        }

        Rectangle {
            id:base
            anchors.fill:parent
            color: "#41444d"
            opacity: 0.5
        }

        Rectangle {
            id:bg
            anchors.centerIn: parent
            radius: 10
            color: "#41444d"
            border.color: "#333333"

            property int popupType: -1

            onPopupTypeChanged: {
                row.popupType = popupType
            }

            // popupType 毎の大きさ定義
            property var wArray: [580, 580, 460, 460, 460]
            property var hArray: [340, 440, 340, 160, 160]

            width:  wArray[dgPopup.popupType]
            height: hArray[dgPopup.popupType]

            // メッセージ領域
            Text {
                id: messageArea
                anchors {
                    horizontalCenter: parent.horizontalCenter
                    top: parent.top
                    topMargin: (dgPopup.popupType === 3) ? 30 : 15
                }
                color: "white"
                font.family: defaultFontName
                font.pixelSize: 18
                horizontalAlignment: Text.AlignLeft
                text: dgPopup.message
            }

            // ボタン領域
            Rectangle { // 区切り線
                width: bg.wArray[dgPopup.popupType] - 60
                height:1
                color:"gray"
                anchors {
                    bottom:row.top
                    bottomMargin: 10
                    horizontalCenter: bg.horizontalCenter
                }
            }

            Row {
                id: row
                property int popupType:-1

                onPopupTypeChanged: {
                    if (popupType == 0) {
                        leftButton.activebg = "dialog_dataLogger_start_r.png"
                        leftButton.idlebg = "dialog_dataLogger_start_n.png"
                        leftButton.width = 176
                        leftButton.height = 60

                        rightButton.activebg = "dialog_dataLogger_start_l.png"
                        rightButton.idlebg = "dialog_dataLogger_start_n.png"
                        rightButton.width = 176
                        rightButton.height = 60
                    }
                    else if (popupType === 1) {
                        leftButton.activebg = "selectbtn_u.png"
                        leftButton.idlebg = "selectbtn.png"
                        leftButton.width = 168
                        leftButton.height = 60
                    }
                    else if (popupType == 2) {
                        leftButton.activebg = "selectbtn_u.png"
                        leftButton.idlebg = "selectbtn.png"
                        leftButton.width = 168
                        leftButton.height = 60
                        leftButton.active = false
                    }
                    else if (popupType == 3) {
                        leftButton.activebg = "dialogbtn156_one.png"
                        leftButton.idlebg = "dialogbtn156_n.png"
                        leftButton.width = 140
                        leftButton.height = 42
                    }
                    else {
                        leftButton.activebg = "dialogbtn156_one.png"
                        leftButton.idlebg = "dialogbtn156_n.png"
                    }
                }

                anchors {
                    horizontalCenter: bg.horizontalCenter
                    bottom: bg.bottom
                    bottomMargin: (dgPopup.popupType === 3) ? 20 : 30
                }
                spacing: 25

                SelectButton {
                    id: leftButton
                    objectName: "m1"
                    activebg:""
                    idlebg: ""
                    width: 140
                    height: 40
                    fontsize: 18
                    active: false
                    message: dgPopup.leftButtonMessage
                }
                SelectButton {
                     id: rightButton
                     objectName: "m2"
                     activebg: ""
                     idlebg: ""
                     width: 140
                     height: 40
                     fontsize: 18
                     active: false
                     message: dgPopup.rightButtonMessage
                     visible: (dgPopup.popupType === 0) ? true : false
                 }
             }

            // データロガー　データ取得開始日時設定部品
            Item {
                id: editDate
                width:bg.width
                visible: (dgPopup.popupType === 1)

                anchors.top: messageArea.bottom
                anchors.topMargin: 10
                anchors.horizontalCenter: messageArea.horizontalCenter
                anchors.bottom: bg.bottom

                // 背景画像
                Image {
                    id: datetimeBackground
                    anchors.horizontalCenter: editDate.horizontalCenter
                    source: "qrc:/resource/png/datalogger_datetime_base.png"
                    y:20
                }

                Image {
                    id: startDatetimeBackground
                    objectName: "startDatetimeBackground"
                    x: 65
                    y: 63
                    property string startDatetimeBackgroundImage: ""
                    source: startDatetimeBackgroundImage
                }

                Image {
                    id: endDatetimeBackground
                    objectName: "endDatetimeBackground"
                    anchors.horizontalCenter: editDate.horizontalCenter
                    y: 175
                    property string endDatetimeBackgroundImage: ""
                    source: endDatetimeBackgroundImage
                }

                Column {
                    x: datetimeBackground.x

                    Text {
                        id: measurableTime
                        objectName: "measurableTime"
                        width:525
                        color: "white"
                        font.family: defaultFontName
                        font.pixelSize: 16
                        horizontalAlignment: Text.Center
                        text: "測定可能時間は約 12 時間"
                    }

                    Row {
                        Column {
                            id: startmonthcolumn1
                            Text {
                                text: "開始日付"
                                width: startdaterow1.width
                                height: 45
                                horizontalAlignment: Text.AlignHCenter
                                verticalAlignment: Text.AlignVCenter
                                font.family: defaultFontName
                                color: "skyblue"
                            }

                            Row {
                                id: startdaterow1
                                
                                ListItem {
                                    id: startmonthdata
                                    objectName: "startmonthdata"
                                    property string activebgImage: ""
                                    message:"4月"
                                    width: 60
                                    height:60
                                    activebg: activebgImage
                                    idlebg: ""
                                    messageAlign: Text.AlignHCenter
                                    type: 2
                                }

                                ListItem {
                                    id: startdaydata
                                    objectName: "startdaydata"
                                    message:"1日"
                                    width: 60
                                    height:60
                                    activebg: "datetime_btn_lr.png"
                                    idlebg: ""
                                    messageAlign: Text.AlignHCenter
                                    type: 2
                                }
                            }
                        }
                        Item {
                            width:30
                            height:105
                        }
                        Column {
                            id: startmonthcolumn2
                            Text {
                                text: "開始時刻"
                                width: startdaterow2.width
                                height: 45
                                horizontalAlignment: Text.AlignHCenter
                                verticalAlignment: Text.AlignVCenter
                                font.family: defaultFontName
                                color: "skyblue"
                            }
                            Row {
                                id: startdaterow2
                                //spacing: -10

                                ListItem {
                                    id: starthourdata
                                    objectName: "starthourdata"
                                    message: "10"
                                    width:60
                                    height:60
                                    activebg: "datetime_btn_lr.png"
                                    idlebg: ""
                                    messageAlign: Text.AlignHCenter
                                    type: 2
                                }

                                Text {
                                    text: ":"
                                    verticalAlignment: Text.AlignVCenter
                                    horizontalAlignment: Text.AlignHCenter
                                    height: 60
                                    width: 30
                                    font.family: defaultFontName
                                    font.pixelSize: 24
                                    color: "white"
                                }
                                ListItem {
                                    id: startminutesdata
                                    objectName: "startminutesdata"
                                    message: "59"
                                    width:60
                                    height:60
                                    activebg: "datetime_btn_l.png"
                                    idlebg: ""
                                    messageAlign: Text.AlignHCenter
                                    type: 2
                                }
                            }
                        }
                    }
                    Item {
                        width: 10
                        height: 18
                    }
                    Row {
                        Column {
                            id: endmonthcolumn1
                            Text {
                                text: "終了日付"
                                width: enddaterow1.width
                                height: 45
                                horizontalAlignment: Text.AlignHCenter
                                verticalAlignment: Text.AlignVCenter
                                font.family: defaultFontName
                                color: "skyblue"
                            }
                            Row {
                                id: enddaterow1

                                ListItem {
                                    id: endmonthdata
                                    objectName: "endmonthdata"
                                    property string activebgImage: ""
                                    message:"4月"
                                    width: 60
                                    height:60
                                    activebg: activebgImage
                                    idlebg: ""
                                    messageAlign: Text.AlignHCenter
                                    type: 2
                                }

                                ListItem {
                                    id: enddaydata
                                    objectName: "enddaydata"
                                    message:"1日"
                                    width: 60
                                    height:60
                                    activebg: "datetime_btn_lr.png"
                                    idlebg: ""
                                    messageAlign: Text.AlignHCenter
                                    type: 2
                                }
                            }
                        }
                        Item {
                            width:30
                            height:45
                        }
                        Column {
                            id: endmonthcolumn2
                            Text {
                                text: "終了時刻"
                                width: enddaterow2.width
                                height: 45
                                horizontalAlignment: Text.AlignHCenter
                                verticalAlignment: Text.AlignVCenter
                                font.family: defaultFontName
                                color: "skyblue"
                            }
                            Row {
                                id: enddaterow2

                                ListItem {
                                    id: endhourdata
                                    objectName: "endhourdata"
                                    message: "10"
                                    width:60
                                    height:60
                                    activebg: "datetime_btn_lr.png"
                                    idlebg: ""
                                    messageAlign: Text.AlignHCenter
                                    type: 2
                                }
                                Text {
                                    text: ":"
                                    verticalAlignment: Text.AlignVCenter
                                    horizontalAlignment: Text.AlignHCenter
                                    height: 60
                                    width: 30
                                    font.family: defaultFontName
                                    font.pixelSize: 24
                                    color: "white"
                                }
                                ListItem {
                                    id: endminutesdata
                                    objectName: "endminutesdata"
                                    message: "59"
                                    width:60
                                    height:60
                                    activebg: "datetime_btn_lr.png"
                                    idlebg: ""
                                    messageAlign: Text.AlignHCenter
                                    type: 2
                                }
                            }
                        }
                        Item {
                            width:30
                            height:45
                        }
                        Column {
                            id: datetimecollectinterval
                            Text {
                                id: datetimeintervalMessage
                                text: "間隔"
                                width: datetimeintervaldata.width
                                height: 45
                                horizontalAlignment: Text.AlignHCenter
                                verticalAlignment: Text.AlignVCenter
                                font.family: defaultFontName
                                color: "skyblue"
                            }

                            Row {
                                ListItem {
                                    id: datetimeintervaldata
                                    objectName: "datetimeintervaldata"
                                    message: "連続"
                                    width: 120
                                    height:60
                                    activebg: "datetime_btn_interval_l.png"
                                    idlebg: ""
                                    messageAlign: Text.AlignHCenter
                                    type: 2
                                    property int interval: dgPopup.interval
                                    onIntervalChanged: {
                                        switch(interval) {
                                        case 0:
                                            message = "連続"
                                            break;
                                        case 1:
                                            message = "5分"
                                            break;
                                        case 2:
                                            message = "15分"
                                            break;
                                        case 3:
                                            message = "30分"
                                            break;
                                        case 4:
                                            message = "60分"
                                            break;
                                        default:
                                            message = "連続"
                                            break;
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }

            Image {
                id: collectminbg
                source: "qrc:/resource/png/datalogger_collect_interval_min_bg.png"
                visible: dgPopup.popupType === 2

                anchors.top: messageArea.bottom
                anchors.topMargin: 10
                anchors.horizontalCenter: messageArea.horizontalCenter

                Column {
                    id: collectinterval
                    y:5
                    Text {
                        id: intervalMessage
                        text: "間隔"
                        width: intervaldata.width
                        height: 20
                        horizontalAlignment: Text.AlignHCenter
                        verticalAlignment: Text.AlignVCenter
                        font.family: defaultFontName
                        color: "skyblue"
                    }
                    Item {
                        width: 10
                        height: 6
                    }
                    ListItem {
                        id: intervaldata
                        objectName: "intervaldata"
                        message: "連続"
                        messageAlign: Text.AlignHCenter
                        width: 160
                        height:40
                        activebg: "datalogger_interval_btn_d.png"
                        idlebg: ""
                        type: 2
                        property int interval: dgPopup.interval
                        onIntervalChanged: {
                            switch(interval) {
                            case 0:
                                message = "連続"
                                break;
                            case 1:
                                message = "5分"
                                break;
                            case 2:
                                message = "15分"
                                break;
                            case 3:
                                message = "30分"
                                break;
                            case 4:
                                message = "60分"
                                break;
                            default:
                                message = "連続"
                                break;
                            }
                        }
                    }
                }
            }
        }
    }
}
