/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0

import "../parts"

/**
 * @brief Data Logger Menu
 */
Item {
    id: root
    objectName: "DataLoggerSetting"
    anchors.fill: parent

    property bool readData1: false          // 取込みデータ1 true:データあり
    property bool readData2: false          // 取込みデータ2 true:データあり

    signal request(int condition)

    function backup(key, value) {
        var temporary = attributes.takeOver
        temporary[key] = value
        attributes.takeOver = temporary
    }

    // 枠
    Image {
        id: groupframe1
        x: functionlist1.x - 8
        y: 72
        anchors.topMargin: 10
        source: "qrc:/resource/png/frame_user_datalogger_left.png"
    }
    // 枠
    Image {
        id: groupframe2
        x: functionlist2.x - 8
        y: 72
        source: "qrc:/resource/png/frame_user_datalogger_right.png"
    }

    // 枠ラベル
    Text {
        x: groupframe1.x
        y: groupframe1.y - 12
        width: groupframe1.width
        horizontalAlignment: Text.AlignHCenter
        color:"white"
        text: "内蔵メモリデータ"
        font.pixelSize: 18
        font.family: defaultFontName
    }
    // 枠ラベル
    Text {
        x: groupframe2.x
        y: groupframe2.y - 12
        width: groupframe2.width
        horizontalAlignment: Text.AlignHCenter
        color:"white"
        text: "本体取込みデータ"
        font.pixelSize: 18
        font.family: defaultFontName
    }

    Item {
        id: selectlist

        width:selectlist.width
        height:selectlist.height
        anchors.verticalCenter: root.verticalCenter
        anchors.verticalCenterOffset: -118
        anchors.horizontalCenterOffset: 0

        Column {
            id: functionlist1
            x: 45
            spacing :15

            // USER 設定呼び出し
            SelectButton {
                id: m1
                objectName: "m1"
                activebg: "combtn_sel.png"
                idlebg: "combtn.png"
                pressbg: "combtn_p.png"
                message: "設定・呼出し"
                width: 224
                height: 82
            }
            // 一括コピー
            SelectButton {
                id: m4
                objectName: "m4"
                activebg: "combtn_sel.png"
                idlebg: "combtn.png"
                pressbg: "combtn_p.png"
                message: "データ一括コピー\n(USB)"
                width:224
                height:82
            }
        }

        Column {
            id: functionlist2
            x: 300
            spacing :15

            Row {
                // 取込みデータ1 設定・呼出し
                SelectButton {
                    id: m2
                    objectName: "m2"
                    activebg: "combtn_sel.png"
                    idlebg: "combtn.png"
                    pressbg: "combtn_p.png"
                    message: "取込みデータ1\n設定・呼出し"
                    width:224
                    height:82
                    disable: (readData1 == true) ? false : true
                }

                // 取込みデータ2 設定・呼出し
                SelectButton {
                    id: m3
                    objectName: "m3"
                    activebg: "combtn_sel.png"
                    idlebg: "combtn.png"
                    pressbg: "combtn_p.png"
                    message: "取込みデータ2\n設定・呼出し"
                    width:224
                    height:82
                    disable: (readData2 == true) ? false : true
                }
            }

            // 設定データ 本体書込み
            SelectButton {
                id: m5
                objectName: "m5"
                activebg: "combtn_sel.png"
                idlebg: "combtn.png"
                pressbg: "combtn_p.png"
                message: "設定データ\n本体書込み"
                width:224
                height:82
            }
        }
    }

    // 画面名
    ScreenName {
        name : "データロガー"
    }
}
