/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
import QtQuick.Controls 2.12
import jp.co.dxantenna.levelchecker.measureResultModel 1.0
import "../parts"

Item {
    id: root
    width: 595
    height: 290

    property int currentChannelIndex: 0         //!< 選択したチャンネルのインデックス
    property int scanChannelIndex: 0            //!< 測定中のチャンネルのインデックス
    property var measureResult: null            //!< 測定結果リスト
    property int selectCnMer: 1                 //!< CN/MERの切替選択
    readonly property int listRows: 10           //!< リストの行数
    readonly property int pixelSize: 10         //!< リスト項目の文字サイズ
    property int baseIndex: 0                   //!< 表示開始位置のインデックス

    // リストヘッダー
    Rectangle {
        id: listTitleArea
        anchors {
            top: root.top
            left: root.left
        }
        height: 41
        width: 571
        color: "transparent"
        SelectButton {
            anchors.fill: listTitleArea
            idlebg: "datamanagement_list_datalogger_header.png"
        }

        // 日時
        Label {
            id: dataLabel
            anchors {
                top: parent.top
                bottom: parent.bottom
                left: parent.left
            }
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            width: 155
            text: "日時\n(年/月/日 時:分:秒)"
            color: "#81BEFF"
            font.family: defaultFontName
            font.pointSize: pixelSize
        }

        // BAND
        Label {
            id: bandLabel
            anchors {
                top: parent.top
                bottom: parent.bottom
                left: dataLabel.right
                leftMargin: 2
            }
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            width: 83
            text: "BAND"
            color: "#81BEFF"
            font.family: defaultFontName
            font.pointSize: pixelSize
        }

        // CH
        Label {
            id: channelLabel
            anchors {
                top: parent.top
                bottom: parent.bottom
                left: bandLabel.right
                leftMargin: 2
            }
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            width: 58
            text: "CH"
            color: "#81BEFF"
            font.family: defaultFontName
            font.pointSize: pixelSize
        }

        // 周波数
        Label {
            id: freqencyLabel
            anchors {
                top: parent.top
                bottom: parent.bottom
                left: channelLabel.right
                leftMargin: 2
            }
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            width: 73
            text: "周波数\n(MHz)"
            color: "#81BEFF"
            font.family: defaultFontName
            font.pointSize: pixelSize
        }

        // LEVEL
        Label {
            id: levelLabel
            anchors {
                top: parent.top
                bottom: parent.bottom
                left: freqencyLabel.right
                leftMargin: 2
            }
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            width: 63
            text: "LEVEL\n(dBuV)"
            color: "#81BEFF"
            font.family: defaultFontName
            font.pointSize: pixelSize
        }

        // MER/CN
        Label {
            id: mercnLabel
            anchors {
                top: parent.top
                bottom: parent.bottom
                left: levelLabel.right
                leftMargin: 2
            }
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            width: 63
            text: "MER/CN\n(dB)"
            color: "#81BEFF"
            font.family: defaultFontName
            font.pointSize: pixelSize
        }

        // BER
        Label {
            id: berLabel
            anchors {
                top: parent.top
                bottom: parent.bottom
                left: mercnLabel.right
                leftMargin: 2
            }
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            width: 63
            text: "BER"
            color: "#81BEFF"
            font.family: defaultFontName
            font.pointSize: pixelSize
        }
    }

    // リスト
    ListView {
        id: listView
        width: parent.width
        height: 290
        anchors {
            top: listTitleArea.bottom
            left: listTitleArea.left
            right: listTitleArea.right
        }
        clip: true
        model: measureResult
        focus: true
        interactive: false
        delegate: delegate
    }

    Component {
        id: delegate
        Item {
            id: listItem
            width: listView.width
            height: 29
            // リスト行
            SelectButton {
                id: row
                anchors {
                    top: parent.top
                    left: parent.left
                    right: parent.right
                    bottom: parent.bottom
                }
                active: (baseIndex + index === currentChannelIndex)
                activebg: "datamanagement_list_datalogger_active.png"
                idlebg: (baseIndex + index) % 2 === 0 ? "datamanagement_list_datalogger_2.png"
                        : "datamanagement_list_datalogger_1.png"
            }

            // 日時
            Label {
                id: listDataLabel
                anchors {
                    top: parent.top
                    bottom: parent.bottom
                    left: parent.left
                }
                width: 155
                verticalAlignment: Text.AlignVCenter
                horizontalAlignment: Text.AlignHCenter
                text:　model.timestamp
                color: "#FFFFFF"
                font.family: defaultFontName
                font.pointSize: pixelSize
            }

            // BAND
            Label {
                id: listBandLabel
                anchors {
                    top: parent.top
                    bottom: parent.bottom
                    left: listDataLabel.right
                    leftMargin: 2
                }
                width: 83
                verticalAlignment: Text.AlignVCenter
                horizontalAlignment: Text.AlignHCenter
                color: "#FFFFFF"
                text: {
                    if(model.band === "スカパー！プレミアムサービス光") {
                        "スカパー！光"
                    } else {
                        model.band
                    }
                }
                font.family: defaultFontName
                font.pointSize: pixelSize
            }

            // CH
            Label {
                id: listChannelLabel
                anchors {
                    top: parent.top
                    bottom: parent.bottom
                    left: listBandLabel.right
                    leftMargin: 2
                }
                width: 58
                verticalAlignment: Text.AlignVCenter
                horizontalAlignment: Text.AlignHCenter
                color: "#FFFFFF"
                text: model.channel
                font.family: defaultFontName
                font.pointSize: pixelSize
            }

            // 周波数
            Label {
                id: listFreqencyLabel
                anchors {
                    top: parent.top
                    bottom: parent.bottom
                    left: listChannelLabel.right
                    leftMargin: 2
                }
                width: 73
                verticalAlignment: Text.AlignVCenter
                horizontalAlignment: Text.AlignHCenter
                color: "#FFFFFF"
                text: model.frequency
                font.family: defaultFontName
                font.pointSize: pixelSize
            }

            // LEVEL
            Label {
                id: listLevelLabel
                anchors {
                    top: parent.top
                    bottom: parent.bottom
                    left: listFreqencyLabel.right
                    leftMargin: 2
                }
                width: 63
                verticalAlignment: Text.AlignVCenter
                horizontalAlignment: Text.AlignHCenter
                color: "#FFFFFF"
                text: model.level
                font.family: defaultFontName
                font.pointSize: pixelSize
            }

            // MER/CN
            Label {
                id: listMerCnLabel
                anchors {
                    top: parent.top
                    bottom: parent.bottom
                    left: listLevelLabel.right
                    leftMargin: 2
                }
                width: 63
                verticalAlignment: Text.AlignVCenter
                horizontalAlignment: Text.AlignHCenter
                color: "#FFFFFF"
                text: displayMer(model.mer, model.band)
                font.family: defaultFontName
                font.pointSize: pixelSize
            }

            // BER
            Label {
                id: listBerLabel
                anchors {
                    top: parent.top
                    bottom: parent.bottom
                    left: listMerCnLabel.right
                    leftMargin: 2
                }
                width: 63
                verticalAlignment: Text.AlignVCenter
                horizontalAlignment: Text.AlignHCenter
                color: "#FFFFFF"
                text: displayBer(model.ber, model.band)
                font.family: defaultFontName
                font.pointSize: pixelSize
            }
        }
    }

    // リストをページ単位でスクロール
    function scrollPage(page)
    {
        listView.positionViewAtIndex(root.listRows * (page - 1), ListView.Beginning)
    }

    function displayMer(mer, band)
    {
        if(band === "PILOT" || band === "LTE" ||
           band === "FM" || band === "CATV上り") {
            return "---"
        }

        if (mer === "-1") {
            return "---"
        }

        return mer
    }

    function displayBer(ber, band)
    {
        if(band === "PILOT" || band === "LTE" ||
           band === "FM" || band === "CATV上り") {
            return "---"
        }

        if (ber === "-1") {
            return "---"
        }

        return ber
    }
}
