/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
import QtQuick.Controls 2.12
import "../parts"
import jp.co.dxantenna.levelchecker.measureResultModel 1.0


/**
 * @brief データロガー測定画面
 */
Item {
    id: measurementList
    objectName: "MeasurementList"
    anchors.fill: parent
    
    property var level: "000.0"                    //!< 測定入力レベル値
    property var mer: "00.0"                       //!< 変調誤差比の値
    property var ber: "0.0E-0"                     //!< ビット誤り率の値
    property var userMode: ""                      //!< ユーザーモードの値
    //property var azimuth: 0                      //!< 方位角
    property string band: ""                       //!< バンド
    property bool isSatelliteBroadCasting: false   //!< 衛星放送かどうか
    property string channel: ""                    //!< チャンネル
    property string displayFrequencyUnit: "MHz"    //!< 中心周波数表示単位
    property string frequency: ""                  //!< 中心周波数
    property string localFrequency: "00.000"       //!< 局発周波数
    property string modulation: ""                 //!< 変調方式
    property string modulationPrefix: ""           //!< 変調方式 接頭句
    property string hierarchy: ""                  //!< 階層
    property string polarization: ""               //!< 偏波
    property int startChannel: 13                  //!< 開始チャンネル
    property int endChannel: 62                    //!< 終了チャンネル
    property int minimumLevel: 20                  //!< 最小レベル
    property int maximumLevel: 120                 //!< 最大レベル
    property int currentListIndex: 0               //!< リストのインデックス
    property int currentBaseIndex: 0               //!< リスト表示開始位置のインデックス
    // property int scanChannelIndex: 0            //!< 測定中のチャンネルのインデックス
    property var values1: []                       //!< 単一の Band あるいは測定する複数の Band のうち、Band のインデックスが偶数の各チャンネルの測定入力レベル
    property var values1Low: []                    //!< 単一の Band あるいは測定する複数の Band のうち、Band のインデックスが偶数の各チャンネルの測定入力レベル(閾値未満の値)
    property var values2: []                       //!< 測定する複数の Band のうち、Band のインデックスが奇数の各チャンネルの測定入力レベル
    property var values2Low: []                    //!< 測定する複数の Band のうち、Band のインデックスが偶数の各チャンネルの測定入力レベル(閾値未満の値)
    property var values: []                        //!< 測定対象の全チャンネルの測定入力レベル
    property int currentPage: 1                    //!< 現在のページ
    property int totalPage: 1                      //!< 現在のページ
    property int selectCnMer: 1                    //!< CN/MERの選択状態
    property bool isModulationVisible: true        //!< 変調方式、表示 非表示設定 true: 表示, false: 非表示
    property var displayChannelDetail: []          //!< チャンネル詳細情報表示可否リスト (画面左下のチャンネル詳細データの表示可否のリスト)
    property var displayModulationPrefixMode: 0    //!< 変調方式 表示モード 接頭句と変調方式をどのように表示するかを決める

    signal request(int condition)

    function backup(key, value) {
        var temporary = attributes.takeOver
        temporary[key] = value
        attributes.takeOver = temporary
    }

    // 測定結果(リスト表示用)
    MeasureResultModel {
        id: measureResultModel
        objectName: "measureResultModel"
    }

    // リスト表示
    List {
        id: list
        objectName: "list"
        x: 200
        y: 22
        currentChannelIndex: measurementList.currentListIndex
        measureResult: measureResultModel
        selectCnMer: measurementList.selectCnMer
        baseIndex: measurementList.currentBaseIndex
    }

    // Page
    Label {
        width: 100
        height: 20
        anchors {
            bottom: list.top
            bottomMargin: 1
            right: parent.right
            rightMargin: 30
        }
        color: "#E6E6E6"
        font.family: defaultFontName
        visible: list.visible
        horizontalAlignment: Text.AlignRight
        text: "ページ " + measurementList.currentPage + "/" + measurementList.totalPage
    }

    // Ch./周波数
    ChannelInformation {
        labelMessage: "チャンネル"
        unitMessage: ""
        message: measurementList.channel
        width: 150
        height: 55
        x: 24
        y: 2
    }

    // 周波数
    ChannelInformation {
        labelMessage: "周波数"
        message: measurementList.frequency
        unitMessage:"MHz"
        width: 150
        height: 55
        x: 24
        y: 64
    }

    // Level
    ChannelInformation {
        labelMessage: "LEVEL"
        message: measurementList.level
        unitMessage:"dBμV"
        width: 150
        height: 55
        x: 24
        y: 124
    }

    // MER
    ChannelInformation {
        labelMessage: (measurementList.selectCnMer === 1) ? "MER" : "CN"
        message: measurementList.mer
        unitMessage:"dB"
        width: 150
        height: 55
        x: 24
        y: 184
        visible: {
            if ( (measurementList.band == "PILOT") ||
                    (measurementList.band == "LTE") ||
                 (measurementList.band == "FM") ||
                 (measurementList.band == "CATV上り") ) {
                false
            } else {
                true
            }
        }
    }

    // BER
    ChannelInformation {
        labelMessage: "BER"
        message: measurementList.ber
        width: 150
        height: 55
        x: 24
        y: 244
        visible: {
            if ( (measurementList.band == "PILOT") ||
                    (measurementList.band == "LTE") ||
                 (measurementList.band == "FM") ||
                 (measurementList.band == "CATV上り") ) {
                false
            } else {
                true
            }
        }
    }

    // チャンネル詳細データ
    ChannelDetailInformation {
        displayBand: measurementList.band
        frequency: measurementList.frequency
        displayFrequencyUnit: measurementList.displayFrequencyUnit
        modulation: measurementList.modulation
        modulationPrefix: measurementList.modulationPrefix
        hierarchy: measurementList.hierarchy
        polarization: measurementList.polarization
        localFrequency: measurementList.localFrequency
        displayChannelDetail: measurementList.displayChannelDetail
        displayModulationPrefixMode: measurementList.displayModulationPrefixMode
        x: 23
        y: 304
    }

    ScreenName {
            name:"データロガー"
    }

    // ユーザーモードのラベル
    Label {
        id: userModeLabel
        width: 100
        height: 20
        x: 633
        y: 371
        horizontalAlignment: Qt.AlignLeft
        text: (measurementList.userMode != "") ? "USER MODE : " : ""
        font.pixelSize: 14
        color: "#E4E6E5"
        font.family: defaultFontName
    }

    // ユーザーモードの値
    Text {
        id: userMode
        width: 80
        height: 20
        x: 633
        y: 393
        text: measurementList.userMode
        horizontalAlignment: Qt.AlignHCenter
        font.pixelSize: 14
        font.bold: true
        font.family: defaultFontName
        color: "#E4E6E5"
    }

    // リストのページ移動
    function onScrollPage(page)
    {
        measurementList.currentPage = page
    }
}
