/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
import QtQuick.Controls 2.12
import "../parts"
import "../data_logger"
import jp.co.dxantenna.levelchecker.measureResultModel 1.0

/**
 * @brief データロガー取得データ表示(詳細) view
 */
Item {
    id: dataLoggerDetailsData
    objectName: "DataLoggerDetailsData"
    anchors.fill: parent

    property var level: "000.0"                 //!< 測定入力レベル値
    property var mer: "00.0"                    //!< 変調誤差比の値
    property var ber: "0.0E-0"                  //!< ビット誤り率の値
    property var userMode: ""                   //!< ユーザーモードの値
    property string band: ""                    //!< バンド
    property bool isSatelliteBroadCasting: false//!< 衛星放送かどうか
    property string channel: ""                 //!< チャンネル
    property string frequency: ""               //!< 中心周波数
    property string displayFrequencyUnit: "MHz" //!< 中心周波数表示単位
    property string localFrequency: "00.000"    //!< 局発周波数
    property string modulation: ""              //!< 変調方式
    property string modulationPrefix: ""        //!< 変調方式 接頭句
    property string hierarchy: ""               //!< 階層
    property string polarization: ""            //!< 偏波
    property int startChannel: 13               //!< 開始チャンネル
    property int endChannel: 62                 //!< 終了チャンネル
    property int minimumLevel: 20               //!< 最小レベル
    property int maximumLevel: 120              //!< 最大レベル
    property int currentChannelIndex: -1        //!< 選択したチャンネルのインデックス
    property int currentPage: 1                 //!< 現在のページ
    property int totalPage: 1                   //!< 現在のページ
    property bool isModulationVisible: true     //!< 変調方式 表示、非表示設定 (True: 表示, False: 非表示)
    property var displayChannelDetail: []       //!< チャンネル詳細情報表示可否リスト (画面左下のチャンネル詳細データの表示可否のリスト)
    property int displayModulationPrefixMode: 0 //!< 変調方式 表示モード 接頭句と変調方式をどのように表示するかを決める
    property int selectCnMer: 1                 //!< MER/CNのどちらを測定設定で設定しているか
    property string fileName: ""                //!< データ名

    signal request(int condition)

    // 測定結果(リスト表示用)
    MeasureResultModel {
        id: measureResultModel
        objectName: "dataLoggerMeasureResultModel"
    }

    // リスト表示
    List {
        id: dataLoggerDetailsList
        objectName: "detailsList"
        x: 200
        anchors.top: fileNameLabel.bottom
        currentChannelIndex: dataLoggerDetailsData.currentChannelIndex
        measureResult: measureResultModel
    }

    // データ名表示
    Text {
        id: fileNameLabel
        objectName: "fileNameLabel"
        anchors {
            top: parent.top
            left: dataLoggerDetailsList.left
        }
        width: 125
        height: 34
        horizontalAlignment: Text.AlignLeft
        verticalAlignment: Text.AlignVCenter
        color: "white"
        text: "データ名  " + fileName
        font.pixelSize: 16
        font.family: defaultFontName
    }

    // Page
    Label {
        height: 20
        width: 300
        anchors {
            bottom: dataLoggerDetailsList.top
            bottomMargin: 1
            right: parent.right
            rightMargin: 30
        }
        color: "#E6E6E6"
        font.family: defaultFontName
        text: "ページ " + dataLoggerDetailsData.currentPage + "/" + dataLoggerDetailsData.totalPage
        horizontalAlignment: Text.AlignRight
    }

    // Ch.
    ChannelInformation {
        labelMessage: "チャンネル"
        unitMessage: ""
        message: dataLoggerDetailsData.channel
        width: 150
        height: 55
        x: 24
        y: 2
    }

    // 周波数
    ChannelInformation {
        labelMessage: "周波数"
        message: dataLoggerDetailsData.frequency
        unitMessage:"MHz"
        width: 150
        height: 55
        x: 24
        y: 64
    }

    // Level
    ChannelInformation {
        labelMessage: "LEVEL"
        message: dataLoggerDetailsData.level
        unitMessage:"dBμV"
        width: 150
        height: 55
        x: 24
        y: 124
    }

    // MER/CN
    ChannelInformation {
        labelMessage: (dataLoggerDetailsData.selectCnMer === 1) ? "MER" : "CN"
        message: dataLoggerDetailsData.mer
        unitMessage:"dB"
        width: 150
        height: 52
        x: 24
        y: 184
        visible: {
            if ( (dataLoggerDetailsData.band == "PILOT") ||
                    (dataLoggerDetailsData.band == "LTE") ||
                 (dataLoggerDetailsData.band == "FM") ||
                 (dataLoggerDetailsData.band == "CATV上り") ) {
                false
            } else {
                true
            }
        }
    }

    // BER
    ChannelInformation {
        labelMessage: "BER"
        message: dataLoggerDetailsData.ber
        width: 150
        height: 55
        x: 24
        y: 244
        visible: {
            if ( (dataLoggerDetailsData.band == "PILOT") ||
                    (dataLoggerDetailsData.band == "LTE") ||
                 (dataLoggerDetailsData.band == "FM") ||
                 (dataLoggerDetailsData.band == "CATV上り") ) {
                false
            } else {
                true
            }
        }
    }

    // チャンネル詳細データ
    ChannelDetailInformation {
        displayBand: dataLoggerDetailsData.band
        frequency: dataLoggerDetailsData.frequency
        displayFrequencyUnit: dataLoggerDetailsData.displayFrequencyUnit
        modulation: dataLoggerDetailsData.modulation
        modulationPrefix: dataLoggerDetailsData.modulationPrefix
        hierarchy: dataLoggerDetailsData.hierarchy
        polarization: dataLoggerDetailsData.polarization
        localFrequency: dataLoggerDetailsData.localFrequency
        displayChannelDetail: dataLoggerDetailsData.displayChannelDetail
        displayModulationPrefixMode: dataLoggerDetailsData.displayModulationPrefixMode
        x: 23
        y: 310
    }

    // ユーザーモードのラベル
    Label {
        id: userModeLabel
        width: 100
        height: 20
        x: 633
        y: 361
        horizontalAlignment: Qt.AlignLeft
        text: (dataLoggerDetailsData.userMode != "") ? "USER MODE : " : ""
        font.pixelSize: 14
        color: "#E4E6E5"
        font.family: defaultFontName
    }

    // ユーザーモードの値
    Text {
        id: userMode
        width: 80
        height: 20
        x: 633
        y: 383
        text: dataLoggerDetailsData.userMode
        horizontalAlignment: Qt.AlignHCenter
        font.pixelSize: 14
        font.bold: true
        font.family: defaultFontName
        color: "#E4E6E5"
    }

    // 画面名
    ScreenName {
        name : "保存データ確認"
    }

    // リストのページ移動
    function onScrollPage(page)
    {
        dataLoggerDetailsData.currentPage = page
        dataLoggerDetailsList.scrollPage(page)
    }
}
