/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
import QtQuick.Controls 2.12
import "../measurement/multi"
import "../parts"

/**
 * @brief 測定結果データ表示（CSV） View
 */
Item {
    id: measurementResultCsvData
    objectName: "MeasurementResultCsvData"
    anchors.fill: parent

    property string band: ""                    //!< バンド
    property string level: "000.0"              //!< 測定入力レベル値
    property string mer: "00.0"                 //!< 変調誤差比の値
    property string ber: "0.0E-0"               //!< ビット誤り率の値
    property string userMode: ""　　　　         //!< ユーザーモードの値
    property bool isSatelliteBroadCasting: false//!< 衛星放送かどうか
    property var azimuth: 0                     //!< 方位角
    property string channel: ""                 //!< チャンネル
    property string frequency: ""               //!< 中心周波数
    property string localFrequency: "00.000"    //!< 局発周波数
    property string modulation: ""              //!< 変調方式
    property string modulationPrefix: ""        //!< 変調方式 接頭句
    property string hierarchy: ""               //!< 階層
    property string polarization: ""            //!< 偏波
    property var listModel: ""                  //!< リストモデル
    property int currentIndex: -1　　　　　　　　　//!< リストのカレントインデックス
    property bool listButtonActiveState: false　//!< リストボタンのアクティブ状態
    property bool isModulationVisible: true     //!< 変調方式 表示、非表示設定 (True: 表示, False: 非表示)
    property string displayFrequencyUnit: "MHz" //!< 中心周波数表示単位
    property var displayChannelDetail: []       //!< チャンネル詳細情報表示可否リスト (画面左下のチャンネル詳細データの表示可否のリスト)
    property int displayModulationPrefixMode: 0 //!< 変調方式 表示モード 接頭句と変調方式をどのように表示するかを決める
    property int bandId: -1                     //!< Band Id(LC70_BAND_T の定義)
    property string fileName: ""                //!< データ名
    property int currentPage : 1                // 表示中のページ数
    property int totalPage : 1                  // 全てのページ数
    readonly property int listRows: 10          // 1ページに表示するリストの数

    readonly property var merCnTitle: [
                                                "MER\n【 dB 】",  // LC70_BAND_UNDEF=0,
                                                "MER\n【 dB 】",  // LC70_BAND_UHF,
                                                "CN\n【 dB 】",   // LC70_BAND_BS,
                                                "CN\n【 dB 】",   // LC70_BAND_CS,
                                                "CN\n【 dB 】",   // LC70_BAND_JCSAT3,
                                                "CN\n【 dB 】",   // LC70_BAND_JCSAT4,
                                                "CN\n【 dB 】",   // LC70_BAND_SCCB,
                                                "CN\n【 dB 】",   // LC70_BAND_SCCC,
                                                "MER\n【 dB 】",  // LC70_BAND_CATV_ALL,
                                                "MER\n【 dB 】",  // LC70_BAND_CATV_90_470MHZ,
                                                "MER\n【 dB 】",  // LC70_BAND_CATV_470_1002MHZ,
                                                "MER\n【 dB 】",  // LC70_BAND_PILOT,
                                                "MER\n【 dB 】",  // LC70_BAND_SKYP,
                                                "MER\n【 dB 】",  // LC70_BAND_LTE,
                                                "MER\n【 dB 】",  // LC70_BAND_FM,
                                                "MER\n【 dB 】",  // LC70_BAND_CATV_UP_STREAM,
                                                "MER\n【 dB 】",  // LC70_BAND_END
                                            ]   //!< Band ごとのMER/CN 表記の使い分け
    readonly property var channelMerCnTitle: [
                                                "MER",  // LC70_BAND_UNDEF=0,
                                                "MER",  // LC70_BAND_UHF,
                                                "CN",   // LC70_BAND_BS,
                                                "CN",   // LC70_BAND_CS,
                                                "CN",   // LC70_BAND_JCSAT3,
                                                "CN",   // LC70_BAND_JCSAT4,
                                                "CN",   // LC70_BAND_SCCB,
                                                "CN",   // LC70_BAND_SCCC,
                                                "MER",  // LC70_BAND_CATV_ALL,
                                                "MER",  // LC70_BAND_CATV_90_470MHZ,
                                                "MER",  // LC70_BAND_CATV_470_1002MHZ,
                                                "MER",  // LC70_BAND_PILOT,
                                                "MER",  // LC70_BAND_SKYP,
                                                "MER",  // LC70_BAND_LTE,
                                                "MER",  // LC70_BAND_FM,
                                                "MER",  // LC70_BAND_CATV_UP_STREAM,
                                                "MER",  // LC70_BAND_END
                                            ]   //!< Band ごとのMER/CN 表記の使い分け

    signal request(int condition)

    Item {
        id: listSizeProperty
        property int rowSize: 30      //!< リスト1行のサイズ
//        property int columnSize: 110  //!< リスト1列のサイズ
        property int fontSize: 14     //!< リスト文字サイズ
    }

    // リストのページ移動
    function onScrollPage(page)
    {
        measurementResultCsvData.currentPage = page
        list.positionViewAtIndex(measurementResultCsvData.listRows * (page - 1), ListView.Beginning)
    }

    // データ名表示
    Text {
        id: fileNameLabel
        objectName: "fileNameLabel"
        x: 200
        anchors {
            top: parent.top
        }
        width: 125
        height: 34
        horizontalAlignment: Text.AlignLeft
        verticalAlignment: Text.AlignVCenter
        color: "white"
        text: "データ名  " + fileName
        font.pixelSize: 16
        font.family: defaultFontName
    }

    // リストヘッダー
    Rectangle {
        id: listTitleArea
        anchors {
            top: fileNameLabel.bottom
            left: fileNameLabel.left
        }
        width: 571
        height: 41
        color: "transparent"
        SelectButton {
            anchors.fill: listTitleArea
            idlebg: "datamanagement_list_single_header.png"
        }

        // BAND
        Label {
            id: bandLabel
            anchors {
                top: parent.top
                bottom: parent.bottom
                left: parent.left
            }
            width: 99
            text: "BAND"
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            color: "#81BEFF"
            font.pixelSize: listSizeProperty.fontSize
        }

        // CH
        Label {
            id: channelLabel
            anchors {
                top: parent.top
                bottom: parent.bottom
                left: bandLabel.right
                leftMargin: 2
            }
            width: 68
            text: "CH"
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            color: "#81BEFF"
            font.pixelSize: listSizeProperty.fontSize
        }

        // FREQ
        Label {
            id: freqLabel
            anchors {
                top: parent.top
                bottom: parent.bottom
                left: channelLabel.right
                leftMargin: 2
            }
            width: 98
            text: "周波数\n(MHz)"
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            color: "#81BEFF"
            font.pixelSize: listSizeProperty.fontSize
        }

        // LEVEL
        Label {
            id: levelLabel
            anchors {
                top: parent.top
                bottom: parent.bottom
                left: freqLabel.right
                leftMargin: 2
            }
            width: 98
            text: "レベル\n(dBuV)"
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            color: "#81BEFF"
            font.pixelSize: listSizeProperty.fontSize
        }

        // MER
        Label {
            id: merLabel
            anchors {
                top: parent.top
                bottom: parent.bottom
                left: levelLabel.right
                leftMargin: 2
            }
            width: 98
//            text: (measurementResultCsvData.bandId >= 0) ? measurementResultCsvData.merCnTitle[measurementResultCsvData.bandId] : ""
            text: "MER/CN\n(dB)"
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            color: "#81BEFF"
            font.pixelSize: listSizeProperty.fontSize
        }

        // BER
        Label {
            id: berLabel
            anchors {
                top: parent.top
                bottom: parent.bottom
                left: merLabel.right
                leftMargin: 2
            }
            width: 98
            text: "BER"
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            color: "#81BEFF"
            font.pixelSize: listSizeProperty.fontSize
        }
    }

    // リスト
    ListView {
        id: list
        anchors {
            top: listTitleArea.bottom
            left: listTitleArea.left
            right: listTitleArea.right
        }
        height: listSizeProperty.rowSize * listRows
        model: measurementResultCsvData.listModel
        delegate: delegate
        currentIndex: measurementResultCsvData.currentIndex
        focus: false
        clip: true
//        boundsBehavior: Flickable.StopAtBounds
//        highlightMoveDuration: 0
//        highlightMoveVelocity: -1
    }

    Component {
        id: delegate
        Item {
            id: listItem
            width: list.width
            height: listSizeProperty.rowSize
            // リスト行
            SelectButton {
                id: row
                anchors {
                    top: parent.top
                    left: parent.left
                    right: parent.right
                    bottom: parent.bottom
                }
                active: (list.currentIndex === index)
                activebg: "datamanagement_list_single_active.png"
                idlebg: index % 2 === 0 ? "datamanagement_list_single_2.png"
                        : "datamanagement_list_single_1.png"
            }

            // BAND
            Label {
                id: listItemBand
                anchors {
                    top: parent.top
                    bottom: parent.bottom
                    left: parent.left
                }
                width: 99
                verticalAlignment: Text.AlignVCenter
                horizontalAlignment: Text.AlignHCenter
                text:　{
                    if(BandRole == "スカパー！プレミアムサービス光") {
                        "スカパー！光"
                    } else {
                        BandRole
                    }
                }
                color: "#FFFFFF"
                font.pixelSize: listSizeProperty.fontSize
            }

            // CH
            Label {
                id: listItemCh
                anchors {
                    top: parent.top
                    bottom: parent.bottom
                    left: listItemBand.right
                    leftMargin: 2
                }
                width: 68
                verticalAlignment: Text.AlignVCenter
                horizontalAlignment: Text.AlignHCenter
                text:　ChannelRole
                color: "#FFFFFF"
                font.pixelSize: listSizeProperty.fontSize
            }

            // FREQ
            Label {
                id: listItemFreq
                anchors {
                    top: parent.top
                    bottom: parent.bottom
                    left: listItemCh.right
                    leftMargin: 2
                }
                width: 98
                verticalAlignment: Text.AlignVCenter
                horizontalAlignment: Text.AlignHCenter
                color: "#FFFFFF"
                text:　FrequencyRole
                font.pixelSize: listSizeProperty.fontSize
            }

            // LEVEL
            Label {
                id: listItemLevel
                anchors {
                    top: parent.top
                    bottom: parent.bottom
                    left: listItemFreq.right
                    leftMargin: 2
                }
                width: 98
                verticalAlignment: Text.AlignVCenter
                horizontalAlignment: Text.AlignHCenter
                color: "#FFFFFF"
                text:　LevelRole
                font.pixelSize: listSizeProperty.fontSize
            }

            // MER
            Label {
                id: listItemMer
                anchors {
                    top: parent.top
                    bottom: parent.bottom
                    left: listItemLevel.right
                    leftMargin: 2
                }
                width: 98
                verticalAlignment: Text.AlignVCenter
                horizontalAlignment: Text.AlignHCenter
                color: "#FFFFFF"
                text:　MerRole
                font.pixelSize: listSizeProperty.fontSize
            }

            // BER
            Label {
                id: listItemBer
                anchors {
                    top: parent.top
                    bottom: parent.bottom
                    left: listItemMer.right
                    leftMargin: 2
                }
                width: 98
                verticalAlignment: Text.AlignVCenter
                horizontalAlignment: Text.AlignHCenter
                color: "#FFFFFF"
                text:　BerRole
                font.pixelSize: listSizeProperty.fontSize
            }
        }
    }

    // Ch.
    ChannelInformation {
        labelMessage: "チャンネル"
        unitMessage: ""
        message: measurementResultCsvData.channel
        width: 150
        height: 55
        x: 24
        y: 2
    }

    // 周波数
    ChannelInformation {
        labelMessage: "周波数"
        message: measurementResultCsvData.frequency
        unitMessage:"MHz"
        width: 150
        height: 55
        x: 24
        y: 64
    }

    // Level
    ChannelInformation {
        labelMessage: "LEVEL"
        message: measurementResultCsvData.level
        unitMessage:"dBμV"
        width: 150
        height: 55
        x: 24
        y: 124
    }

    // MER/CN
    ChannelInformation {
        labelMessage: (measurementResultCsvData.bandId >= 0) ? measurementResultCsvData.channelMerCnTitle[measurementResultCsvData.bandId] : ""
        message: measurementResultCsvData.mer
        unitMessage:"dB"
        width: 150
        height: 55
        x: 24
        y: 184
        visible: {
            if ( (measurementResultCsvData.band == "PILOT") ||
                    (measurementResultCsvData.band == "LTE") ||
                 (measurementResultCsvData.band == "FM") ||
                 (measurementResultCsvData.band == "CATV上り") ) {
                false
            } else {
                true
            }
        }
    }

    // BER
    ChannelInformation {
        labelMessage: "BER"
        message: measurementResultCsvData.ber
        width: 150
        height: 55
        x: 24
        y: 244
        visible: {
            if ( (measurementResultCsvData.band == "PILOT") ||
                    (measurementResultCsvData.band == "LTE") ||
                 (measurementResultCsvData.band == "FM") ||
                 (measurementResultCsvData.band == "CATV上り") ) {
                false
            } else {
                true
            }
        }
    }

    // チャンネル詳細データ
    ChannelDetailInformation {
        displayBand: measurementResultCsvData.band
        frequency:  measurementResultCsvData.frequency
        displayFrequencyUnit: measurementResultCsvData.displayFrequencyUnit
        modulation: measurementResultCsvData.modulation
        modulationPrefix: measurementResultCsvData.modulationPrefix
        hierarchy: measurementResultCsvData.hierarchy
        polarization: measurementResultCsvData.polarization
        localFrequency: measurementResultCsvData.localFrequency
        displayChannelDetail: measurementResultCsvData.displayChannelDetail
        displayModulationPrefixMode: measurementResultCsvData.displayModulationPrefixMode
        x: 23
        y: 310
    }

    // 画面名
    ScreenName {
        name : "保存データ確認"
    }
}
