/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
import QtQuick.Controls 2.12
import "../parts"

/**
 * @brief 測定結果一覧表示 View
 */
Item {
    id: root
    objectName: "MeasurementResultDataList"
    anchors.fill: parent

    property var listModel: ""
    property int currentIndex: -1
    property int currentPage : 1      // 表示中のページ数
    property int totalPage : 1        // 全てのページ数
    readonly property int listRows: 5 // 1ページに表示するリストの数

    property int activeArea: 0             // フォーカスを持つ領域

    readonly property int measurementArea: 1        // 測定選択リストにフォーカスがある(測定選択の中の行移動可能)
    readonly property int filelistArea: 2           // ファイルリストにフォーカスがある(ファイルリストの中の行移動可能)
    readonly property int actionArea: 3             // 右端のボタンにフォーカスがある(ボタン間の移動可能)

    property int currentMeasurementIndex: 0         // 測定選択リストの現在選択中の行の中で、現在編集中の列のインデックス
    property int currentActionIndex: 0              // 右端のボタンエリア内の現在選択されているインデックス

    readonly property int measurementIndexSingle: 1     // 測定選択エリア内のシングル測定ボタンのインデックス
    readonly property int measurementIndexMulti: 2      // 測定選択エリア内のマルチ測定ボタンのインデックス
    readonly property int measurementIndexDatalogger: 3 // 測定選択エリア内のデータロガーボタンのインデックス
    readonly property int measurementIndexList: 4       // 測定選択エリア内のリストボタンのインデックス

    readonly property int actionIndexAllSelect: 1   // 右端のボタンエリア内の全選択ボタンのインデックス
    readonly property int actionIndexcopy: 2        // 右端のボタンエリア内のコピーボタンのインデックス
    readonly property int actionIndexDelete: 3      // 右端のボタンエリア内の削除ボタンのインデックス


    signal request(int condition)

    function backup(key, value) {
        var temporary = attributes.takeOver
        temporary[key] = value
        attributes.takeOver = temporary
    }

    Item {
        id: takeOverData
        objectName: "takeOverData"
        property string selecteMenu: ""
    }

    function getTakeOver() {
        takeOverData.selecteMenu = attributes.takeOver["selecteMenu"]
    }

    // リストのページ移動
    function onScrollPage(page)
    {
        root.currentPage = page
        list.positionViewAtIndex(root.listRows * (page - 1), ListView.Beginning)
    }

    // シングル測定
    SelectButton {
        id: m1
        objectName: "m1"
        active: activeArea == measurementArea && currentMeasurementIndex == measurementIndexSingle
        activebg: "measurement_datalistbtn.png"
        idlebg: "measurement_datalistbtn_n.png"
        pressbg: "measurement_datalistbtn_p.png"
        message: "　　シングル測定"
        fontsize: 17
        width:171
        height:51
        anchors {
            bottom: listTitleArea.top
            bottomMargin: 20
            right: m2.left
            rightMargin: 27
        }
    }
    Image {
        id: iconSingle
        source: "qrc:/resource/png/" + "measurement_datalistbtn_icon_single.png"
        anchors {
            top: m1.top
            topMargin: 5
            left: m1.left
        }
        width:53
        height:40
    }

    // マルチ測定
    SelectButton {
        id: m2
        objectName: "m2"
        active: activeArea == measurementArea && currentMeasurementIndex == measurementIndexMulti
        activebg: "measurement_datalistbtn.png"
        idlebg: "measurement_datalistbtn_n.png"
        pressbg: "measurement_datalistbtn_p.png"
        message: "　　マルチ測定"
        fontsize: 17
        width:171
        height:51
        anchors {
            bottom: listTitleArea.top
            bottomMargin: 20
            horizontalCenter: root.horizontalCenter
        }
    }
    Image {
        id: iconMulti
        source: "qrc:/resource/png/" + "measurement_datalistbtn_icon_multi.png"
        anchors {
            top: m2.top
            topMargin: 5
            left: m2.left
        }
        width:53
        height:40
    }

    // データロガー測定
    SelectButton {
        id: m3
        objectName: "m3"
        active: activeArea == measurementArea && currentMeasurementIndex == measurementIndexDatalogger
        activebg: "measurement_datalistbtn.png"
        idlebg: "measurement_datalistbtn_n.png"
        pressbg: "measurement_datalistbtn_p.png"
        message: "　　データロガー"
        fontsize: 17
        width:171
        height:51
        anchors {
            bottom: listTitleArea.top
            bottomMargin: 20
            left: m2.right
            leftMargin: 28
        }
    }
    Image {
        id: iconDatalogger
        source: "qrc:/resource/png/" + "measurement_datalistbtn_icon_datalogger.png"
        anchors {
            top: m3.top
            topMargin: 5
            left: m3.left
        }
        width:53
        height:40
    }

    // ページラベル
//    Label {
//        width: 300
//        height: 20
//        x: 660
//        anchors {
//            bottom: listTitleArea.top
//            bottomMargin: 1
//            right: listTitleArea.right
//            rightMargin: 1
//        }
//        horizontalAlignment: Text.AlignRight
//        color: "#E6E6E6"
//        font.family: defaultFontName
//        text: "ページ " + root.currentPage + "/" + root.totalPage
//    }

    // リストヘッダー
    Rectangle {
        id: listTitleArea
        anchors {
            top: root.top
            topMargin: 90
            horizontalCenter: root.horizontalCenter
        }
        height: 34
        width: 568
        color: "transparent"
        SelectButton {
            anchors.fill: listTitleArea
            idlebg: "measurement_datalist_9.png"
        }
        // 番号
        Label {
            id: listNoLabel
            anchors {
                top: parent.top
                bottom: parent.bottom
                left: parent.left
            }
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            width: 61
            text: "番号"
            color: "#80BFFF"
            font.family: defaultFontName
        }
        // データ名
        Label {
            id: listFileNameLabel
            anchors {
                top: parent.top
                bottom: parent.bottom
                left: listNoLabel.right
                leftMargin: 4
            }
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            width: 241
            text: "データ名"
            color: "#80BFFF"
            font.family: defaultFontName
        }
        // 日時
        Label {
            id: listFileDataLabel
            anchors {
                top: parent.top
                bottom: parent.bottom
                left: listFileNameLabel.right
                leftMargin: 1
            }
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            width: 260
            text: "日時"
            color: "#80BFFF"
            font.family: defaultFontName
        }
    }

    // リスト
    ListView {
        id: list
        clip:true
        anchors {
            top: listTitleArea.bottom
            left: listTitleArea.left
            right: listTitleArea.right
        }
        height: 215
        model: root.listModel
        delegate: delegate
        currentIndex: root.currentIndex
        highlightFollowsCurrentItem: false
        focus: false
        boundsBehavior: Flickable.StopAtBounds
    }

    Component {
        id: delegate
        Item {
            id: listItem
            width: list.width
            height: 43
            // リスト行
            SelectButton {
                id: row
                anchors {
                    top: parent.top
                    left: parent.left
                    right: parent.right
                    bottom: parent.bottom
                }
                active: (list.currentIndex === index) && (activeArea == filelistArea)
                activebg: "measurement_datalist_8.png"
                idlebg: index % 2 === 0 ? "measurement_datalist_5.png"
                        : "measurement_datalist_6.png"
            }
            // No.
            Label {
                id: listItemNoLabel
                anchors {
                    top: parent.top
                    bottom: parent.bottom
                    left: parent.left
                }
                width: 61
                verticalAlignment: Text.AlignVCenter
                horizontalAlignment: Text.AlignHCenter
                text:　NumberRole
                color: "#FFFFFF"
                font.family: defaultFontName
            }
            // ファイル名
            Label {
                id: listFileNameLabel
                anchors {
                    top: parent.top
                    bottom: parent.bottom
                    left: listItemNoLabel.right
                    leftMargin: 4
                }
                width: 241
                verticalAlignment: Text.AlignVCenter
                horizontalAlignment: Text.AlignHCenter
                color: "#FFFFFF"
                text: UserDataRole
                font.family: defaultFontName
            }
            // 日時
            Label {
                id: listFileDataLabel
                anchors {
                    top: parent.top
                    bottom: parent.bottom
                    left: listFileNameLabel.right
                    leftMargin: 1
                }
                width: 260
                verticalAlignment: Text.AlignVCenter
                horizontalAlignment: Text.AlignHCenter
                color: "#FFFFFF"
                text:　DateRole
                font.family: defaultFontName
            }
        }
    }

    // 画面名
    ScreenName {
        name : "保存データ呼び出し"
    }
}
