/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
import QtQuick.Controls 2.12
import "../parts"

/**
 * @brief データ管理 操作画面
 */
Item {
    id: root
    anchors.fill: parent
    property var listModel: ""
    property int currentIndex: -1
    property int currentPage: 1             // 表示中のページ数
    property int totalPage: 1               // 全てのページ数
    property string screenName: ""          // スクリーン名
    property string operationName: ""       // 処理名
    property bool cursoredButtonArea: false // ボタン領域にカーソルが当たっているか
    readonly property int listRows: 6       // 1ページに表示するリストの数

    function onScrollPage(page)
    {
        list.positionViewAtIndex(root.listRows * (page - 1), ListView.Beginning)
    }

    // ページラベル
    Label {
        width: 300
        height: 20
        anchors {
            bottom: listTitleArea.top
            bottomMargin: 1
            right: listTitleArea.right
            rightMargin: 1
        }
        horizontalAlignment: Text.AlignRight
        color: "#E6E6E6"
        font.family: defaultFontName
        text: "ページ " + root.currentPage + "/" + root.totalPage
    }

    // リストヘッダー
    Rectangle {
        id: listTitleArea
        anchors {
            top: root.top
            topMargin: 50
            horizontalCenter: root.horizontalCenter
        }
        height: 30
        width: 600
        color: "#31333A"
        Label {
            id: listNoLabel
            anchors {
                top: parent.top
                bottom: parent.bottom
                left: parent.left
            }
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            width: 50
            text: "番号"
            color: "#80BFFF"
            font.family: defaultFontName
        }
        Rectangle {
            id: separator1
            anchors {
                top: parent.top
                left: listNoLabel.right
                bottom: parent.bottom
            }
            width: 1
            color: "#28292E"
        }
        Label {
            id: listFileNameLabel
            anchors {
                top: parent.top
                bottom: parent.bottom
                left: separator1.right
            }
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            width: 549
            text: "保存データ"
            color: "#80BFFF"
            font.family: defaultFontName
        }
    }

    // リスト
    ListView {
        id: list
        clip:true
        anchors {
            top: listTitleArea.bottom
            left: listTitleArea.left
            right: listTitleArea.right
        }
        height: 240
        model: root.listModel
        delegate: delegate
        currentIndex: root.currentIndex
        highlightFollowsCurrentItem: false
        focus: false
        boundsBehavior: Flickable.StopAtBounds
    }

    Component {
        id: delegate
        Item {
            id: listItem
            width: list.width
            height: 40
            // リスト行
            Rectangle {
                id: row
                anchors {
                    top: parent.top
                    left: parent.left
                    right: parent.right
                    bottom: parent.bottom
                }
                color: {
                    if (list.currentIndex === index && root.cursoredButtonArea === false) {
                        // リストにカーソルが当たっている場合
                        "#157FE5"
                    }　else {
                        if (IsSelectedRole) {
                            // 選択中の場合
                            "#275B94"
                        } else {
                            if (index % 2 === 0) {
                                "#43454D"
                            } else {
                                "#383A40"
                            }
                        }
                    }
                }
                border.width: 2
                border.color: {
                    if (list.currentIndex === index && root.cursoredButtonArea === false) {
                        // カーソルが当たっている場合
                        "#7FBFFF"
                    } else {
                        "transparent"
                    }
                }
            }

            // No.
            Label {
                id: listItemNoLabel
                anchors {
                    top: parent.top
                    bottom: parent.bottom
                    left: parent.left
                }
                width: 50
                verticalAlignment: Text.AlignVCenter
                horizontalAlignment: Text.AlignHCenter
                text:　NumberRole
                color: "#80BFFF"
                font.family: defaultFontName
            }
            // セパレーター
            Rectangle {
                id: separator2
                anchors {
                    top: parent.top
                    left: listItemNoLabel.right
                    bottom: parent.bottom
                }
                width: 1
                color: "#28292E"
            }
            // ファイル名
            Label {
                id: listFileNameLabel
                anchors {
                    top: parent.top
                    bottom: parent.bottom
                    left: separator2.right
                    leftMargin: 10
                }

                width: 499
                verticalAlignment: Text.AlignVCenter
                horizontalAlignment: Text.AlignLeft
                color: "#FFFFFF"
                text:　FileNameRole
                font.family: defaultFontName
            }
            // セパレータ
            Rectangle {
                id : separator3
                anchors {
                    top: parent.top
                    left: listFileNameLabel.right
                    bottom: parent.bottom
                }
                width: 1
                color: "#28292E"
            }

            Rectangle{
                id : listCheckBoxArea
                anchors {
                    top: parent.top
                    bottom: parent.bottom
                    left: separator3.right
                    right: parent.right
                }
                color: "transparent"

                // チェックボックス
                Image {
                    id: listCheckBox
                    anchors {
                        fill: parent
                        margins: 10
                    }

                    // チェックボックスのロールから値を取得
                    source: IsSelectedRole ? "qrc:/resource/png/check_on.png" : "qrc:/resource/png/check_off.png"
                    // ファイル名が設定されていない場合は、チェックボックスは非表示にする
                    visible: (FileNameRole == "") ? false : true
                }
            }
        }
    }

    // 全選択 / 削除ボタン
    SelectButton {
        id: m1
        objectName: "m1"
        anchors {
            top: listTitleArea.top
            left: listTitleArea.right
            leftMargin: 16
        }
        height: 130
        width: 80
        message: "全選択\n ／\n 解除"
        activebg: "measurement_operationbtn_dl.png"
        idlebg: "measurement_operationbtn_n_dl.png"
        pressbg: "measurement_operationbtn_p_dl.png"
    }

    // 処理ボタン
    SelectButton {
        id: m2
        objectName: "m2"
        anchors {
            top: m1.bottom
            topMargin: 16
            left: m1.left
            right: m1.right
        }
        height: 130
        width: 80
        message: root.operationName
        activebg:"measurement_operationbtn_ul.png"
        idlebg: "measurement_operationbtn_n_ul.png"
        pressbg: "measurement_operationbtn_p_ul.png"
    }

    // 画面名
    ScreenName {
        name : root.screenName
    }
}
