/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0

/**
 * @brief MachineStatus view
 */


Item {
    id:root
    objectName: "MachineStatus"
    height: 30
    width: 400

    property bool usbTypeCVisible: false
    property bool usb2Visible: false
    property string soundVolume: ""
    property int batteryStatus: -1
    property int batteryLevel: -1
    property int batteryVol: -1

    readonly property int batteryStatusUnknown: 0
    readonly property int batteryStatusIdle: 1
    readonly property int batteryStatusCharging: 2
    readonly property int batteryStatusFullCharge: 3
    readonly property int batteryLevelUnknown: 0
    readonly property int batteryLevelEmpty: 1
    readonly property int batteryLevelWarning: 2
    readonly property int batteryLevel1: 3
    readonly property int batteryLevel2: 4
    readonly property int batteryLevel3: 5
    readonly property int batteryLevelFull: 6

    onBatteryStatusChanged: updateBatteryIcon()
    onBatteryLevelChanged: updateBatteryIcon()
    function updateBatteryIcon() {
        // 点滅表示の有無
        if (batteryStatus === batteryStatusIdle && batteryLevel === batteryLevelEmpty) {
            // バッテリーアイコンの点滅表示を開始する
            batteryBlinkTimer.startTime = new Date()
            batteryBlinkTimer.start()
        } else {
            // 点滅タイマーを停止する
            batteryBlinkTimer.stop()
            // ちょうど非表示の周期である可能性があるため、アイコンを表示する
            battery.visible = true
        }
        // アイコン画像
        battery.source = ""
        if (batteryStatus === batteryStatusUnknown || batteryLevel === batteryLevelUnknown) {
            battery.source = "qrc:/resource/png/icon_battery_unknown.png"
        } else if (batteryStatus === batteryStatusFullCharge) {
            battery.source = "qrc:/resource/png/icon_battery_nocharge_full.png"
        } else if (batteryStatus === batteryStatusCharging) {
            if (batteryLevel === batteryLevelEmpty) {
                battery.source = "qrc:/resource/png/icon_battery_charge_empty.png"
            } else if (batteryLevel === batteryLevelWarning) {
                battery.source = "qrc:/resource/png/icon_battery_charge_warn.png"
            } else if (batteryLevel === batteryLevel1) {
                battery.source = "qrc:/resource/png/icon_battery_charge_1.png"
            } else if (batteryLevel === batteryLevel2) {
                battery.source = "qrc:/resource/png/icon_battery_charge_2.png"
            } else if (batteryLevel === batteryLevel3) {
                battery.source = "qrc:/resource/png/icon_battery_charge_3.png"
            } else if (batteryLevel === batteryLevelFull) {
                battery.source = "qrc:/resource/png/icon_battery_charge_full.png"
            }
        } else if (batteryStatus === batteryStatusIdle) {
            if (batteryLevel === batteryLevelEmpty) {
                battery.source = "qrc:/resource/png/icon_battery_nocharge_empty.png"
            } else if (batteryLevel === batteryLevelWarning) {
                battery.source = "qrc:/resource/png/icon_battery_nocharge_warn.png"
            } else if (batteryLevel === batteryLevel1) {
                battery.source = "qrc:/resource/png/icon_battery_nocharge_1.png"
            } else if (batteryLevel === batteryLevel2) {
                battery.source = "qrc:/resource/png/icon_battery_nocharge_2.png"
            } else if (batteryLevel === batteryLevel3) {
                battery.source = "qrc:/resource/png/icon_battery_nocharge_3.png"
            } else if (batteryLevel === batteryLevelFull) {
                battery.source = "qrc:/resource/png/icon_battery_nocharge_full.png"
            }
        }
    }


    // USB type -c
    Image {
        id:usb3_0
        height: parent.height
        width: 40
        source: "qrc:/resource/png/icon_type-c_n.png"
        anchors.right: usb2_0.left
        visible: root.usbTypeCVisible
    }

    // USB 2.0
    Image {
        id:usb2_0
        height: parent.height
        width: 40
        source: "qrc:/resource/png/icon_usb_n.png"
        anchors.right: sound_volume.left
        visible: root.usb2Visible
    }

    // 音量
    Image {
        id:sound_volume
        height: parent.height
        width: 40
        source: root.soundVolume
        anchors.right:batteryText.left
    }

    // バッテリー
    Image {
        id:battery
        height: parent.height
        width: 40
        source: ""
        anchors.right:systemdate.left
        anchors.rightMargin: 15
    }
    // バッテリー(充電中)点滅タイマー
    Timer {
        id: batteryBlinkTimer
        interval: 100
        running: false
        repeat: true
        property var startTime: 0
        property var currentTime: 0
        onTriggered: {
            currentTime = new Date()
            if (currentTime - startTime >= 500) {
                battery.visible = !battery.visible
                startTime = currentTime
            }
        }
    }
    // バッテリー残量
    Text {
        id: batteryText
        text: {
            if ( (batteryVol < 0) || (100 < batteryVol) ) {
                ""
            } else {
                batteryVol + "%"
            }
        }
        height: parent.height
        width: 45
        color: "white"
        anchors.top: battery.top
        anchors.topMargin: 7
        anchors.right:battery.left
        horizontalAlignment: Text.AlignRight
        font.pixelSize: 15
        font.family: defaultFontName
    }

    // 日付　時刻
    Text {
        id: systemdate
        text: new Date().toLocaleString(Qt.locale(), " yyyy\nMM/dd")
        height: parent.height
        color: "white"
        anchors.right: systemdate2.left
        anchors.rightMargin: 10
        verticalAlignment: Text.AlignVCenter
        font.pixelSize: 15
        font.family: defaultFontName
    }

    Text {
        id: systemdate2
        text: new Date().toLocaleString(Qt.locale(), "HH:mm")
        height: parent.height
        color: "white"
        anchors.right: parent.right
        anchors.rightMargin: 10
        verticalAlignment: Text.AlignVCenter
        font.pixelSize: 24
        font.family: defaultFontName
    }

    // 時刻更新用
    Timer {
        interval:1000
        running: true
        repeat: true
        onTriggered: {
            var newDate = new Date()
            systemdate.text = newDate.toLocaleString(Qt.locale(), " yyyy\nMM/dd")
            systemdate2.text = newDate.toLocaleString(Qt.locale(), "HH:mm")
        }
    }
}
