/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0

import "../parts"

/**
 * @brief HOME View
 */
Item {
    id: root
    objectName: "Home"
    anchors.fill: parent

    property string backgroundImage: "qrc:/resource/png/back.png"
    property bool isDeveloperMode: false

    width:800
    signal request(int condition)

    function backup(key, value) {
        var temporary = attributes.takeOver
        temporary[key] = value
        attributes.takeOver = temporary
    }

    // 機能リスト
    Column {
        id: functionlist
        objectName: "functionlist"
        anchors.horizontalCenter:root.horizontalCenter
        anchors.top:root.top
        anchors.topMargin: 50
        visible: !isDeveloperMode

        Row {
            // シングル測定
            MenuButton {
                id: m1
                objectName: "m1"
                activebg: "menubtn_sel_common.png"
                idlebg: "menubtn.png"
                message: "シングル測定"
                icon: "icon_home_single_cur.png"
                width:164
                height:136
            }
            MenuButton {
                id: m6
                objectName: "m6"
                activebg: "menubtn_sel_common.png"
                idlebg: "menubtn.png"
                message: "マルチ測定"
                icon: "icon_home_multi_cur.png"
                width:164
                height:136
            }
            MenuButton {
                id: m5
                objectName: "m5"
                activebg: "menubtn_sel_common.png"
                idlebg: "menubtn.png"
                message: "データロガー"
                icon: "icon_home_datalogger_cur.png"
                width:164
                height:136
            }
            MenuButton {
                id: m3
                objectName: "m3"
                activebg: "menubtn_sel_common.png"
                idlebg: "menubtn.png"
                message: "その他"
                icon: "icon_home_dc_cur.png"
                width:164
                height:136
            }
        }
        Row {
            MenuButton {
                id: m2
                objectName: "m2"
                activebg: "menubtn_sel_common.png"
                idlebg: "menubtn.png"
                message: "USER測定"
                icon: "icon_home_user_cur.png"
                width:164
                height:136
            }
            MenuButton {
                id: m8
                objectName: "m8"
                activebg: "menubtn_sel_common.png"
                idlebg: "menubtn.png"
                message: "測定設定"
                icon: "icon_home_sokutei_cur.png"
                width:164
                height:136
            }
            MenuButton {
                id: m9
                objectName: "m9"
                idlebg: "menubtn.png"
                activebg: "menubtn_sel_common.png"
                message: "システム設定"
                icon: "icon_home_system_cur.png"
                width:164
                height:136
            }
            MenuButton {
                id: m7
                objectName: "m7"
                activebg: "menubtn_sel_common.png"
                idlebg: "menubtn.png"
                message: "データ管理"
                icon: "icon_home_data_cur.png"
                width:164
                height:136
            }
        }
    }

    Row {
        id:developerMode
        anchors {
            centerIn: root
            verticalCenterOffset: -20
        }
        spacing: 30
        visible: isDeveloperMode

        SelectButton {
            id:selectOn
            objectName: "developerOn"
            message:"ON"
            activebg: "combtn_sel.png"
            idlebg: "combtn.png"
            width:231
        }
        SelectButton {
            id:selectOff
            objectName: "developerOff"
            message:"OFF"
            activebg: "combtn_sel.png"
            idlebg: "combtn.png"
            width:231
        }
    }

    // 画面名
    ScreenName {
        name : isDeveloperMode ? "デベロッパーモード設定" : "HOME"
    }

}
