/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
import QtQuick.Controls 2.12

import "../parts"

Item {
    id: antennaAdjustment
    objectName: "AntennaAdjustment"
    anchors.fill: parent

    property var jcsat3aLevel: "000.0"          //!< 測定入力レベル
    property var jcsat3aLevelNeedlePosition: 0 //!< 測定入力レベルの針の位置(0〜140)
    property var jcsat3aLevelRedZoneRatio: 0.10 //!< ゲージに表示する赤の割合(最大値 1.0 とする)
    property var jcsat3aMer: "00.0"             //!< 変調誤差比
    property var jcsat3aBer: "0.0E-0"           //!< ビット誤り率

    property var jcsat4bLevel: "000.0"          //!< 測定入力レベル
    property var jcsat4bLevelNeedlePosition: 0 //!< 測定入力レベルの針の位置(0〜140)
    property var jcsat4bLevelRedZoneRatio: 0.10 //!< ゲージに表示する赤の割合(最大値 1.0 とする)
    property var jcsat4bMer: "00.0"             //!< 変調誤差比
    property var jcsat4bBer: "0.0E-0"           //!< ビット誤り率

    property string band: ""                //!< バンド
    property string channel: "JD1"          //!< チャンネル
    property string frequency: ""           //!< 中心周波数
    property string polarization: ""        //!< 偏波
    property string localFrequency: ""      //!< 局発周波数
    property int selectCnMer: 1             //!< CNR/MER切替状態
    property bool jcsat3aTarget: false;     //!< JCSAT-3A 測定中
    property bool jcsat4bTarget: false;     //!< JCSAT-4B 測定中

    readonly property int jcsat3ASelection: 0   //!< JCSAT-3A を識別
    readonly property int jcsat4BSelection: 1   //!< JCSAT-4B を識別

    signal request(int condition)

    function backup(key, value) {
        var temporary = attributes.takeOver
        temporary[key] = value
        attributes.takeOver = temporary
    }

    // JCSAT-3A
    AntennaGauge {
        id: jcsat3aGauge
        x: 16
        y: 30
        band: "JCSAT-3A"
        needlePosition: jcsat3aLevelNeedlePosition

        redZoneRatio: jcsat3aLevelRedZoneRatio
        selectCnMer: antennaAdjustment.selectCnMer
        mer: jcsat3aMer
        ber: jcsat3aBer
    }

    // JCSAT-4B
    AntennaGauge {
        id: jcsat4bGauge
        x: 416
        y: 30
        band: "JCSAT-4B"
        needlePosition: jcsat4bLevelNeedlePosition
        redZoneRatio: jcsat4bLevelRedZoneRatio
        selectCnMer: antennaAdjustment.selectCnMer
        mer: jcsat4bMer
        ber: jcsat4bBer
    }



    // チャンネル
    Label {
       width:20
       height: 32
       x: 347
       y: 16
       horizontalAlignment: Qt.AlignLeft
       text: channel
       font.pixelSize: 48
       color: "#E4E6E5"
       font.family: defaultFontName
    }


    // 区切り線
    Image {
        id: line
        width: 800
        height: 62
        x: 0
        y: 350
        source: "qrc:/resource/png/line_footer.png"
    }

    // 周波数ラベル
    Label {
        id: labelFrequency
        width: contentWidth
        height: 18
        x: 300
        y: 360
        text: "周波数"
        font.pixelSize: 16
        color: "#E4E6E5"
        font.family: defaultFontName
    }

    // 周波数 コロン
    Label {
        id: coronFrequency
        anchors {
            top: labelFrequency.top
            left: labelFrequency.right
            leftMargin: 20
        }
        font.pixelSize: 16
        font.family: defaultFontName
        width: contentWidth
        height: 18
        text: ":"
        color: "#E4E6E5"
    }

    // 周波数
    Label {
        id: valueFrequency
        width: contentWidth
        height: 18
        anchors {
            top: labelFrequency.top
            left: coronFrequency.right
            leftMargin: 10
        }
        font.family: defaultFontName
        font.pixelSize: 16
        text: frequency
        color: "#E4E6E5"
    }

    // 周波数単位
    Label {
        id: unitFrequency
        anchors {
            top: valueFrequency.top
            left: valueFrequency.right
            leftMargin: 10
        }
        width: 30
        height: 18
        text: "MHz"
        font.pixelSize: 16
        font.family: defaultFontName
        color: "#E4E6E5"
        visible: (frequency !== "")
    }

    // 偏波ラベル
    Label {
        id: labelPolarization
        anchors.left: labelFrequency.left
        y: 380
        width: contentWidth
        height: 18
        text: "偏波"
        font.pixelSize: 16
        color: "#E4E6E5"
        font.family: defaultFontName
    }

    // 偏波 コロン
    Label {
        id: coronPolarization
        anchors{
            top: labelPolarization.top
            left: coronFrequency.left
        }
        width: contentWidth
        height: 18
        text: ":"
        color: "#E4E6E5"
        font.pixelSize: 16
        font.family: defaultFontName
    }

    // 偏波
    Label {
        id : valuePolarization
        width: contentWidth
        height: 18
        anchors {
            top: labelPolarization.top
            left: valueFrequency.left
        }
        font.pixelSize: 16
        font.family: defaultFontName
        text: polarization
        color: "#E4E6E5"
    }

    // 局発周波数ラベル
    Label {
        id: labelLocalFrequency
        anchors.left: labelFrequency.left
        y: 400
        width: contentWidth
        height: 18
        text: "局発"
        font.pixelSize: 16
        color: "#E4E6E5"
        font.family: defaultFontName
    }

    // 局発周波数 コロン
    Label {
        anchors {
            top: labelLocalFrequency.top
            left: coronFrequency.left
        }
        width: contentWidth
        height: 18
        text: ":"
        color: "#E4E6E5"
        font.pixelSize: 16
        font.family: defaultFontName
    }

    // 局発周波数
    Label {
        id: antennaLocalFrequency
        width: contentWidth
        height: 18
        anchors {
            top: labelLocalFrequency.top
            left: valueFrequency.left
        }
        font.pixelSize: 16
        font.family: defaultFontName
        text: localFrequency
        color: "#E4E6E5"
    }

    // 局発周波数単位
    Label {
        width: contentWidth
        height: 18
        anchors {
            top: antennaLocalFrequency.top
            left: antennaLocalFrequency.right
            leftMargin: 10
        }
        text: "GHz"
        font.pixelSize: 16
        font.family: defaultFontName
        color: "#E4E6E5"
        visible: (localFrequency !== "")
    }

    // イメージ
    MeasurementFunctionButton {
        id: imageButton
        objectName: "imageButton"
        x:10
        y: 344
        idleImage: "qrc:/resource/png/icon_save1_n.png"
        pressedImage: "qrc:/resource/png/icon_save1_on.png"
    }

    Image {
        id: during_measurement_3a
        x: 248
        y: 213
        width: 50
        height: 18
        source: "qrc:/resource/png/icon_during_measurement.png"
        visible: antennaAdjustment.jcsat3aTarget
    }
    //測定中アイコン　JSAT-4B
    Image {
        id: during_measurement_4b
        x: 647
        y: 213
        width: 50
        height: 18
        source: "qrc:/resource/png/icon_during_measurement.png"
        visible: antennaAdjustment.jcsat4bTarget
    }

    function updateLevelThreshold(red, yellow, selection)
    {
        if (selection === jcsat3ASelection) {
            jcsat3aGauge.updateThreshold(red, yellow)
        } else if (selection === jcsat4BSelection) {
            jcsat4bGauge.updateThreshold(red, yellow)
        }
    }

    function updateJcsat3aLevelMeterValue(levelValue, levelNeedlePosition) {
        antennaAdjustment.jcsat3aLevel = levelValue
        jcsat3aGauge.level = levelValue
        jcsat3aGauge.updateMeterValue(levelValue, levelNeedlePosition)
    }

    function updateJcsat4bLevelMeterValue(levelValue, levelNeedlePosition) {
        antennaAdjustment.jcsat4bLevel = levelValue
        jcsat4bGauge.level = levelValue
        jcsat4bGauge.updateMeterValue(levelValue, levelNeedlePosition)
    }
}
