/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
import "../parts"

Item {
    id: root
    objectName: "CATV"
    anchors.fill: parent


    signal request(int condition)

    property int transitionMode: 0; // 画面モード(どの画面から遷移してきたか)

    readonly property int singleMeasurementMode : 0    // マニュアルシングル測定画面から遷移してきた場合
    readonly property int multiMeasurementMode  : 1    // マニュアルマルチ測定画面から遷移してきた場合
    readonly property int thresholdSettingMode  : 2    // 閾値設定画面から遷移してきた場合
    readonly property int autoSettingMode       : 3    // 自動設定画面から遷移してきた場合

    function backup(key, value) {
        var temporary = attributes.takeOver
        temporary[key] = value
        attributes.takeOver = temporary
    }

    // 画面名
    ScreenName {
        objectName: "screenName"
        name : "CATV"
    }

    Column {
        id: functionlist
        anchors.horizontalCenterOffset: 0
        objectName: "functionlist"
        anchors.horizontalCenter:root.horizontalCenter
        anchors.top:root.top
        anchors.topMargin: 88

        spacing: 23

        // 1 行目
        Row {
            spacing: 18

            // CAV ALL
            ImageButton {
                id: m1
                objectName: "m1"
                activebg: (transitionMode == root.thresholdSettingMode) ? "catv_bandbtn_sel.png" : "catv_bandbtn_sel.png"
                idlebg: "catv_bandbtn_n.png"
                icon: "icon_band_catv_all_cur.png"
                width:  148
                height: 94

            }

            // CATV 90-470Hz
            ImageButton {
                id: m2
                objectName: "m2"
                activebg: (root.transitionMode == root.autoSettingMode) ? "catv_bandbtn_sel.png" : "catv_bandbtn_sel.png"
                idlebg: "catv_bandbtn_n.png"
                icon: "icon_band_catv_90-470_cur.png"
//                width:  165
//                height: 114

                width:148
                height:94

                disable: (root.transitionMode == root.thresholdSettingMode)
            }

            // CATV 470-1002Hz
            ImageButton {
                id: m3
                objectName: "m3"
                activebg: ((root.transitionMode == root.singleMeasurementMode) || (root.transitionMode == root.multiMeasurementMode))
                                ? "catv_bandbtn_sel.png" : "catv_bandbtn_sel.png"
                idlebg: "catv_bandbtn_n.png"
                icon: "icon_band_catv_470-1000_cur.png"
                width:  148
                height: 94
                disable: (root.transitionMode == root.thresholdSettingMode)
            }
        }
        Row {
            spacing: 18

            // スカパー光
            ImageButton {
                id: m4
                objectName: "m4"
                activebg: (root.transitionMode == root.autoSettingMode) ? "catv_bandbtn_sel.png" : "catv_bandbtn_sel.png"
                idlebg: "catv_bandbtn_n.png"
                icon: "icon_band_sky_cur.png"
                width:  148
                height: 94
            }

            // PILOT
            ImageButton {
                id: m5
                objectName: "m5"
                activebg: {
                    if((root.transitionMode == root.singleMeasurementMode) || (root.transitionMode == root.multiMeasurementMode)) {
                        "catv_bandbtn_sel.png"
                    } else if (root.transitionMode == root.thresholdSettingMode) {
                        "catv_bandbtn_sel.png"
                    } else {
                        ""
                    }
                }
                idlebg: "catv_bandbtn_n.png"
                icon: "icon_band_pilot_cur.png"
                width:  148
                height: 94
                disable: root.transitionMode == root.autoSettingMode
            }

            // CATV上り
            ImageButton {
                id : m6
                objectName : "m6"
                activebg : ((root.transitionMode == root.singleMeasurementMode) || (root.transitionMode == root.multiMeasurementMode))
                                 ? "catv_bandbtn_sel.png" : "catv_bandbtn_sel.png"
                idlebg: "catv_bandbtn_n.png"
                icon : "icon_band_catv_up_stream_cur.png"
                width : 148
                height : 94
                disable : root.transitionMode == root.autoSettingMode
            }
        }
    }
}

/*##^##
Designer {
    D{i:0;autoSize:true;height:480;width:640}
}
##^##*/
