/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
import QtQuick.Controls 2.12
import "../../parts"
import jp.co.dxantenna.levelchecker.measureResultModel 1.0
import jp.co.dxantenna.levelchecker.multiGraphModel 1.0

/**
 * @brief マルチチャンネル測定
 */
Item {
    id: multiMeasurement
    anchors.fill: parent

    property var level: "---"                    //!< 測定入力レベル値
    property var mer: "---"                      //!< 変調誤差比の値
    property var ber: "---"                      //!< ビット誤り率の値
    property var userMode: ""                    //!< ユーザーモードの値
    property string band: ""                     //!< バンド
    property bool isSatelliteBroadCasting: false //!< 衛星放送かどうか
    property string channel: ""                  //!< チャンネル
    property string frequency: ""                //!< 中心周波数
    property string displayFrequencyUnit: "MHz"  //!< 中心周波数表示単位
    property string localFrequency: "00.000"     //!< 局発周波数
    property string modulation: ""               //!< 変調方式
    property string modulationPrefix: ""         //!< 変調方式の接頭句
    property string hierarchy: ""                //!< 階層
    property string polarization: ""             //!< 偏波
    property int startChannel: 13                //!< 開始チャンネル
    property int endChannel: 62                  //!< 終了チャンネル
    property int minimumLevel: 20                //!< 最小レベル
    property int maximumLevel: 120               //!< 最大レベル
    property int currentChannelIndex: -1         //!< 選択したチャンネルのインデックス
    property int scanChannelIndex: 0             //!< 測定中のチャンネルのインデックス
    property var values1: []                     //!< 単一の Band あるいは測定する複数の Band のうち、Band のインデックスが偶数の各チャンネルの測定入力レベル
    property var values1Low: []                  //!< 単一の Band あるいは測定する複数の Band のうち、Band のインデックスが偶数の各チャンネルの測定入力レベル(閾値未満の値)
    property var values2: []                     //!< 測定する複数の Band のうち、Band のインデックスが奇数の各チャンネルの測定入力レベル
    property var values2Low: []                  //!< 測定する複数の Band のうち、Band のインデックスが偶数の各チャンネルの測定入力レベル(閾値未満の値)
    property var values: []                      //!< 測定対象の全チャンネルの測定入力レベル
    property int currentPage: 1                  //!< 現在のページ
    property int totalPage: 1                    //!< 現在のページ
    property int currentBandIndex: 0             //!< BAND のインデックス
//    property int numberOfChannels: 60            //!< 選択した BAND で表示するチャンネル数(13, 60, 120, 160)
    property var fmChannels: null                //!< スキャン後の FM のチャンネル
    property var userCategory: null              //!< ユーザー定義のチャンネル
    property int selectCnMer: 1                  //!< MER/CNのどちらを測定設定で設定しているか
    property int graphType: 3                    //!< グラフの種類(0:13 本 1: 60 本 2: 120 本 3: 160 本)
    property var displayChannel: []              //!< 表示するチャンネルのリスト
    property bool isModulationVisible: true      //!< 変調方式 表示、非表示設定 (True: 表示, False: 非表示)
    property var displayChannelDetail: []        //!< チャンネル詳細情報表示可否リスト (画面左下のチャンネル詳細データの表示可否のリスト)
    property int minimumMer: 0                   //!< MERの最小値
    property int maximumMer: 0                   //!< MERの最大値
    property int displayModulationPrefixMode: 0  //!< 変調方式 表示モード 接頭句と変調方式をどのように表示するかを決める
    property int graphIndex: 0                   //!< グラフ画像のインデックス
    property bool autoScroll: false               //!< リストの自動スクロール有無
    property int selectGraphList: 0              //!< 0:グラフ, 1:リスト
    property int blinkInterval: 0                //!< 点滅間隔
    property bool hasMultiBandsInUserSetting: false //!< マルチ測定で Band を跨る場合

//    onCurrentBandIndexChanged: {
//        if (currentBandIndex === 0) {
//            numberOfChannels = 40
//        } else if (currentBandIndex === 1) {
//            numberOfChannels = 12
//        } else if (currentBandIndex === 2) {
//            numberOfChannels = 12
//        } else if (currentBandIndex === 3) {
//            numberOfChannels = 13
//        } else if (currentBandIndex === 4) {
//            numberOfChannels = 13
//        } else if (currentBandIndex === 5) {
//            numberOfChannels = 11
//        } else if (currentBandIndex === 6) {
//            numberOfChannels = 12
//        } else if (currentBandIndex === 7) {
//            numberOfChannels = 12
//        } else if (currentBandIndex === 8) {
//            numberOfChannels = 12
//        } else if (currentBandIndex === 9) {
//            numberOfChannels = 14
//        } else if (currentBandIndex === 10) {
//            numberOfChannels = 14
//        } else if (currentBandIndex === 11) {
//            numberOfChannels = 8
//        } else if (currentBandIndex === 12) {
//            numberOfChannels = 8
//        } else if (currentBandIndex === 13) {
//            numberOfChannels = 152
//        } else if (currentBandIndex === 14) {
//            numberOfChannels = 63
//        } else if (currentBandIndex === 15) {
//            numberOfChannels = 89
//        } else if (currentBandIndex === 16) {
//            numberOfChannels = 20
//        } else if (currentBandIndex === 17) {
//            numberOfChannels = 113
//        } else if (currentBandIndex === 18) {
//            numberOfChannels = 8
//        } else if (currentBandIndex === 19) {
//            numberOfChannels = 13
//        } else if (currentBandIndex === 20) {
//            numberOfChannels = 15
//        } else if (currentBandIndex === 21) {
//            numberOfChannels = 50		//BS CS統合
//        } else if (currentBandIndex === 22) {
//            // ユーザー設定 1
//            numberOfChannels = 13
//        } else if (currentBandIndex === 23) {
//            // ユーザー設定 2
//            numberOfChannels = 60
//        } else if (currentBandIndex === 24) {
//            // ユーザー設定 3
//            numberOfChannels = 120
//        }
//    }

    onFmChannelsChanged: {
        if (fmChannels != null) {
            graph.setFMChannel(fmChannels)
            currentBandIndex = 20
        }
    }

    onUserCategoryChanged: {
        if (userCategory != null) {
            graph.setUserCategory(userCategory)
        }
    }

    signal request(int condition)

    function backup(key, value) {
        var temporary = attributes.takeOver
        temporary[key] = value
        attributes.takeOver = temporary
    }

    // 測定結果(グラフ表示用)
    MultiGraphModel {
        id: multiGraphModel
        objectName: "multiGraphModel"
    }

    // グラフ表示
    // 枠を画像で表示
    MultiMeasurementFixedGraph {
        id: fixedGraph
        objectName: "fixedGraph"
        x: 240
        y: 10
        band: multiMeasurement.band
        minimumLevel: multiMeasurement.minimumLevel
        maximumLevel: multiMeasurement.maximumLevel
        graphIndex: multiMeasurement.graphIndex
        multiResult: multiGraphModel
        displayChannel : multiMeasurement.displayChannel
        visible: true
    }

    // 測定結果(リスト表示用)
    MeasureResultModel {
        id: measureResultModel
        objectName: "measureResultModel"
    }

    // リスト表示
    MultiMeasurementList {
        id: list
        objectName: "list"
        x: 210
        y: 22
        currentChannelIndex: multiMeasurement.currentChannelIndex
        scanChannelIndex: multiMeasurement.scanChannelIndex
        measureResult: measureResultModel
        selectCnMer: multiMeasurement.selectCnMer
        minimumMer: multiMeasurement.minimumMer
        maximumMer: multiMeasurement.maximumMer
        visible: false
        hasMultiBandsInUserSetting: multiMeasurement.hasMultiBandsInUserSetting
    }

    // Page
    Label {
        width: 300
        height: 20
        anchors {
            bottom: list.top
            bottomMargin: 1
            right: list.right
            rightMargin: 1
        }
        horizontalAlignment: Text.AlignRight
        color: "#E6E6E6"
        font.family: defaultFontName
        visible: list.visible
        text: "ページ " + multiMeasurement.currentPage + "/" + multiMeasurement.totalPage
    }

    // Ch./周波数
    ChannelInformation {
        labelMessage: "チャンネル"
        unitMessage: ""
        message: multiMeasurement.channel
        width: 150
        height: 55
        x: 24
        y: 2
    }

    // 周波数
    ChannelInformation {
        labelMessage: "周波数"
        message: multiMeasurement.frequency
        unitMessage:"MHz"
        width: 150
        height: 55
        x: 24
        y: 64
    }

    // Level
    ChannelInformation {
        labelMessage: "LEVEL"
        message: multiMeasurement.level
        unitMessage:"dBμV"
        width: 150
        height: 55
        x: 24
        y: 124
    }

    // 変調方式
    ChannelInformation {
        labelMessage: "変調方式"
        message: (multiMeasurement.modulationPrefix == "")
                 ? multiMeasurement.modulation : multiMeasurement.modulationPrefix
        secondMessage: (multiMeasurement.modulationPrefix != "") ? multiMeasurement.modulation : ""
        unitMessage:""
        doubleLine: (multiMeasurement.modulationPrefix == "")
                 ? false : true
        width: 150
        height: (multiMeasurement.modulationPrefix == "")
                ? 55 : 85
        x: 24
        y: 184
        visible: {
            if((selectGraphList == 0) && (isModulationVisible == true)) {
                true
            } else {
                false
            }
        }
    }

    // MER
    ChannelInformation {
        labelMessage: (multiMeasurement.selectCnMer === 1) ? "MER" : "CN"
        message: multiMeasurement.mer
        unitMessage:"dB"
        width: 150
        height: 55
        x: 24
        y: 184
        // PILOT, LTE, FM, CATV 上りであれば表示しない
        visible: (selectGraphList == 1 && (currentBandIndex !== 16 && currentBandIndex !== 18 && currentBandIndex !== 19 && currentBandIndex !== 21)) ? true : false
    }

    // BER
    ChannelInformation {
        labelMessage: "BER"
        message: multiMeasurement.ber
        width: 150
        height: 55
        x: 24
        y: 244
        // PILOT, LTE, FM, CATV 上りであれば表示しない
        visible: (selectGraphList == 1 && (currentBandIndex !== 16 && currentBandIndex !== 18 && currentBandIndex !== 19 && currentBandIndex !== 21)) ? true : false
    }

    // チャンネル詳細データ
    ChannelDetailInformation {
        displayBand: multiMeasurement.band
        frequency: multiMeasurement.frequency
        displayFrequencyUnit: multiMeasurement.displayFrequencyUnit
        modulation: multiMeasurement.modulation
        modulationPrefix: multiMeasurement.modulationPrefix
        polarization: multiMeasurement.polarization
        localFrequency: multiMeasurement.localFrequency
        displayChannelDetail: multiMeasurement.displayChannelDetail
        displayModulationPrefixMode: multiMeasurement.displayModulationPrefixMode
        x: 23
        y: 310
    }

    // グラフ
    MeasurementButton {
        id: graphButton
        objectName: "graphButton"
        x: 340
        y: 361
        contentsFileName: "qrc:/resource/png/icon_graph.png"
        activeStatusFileName: "qrc:/resource/png/single_btn_meter_c.png"
        active: false
        index: 0
    }

    // リスト
    MeasurementButton {
        id: listButton
        objectName: "listButton"
        x: 410
        y: 361
        contentsFileName: "qrc:/resource/png/icon_list.png"
        activeStatusFileName: "qrc:/resource/png/single_btn_delay_c.png"
        active: false
        adjustX: 4
        index: 1
    }

    // 区切り線
    Image {
        id: line
        width: 800
        height: 62
        x: 0
        y: 350
        source: "qrc:/resource/png/line_footer.png"
    }

    // ユーザーモードのラベル
    Label {
        id: userModeLabel
        width: 100
        height: 20
        x: 633
        y: 361
        horizontalAlignment: Qt.AlignLeft
        text: (multiMeasurement.userMode != "") ? "USER MODE : " : ""
        font.pixelSize: 14
        color: "#E4E6E5"
        font.family: defaultFontName
    }

    // ユーザーモードの値
    Text {
        id: userMode
        width: 80
        height: 20
        x: 633
        y: 383
        text: multiMeasurement.userMode
        horizontalAlignment: Qt.AlignLeft
        font.pixelSize: 14
        font.bold: true
        font.family: defaultFontName
        color: "#E4E6E5"
    }

    // イメージ
    MeasurementFunctionButton {
        id: imageButton
        objectName: "imageButton"
        x: 10
        y: 344
        idleImage: "qrc:/resource/png/icon_save1_n.png"
        pressedImage: "qrc:/resource/png/icon_save1_on.png"
    }

    // DATA
    MeasurementFunctionButton {
        id: dataButton
        objectName: "dataButton"
        x: 70
        y: 344
        idleImage: "qrc:/resource/png/icon_save2_multi_n.png"
        pressedImage: "qrc:/resource/png/icon_save2_multi_on.png"
    }

    // 測定結果表示中　表示
    Label {
        id: measurementResultDisplay
        objectName: "measurementResultDisplay"
        width: 150
        height: 20
        anchors {
            bottom: list.top
            bottomMargin: 1
            left: list.left
            leftMargin: 1
        }
        color: "#E6E6E6"
        font.family: defaultFontName
        text: ""
    }

    // リストのページ移動
    function onScrollPage(page)
    {
        multiMeasurement.currentPage = page
        list.scrollPage(page)
    }
}
