/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
//import QtCharts 2.3
import QtQuick.Controls 2.12
import "../../parts"
import jp.co.dxantenna.levelchecker.multiGraphModel 1.0

Item {
    id: root
    width: 504
    height: 300

    property string band: ""                                             //!< バンド
    property int minimumLevel: 20                                        //!< 最小レベル
    property int maximumLevel: 120                                       //!< 最大レベル
    property var multiResult: null                                       //!< マルチ測定グラフ用の測定結果
    property int barLength: 252                                          //!< 棒グラフの最大の長さ
    property int poleLength: 270                                         //!< 測定中の白線、選択中のチャンネルの青線の長さ
    property var displayChannel    : []                                  //!< 表示するチャンネルのリスト
    property var colors: [
                            "#FE0000",
                            "#00D926",
                            "#FE0000",
                            "#00D926",
//                            "#CFA2E7",
//                            "#57D9D9"
                            ]                                            //!< 棒グラフの色(配色 1 の閾値未満、以上、配色 2 の閾値未満、以上に対応)
    property int graphIndex: 0
    onGraphIndexChanged: {
        background.source = root.backgroundImages[root.graphIndex]
    }

    property var barInterval: [
                                12.6154,            // 地デジ
                                43.9783,            // BS 右旋
                                43.9783,            // BS 左旋
                                40.3135,            // CS 右旋
                                40.3135,            // CS 左旋
                                 3.3333,            // CATV ALL
                                 8.0645,            // CATV 1〜C63
                                 5.6782,            // CATV 13〜C101
                                 4.4152,            // スカパー！光
                                25.4611,            // PILOT
                                43.9783,            // CATV 上り
                                37.2124,            // JCSAT3A 垂直
                                37.2124,            // JCSAT3A 水平
                                32.2508,            // JCSAT4B 垂直
                                32.2508,            // JCSAT4B 水平
                                43.9783,            // SCC-B 垂直
                                48.3762,            // SCC-B 水平
                                43.9783,            // SCC-C 垂直
                                43.9783,            // SCC-C 水平
                                96.7523,            // LTE
                                43.9783,            // FM
                                10.0612,    	    // BS CS統合
                            ]                                            //!< 棒グラフの目盛りの間隔
    property var barHeight: [
                                      7,            // 地デジ
                                     14,            // BS 右旋
                                     14,            // BS 左旋
                                     14,            // CS 右旋
                                     14,            // CS 左旋
                                      3,            // CATV ALL
                                      8,            // CATV 1〜C63
                                      6,            // CATV 13〜C101
                                      4,            // スカパー！光
                                     14,            // PILOT
                                     14,            // CATV 上り
                                     14,            // JCSAT3A 垂直
                                     14,            // JCSAT3A 水平
                                     14,            // JCSAT4B 垂直
                                     14,            // JCSAT4B 水平
                                     14,            // SCC-B 垂直
                                     14,            // SCC-B 水平
                                     14,            // SCC-C 垂直
                                     14,            // SCC-C 水平
                                     14,            // LTE
                                     14,            // FM
                                     7,            // BS CS統合
                            ]                                           //!< 棒グラフの幅
    property var backgroundImages: [
                                        "qrc:/resource/png/multi_graph_uhf.png",
                                        "qrc:/resource/png/multi_graph_bs_right.png",
                                        "qrc:/resource/png/multi_graph_bs_left.png",
                                        "qrc:/resource/png/multi_graph_cs_right.png",
                                        "qrc:/resource/png/multi_graph_cs_left.png",
                                        "qrc:/resource/png/multi_graph_catv_all_1_c101.png",
                                        "qrc:/resource/png/multi_graph_catv_1_c63.png",
                                        "qrc:/resource/png/multi_graph_catv_13_c101.png",
                                        "qrc:/resource/png/multi_graph_sky_perftv_hikari.png",
                                        "qrc:/resource/png/multi_graph_pilot.png",
                                        "qrc:/resource/png/multi_graph_catv_upload.png",
                                        "qrc:/resource/png/multi_graph_jcsat3a_vertical.png",
                                        "qrc:/resource/png/multi_graph_jcsat3a_horizontal.png",
                                        "qrc:/resource/png/multi_graph_jcsat4b_vertical.png",
                                        "qrc:/resource/png/multi_graph_jcsat4b_horizontal.png",
                                        "qrc:/resource/png/multi_graph_sccb_vertical.png",
                                        "qrc:/resource/png/multi_graph_sccb_horizontal.png",
                                        "qrc:/resource/png/multi_graph_sccc_vertical.png",
                                        "qrc:/resource/png/multi_graph_sccc_horizontal.png",
                                        "qrc:/resource/png/multi_graph_lte.png",
                                        "qrc:/resource/png/multi_graph_fm.png",
                                        "qrc:/resource/png/multi_graph_bs_cs.png"	//BS CS統合
                                        ]                                //!< インデックスに対応する画像

    property var xCoordinate: [
                                100,
                                 92,
                                 92,
                                 92,
                                 92,
                                100,
                                100,
                                100,
                                100,
                                 98,
                                 92,
                                 94,
                                 94,
                                 94,
                                 94,
                                 92,
                                 91,
                                 94,
                                 94,
                                 80,
                                 92,
                                 100	//BS CS統合
                                ]                                       //!< 最初の棒グラフを表示する X 座標

    // グラフの枠
    Image {
        id: background
        x: -42
        y: 0
        source: root.backgroundImages[root.graphIndex]
        width: 580
        height: 326
    }

    // 棒
    Component {
        id: barComponent
        Item {
            id: barItem
            width: barList.width
            height: root.barInterval[root.graphIndex]
            Rectangle {
                id: bar
                anchors.top: parent.top
                anchors.topMargin: root.barInterval[root.graphIndex] / 4
                anchors.left: parent.left
                anchors.leftMargin: 22
                width: barLength * (model.level - minimumLevel) / (maximumLevel - minimumLevel)
                height: root.barHeight[root.graphIndex] - (border.width * 2)
                color: (model.colorIndex !== undefined) ? colors[model.colorIndex] : "transparent"
                border.color: "transparent"
                border.width: 1

                // 現在選択しているチャンネル
                Text {
                    text: "●"
                    color: "#3FA0FE"
                    anchors.right: selectionPole.right
                    anchors.rightMargin: -10                // ● を上端に配置するための調整値
                    anchors.bottom: selectionPole.bottom
                    anchors.bottomMargin: -9                // ● を先の中央に寄せるための調整値
                    font.family: defaultFontName
                    visible: (model.selection !== undefined) ? model.selection : false
                }

                Rectangle {
                    id: selectionPole
                    width: poleLength
                    height: 1
                    color: "#3FA0FE"
                    anchors.left: parent.left
                    anchors.verticalCenter: parent.verticalCenter
                    visible: (model.selection !== undefined) ? model.selection : false
                }

                // 現在SCAN中のチャンネル
                Text {
                    text: "◆"
                    color: "#E6E6E6"
                    anchors.right: scanningPole.right
                    anchors.rightMargin: -10                // ◆ を上端に配置するための調整値
                    anchors.bottom: scanningPole.bottom
                    anchors.bottomMargin: -9                // ◆ を先の中央に寄せるための調整値
                    font.family: defaultFontName
                    visible: (model.currentMeasuring !== undefined) ? model.currentMeasuring : false
                }

                Rectangle {
                    id: scanningPole
                    width: poleLength
                    height: 1
                    color: "#E6E6E6"
                    anchors.left: parent.left
                    anchors.verticalCenter: parent.verticalCenter
                    visible: (model.currentMeasuring !== undefined) ? model.currentMeasuring : false
                }
            }
        }
    }

    // 棒グラフのリスト(90°左に回転するので座標は調整する)
    ListView {
        id: barList
        width: parent.height
        height: parent.width
        x: root.xCoordinate[root.graphIndex]
        y: -100
        model: multiResult
        delegate: barComponent
        rotation: 270
    }
}
