/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
//import QtCharts 2.3
import QtQuick.Controls 2.12
import "../../parts"
import jp.co.dxantenna.levelchecker.multiGraphModel 1.0

Item {
    id: root
    width: 520
    height: 300

    property string band: ""                                             //!< バンド
    property int minimumLevel: 20                                        //!< 最小レベル
    property int maximumLevel: 120                                       //!< 最大レベル
    property var multiResult: null                                       //!< マルチ測定グラフ用の測定結果
    property int graphType: 3                                            //!< グラフの種類(0:13 本 1: 60 本 2: 120 本 3: 160 本)
    property var barWidth: [ 40, 8.666, 4.333, 3.25 ]                    //!< 棒グラフの幅(13 本, 60 本, 120 本, 160 本に対応)
    property int barLength: 250                                          //!< 棒グラフの最大の長さ
    property int poleLength: 270                                         //!< 測定中の白線、選択中のチャンネルの青線の長さ
    property var yAxisLabels       : ["120", "100","80","60","40","20"]  //!< y軸に表示しているメモリの値 BAND: CS以外
    property var yAxisLabelsCS     : ["120", "100","80","60","40","35"]  //!< y軸に表示しているメモリの値 BAND: CS
    property var displayChannel    : []                                  //!< 表示するチャンネルのリスト
    readonly property var startpos : [7, 3, 1, 0]                        //!< x軸ラベルの開始(13 本, 60 本, 120 本, 160 本に対応)
    readonly property var interval : [80, 78, 80, 80]                    //!< x軸ラベルの間隔(13 本, 60 本, 120 本, 160 本に対応)
    property var colors: [
                            "#FE0000",
                            "#00D926",
                            "#CFA2E7",
                            "#57D9D9"
                            ]                                            //!< 棒グラフの色(配色 1 の閾値未満、以上、配色 2 の閾値未満、以上に対応)

    // 背景
    Rectangle {
        id: background
        anchors{
            top : graphUnit.top
            topMargin: -10
            left: graphUnit.left
            leftMargin: -5
        }
        width:  570
        height: 350
        color: "#22232C"
    }

    // x座標のラベルを表示する
    Repeater {
        model: root.displayChannel.length
        Rectangle {
            anchors {
                top: xAxis.bottom
                topMargin: 10
            }
            x : root.startpos[graphType] + (root.interval[graphType] * index)
            width:  40
            height: 20
            Label {
                anchors.centerIn: parent
                text: root.displayChannel[index]
                color: "#E6E6E6"
                font.family: defaultFontName
                font.pixelSize: 12
            }
            color: "transparent"
        }
    }

    // x座標のメモリを表示する
    Repeater {
        model: (root.displayChannel.length * 2) - 1
        Rectangle {
            anchors {
                top: xAxis.bottom
                topMargin: 5
            }
            x: root.startpos[graphType] + (root.interval[graphType] / 2 * index) + 20
            width:  2
            height: 2
            color: "#5C5F66"
        }
    }

    // y座標の線を記述する
    Column {
        y: 50
        spacing: root.barLength / 5
        Repeater {
            model: 5
            Rectangle {
                x: yAxis.x
                width : root.width
                height: 1
                color : "#5C5F66"
            }
        }
    }

    // y座標のラベルを表示する
     Repeater {
         model: 6
         Rectangle{
             anchors {
                 right: xAxis.left
                 rightMargin: 5
             }
             y : ((root.barLength / 5) * index) + 47
             x : yAxis.x - 15
             width : 30
             height: 10
             color: "transparent"
             Label {
                 anchors.centerIn: parent
                 verticalAlignment: Text.AlignVCenter
                 text : root.yAxisLabels[index]
                 font.pixelSize: 12
                 color  : "#E6E6E6"
                 font.family: defaultFontName
             }
         }
     }

    // X 軸
    Rectangle {
        id: xAxis
        width: root.width
        height: 2
        x: 17
        y: 300
        color: "#EEEEEE"
    }

    // Y 軸
    Rectangle {
        id: yAxis
        width: 2
        height: root.poleLength
        x: 17
        y: 30
        color: "#EEEEEE"
    }

    // 棒
    Component {
        id: barComponent
        Item {
            id: barItem
            width: barList.width
            height: root.barWidth[root.graphType]
            Rectangle {
                id: bar
                anchors.top: parent.top
                anchors.left: parent.left
                width: barLength * (model.level - minimumLevel) / (maximumLevel - minimumLevel)
                height: root.barWidth[root.graphType] - (border.width * 2)
                color: (model.colorIndex !== undefined) ? colors[model.colorIndex] : "transparent"
                border.color: "transparent"
                border.width: (graphType === 0) ? 12 : (graphType === 1) ? 2 : 1

                // 現在選択しているチャンネル
                Text {
                    text: "●"
                    color: "#3FA0FE"
                     anchors.right: selectionPole.right
                     anchors.rightMargin: -10                // ● を上端に配置するための調整値
                     anchors.bottom: selectionPole.bottom
                     anchors.bottomMargin: -9                // ● を先の中央に寄せるための調整値
                     font.family: defaultFontName
                     visible: (model.selection !== undefined) ? model.selection : false
                }

                Rectangle {
                    id: selectionPole
                    width: poleLength
                    height: 1
                    color: "#3FA0FE"
                    anchors.left: parent.left
                    anchors.verticalCenter: parent.verticalCenter
                    visible: (model.selection !== undefined) ? model.selection : false
                }

                // 現在SCAN中のチャンネル
                Text {
                    text: "◆"
                    color: "#E6E6E6"
                    anchors.right: scanningPole.right
                    anchors.rightMargin: -10                // ◆ を上端に配置するための調整値
                    anchors.bottom: scanningPole.bottom
                    anchors.bottomMargin: -9                // ◆ を先の中央に寄せるための調整値
                    font.family: defaultFontName
                    visible: (model.currentMeasuring !== undefined) ? model.currentMeasuring : false
                }

                Rectangle {
                    id: scanningPole
                    width: poleLength
                    height: 1
                    color: "#E6E6E6"
                    anchors.left: parent.left
                    anchors.verticalCenter: parent.verticalCenter
                    visible: (model.currentMeasuring !== undefined) ? model.currentMeasuring : false
                }
            }
        }
    }

    // 棒グラフのリスト(90°左に回転するので座標は調整する)
    ListView {
        id: barList
        width: parent.height - 20
        height: parent.width
        x: 140
        y: -100
        model: multiResult
        delegate: barComponent
        rotation: 270
    }

    // グラフの単位
    Label {
        id: graphUnit
        width: 100
        height: 16
        x: -20
        y: -4
        color: "#E6E6E6"
        text: "(dBuV)"
        font.family: defaultFontName
        font.pixelSize: 12
    }
}
