/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
import QtQuick.Controls 2.12
import jp.co.dxantenna.levelchecker.measureResultModel 1.0

Rectangle {
    id: root
    width: 568
    height: 290
    color: "transparent"

    property int currentChannelIndex: -1        //!< 選択したチャンネルのインデックス
    property int scanChannelIndex: 0            //!< 測定中のチャンネルのインデックス
    property var measureResult: null            //!< 測定結果リスト
    property int selectCnMer: 1                 //!< CN/MER切替状態
    readonly property int listRows: 6           //!< リストの行数
    property int minimumMer: 0;                 //!< MERの最大値
    property int maximumMer: 0;                 //!< MERの最小値
    property bool storing: false                //!< 測定データ保存動作中
    property bool hasMultiBandsInUserSetting: false //!< マルチ測定で Band を跨る場合

    // 測定中の行を先頭にする
    onScanChannelIndexChanged: {
        if (multiMeasurement.autoScroll === true) {
            var index = root.scanChannelIndex - 1
            if (index < 0) {
                index = 0
            }

            listView.positionViewAtIndex(index, ListView.Beginning)
            multiMeasurement.currentPage = (index / root.listRows) + 1;
        }
    }

    Row {
        id: header
        z: 2
        Item {
            width: 40
            height: 50
            clip: true
            Rectangle {
                anchors.fill: parent
                anchors.topMargin: -border.width
                anchors.bottomMargin: -border.width
                anchors.leftMargin: -border.width
                color: "#30333A"
                border.width: 1
                border.color: "#28292E"
                Label {
                    text: "No."
                    color: "#81BEFF"
                    font.family: defaultFontName
                    anchors.centerIn: parent
                }
            }
        }

        Item {
            width: !hasMultiBandsInUserSetting ? 0 : 110
            height: 50
            clip: true
            Rectangle {
                anchors.fill: parent
                anchors.topMargin: -border.width
                anchors.bottomMargin: -border.width
                anchors.leftMargin: -border.width
                color: "#30333A"
                border.width: 1
                border.color: "#28292E"
                Label {
                    text: "Band"
                    color: "#81BEFF"
                    font.family: defaultFontName
                    anchors.centerIn: parent
                }
            }
        }


        Item {
            width: !hasMultiBandsInUserSetting ? 105 : 75
            height: 50
            clip: true
            Rectangle {
                anchors.fill: parent
                anchors.topMargin: -border.width
                anchors.bottomMargin: -border.width
                anchors.leftMargin: -border.width
                color: "#30333A"
                border.width: 1
                border.color: "#28292E"
                Label {
                    text: "ch."
                    color: "#81BEFF"
                    font.family: defaultFontName
                    anchors.centerIn: parent
                }
            }
        }

        Item {
            width: !hasMultiBandsInUserSetting ? 105 : 85
            height: 50
            clip: true
            Rectangle {
                anchors.fill: parent
                anchors.topMargin: -border.width
                anchors.bottomMargin: -border.width
                anchors.leftMargin: -border.width
                color: "#30333A"
                border.width: 1
                border.color: "#28292E"
                Label {
                    text: " LEVEL\n(dBuV)"
                    color: "#81BEFF"
                    font.family: defaultFontName
                    anchors.centerIn: parent
                }
            }
        }

        Item {
            width: !hasMultiBandsInUserSetting ? 105 : 75
            height: 50
            clip: true
            Rectangle {
                anchors.fill: parent
                anchors.topMargin: -border.width
                anchors.bottomMargin: -border.width
                anchors.leftMargin: -border.width
                color: "#30333A"
                border.width: 1
                border.color: "#28292E"
                Label {
                    text: (root.selectCnMer === 1) ? "MER\n(dB)" : "CN\n(dB)"
                    color: "#81BEFF"
                    font.family: defaultFontName
                    anchors.centerIn: parent
                }
            }
        }

        Item {
            width: !hasMultiBandsInUserSetting ? 105 : 85
            height: 50
            clip: true
            Rectangle {
                anchors.fill: parent
                anchors.topMargin: -border.width
                anchors.bottomMargin: -border.width
                anchors.leftMargin: -border.width
                color: "#30333A"
                border.width: 1
                border.color: "#28292E"
                Label {
                    text: "BER"
                    color: "#81BEFF"
                    font.family: defaultFontName
                    anchors.centerIn: parent
                }
            }
        }

        Item {
            width: !hasMultiBandsInUserSetting ? 108 : 98
            height: 50
            clip: true
            Rectangle {
                anchors.fill: parent
                anchors.topMargin: -border.width
                anchors.bottomMargin: -border.width
                anchors.leftMargin: -border.width
                color: "#30333A"
                border.width: 1
                border.color: "#28292E"
                Label {
                    text: "周波数\n(MHz)"
                    color: "#81BEFF"
                    font.family: defaultFontName
                    anchors.centerIn: parent
                }
            }
        }
    }

    // 行のデリゲート
    Component {
        id: delegateRow
        Item {
            id: rowBase
            width: 568
            height: 40
            Row {
                Item {
                    id: columnNumber
                    width: 40
                    height: 40
                    clip: true
                    Rectangle {
                        anchors.fill: parent
                        anchors.topMargin: -border.width
                        anchors.bottomMargin: -border.width
                        anchors.leftMargin: -border.width
                        color: (index === currentChannelIndex) ? "#265A93" : (index % 2 === 0) ? "#41444D" : "#30333A"
                        border.width: 1
                        border.color: "#28292E"
                        Label {
                            text: (model.channel !== undefined && model.channel !== "") ? index + 1 : ""
                            color: "#81BEFF"
                            font.family: defaultFontName
                            anchors.verticalCenter: parent.verticalCenter
                            anchors.right: parent.right
                            anchors.rightMargin: 5
                        }
                    }
                }
                Item {
                    id: columnBand
                    width: !hasMultiBandsInUserSetting ? 0 : 110
                    height: 40
                    clip: true
                    Rectangle {
                        anchors.fill: parent
                        anchors.topMargin: -border.width
                        anchors.bottomMargin: -border.width
                        anchors.leftMargin: -border.width
                        color: (index === currentChannelIndex) ? "#265A93" : (index % 2 === 0) ? "#41444D" : "#30333A"
                        border.width: 1
                        border.color: "#28292E"
                        Label {
                            text: {
                                if (model.bandName !== undefined) {
                                    if(model.bandName === "スカパー！プレミアムサービス光") {
                                        "スカパー！光"
                                    } else {
                                        model.bandName
                                    }
                                } else {
                                    ""
                                }
                            }
                            color: "#E6E6E6"
                            font.family: defaultFontName
                            font.pointSize: 12
                            anchors.centerIn: parent
                        }
                    }
                }
                Item {
                    id: columnChannel
                    width: !hasMultiBandsInUserSetting ? 105 : 75
                    height: 40
                    clip: true
                    Rectangle {
                        anchors.fill: parent
                        anchors.topMargin: -border.width
                        anchors.bottomMargin: -border.width
                        anchors.leftMargin: -border.width
                        color: (index === currentChannelIndex) ? "#265A93" : (index % 2 === 0) ? "#41444D" : "#30333A"
                        border.width: 1
                        border.color: "#28292E"
                        Label {
                            text: (model.channel !== undefined) ? model.channel : ""
                            color: "#E6E6E6"
                            font.family: defaultFontName
                            anchors.centerIn: parent
                        }
                    }
                }
                Item {
                    id: columnLevel
                    width: !hasMultiBandsInUserSetting ? 105 : 85
                    height: 40
                    clip: true
                    Rectangle {
                        anchors.fill: parent
                        anchors.topMargin: -border.width
                        anchors.bottomMargin: -border.width
                        anchors.leftMargin: -border.width
                        color: (index === currentChannelIndex) ? "#265A93" : (index % 2 === 0) ? "#41444D" : "#30333A"
                        border.width: 1
                        border.color: "#28292E"
                        Label {
                            text: (model.level === undefined) ? "" : (model.level === -1) ? "---" : model.level
                            color: "#E6E6E6"
                            font.family: defaultFontName
                            anchors.centerIn: parent
                        }
                    }
                }
                Item {
                    id: columnMer
                    width: !hasMultiBandsInUserSetting ? 105 : 75
                    height: 40
                    clip: true
                    Rectangle {
                        anchors.fill: parent
                        anchors.topMargin: -border.width
                        anchors.bottomMargin: -border.width
                        anchors.leftMargin: -border.width
                        color: (index === currentChannelIndex) ? "#265A93" : (index % 2 === 0) ? "#41444D" : "#30333A"
                        border.width: 1
                        border.color: "#28292E"
                        Label {
                            text: displayMer(model.mer)
                            color: "#E6E6E6"
                            font.family: defaultFontName
                            anchors.centerIn: parent
                        }
                    }
                }
                Item {
                    id: columnBer
                    width: !hasMultiBandsInUserSetting ? 105 : 85
                    height: 40
                    clip: true
                    Rectangle {
                        anchors.fill: parent
                        anchors.topMargin: -border.width
                        anchors.bottomMargin: -border.width
                        anchors.leftMargin: -border.width
                        color: (index === currentChannelIndex) ? "#265A93" : (index % 2 === 0) ? "#41444D" : "#30333A"
                        border.width: 1
                        border.color: "#28292E"
                        Label {
                            text: displayBer(model.ber)
                            color: "#E6E6E6"
                            font.family: defaultFontName
                            anchors.centerIn: parent
                        }
                    }
                }
                Item {
                    id: columnFrequency
                    width: !hasMultiBandsInUserSetting ? 108 : 98
                    height: 40
                    clip: true
                    Rectangle {
                        anchors.fill: parent
                        anchors.topMargin: -border.width
                        anchors.bottomMargin: -border.width
                        anchors.leftMargin: -border.width
                        color: (index === currentChannelIndex) ? "#265A93" : (index % 2 === 0) ? "#41444D" : "#30333A"
                        border.width: 1
                        border.color: "#28292E"
                        Label {
                            text: (model.frequency != undefined) ? model.frequency : ""
                            color: "#E6E6E6"
                            font.family: defaultFontName
                            anchors.centerIn: parent
                        }
                    }
                }
            }
            Rectangle {
                anchors.fill: rowBase
                border.width: 2
                border.color: (index === scanChannelIndex) ? "#FFFFFF" : "transparent"
                color: "transparent"
            }
        }
    }

    // リスト
    ListView {
        id: listView
        width: parent.width
        height: 240
        anchors.top: header.bottom
        anchors.left: header.left
        clip: true
        model: measureResult
        focus: true
        interactive: false
        delegate: delegateRow
    }

    // 画面操作説明アイコン
    Image {
        id: screenOperationIcon
        width: (!root.storing) ? 24 : 162
        height: 24
        source: (!root.storing) ? "qrc:/resource/png/icon_enter.png" : ""
        anchors {
            top: listView.bottom
            left: listView.left
            topMargin: 9
        }
    }

    // 説明
    Text {
        id: screenOperationText
        anchors.bottom: screenOperationIcon.bottom
        anchors.bottomMargin: 5
        anchors.left: screenOperationIcon.right
        anchors.leftMargin: 7
        width: 100
        color: "#80BFFF"
        text: (!root.storing) ? "決定ボタン：自動スクロールする/しない" : ""
        font.pixelSize: 15
        font.family: defaultFontName
    }

    // リストをページ単位でスクロール
    function scrollPage(page)
    {
        listView.positionViewAtIndex(root.listRows * (page - 1), ListView.Beginning)
    }

    function displayMer(mer)
    {
        if (mer === undefined) {
            return ""
        }


        if (mer === "-1") {
            return "---"
        } else if (mer === "-2.0") {
            return "<5.0"     // constant.h MER_TIMEOUT_VALUE 参照
        }else if(mer === "-3.0"){
            return "<20.0"
        }

//        if (mer < root.minimumMer) {
//            return "<" + root.minimumMer.toString()
//        }

//        if (mer > root.maximumMer) {
//            return ">" + root.maximumMer.toString()
//        }

        return mer
    }

    function displayBer(ber)
    {
        if (ber === undefined) {
            return ""
        }

        if (ber === "-1") {
            return "---"
        } else if (ber === "-2") {
            return "2.2e-2"     // constant.h BER_TIMEOUT_VALUE 参照
        }

        var value = Number(ber).toExponential(1).replace('e+0', 'e-0')
        if (isNaN(value)) {
//            value = "2.2e-2"    // constant.h BER_TIMEOUT_VALUE 参照
              value = "---"    // constant.h BER_TIMEOUT_VALUE 参照
        }

        return value
    }
}
