/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
import QtQuick.Window 2.12
import QtQuick.Controls 2.12

import "../../parts"

// コンスタレーション
Item {
    id: constellation

    property var channel:""
    property var level:""
    property var broadcastingSystem:""
    property var frequency:""
    property var displayFrequencyUnit:""
    property var modulation: ""
    property var modulationPrefix: ""
    property var localFrequency:""
    property var hierarchy: ""
    property var mer:""
    property var ber:""
    property var constellationData: singleMeasurement.constellationData                 //!< 一回で読み出したコンスタレーションデータ
    property bool isConstellationDataClear: singleMeasurement.isConstellationDataClear  //!< グラフ表示のクリアー有無
    property string backgroundImage: "qrc:/resource/png/conste_frame.png"
    property bool isLocalOscillatorVisible: false                                       //!< 局発周波数表示可否フラグ
    property int selectCnMer: 1                                                         //!< MER/CNのどちらを測定設定で設定しているか
    property bool isSatelliteBroadCasting : false                                       //!< 衛星放送かどうか
    property string polarization: ""                                                    //!< 偏波
    property string band : ""                                                           //!< BAND名
    property string selectedModulation: ""                                              //!< 選択変調方式 CATVで使用
    property int axisAreaCellCount : 4                                                  //!< xy-axisで区切られたエリアの縦横のセル数
    property real coefficient: 1.0                                                      //!< コンスタレーションの座標の計算用の係数
    property bool locked: true                                                          //!< ロック有無
    property int blinkInterval: 0                                                       //!< 点滅間隔
    property bool confirmedValue: singleMeasurement.confirmedValue                      //!< ロックタイムアウト判定で値が確定したかどうか

    signal request(int condition)

    onBandChanged: {
        if (band === "地上デジタル") {
            broadcastingSystem.message = "ISDBT"
        } else if ((band === "BS") || (band === "110°CS")) {
            broadcastingSystem.message = "ISDBS/S3"
        } else if ((band === "JCSAT-3A") || (band === "JCSAT-4B") || (band === "SCC-B") || (band === "SCC-C")) {
            broadcastingSystem.message = "DVBS/S2"
        } else if (band === "CATV") {
            if(selectedModulation === "OFDM") {
                broadcastingSystem.message = "ISDBT"
            } else if(selectedModulation === "64QAM") {
                broadcastingSystem.message = "ISDBC"
            }
        } else if (band === "CATV OFDM") {
            broadcastingSystem.message = "CATV OFDM"
        } else if (band === "スカパー！プレミアムサービス光") {
            broadcastingSystem.message = "OPTICAST"
        }
    }

    onSelectedModulationChanged: {
        if (band === "CATV") {
            if(selectedModulation === "OFDM") {
                broadcastingSystem.message = "ISDBT"
            } else if(selectedModulation === "64QAM") {
                broadcastingSystem.message = "ISDBC"
            }
        }
    }

    onModulationChanged: {
        modulation.message = constellation.modulation
        if (constellation.modulation.toString().indexOf("OFDM") !== -1) {
            constellation.backgroundImage = "qrc:/resource/png/conste_frame.png"
            constellation.axisAreaCellCount = 4
            constellation.coefficient = 1.0
        } else if (constellation.modulation.toString().indexOf("64QAM") !== -1) {
            if (constellation.broadcastingSystem === "ISDBT") {
                constellation.backgroundImage = "qrc:/resource/png/conste_frame.png"
                constellation.axisAreaCellCount = 4
                constellation.coefficient = 1.0
            } else {
                constellation.backgroundImage = "qrc:/resource/png/conste_8x8.png"
                constellation.axisAreaCellCount = 64
                constellation.coefficient = 0.9
            }
        } else if (constellation.modulation.toString().indexOf("256QAM") !== -1) {
            constellation.backgroundImage = "qrc:/resource/png/conste_16x16.png"
            constellation.axisAreaCellCount = 256
            constellation.coefficient = 0.84
        } else {
            constellation.backgroundImage = "qrc:/resource/png/conste_frame.png"
            constellation.axisAreaCellCount = 4
            constellation.coefficient = 1.0
        }
    }

    onModulationPrefixChanged: {
        if (constellation.modulationPrefix == "") {
            modulation.message = constellation.modulation
        } else {
            modulation.message = constellation.modulationPrefix + " " + constellation.modulation
        }
    }

    Column {
        id: channelnfo

        x: 25
        width:parent.width/2
        height:childrenRect.height

        property int rowspacing : 10
        spacing: -5
        Row {
            height: 75
            spacing: parent.rowspacing

            ChannelInformation {
                id:channel
                labelMessage: "チャンネル"
                message: constellation.channel
                messageFontSize: 32
                width: 100
            }

            // 地デジの場合のみ表示する
            ChannelInformation {
                id:hierarchy
                labelMessage: "階層"
                message: constellation.hierarchy
                messageFontSize: 32
                width: 90
                visible: (constellation.band == "地上デジタル")
            }

            // 衛星放送の場合のみ表示する
            ChannelInformation {
                id:polarization
                labelMessage: "偏波"
                message: constellation.polarization
                messageFontSize: 32
                width: 90
                visible: constellation.isSatelliteBroadCasting
            }

            // 階層, 偏波が非表示の場合のみ表示する
            Item {
                id: padding
                height: 75
                width: 90
                visible: (polarization.visible == false && hierarchy.visible == false)
            }

            ChannelInformation {
                id:broadcastingSystem
                labelMessage: "放送方式"
//                message: constellation.broadcastingSystem
                messageFontSize: 32
                width: 200
                anchors.topMargin: -10
            }
        }
        Row {
            height:75
            //x:20
            //spacing: parent.rowspacing  izumi
            spacing: 10


            ChannelInformation {
                id:frequency
                labelMessage:"周波数"

                message: String(constellation.frequency)
                messageFontSize: 32
                unitMessage:String(constellation.displayFrequencyUnit)
                width:200
            }
            ChannelInformation {
                id:modulation
                labelMessage: "変調方式"
                message: constellation.modulation
                messageFontSize: 20
                width:200
                constetopmrgine: 16


            }
        }
        Row {
            height:75
            //x:40
            spacing: parent.rowspacing
            ChannelInformation {
                id:level
                labelMessage: "LEVEL"
                message: constellation.level
                messageFontSize: 32
                unitMessage:"dBμV"
                width:200
            }
        }
        Row {
            height:75
            //x:60
            spacing: parent.rowspacing
            ChannelInformation {
                id:mer
                labelMessage: (constellation.selectCnMer === 1) ? "MER" : "CN"
                message: constellation.mer
                unitMessage:"dB"
                messageFontSize: 32
                width:200
                blinkInterval: constellation.blinkInterval
            }
            ChannelInformation {
                id:ber
                labelMessage: "BER"
                messageFontSize: 32
                message: constellation.ber
                width:200
                blinkInterval: constellation.blinkInterval
            }
        }
        Row {
            height: 75
            //x:80
            spacing: parent.rowspacing
            ChannelInformation {
                id: localFrequency
                labelMessage: "局部発振周波数"
                message: constellation.localFrequency
                unitMessage: "GHz"
                width: 200
                visible: constellation.isLocalOscillatorVisible
            }
        }
    }

    Image {
        id: constellationGraphBackground
        width: 326
        height: 326
        x: 445
        y: 0
        source: constellation.backgroundImage

        ConstellationGraph {
            id: constellationGraph
            anchors.fill: parent
            constellationData: constellation.constellationData
            axisAreaCellCount: constellation.axisAreaCellCount
            coefficient: constellation.coefficient
            onConstellationDataChanged: {
                constellationGraph.requestToDraw()
            }
            isConstellationDataClear: constellation.isConstellationDataClear
            locked: constellation.locked
            confirmedValue: constellation.confirmedValue
        }
    }
}
