/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
import QtQuick.Controls 2.12

/**
 * @brief コンスタレーショングラフ QML
 */
Item {
    id: root

    property real cellLineWidth : 1.0
    property real rectLineWidth : 3.0
    property real axisLineWidth : 2.0

    property int axisAreaCellCount : 4  // xy-axisで区切られたエリアの縦横のセル数（縦横で同じ数とする／グラフ全体のセル総数は「縦：(axisAreaCellCount*2) x 横：(axisAreaCellCount*2)」となる）
    property real cellWidth : (width - ((rectLineWidth * 2) + axisLineWidth + (cellLineWidth * (axisAreaCellCount - 1) * 2))) / (axisAreaCellCount * 2)
    property real cellHeight : (height - ((rectLineWidth * 2) + axisLineWidth + (cellLineWidth * (axisAreaCellCount - 1) * 2))) / (axisAreaCellCount * 2)

    property real coefficient: 1.0      // 実機で QAM を選択している場合の表示調整用係数(1 より小さければ拡大)

    property real maxX: 80.0 * coefficient
    property real maxY: 80.0 * coefficient
    property real minX: -80.0 * coefficient
    property real minY: -80.0 * coefficient

    property real dotRadius : 1

    property variant constellationData : []
    property bool isConstellationDataClear: false
    onIsConstellationDataClearChanged: {
        if (isConstellationDataClear === true) {
            var ctx = canvas.getContext("2d");
            ctx.reset();
            canvas.requestPaint();
        }
    }
    property bool locked: true                      //!< ロック有無
    property bool confirmedValue: false

    // グラフ
    Canvas {
        id: canvas
        anchors.fill: root
        antialiasing: true
        onPaint: {
            var ctx = getContext("2d")
            ctx.save()
            if (root.isConstellationDataClear === true) ctx.clearRect(0, 0, width, height)
            ctx.fillStyle = "white"
            ctx.lineWidth = 1
            if (root.constellationData !== undefined) {
                var graphAreaWidth = (width - (rectLineWidth * 2))
                var graphAreaHeight = (height - (rectLineWidth * 2))
                for (var i = 0; i < root.constellationData.length; ++i) {
                    var data_x = (root.constellationData[i].x - root.minX) * (graphAreaWidth / (root.maxX - root.minX)) + rectLineWidth
                    var data_y = graphAreaHeight - ((root.constellationData[i].y - root.minY) * (graphAreaHeight / (root.maxY - root.minY))) + rectLineWidth
                    // console.log("i:" + i + " X(" + root.constellationData[i].x + "):" + data_x + " Y(" + root.constellationData[i].y + "):" + data_y)
                    ctx.beginPath()
                    ctx.arc(data_x, data_y, dotRadius, 0, 360, false)
                    ctx.closePath()
                    ctx.fill()
                }
            }
            ctx.restore()
        }


        Image {
            id: during_measure
            source: "qrc:/resource/png/during_measurment_single.png"
            x: (parent.width - caution.width) / 2 + 60



            y: (parent.height - caution.height) / 2 -15
            visible: (!(root.confirmedValue == false) && !root.locked)
        }
        // ロック
        Rectangle {
            id : caution
            width: 270
            height: 32
            x: (parent.width - caution.width) / 2
            y: (parent.height - caution.height) / 2
            color: "transparent"
            border.color: "#E6E6E6"
            visible: false
            Label {
                anchors.centerIn: parent
                color: "#E6E6E6"
                text: "測定中"
                font.family: defaultFontName
                font.pixelSize: 24
            }
        }
    }

    function requestToDraw()
    {
        canvas.requestPaint()
    }

    function clear()
    {
        root.isConstellationDataClear = true
        canvas.requestPaint()
    }
}
