/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
import QtCharts 2.3
import QtQuick.Controls 2.12
import "../../parts"

// 遅延プロファイル
Item {
    id: delayProfile

    property var channel:""
    property var level:""
    property var broadcastingSystem:""
    property var frequency:""
    property var displayFrequencyUnit:""
    property var hierarchy: ""
    property var delayTime: ""
    property var localFrequency:""
    property var levelDifference:"0"
    property var mer:""
    property var ber:""
    property var lineSeries: null
    onLineSeriesChanged: {
        graph.update()
    }
    property double givalue: 0
    property double interval: -84
    property bool cursoredGraph: false
    onCursoredGraphChanged: {
        if (cursoredGraph) {
            graph.focus = true
        }
    }

    property bool isLocalOscillatorVisible : false  //!< 局発周波数表示可否フラグ
    property int selectCnMer: 1                     //!< CNR/MER切替状態
    property int markerX: 0                         //!< マーカーの X 座標
    property bool isSatelliteBroadCasting: false    //!< 衛星放送かどうか
    property string polarization: ""                //!< 偏波
    property string band: ""                        //!< BAND名
    property bool locked: true                      //!< ロック有無
    property int blinkInterval: 0                   //!< 点滅間隔


    Image {
         id: delay_graph
         source: "qrc:/resource/png/delay_graph.png"
         width: 564

         x:197
         y:31
     }

    Column {
        id: channelnfo

        x: 25
        width:parent.width/2
        height:childrenRect.height

        property int rowspacing : 10
        spacing: -5
       Row {
           height: 75
           spacing: parent.rowspacing

           ChannelInformation {
               id:channel
               labelMessage: "チャンネル"
               message: delayProfile.channel
               messageFontSize: 28
               width: 150
           }

           // 地デジの場合のみ表示する
           ChannelInformation {
               id:hierarchy
               labelMessage: "階層"
               message: delayProfile.hierarchy
               messageFontSize: 16
               width: 40
               visible: false
               //visible: (delayProfile.band == "地上\uff83\uff9e\uff7c\uff9e\uff80\uff99")
           }

           // 衛星放送の場合のみ表示する
           ChannelInformation {
               id: polarization
               labelMessage: "偏波"
               message: delayProfile.polarization
               messageFontSize: 16
               width: 40
               visible: delayProfile.isSatelliteBroadCasting
           }

           // 階層, 偏波が非表示の場合のみ表示する
           Item {
               id: padding
               height: 75
               width: 40
               visible: (polarization.visible == false && hierarchy.visible == false)
           }

           ChannelInformation {
               id:broadcastingSystem
               labelMessage: "放送方式"
               message: delayProfile.broadcastingSystem
               messageFontSize: 16
               width: 80
               visible: false
           }
       }
       Row {
           height:75
           spacing: parent.rowspacing

           ChannelInformation {
               id:frequency
               labelMessage:"周波数"
               message: String(delayProfile.frequency)
               messageFontSize: 28
               unitMessage: String(delayProfile.displayFrequencyUnit)
               width: 160
           }

       }
       Row {
           height:75
           spacing: parent.rowspacing
           ChannelInformation {
               id:level
               labelMessage: "LEVEL"
               message:delayProfile.level
               messageFontSize: 20
               unitMessage:"dBμV"
               width: 160
               visible: false
           }
           ChannelInformation {
               id:delay
               labelMessage: "遅延時間"
               message:delayProfile.delayTime
               unitMessage: "μS"
               width: 160
               messageFontSize: 28

           }

       }
       Row {
           height:75
           spacing: parent.rowspacing
           ChannelInformation {
               id:mer
               labelMessage: (delayProfile.selectCnMer ===  1) ? "MER" : "CN"
               message:delayProfile.mer
               unitMessage:"dB"
               width: 130
               blinkInterval: delayProfile.blinkInterval
               visible: false
           }
           ChannelInformation {
               id:ber
               labelMessage: "BER"
               message: delayProfile.ber
               width: 130
               blinkInterval: delayProfile.blinkInterval
               visible: false
           }
       }
       ChannelInformation {
           id:leveldifference
           labelMessage: "レベル差"
           message:delayProfile.levelDifference
           unitMessage:"dB"
           width: 160
           messageFontSize: 28
       }
       Row {
           height:75
           spacing: parent.rowspacing
           ChannelInformation {
               id: localFrequency
               labelMessage: "局部発振周波数"
               message: delayProfile.localFrequency
               unitMessage: "GHz"
               width: 130
               visible: delayProfile.isLocalOscillatorVisible
           }
       }
    }

    // グラフの枠
    Rectangle {
        id: chartBｃorder
        width: graph.width - 14
        height: graph.height - 14
        anchors.centerIn: graph
        //color: (cursoredGraph) ? "#7FBFBB" : "transparent"
        color:"transparent"

    }

    // グラフ
    ChartView {
        id: graph
        x: 196
        y: 35
        width:569
        height: 294
        antialiasing: true
        animationOptions: ChartView.NoAnimation
        //theme: ChartView.ChartThemeDark
        legend.visible: false
        margins.bottom: 50
        focus: true
        backgroundColor: "transparent"


        property int minimumTime: -84                   //!< 最小時間
        property int maximumTime: 252                   //!< 最大時間
        property int minimumLevel: -50                  //!< 最小レベル
        property int maximumLevel: 0                    //!< 最大レベル
        property int currentTimeIndex: 0                //!< 選択した時間のインデックス
        property double interval: delayProfile.interval //!< ガードインターバル長(μs) MODE1 有効シンボル長 252μs 1/4 で 63μs
        property int totalTime: 336

        QtObject {
            id: constant
            readonly property int beginningX: 30    //!< 最小値の X 座標
            readonly property int endingX: 52      //!< 最大値の X 座標
            readonly property int totalValues: 2048 //!< 取得するデータ数
            readonly property int xAxisLength: constant.endingX - constant.beginningX   //!< X 軸の表示上の長さ(pixel)
//            readonly property double step: constant.xAxisLength / constant.totalValues  //!< 1 μs 毎の幅
            readonly property double step: constant.xAxisLength / constant.totalValues  //!< 1 μs 毎の幅


        }




        // X 軸は時間
        ValueAxis {
            id: valueAxisX
            min: graph.minimumTime
            max: graph.maximumTime
            labelFormat: "%0d"
            labelsFont.family: defaultFontName
            labelsFont.pixelSize: 12
            gridVisible: false
            visible: false
        }

        // Y 軸は測定レベルの確度
        ValueAxis {
            id: valueAxisY
            min: graph.minimumLevel
            max: graph.maximumLevel
            tickCount: (graph.maximumLevel - graph.minimumLevel) / 10 + 1 // 最小レベルから最大レベルまでを 10 区切りで分割した数
            labelFormat: "%0d "
            labelsFont.family: defaultFontName
            labelsFont.pixelSize: 12
            visible:false
        }

        // Y 軸の単位
        Label {
            width: 100
            height: 16
            anchors.top: parent.top
            anchors.left: parent.left
            anchors.topMargin: 15
            anchors.leftMargin: 15
            color: "#E6E6E6"
            text: "(dB)"
            font.family: defaultFontName
            font.pixelSize: 12
            visible: false
        }

         // X 軸の単位
         Label {
             id : axisXUnit
             width: 30
             height: 16
             anchors {
                 bottom: parent.bottom
                 bottomMargin: 50
                 right: parent.right
                 rightMargin: 26
             }
             color: "#E6E6E6"
             text: "(μs)"
             font.family: defaultFontName
             font.pixelSize: 12
             visible: false
         }




        // ガードインターバル
        Rectangle {
            id: guardInterval
            color: "#E6E6E6"
            opacity: 0.1
            x: constant.beginningX
            y: 6
            //width: (graph.interval - graph.minimumTime) * (constant.xAxisLength / graph.totalTime)+12  // ガードインターバル長に最小時間(-84)を加えた値に 1μs 分の幅を掛ける
            width: (singleMeasurement.guardInterval === 126) ? 318
                                                            : (singleMeasurement.guardInterval === 63)
                                                              ?223
                                                              :(singleMeasurement.guardInterval === 31.3)
                                                                ?174
                                                                :(singleMeasurement.guardInterval === 252)
                                                                  ?510

                                                            : 318

            height: 230
           // visible: false

        }

        // 破線
        Canvas {
            id: dashedLine
            anchors.top: guardInterval.top
            anchors.left: guardInterval.right
            width: 3
            height: guardInterval.height
            onPaint: {
                var ctx = getContext('2d')
                ctx.save();
                ctx.strokeStyle = "#606068";
                ctx.lineWidth = 3;
                ctx.moveTo(0, 0);
                ctx.setLineDash([2, 1]);
                ctx.lineTo(0, dashedLine.height);
                ctx.stroke();
                ctx.restore();
            }


        }




        // 現在選択している時間
        Item {
            id: marker
            width: 1
            height: 20
            x: constant.beginningX + delayProfile.markerX
            y: -24

            Text {
                text: "●"
                color: "#00DA24"
                anchors.bottom: parent.bottom
                anchors.horizontalCenter: parent.horizontalCenter
                font.family: defaultFontName
            }

            Rectangle {
                width: 1
                height: 240
                color: "#00DA24"
                anchors.top: parent.bottom
            }
        }

        Image {
            id: during_measure
            source: "qrc:/resource/png/during_measurment_single.png"
            visible: !delayProfile.locked
            x: (parent.width - caution.width) / 2 + 60
            y: (parent.height - caution.height) / 2 -28
        }
        // ロック
        Rectangle {
            id : caution
            width: 270
            height: 32
            x: (parent.width - caution.width) / 2
            y: (parent.height - caution.height) / 2 -24
            color: "transparent"
            border.color: "#E6E6E6"
            visible: false
            Label {
                anchors.centerIn: parent
                color: "#E6E6E6"
                text: "測定中"
                font.family: defaultFontName
                font.pixelSize: 24
            }

        }
    }



    //画面操作説明画像
    Image {
        id: screenOperationImage
        anchors {
            bottom: graph.bottom
            bottomMargin: 0
            horizontalCenter: graph.horizontalCenter
        }
        source: delayProfile.cursoredGraph ? "qrc:/resource/png/delayProfile_Operation_2.png" : "qrc:/resource/png/delayProfile_Operation_1.png"
        width: sourceSize.width
        height: sourceSize.height
        visible: false
    }

    Image {
        id: cursol_lr
        source: "qrc:/resource/png/icon_cur_lr.png"
        x:406
        y:320
        visible: delayProfile.cursoredGraph ? true:false
    }
    Image {
        id: cursol_enter
        source: "qrc:/resource/png/icon_enter.png"
        x:222
        y:320
        visible:true
    }

    function createSeries()
    {
        lineSeries  = graph.createSeries(ChartView.SeriesTypeLine, "delay", valueAxisX, valueAxisY);
        lineSeries.color = "#55D9DB"
        delayProfileLineSeries.update(graph.series(0));
        graph.update()
    }
    Text{
        id: cur_txt
        text: qsTr("左右ボタン: カーソル移動")
        x:435
        y:323
        color: "#80BFFF"
        visible:  delayProfile.cursoredGraph ? true : false
        font.pixelSize: 20

    }
    Text{
        id: enter_txt
        text: delayProfile.cursoredGraph ? qsTr("決定ボタン: 戻る"):qsTr("決定ボタン: グラフへ移動")
        x:250
        y:322

        color: "#80BFFF"
        font.pixelSize: 20

    }



    /*Text {
        id:
        text: qsTr("グラフ操作中")
        visible: delayProfile.cursoredGraph ? true : false
        color: "white"
        x:570
        y:350
        font.pixelSize: 26
    }*/
}
