/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
import "../../parts"

// シングル測定メーター
Item {
    id: meter

    property var level: ""                                                  //!< 測定入力レベル値
    property var levelRedZoneRatio: 0.00                                    //!< ゲージに表示する赤の割合(最大値 1.0 とする)
    property var mer: "5.0"                                                 //!< 変調誤差比の値
    property var merRedZoneRatio: 0.00                                      //!< ゲージに表示する赤の割合(最大値 1.0 とする)
    property var merYellowZoneRatio: 0.00                                   //!< ゲージに表示する黃の割合(最大値 1.0 とする)
    property var ber: "0.0E"                                                //!< ビット誤り率の値
    property var exponential: "-0"                                          //!< ビット誤り率の値の累乗
    property var berRedZoneRatio: 0.00                                      //!< ゲージに表示する赤の割合(最大値 1.0 とする)
    property var berYellowZoneRatio: 0.00                                   //!< ゲージに表示する黃の割合(最大値 1.0 とする)
    property var userMode: ""                                               //!< ユーザーモードの値
    property int selectCnMer: 1                                             //!< CN/MERの選択状態
    property string band: ""                                                //!< バンド
    property string channel: ""                                             //!< チャンネル
    property string frequency: ""                                           //!< 中心周波数
    property string displayFrequencyUnit: ""                                //!< 中心周波数単位
    property string modulation: ""                                          //!< 変調方式
    property string modulationPrefix: ""                                    //!< 変調方式の接頭句
    property string hierarchy: ""                                           //!< 階層せ
    property bool isSatelliteBroadCasting: false                            //!< 衛星放送かどうか
    property bool isDisplaylevelHierarchyPolarization: true                 //!< 階層/ 偏波を表示するかどうか
    property string localFrequency: ""                                      //!< 局部発信周波数
    property string polarization: ""                                        //!< 偏波
    property bool isModulationVisible: true                                 //!< 変調方式 表示可否値 (True: 表示, False 非表示)
    property var merCnrGaugeStepValue: []                                   //!< MER/CNRゲージの目盛りに表示する文字列リスト

    property int displayModulationPrefixMode: 0                             //!< 変調方式 表示モード 接頭句と変調方式をどのように表示するかを決める
    property bool frequencyComboboxVisible: false                           //!< 周波数コンボボックスを表示するかどうか
    property bool editFrequencyCombobox: false                              //!< 周波数コンボボックスを操作中かどうか
    property int blinkInterval: 0                                           //!< 点滅間隔

    // Level
    LevelGauge {
        id: level
        objectName: "level"
        x: (mainFrame.width - level.width) / 2
        y: 0
        redZoneRatio: meter.levelRedZoneRatio
        band: meter.band
        channel: meter.channel
        frequency: meter.frequency
        displayfrequencyUnit: meter.displayFrequencyUnit
        modulation: meter.modulation
        modulationPrefix: meter.modulationPrefix
        hierarchy: meter.hierarchy
        isSatelliteBroadCasting: meter.isSatelliteBroadCasting
        isDisplaylevelHierarchyPolarization: meter.isDisplaylevelHierarchyPolarization
        localFrequency: meter.localFrequency
        polarization: meter.polarization
        isModulationVisible: meter.isModulationVisible
        displayModulationPrefixMode: meter.displayModulationPrefixMode
        frequencyComboboxVisible: meter.frequencyComboboxVisible
        editFrequencyCombobox: meter.editFrequencyCombobox
        blinkInterval: meter.blinkInterval
    }

    // MER/CN
    MerGauge {
        id: mer
        x: 15
        y: 0
        selectCnMer: meter.selectCnMer
        redZoneRatio: meter.merRedZoneRatio
        yellowZoneRatio: meter.merYellowZoneRatio
        band: meter.band
        scales: meter.merCnrGaugeStepValue
        visible: (meter.band != "PILOT" && meter.band != "LTE" && meter.band != "FM" && meter.band != "CATV上り")
        blinkInterval: meter.blinkInterval
    }

    // BER
    BerGauge {
        id: ber
        x: 640
        y: 0
        redZoneRatio: meter.berRedZoneRatio
        yellowZoneRatio: meter.berYellowZoneRatio
        exponential: meter.exponential
        visible: (meter.band != "PILOT" && meter.band != "LTE" && meter.band != "FM" && meter.band != "CATV上り")
        blinkInterval: meter.blinkInterval
    }

    function updateLevelMeterValue(levelValue, levelNeedlePosition) {
        level.updateLevel(levelValue, levelNeedlePosition)
    }

    function updateMerMeterValue(merValue, merNeedlePosition) {
        mer.updateMer(merValue, merNeedlePosition)
    }

    function updateBerMeterValue(berValue, berNeedlePosition) {
        ber.updateBer(berValue, berNeedlePosition)
    }

    function updateLevelThreshold(red, yellow)
    {
        level.updateThreshold(red, yellow)
    }

    function updateMerThreshold(red, yellow)
    {
        mer.updateThreshold(red, yellow)
    }

    function updateBerThreshold(red, yellow)
    {
        ber.updateThreshold(red, yellow)
    }
}
