/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
import QtQuick.Controls 2.12

import "../../parts"
import jp.co.dxantenna.levelchecker.delayProfileLineSeriesModel 1.0

/**
 * @brief シングルチャンネル測定 View
 */
Item {
    id: singleMeasurement
    anchors.fill: parent

    property var level: "---"                       //!< 測定入力レベル値
    property var levelRedZoneRatio: 0.00            //!< ゲージに表示する赤の割合(最大値 1.0 とする)
    property var mer: "---"                         //!< 変調誤差比の値
    property var merRedZoneRatio: 0.00              //!< ゲージに表示する赤の割合(最大値 1.0 とする)
    property var merYellowZoneRatio: 0.00           //!< ゲージに表示する黃の割合(最大値 1.0 とする)
    property var ber: "---"                         //!< ビット誤り率の値
    property var exponential: ""                    //!< ビット誤り率の値の累乗
    property var berRedZoneRatio: 0.00              //!< ゲージに表示する赤の割合(最大値 1.0 とする)
    property var berYellowZoneRatio: 0.00           //!< ゲージに表示する黃の割合(最大値 1.0 とする)
    property var userMode: ""                       //!< ユーザーモードの値

    property var constellationData: []              //!< 一回で読み出したコンスタレーションデータ
    property bool isConstellationDataClear: false   //!< グラフ表示のクリアー有無
    property string band: ""                        //!< バンド名
    property bool isSatelliteBroadCasting: false    //!< 衛星放送かどうか
    property string channel: ""                     //!< チャンネル
    property string frequency: ""                   //!< 中心周波数
    property string displayFrequencyUnit: "MHz"     //!< 中心周波数表示単位
    property string modulation: ""                  //!< 変調方式
    property string modulationPrefix: ""            //!< 変調方式の接頭句
    property string selectedModulation: ""          //!< 選択変調方式 CATVで使用
    property string broadcastingSystem: ""          //!< 放送方式
    property string hierarchy: ""                   //!< 階層
    property string localFrequency: ""              //!< 局発周波数
    property int buttonPattern: 0                   //!< 選択ボタンのパターン(0: 測定、コンスタレーション、遅延プロファイル 1:測定、コンスタレーション 2:測定)
    property bool isLocalOscillatorVisible: false   //!< 局発周波数 表示可否フラグ
    property int selectCnMer: 1                     //!< CNR/MER切替状態
    property bool isDisplaylevelHierarchyPolarization: true    //!< 階層/偏波を表示するかどうか
    property string polarization: ""                           //!< 偏波
    property double guardInterval: -84                  //!< ガードインターバル
    property var delayTime: ""                          //!< 遅延時間
    property int levelDifference: 0                     //!< レベル差
    property bool isModulationVisible: true             //!< 変調方式 表示、非表示設定 (True: 表示, False: 非表示)
    property bool isGoodIconVisible: false              //!< goodアイコン(受信良好状態を示すアイコン) 表示、非表示設定 (True: 表示, False: 非表示)
    property var merCnrGaugeStepValue: []               //!< MER/・CNRゲージの目盛りに表示する文字列のリスト
    property int displayModulationPrefixMode: 0         //!< 変調方式 表示モード 接頭句と変調方式をどのように表示するかを決める
    property bool locked: true                          //!< ロック有無
    property bool frequencyComboboxVisible: false       //!< 周波数コンボボックスを表示するかどうか
    property bool editFrequencyCombobox: false          //!< 周波数コンボボックスを操作中かどうか
    property int blinkInterval: 0                       //!< 点滅間隔

    property bool confirmedValue:false                  //!< ロック判定で値が確定したかどうか

    signal request(int condition)

    function backup(key, value) {
        var temporary = attributes.takeOver
        temporary[key] = value
        attributes.takeOver = temporary
    }

    // GoodIcon
    Image {
        id: goodIcon
        source: "qrc:/resource/png/icon_good.png"
        anchors {
            top: parent.top
            right: parent.right
            rightMargin: 40
        }
        width:   75
        height:  30
        visible: singleMeasurement.isGoodIconVisible
    }

    // メーター
    Meter {
        id: singleMeter
        objectName: "meter"
        visible: true

        // メーターを表示中のみ表示に反映させる
        Binding on levelRedZoneRatio {
            value: singleMeasurement.levelRedZoneRatio
            when: singleMeter.visible
        }

        Binding on merRedZoneRatio {
            value: singleMeasurement.merRedZoneRatio
            when: singleMeter.visible
        }

        Binding on merYellowZoneRatio {
            value: singleMeasurement.merYellowZoneRatio
            when: singleMeter.visible
        }

        Binding on exponential {
            value: singleMeasurement.exponential
            when: singleMeter.visible
        }

        Binding on berRedZoneRatio {
            value: singleMeasurement.berRedZoneRatio
            when: singleMeter.visible
        }

        Binding on berYellowZoneRatio {
            value: singleMeasurement.berYellowZoneRatio
            when: singleMeter.visible
        }

        Binding on userMode {
            value: singleMeasurement.userMode
            when: singleMeter.visible
        }

        Binding on channel {
            value: singleMeasurement.channel
            when: singleMeter.visible
        }

        Binding on frequency {
            value: singleMeasurement.frequency
            when: singleMeter.visible
        }

        Binding on displayFrequencyUnit {
            value: singleMeasurement.displayFrequencyUnit
            when: singleMeter.visible
        }

        Binding on modulation {
            value: singleMeasurement.modulation
            when: singleMeter.visible
        }

        Binding on modulationPrefix {
            value: singleMeasurement.modulationPrefix
            when: singleMeter.visible
        }

        Binding on hierarchy {
            value: singleMeasurement.hierarchy
            when: singleMeter.visible
        }

        Binding on isDisplaylevelHierarchyPolarization {
            value: singleMeasurement.isDisplaylevelHierarchyPolarization
            when: singleMeter.visible
        }

        Binding on localFrequency {
            value: singleMeasurement.localFrequency
            when: singleMeter.visible
        }

        Binding on isModulationVisible {
            value: singleMeasurement.isModulationVisible
            when: singleMeter.visible
        }

        Binding on merCnrGaugeStepValue {
            value: singleMeasurement.merCnrGaugeStepValue
            when: singleMeter.visible
        }

        Binding on displayModulationPrefixMode {
            value: singleMeasurement.displayModulationPrefixMode
            when: singleMeter.visible
        }

        Binding on frequencyComboboxVisible {
            value: singleMeasurement.frequencyComboboxVisible
            when: singleMeter.visible
        }

        Binding on editFrequencyCombobox {
            value: singleMeasurement.editFrequencyCombobox
            when: singleMeter.visible
        }

        Binding on selectCnMer {
            value: singleMeasurement.selectCnMer
            when: singleMeter.visible
        }

        Binding on isSatelliteBroadCasting {
            value: singleMeasurement.isSatelliteBroadCasting
            when: singleMeter.visible
        }

        Binding on polarization {
            value: singleMeasurement.polarization
            when: singleMeter.visible
        }

        Binding on band {
            value: singleMeasurement.band
            when: singleMeter.visible
        }

        Binding on blinkInterval {
            value: singleMeasurement.blinkInterval
            when: singleMeter.visible
        }
    }

    // コンスタレーション
    Constellation {
        id: singleConstellation
        objectName: "constellation"
        visible: false

        // コンスタレーションを表示中のみ表示に反映させる
        Binding on level {
            value: singleMeasurement.level
            when: singleConstellation.visible
        }

        Binding on mer {
            value: singleMeasurement.mer
            when: singleConstellation.visible
        }

        Binding on ber {
            value: singleMeasurement.ber
            when: singleConstellation.visible
        }

        Binding on channel {
            value: singleMeasurement.channel
            when: singleConstellation.visible
        }

        Binding on frequency {
            value: singleMeasurement.frequency
            when: singleConstellation.visible
        }

        Binding on displayFrequencyUnit {
            value: singleMeasurement.displayFrequencyUnit
            when: singleConstellation.visible
        }

        Binding on modulation {
            value: singleMeasurement.modulation
            when: singleConstellation.visible
        }

        Binding on modulationPrefix {
            value: singleMeasurement.modulationPrefix
            when: singleConstellation.visible
        }

        Binding on selectedModulation {
            value: singleMeasurement.selectedModulation
            when: singleConstellation.visible
        }

        Binding on broadcastingSystem {
            value: singleMeasurement.broadcastingSystem
            when: singleConstellation.visible
        }

        Binding on hierarchy {
            value: singleMeasurement.hierarchy
            when: singleConstellation.visible
        }

        Binding on localFrequency {
            value: singleMeasurement.localFrequency
            when: singleConstellation.visible
        }

        Binding on isLocalOscillatorVisible {
            value: singleMeasurement.isLocalOscillatorVisible
            when: singleConstellation.visible
        }

        Binding on selectCnMer {
            value: singleMeasurement.selectCnMer
            when: singleConstellation.visible
        }

        Binding on isSatelliteBroadCasting {
            value: singleMeasurement.isSatelliteBroadCasting
            when: singleConstellation.visible
        }

        Binding on polarization {
            value: singleMeasurement.polarization
            when: singleConstellation.visible
        }

        Binding on band {
            value: singleMeasurement.band
            when: singleConstellation.visible
        }

        Binding on locked {
            value: singleMeasurement.locked
            when: singleConstellation.visible
        }

        Binding on blinkInterval {
            value: singleMeasurement.blinkInterval
            when: singleConstellation.visible
        }

        Binding on confirmedValue {
            value: singleMeasurement.confirmedValue
            when: singleMeter.visible
        }
    }

    // 遅延プロファイルのグラフに表示するデータ
    DelayProfileLineSeriesModel {
        id: delayProfileLineSeries
        objectName: "delayProfileLineSeries"
    }

    // 遅延プロファイル
    DelayProfile {
        id: singleDelayProfile
        objectName: "delayProfile"
        visible: false

        Component.onCompleted: {
            singleDelayProfile.createSeries();
        }

        // 遅延プロファイルを表示中のみ表示に反映させる
        Binding on level {
            value: singleMeasurement.level
            when: singleDelayProfile.visible
        }

        Binding on mer {
            value: singleMeasurement.mer
            when: singleDelayProfile.visible
        }

        Binding on ber {
            value: singleMeasurement.ber
            when: singleDelayProfile.visible
        }

        Binding on channel {
            value: singleMeasurement.channel
            when: singleDelayProfile.visible
        }

        Binding on frequency {
            value: singleMeasurement.frequency
            when: singleDelayProfile.visible
        }

        Binding on delayTime {
            value: singleMeasurement.delayTime
            when: singleDelayProfile.visible
        }

        Binding on displayFrequencyUnit {
            value: singleMeasurement.displayFrequencyUnit
            when: singleDelayProfile.visible
        }

        Binding on broadcastingSystem {
            value: singleMeasurement.broadcastingSystem
            when: singleDelayProfile.visible
        }

        Binding on hierarchy {
            value: singleMeasurement.hierarchy
            when: singleDelayProfile.visible
        }

        Binding on localFrequency {
            value: singleMeasurement.localFrequency
            when: singleDelayProfile.visible
        }

        Binding on levelDifference {
            value: singleMeasurement.levelDifference
            when: singleDelayProfile.visible
        }

        Binding on isLocalOscillatorVisible {
            value: singleMeasurement.isLocalOscillatorVisible
            when: singleDelayProfile.visible
        }

        Binding on selectCnMer {
            value: singleMeasurement.selectCnMer
            when: singleDelayProfile.visible
        }

        Binding on interval {
            value: singleMeasurement.guardInterval
            when: singleDelayProfile.visible
        }

        Binding on isSatelliteBroadCasting {
            value: singleMeasurement.isSatelliteBroadCasting
            when: singleDelayProfile.visible
        }

        Binding on polarization {
            value: singleMeasurement.polarization
            when: singleDelayProfile.visible
        }

        Binding on band {
            value: singleMeasurement.band
            when: singleDelayProfile.visible
        }

        Binding on locked {
            value: singleMeasurement.locked
            when: singleDelayProfile.visible
        }

        Binding on blinkInterval {
            value: singleMeasurement.blinkInterval
            when: singleDelayProfile.visible
        }
    }

    // シングル測定
    MeasurementButton {
        id: singleButton
        objectName: "singleButton"
        // 遅延プロファイルを表示しないときは中央に寄せる
        x: (constellationButton.visible === true) ? (delayProfileButton.visible === true) ? 285 : 327 : 366
        y: 361
        contentsFileName: "qrc:/resource/png/single_icon_meter.png"
        activeStatusFileName: (buttonPattern == 0 || buttonPattern == 1) ? "qrc:/resource/png/single_btn_meter_c.png" : "qrc:/resource/png/single_btn_single_mode_p.png"
        active: false
        index: 0
    }

    // コンスタレーション
    MeasurementButton {
        id: constellationButton
        objectName: "constellationButton"
        // 遅延プロファイルを表示しないときは中央に寄せる
        x: (delayProfileButton.visible === true) ? 368 : 419
        y: 361
        contentsFileName: "qrc:/resource/png/single_icon_consta.png"
        activeStatusFileName: (delayProfileButton.visible === true) ? "qrc:/resource/png/single_btn_consta_c.png" : "qrc:/resource/png/single_btn_delay_c.png"
        active: false
        adjustX: 4
        index: 1
        visible: (singleMeasurement.band != "PILOT" && singleMeasurement.band != "LTE" && singleMeasurement.band != "FM" && singleMeasurement.band != "CATV上り" && singleMeasurement.band != "")
    }

    // 遅延プロファイル
    MeasurementButton {
        id: delayProfileButton
        objectName: "delayProfileButton"
        x: 448
        y: 361
        contentsFileName: "qrc:/resource/png/single_icon_delay.png"
        activeStatusFileName: "qrc:/resource/png/single_btn_delay_c.png"
        active: false
        adjustX: 4
        index: 2
        visible: (buttonPattern == 0) ? true : false
    }

    // 区切り線
    Image {
        id: line
        width: 800
        height: 62
        x: 0
        y: 350
        source: "qrc:/resource/png/line_footer.png"
    }

    // ユーザーモードのラベル
    Label {
        id: userModeLabel
        width: 100
        height: 20
        x: 633
        y: 361
        horizontalAlignment: Qt.AlignLeft
        text: (singleMeasurement.userMode != "") ? "USER MODE : " : ""
        font.pixelSize: 14
        color: "#E4E6E5"
        font.family: defaultFontName
    }

    // ユーザーモードの値
    Text {
        id: userMode
        width: 80
        height: 20
        x: 633
        y: 383
        text: singleMeasurement.userMode
        horizontalAlignment: Qt.AlignLeft
        font.pixelSize: 14
        font.bold: true
        color: "#E4E6E5"
        font.family: defaultFontName
    }

    // イメージ
    MeasurementFunctionButton {
        id: imageButton
        objectName: "imageButton"
        x: 10
        y: 344
        idleImage: "qrc:/resource/png/icon_save1_n.png"
        pressedImage: "qrc:/resource/png/icon_save1_on.png"
    }

    // DATA
    MeasurementFunctionButton {
        id: dataButton
        objectName: "dataButton"
        x: 70
        y: 344
        idleImage: "qrc:/resource/png/icon_save2_single_n.png"
        pressedImage: "qrc:/resource/png/icon_save2_single_on.png"
    }

    function updateLevelMeterValue(levelValue, levelNeedlePosition) {
        singleMeasurement.level = levelValue
        singleMeter.updateLevelMeterValue(levelValue, levelNeedlePosition)
    }

    function updateMerMeterValue(merValue, merNeedlePosition) {
        singleMeasurement.mer = merValue
        singleMeter.updateMerMeterValue(merValue, merNeedlePosition)
    }

    function updateBerMeterValue(berValue, berNeedlePosition) {
        singleMeasurement.ber = berValue
        singleMeter.updateBerMeterValue(berValue, berNeedlePosition)
    }

    function updateLevelThreshold(red, yellow)
    {
        singleMeter.updateLevelThreshold(red, yellow)
    }

    function updateMerThreshold(red, yellow)
    {
        singleMeter.updateMerThreshold(red, yellow)
    }

    function updateBerThreshold(red, yellow)
    {
        singleMeter.updateBerThreshold(red, yellow)
    }
}
