/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import QtQuick.Controls 2.12
import "../parts"

/**
 * @brief 局部発振周波数 View
 */
Item {
    id: root
    objectName: "LocalOscillator"
    anchors.fill: parent
    width:800

    // リスト項目の高さ
    property int itemHeight: 50
    signal request(int condition)

    Item {
        id: takeOverData
        objectName: "takeOverData"
        property string selectedBand : ""
    }

    function getTakeOver() {
        takeOverData.selectedBand = attributes.takeOver["selectedBand"]
    }

    function backup(key, value) {
        var temporary = attributes.takeOver
        temporary[key] = value
        attributes.takeOver = temporary
    }

    // リストヘッダー背景
    Rectangle {
        id: headerAreaBackground
        anchors.fill: headerArea
        color: "#30333A"
    }

    // リストヘッダー
    Row {
        id: headerArea
        width :600
        height: 49
        anchors.top: root.top
        anchors.topMargin: 50
        anchors.left: root.left
        anchors.leftMargin: 50
        // 番号ヘッダー
        Text {
            id: numberHeader
            text: "番号"
            width: 50
            anchors.top: headerArea.top
            anchors.bottom: headerArea.bottom
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            font.pixelSize: 16
            font.family: defaultFontName
            color: "skyblue"
        }
        // BANDヘッダー
        Text {
            id: broadcastingHeader
            text: "BAND"
            width: 250
            anchors.top: headerArea.top
            anchors.bottom: headerArea.bottom
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            font.pixelSize: 16
            font.family: defaultFontName
            color: "skyblue"
        }
        // 局部発振周波数
        Text {
            id: localOscillatorHzHeader
            text: "局部発振周波数"
            width: 250
            anchors.top: headerArea.top
            anchors.bottom: headerArea.bottom
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            font.pixelSize: 16
            font.family: defaultFontName
            color: "skyblue"
        }
    }

    // リスト部背景画像
    Image {
        id: oscillatorItemBackground1
        source: "qrc:/resource/png/local_oscillator_listEdit_n.png"
        height: 49
        anchors {
            top: headerArea.bottom
            left: headerArea.left
            right: headerArea.right
            topMargin: 1
        }
    }
    Image {
        id: oscillatorItemBackground2
        source: "qrc:/resource/png/local_oscillator_listEdit_n.png"
        height: 49
        anchors {
            top: oscillatorItemBackground1.bottom
            left: headerArea.left
            right: headerArea.right
            topMargin: 1
        }
    }
    Image {
        id: oscillatorItemBackground3
        source: "qrc:/resource/png/local_oscillator_listEdit_n.png"
        height: 49
        anchors {
            top: oscillatorItemBackground2.bottom
            left: headerArea.left
            right: headerArea.right
            topMargin: 1
        }
    }
    Image {
        id: oscillatorItemBackground4
        source: "qrc:/resource/png/local_oscillator_listEdit_n.png"
        height: 49
        anchors {
            top: oscillatorItemBackground3.bottom
            left: headerArea.left
            right: headerArea.right
            topMargin: 1
        }
    }

    // JCSAT-4B 項目
    LocalOscillatorItem {
        id : oscillatorItem1
        objectName : "oscillatorItem1"
        number:   "1"
        broadcasting: "JCSAT-3A"
        anchors {
            top: headerArea.bottom
            left: headerArea.left
            right: headerArea.right
        }
        itemHeight: root.itemHeight
        activebg: "local_oscillator_select_d.png"
        editbg:   "local_oscillator_listEdit.png"
        isTop: true
    }

    // JCSAT-3A 項目
    LocalOscillatorItem {
        id : oscillatorItem2
        objectName : "oscillatorItem2"
        number:   "2"
        broadcasting: "JCSAT-4B"
        anchors {
            top: oscillatorItem1.bottom
            left: headerArea.left
            right: headerArea.right
        }
        itemHeight: root.itemHeight
        activebg: "local_oscillator_select_ud.png"
        editbg:   "local_oscillator_listEdit.png"
        isTop: false
    }

    // SCC-C2 項目
    LocalOscillatorItem {
        id : oscillatorItem3
        objectName : "oscillatorItem3"
        number: "3"
        broadcasting: "SCC-B2"
        anchors {
            top: oscillatorItem2.bottom
            left: headerArea.left
            right: headerArea.right
        }
        itemHeight: root.itemHeight
        activebg: "local_oscillator_select_ud.png"
        editbg:   "local_oscillator_listEdit.png"
        isTop: false
    }

    // SCC-B2 項目
    LocalOscillatorItem {
        id : oscillatorItem4
        objectName : "oscillatorItem4"
        number: "4"
        broadcasting: "SCC-C2"
        anchors {
            top: oscillatorItem3.bottom
            left: headerArea.left
            right: headerArea.right
        }
        itemHeight: root.itemHeight
        activebg: "local_oscillator_select_u.png"
        editbg:   "local_oscillator_listEdit.png"
        isTop: false
    }

    // 空行を表示する
    Rectangle{
        id: explanationLabelArea
        anchors {
            top: oscillatorItem4.bottom
            left:  headerArea.left
            right: headerArea.right
            topMargin: 1
        }
        height: root.itemHeight
        color: "#363840"
        Label {
            id: explanationLabel
            text: "入力範囲：10〜12GHz, 0GHz(未使用設定)"
            color: "#E4E4E4"
            font.family: defaultFontName
            anchors.centerIn: parent
            font.pixelSize: 21
        }
    }

    // 保存ボタン
    SelectButton {
        id : register
        objectName: "register"
        anchors{
            top: oscillatorItem1.top
            bottom: oscillatorItem4.bottom
            left: headerArea.right
            leftMargin: 10
        }
        width : 90
        activebg: "localoscillator_savebtn.png"
        idlebg: "localoscillator_savebtn_n.png"
        message: "保存"
    }
    // 画面名
    ScreenName {
        name : "局部発振周波数"
    }
}
