/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import "../parts"

/**
 * @brief 閾値設定 View
 */
Item {
    id:root
    width: 640
    objectName: "ThresholdSetting"

    property string bandname: "band"
    property string merMinimum: "5"
    property string merMaximum: "35"
    property int columnspacing: 30
    default property int fontsize: 16
    property bool merbervis:true
    property int levelpos: 0

    signal request(int condition)

    // 前画面の設定値を受け取るための仕組み
    // ここから
    function backup(key, value) {
        var temporary = attributes.takeOver
        temporary[key] = value
        attributes.takeOver = temporary
    }

    Image {
        id: levelframe
        x: 79
        y: 16+levelpos
        source: "qrc:/resource/png/thresh_frame.png"

    }

    Image {
        id: merframe
        x: 79
        y: 114
        source: "qrc:/resource/png/thresh_frame.png"
        visible: merbervis
    }

    Image {
        id: berframe
        x: 81
        y: 215
        source: "qrc:/resource/png/thresh_frame.png"
        visible: merbervis
    }

    Item {
        id: takeOverData
        objectName: "takeOverData"
        property string selectedBand: ""
        property string selectedBroadcast: ""
        property string selectedModulation: ""
    }

    function getTakeOver() {
        takeOverData.selectedBand = attributes.takeOver["selectedBand"]
        takeOverData.selectedModulation = attributes.takeOver["selectedModulation"] ? attributes.takeOver["selectedModulation"] : ""
        takeOverData.selectedBroadcast = attributes.takeOver["selectedBroadcast"] ? attributes.takeOver["selectedBroadcast"] : ""
    }

    // ここまで

   /* Text {
        id: band
        objectName:"bandName"
        anchors.horizontalCenter:root.horizontalCenter
        text: parent.bandname
        font.pixelSize: 24
        font.family: defaultFontName
        color: "white"
    }*/

    Text {
        id: name
        x: 55
        y: 46+levelpos
        text: qsTr("LEVEL")
        color: "skyblue"
        font.pixelSize: 18
    }

    Text {
        id: mercntxt
        x: 42
        y: 144
        text: qsTr("MER/CN")
        color: "skyblue"
        font.pixelSize: 18
        visible: merbervis
    }

    Text {
        id: bertxt
        x: 65
        y: 246
        text: qsTr("BER")
        color: "skyblue"
        font.pixelSize: 18
        visible: merbervis
    }

    //---------------------------------LEVEEL------------------------------


    Row{
        id: levelthresh
        x: 125
        y: 22+levelpos



        ThresholdLabel {
            id: label3
            labelColor: "#99000F"
            labelTextColor: "white"
            labelText: "低入力"
        }

        ThresholdEdit {
            id: select1
            objectName: "select1"
            exp: false
            z: 2
            idlebg:"threshold_number_base.png"
            activebg: "threshold_number_cur.png"
            editbg:"threshold_number_base_edit.png"
            edit1idlebg:""            // 編集未選択の背景
            edit1activebg: "threshold_number_cur_r.png"    // 編集対象の背景
            edit2idlebg:""            // 編集未選択の背景
            edit2activebg: "threshold_number_cur_lr.png"    // 編集対象の背景
            edit3idlebg:""            // 編集未選択の背景
            edit3activebg: "threshold_number_cur_lr.png"    // 編集対象の背景
            edit4idlebg:""            // 編集未選択の背景
            edit4activebg: "threshold_number_cur_lr.png"    // 編集対象の背景
            edit5idlebg:""            // 編集未選択の背景
            edit5activebg: "threshold_number_cur_l.png"    // 編集対象の背景

        }

        ThresholdLabel {
            id:label4
            z: 1
            labelColor: "#3A75B2"
            labelTextColor: "white"
            labelText: "良好"
        }

        ThresholdEdit {
            id: select2
            objectName: "select2"
            exp: false
            z: 2
            idlebg:"threshold_number_base.png"
            activebg: "threshold_number_cur.png"
            editbg:"threshold_number_base_edit.png"
            edit1idlebg:""            // 編集未選択の背景
            edit1activebg: "threshold_number_cur_r.png"    // 編集対象の背景
            edit2idlebg:""            // 編集未選択の背景
            edit2activebg: "threshold_number_cur_lr.png"    // 編集対象の背景
            edit3idlebg:""            // 編集未選択の背景
            edit3activebg: "threshold_number_cur_lr.png"    // 編集対象の背景
            edit4idlebg:""            // 編集未選択の背景
            edit4activebg: "threshold_number_cur_lr.png"    // 編集対象の背景
            edit5idlebg:""            // 編集未選択の背景
            edit5activebg: "threshold_number_cur_l.png"    // 編集対象の背景

        }

        ThresholdLabel {
            id:label5
            labelColor: "#99000F"
            labelTextColor: "white"
            labelText: "過入力"
        }

    }



    //---------------------------------MER/CN----------------------------------

    Row{
        id: mercnthresh
        x: 125
        y: 120

        visible: merbervis
        ThresholdLabel {
            labelColor: "#99000F"
            labelTextColor: "white"
            labelText: "受信不可"
        }
        ThresholdEdit {
            id: select3
            objectName: "select3"
            exp: false
            z: 2
            isFirstFixed: true // 先頭は編集不可
            idlebg:"threshold_number_base.png"
            activebg: "threshold_number_cur.png"
            editbg:"threshold_number_base_edit.png"
            edit1activebg: ""                              // 編集対象の背景
            edit2activebg: "threshold_number_cur_r.png"    // 編集対象の背景
            edit3activebg: "threshold_number_cur_lr.png"   // 編集対象の背景
            edit4activebg: "threshold_number_cur_lr.png"   // 編集対象の背景
            edit5activebg: "threshold_number_cur_l.png"    // 編集対象の背景

        }
        ThresholdLabel {
            z: 1
            labelColor: "#CCCC00"
            labelTextColor: "white"
            labelText: "余裕度低"
        }
        ThresholdEdit {
            id: select4
            objectName: "select4"
            exp: false
            z: 2
            isFirstFixed: true // 先頭は編集不可
            idlebg:"threshold_number_base.png"
            activebg: "threshold_number_cur.png"
            editbg:"threshold_number_base_edit.png"
            edit1idlebg:""            // 編集未選択の背景
            edit1activebg: ""                               // 編集対象の背景
            edit2idlebg:""            // 編集未選択の背景
            edit2activebg: "threshold_number_cur_r.png"     // 編集対象の背景
            edit3idlebg:""            // 編集未選択の背景
            edit3activebg: "threshold_number_cur_lr.png"    // 編集対象の背景
            edit4idlebg:""            // 編集未選択の背景
            edit4activebg: "threshold_number_cur_lr.png"    // 編集対象の背景
            edit5idlebg:""            // 編集未選択の背景
            edit5activebg: "threshold_number_cur_l.png"    // 編集対象の背景

        }

        ThresholdLabel {
            labelColor: "#198006"
            labelTextColor: "white"
            labelText: "良好"
        }



    }


    //----------------------------------BER-------------------------------------
    Row{
        x: 125
        y: 222

        visible: merbervis

        ThresholdLabel {
            labelColor: "#99000F"
            labelTextColor: "white"
            labelText: "測定不可"
        }
        ThresholdEdit {
            id: select5
            objectName: "select5"
            exp: true
            z: 2
            idlebg:"threshold_number_base_exp.png"
            activebg: "threshold_number_cur_exp.png"
            editbg:"threshold_number_base_exp_edit.png"
            edit1idlebg:""            // 編集未選択の背景
            edit1activebg: "threshold_number_cur_r.png"    // 編集対象の背景
            edit2idlebg:""            // 編集未選択の背景
            edit2activebg: "threshold_number_cur_lr.png"    // 編集対象の背景
            edit3idlebg:""            // 編集未選択の背景
            edit3activebg: "threshold_number_cur_lr.png"    // 編集対象の背景
            edit4idlebg:""            // 編集未選択の背景
            edit4activebg: "threshold_number_cur_lr.png"    // 編集対象の背景
            edit5idlebg:""            // 編集未選択の背景
            edit5activebg: "threshold_number_cur_l.png"    // 編集対象の背景

        }

        ThresholdLabel {
            z: 1
            labelColor: "#CCCC00"
            labelTextColor: "white"
            labelText: "余裕度低"
        }
        ThresholdEdit {
            id: select6
            objectName: "select6"
            exp: true
            z: 2
            idlebg:"threshold_number_base_exp.png"
            activebg: "threshold_number_cur_exp.png"
            editbg:"threshold_number_base_exp_edit.png"
            edit1idlebg:""            // 編集未選択の背景
            edit1activebg: "threshold_number_cur_r.png"    // 編集対象の背景
            edit2idlebg:""            // 編集未選択の背景
            edit2activebg: "threshold_number_cur_lr.png"    // 編集対象の背景
            edit3idlebg:""            // 編集未選択の背景
            edit3activebg: "threshold_number_cur_lr.png"    // 編集対象の背景
            edit4idlebg:""            // 編集未選択の背景
            edit4activebg: "threshold_number_cur_lr.png"    // 編集対象の背景
            edit5idlebg:""            // 編集未選択の背景
            edit5activebg: "threshold_number_cur_l.png"    // 編集対象の背景

        }

        ThresholdLabel {
            labelColor: "#198006"
            labelTextColor: "white"
            labelText: "良好"
        }


    }



    /*Grid {
        id:updatearea
        width: 800
        height: 245
        anchors.horizontalCenterOffset: 0
        anchors.top: band.bottom
        anchors.topMargin: 50
        anchors.horizontalCenter: root.horizontalCenter

        columns:5
        rows:3

        //anchors.horizontalCenter: guidance.horizontalCenter

        // 1段目
        Item {
            id:header1
            width: 1
            height: 1
        }

        Text {
            id:header2
            text:"最小値"
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            font.pixelSize: root.fontsize
            font.family: defaultFontName
            color:"gray"
            width:label2.width
        }

        Item {
            id:header3
            width: 1
            height: 1
        }

        Text {
            id:header4
            text:"インジケータ"
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            font.pixelSize: root.fontsize
            font.family: defaultFontName
            color:"gray"
            width:select1.width
        }

        Item {
            id:header5
            width: 1
            height: 1
        }

        Text {
            id:header6
            text:"インジケータ"
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            font.pixelSize: root.fontsize
            font.family: defaultFontName
            color:"gray"
            width:select2.width
        }

        Item{
            id:header7
            width: 1
            height: 1
        }

        Text {
            id:header8
            text:"最大値"
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            font.pixelSize: root.fontsize
            font.family: defaultFontName
            color:"gray"
            width:label6.width
        }


        // 2段め
        ThresholdLabel {
            id:label1
            labelColor: "gray"
            labelTextColor: "skyblue"
            labelText: "LEVEL"
        }

        ThresholdLabel {
            id: label3
            labelColor: "#99000F"
            labelTextColor: "white"
            labelText: "受信不可"
        }

        ThresholdEdit {
            id: select1
            objectName: "select1"
            exp: false
            z: 2
            idlebg:"threshold_number_base.png"
            activebg: "threshold_number_base_active_rd.png"
            editbg:"threshold_number_base_edit.png"
            edit1idlebg:""            // 編集未選択の背景
            edit1activebg: "threshold_number_cur_r.png"    // 編集対象の背景
            edit2idlebg:""            // 編集未選択の背景
            edit2activebg: "threshold_number_cur_lr.png"    // 編集対象の背景
            edit3idlebg:""            // 編集未選択の背景
            edit3activebg: "threshold_number_cur_lr.png"    // 編集対象の背景
            edit4idlebg:""            // 編集未選択の背景
            edit4activebg: "threshold_number_cur_lr.png"    // 編集対象の背景
            edit5idlebg:""            // 編集未選択の背景
            edit5activebg: "threshold_number_cur_l.png"    // 編集対象の背景

        }

        ThresholdLabel {
            id:label4
            z: 1
            labelColor: "#3A75B2"
            labelTextColor: "white"
            labelText: "受信可"
        }

        ThresholdEdit {
            id: select2
            objectName: "select2"
            exp: false
            z: 2
            idlebg:"threshold_number_base.png"
            activebg: "threshold_number_base_active_ld.png"
            editbg:"threshold_number_base_edit.png"
            edit1idlebg:""            // 編集未選択の背景
            edit1activebg: "threshold_number_cur_r.png"    // 編集対象の背景
            edit2idlebg:""            // 編集未選択の背景
            edit2activebg: "threshold_number_cur_lr.png"    // 編集対象の背景
            edit3idlebg:""            // 編集未選択の背景
            edit3activebg: "threshold_number_cur_lr.png"    // 編集対象の背景
            edit4idlebg:""            // 編集未選択の背景
            edit4activebg: "threshold_number_cur_lr.png"    // 編集対象の背景
            edit5idlebg:""            // 編集未選択の背景
            edit5activebg: "threshold_number_cur_l.png"    // 編集対象の背景

        }

        ThresholdLabel {
            id:label5
            labelColor: "#99000F"
            labelTextColor: "white"
            labelText: "受信不可"
        }・

        // 3段目
        ThresholdLabel {
            labelColor: "gray"
            labelTextColor: "skyblue"
            labelText: "MER/CN"
        }

        ThresholdLabel {
            labelColor: "#99000F"
            labelTextColor: "white"
            labelText: "受信不可"
        }
        ThresholdEdit {
            id: select3
            objectName: "select3"
            exp: false
            z: 2
            isFirstFixed: true // 先頭は編集不可
            idlebg:"threshold_number_base.png"
            activebg: "threshold_number_base_active_rud.png"
            editbg:"threshold_number_base_edit.png"
            edit1activebg: ""                              // 編集対象の背景
            edit2activebg: "threshold_number_cur_r.png"    // 編集対象の背景
            edit3activebg: "threshold_number_cur_lr.png"   // 編集対象の背景
            edit4activebg: "threshold_number_cur_lr.png"   // 編集対象の背景
            edit5activebg: "threshold_number_cur_l.png"    // 編集対象の背景

        }
        ThresholdLabel {
            z: 1
            labelColor: "#8C8109"
            labelTextColor: "white"
            labelText: "余裕度低"
        }
        ThresholdEdit {
            id: select4
            objectName: "select4"
            exp: false
            z: 2
            isFirstFixed: true // 先頭は編集不可
            idlebg:"threshold_number_base.png"
            activebg: "threshold_number_base_active_lud.png"
            editbg:"threshold_number_base_edit.png"
            edit1idlebg:""            // 編集未選択の背景
            edit1activebg: ""                               // 編集対象の背景
            edit2idlebg:""            // 編集未選択の背景
            edit2activebg: "threshold_number_cur_r.png"     // 編集対象の背景
            edit3idlebg:""            // 編集未選択の背景
            edit3activebg: "threshold_number_cur_lr.png"    // 編集対象の背景
            edit4idlebg:""            // 編集未選択の背景
            edit4activebg: "threshold_number_cur_lr.png"    // 編集対象の背景
            edit5idlebg:""            // 編集未選択の背景
            edit5activebg: "threshold_number_cur_l.png"    // 編集対象の背景

        }

        ThresholdLabel {
            labelColor: "#198006"
            labelTextColor: "white"
            labelText: "余裕度高"
        }
        ThresholdLabel {
            labelColor: "#255A20"
            labelTextColor: "white"
            labelText: root.merMaximum
        }

        // ４段目
        ThresholdLabel {
            labelColor: "gray"
            labelTextColor: "skyblue"
            labelText: "BER"
        }
        ThresholdLabel {
            labelColor: "#99000F"
            labelTextColor: "white"
            labelText: "測定不可"
        }
        ThresholdEdit {
            id: select5
            objectName: "select5"
            exp: true
            z: 2
            idlebg:"threshold_number_base_exp.png"
            activebg: "threshold_number_base_exp_active_rud.png"
            editbg:"threshold_number_base_exp_edit.png"
            edit1idlebg:""            // 編集未選択の背景
            edit1activebg: "threshold_number_cur_r.png"    // 編集対象の背景
            edit2idlebg:""            // 編集未選択の背景
            edit2activebg: "threshold_number_cur_lr.png"    // 編集対象の背景
            edit3idlebg:""            // 編集未選択の背景
            edit3activebg: "threshold_number_cur_lr.png"    // 編集対象の背景
            edit4idlebg:""            // 編集未選択の背景
            edit4activebg: "threshold_number_cur_lr.png"    // 編集対象の背景
            edit5idlebg:""            // 編集未選択の背景
            edit5activebg: "threshold_number_cur_l.png"    // 編集対象の背景

        }

        ThresholdLabel {
            z: 1
            labelColor: "#8C8109"
            labelTextColor: "white"
            labelText: "余裕度低"
        }
        ThresholdEdit {
            id: select6
            objectName: "select6"
            exp: true
            z: 2
            idlebg:"threshold_number_base_exp.png"
            activebg: "threshold_number_base_exp_active_lud.png"
            editbg:"threshold_number_base_exp_edit.png"
            edit1idlebg:""            // 編集未選択の背景
            edit1activebg: "threshold_number_cur_r.png"    // 編集対象の背景
            edit2idlebg:""            // 編集未選択の背景
            edit2activebg: "threshold_number_cur_lr.png"    // 編集対象の背景
            edit3idlebg:""            // 編集未選択の背景
            edit3activebg: "threshold_number_cur_lr.png"    // 編集対象の背景
            edit4idlebg:""            // 編集未選択の背景
            edit4activebg: "threshold_number_cur_lr.png"    // 編集対象の背景
            edit5idlebg:""            // 編集未選択の背景
            edit5activebg: "threshold_number_cur_l.png"    // 編集対象の背景

        }

        ThresholdLabel {
            labelColor: "#198006"
            labelTextColor: "white"
            labelText: "余裕度高"
        }
        ThresholdLabel {
            labelColor: "#255A20"
            labelTextColor: "white"
            labelText: "1.00E-8"
        }
    }*/


    Row {
        x: 223
        y: 305
        //anchors.top:updatearea.bottom
        anchors.topMargin: 10
        //anchors.horizontalCenter: updatearea.horizontalCenter

        spacing: 10
        SelectButton {
            id: save
            objectName: "save"
            message: "保存"
            activebg: "brightnessSetting_btn_save_active.png"
            idlebg: "brightnessSetting_btn_save_n.png"
            pressbg: "brightnessSetting_btn_save_p.png"
            width:176
            height:68
        }
        SelectButton {
            id: initialize
            objectName: "initialize"
            message: "初期値表示"
            activebg: "brightnessSetting_btn_save_active.png"
            idlebg: "brightnessSetting_btn_save_n.png"
            pressbg: "brightnessSetting_btn_save_p.png"
            width:176
            height:68
        }

    }


    ScreenName {
        name:"インジケータ"
    }



}

