/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12

// メニューバーに表示する内容を機能と階層毎に定義する
// メニューバーの階層は階層をあらわすための配列と、選択項目によって次の階層を変更するための配列の二次元配列とする
// ※測定の場合は一次元配列で定義可能だが、他と使用方法を統一するため二次元配列で定義する
//
// 使用方法 は function selectModel(type, rank, index) を参照
//
// リスト要素の定義
// name: 項目名
// note: 項目名下に表示する注意書き
// icon: アイコンファイルのパス

Item {


    id: root
    property bool checkopt: false
    // 測定のメニューバーに表示する内容を配列で定義(配列のインデックスとメニューバーの階層は同期させる)
    readonly property var measurement: [
        [measurementFirstFloor],
        [(checkopt === true) ? measurementSecondFloorSingle : measurementSecondFloorSingleoptical, measurementSecondFloorMulti, measurementSecondFloorSingleoptical],
        [measurementThirdFloor1, measurementThirdFloor2, measurementThirdFloor3],
        [measurementFourthFloor1, measurementFourthFloor2]]

    // ファイルリスト表示する内容を配列で定義
    readonly property var filelist: [
        [fileListFirstFloor],
        [fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor,
         fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor,
         fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor,
         fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor,
         fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor,
         fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor,
         fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor,
         fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor,
         fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor,
         fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor,
         fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor,
         fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor,
         fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor,
         fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor, fileListSecondFloor]]

	property alias flFirstFloor: fileListFirstFloor

    // 測定第 1 階層(測定種類)
    ListModel {
        id: measurementFirstFloor
        property string title: "測定メニュー"
        ListElement { name: "シングル測定"; note: ""; icon: "qrc:/resource/png/icon_menu_single.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "マルチ測定"; note: ""; icon: "qrc:/resource/png/icon_menu_multi.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
    }

    // 測定第 2 階層(Band)　constant.h の enum MenuBarBandIndexSingleMeasurement と同じ順にする
    ListModel {
        id: measurementSecondFloorSingle
        property string title: "BAND"
        ListElement { name: "地上デジタル"; note: ""; icon: "qrc:/resource/png/icon_band_chidigi.png"; cursor: "qrc:/resource/png/menubar_cur.png"}
        ListElement { name: "BS"; note: ""; icon: "qrc:/resource/png/icon_band_bs.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "110°CS"; note: ""; icon: "qrc:/resource/png/icon_band_cs.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "BS\n110°CS"; note: ""; icon: "qrc:/resource/png/icon_band_bs_cs.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "CATV\n ALL"; note: ""; icon: "qrc:/resource/png/icon_band_catv_all.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "CATV\n 90-470"; note: ""; icon: "qrc:/resource/png/icon_band_catv_90-470.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "CATV\n 470-1000"; note: ""; icon: "qrc:/resource/png/icon_band_catv_470-1000.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "スカパー!\nプレミアム\nサービス光"; note: ""; icon: "qrc:/resource/png/icon_band_catv_sky.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "PILOT"; note: ""; icon: "qrc:/resource/png/icon_band_catv_pilot.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "CATV上り"; note: ""; icon: "qrc:/resource/png/icon_band_catv_up_stream.png"; cursor: "qrc:/resource/png/menubar_cur.png"}
        ListElement { name: "JCSAT-3A"; note: ""; icon: "qrc:/resource/png/icon_band_3a.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "JCSAT-4B"; note: ""; icon: "qrc:/resource/png/icon_band_4b.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "アンテナ調整"; note: ""; icon: "qrc:/resource/png/icon_band_antenna ad .png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "SCC-B"; note: ""; icon: "qrc:/resource/png/icon_band_b.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "SCC-C"; note: ""; icon: "qrc:/resource/png/icon_band_c.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "LTE"; note: ""; icon: "qrc:/resource/png/icon_band_lte.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "FM"; note: ""; icon: "qrc:/resource/png/icon_band_fm.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
    }

    // 測定第 2 階層(Band)　constant.h の enum MenuBarBandIndexMultiMeasurement と同じ順にする
    ListModel {
        id: measurementSecondFloorMulti
        property string title: "BAND"
        ListElement { name: "地上デジタル"; note: ""; icon: "qrc:/resource/png/icon_band_chidigi.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "BS"; note: ""; icon: "qrc:/resource/png/icon_band_bs.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "110°CS"; note: ""; icon: "qrc:/resource/png/icon_band_cs.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "BS\n110°CS"; note: ""; icon: "qrc:/resource/png/icon_band_bs_cs.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "CATV\n ALL"; note: ""; icon: "qrc:/resource/png/icon_band_catv_all.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "CATV\n 90-470"; note: ""; icon: "qrc:/resource/png/icon_band_catv_90-470.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "CATV\n 470-1000"; note: ""; icon: "qrc:/resource/png/icon_band_catv_470-1000.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "スカパー！\nプレミアム\nサービス光"; note: ""; icon: "qrc:/resource/png/icon_band_catv_sky.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "PILOT"; note: ""; icon: "qrc:/resource/png/icon_band_catv_pilot.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "CATV上り"; note: ""; icon: "qrc:/resource/png/icon_band_catv_up_stream.png"; cursor: "qrc:/resource/png/menubar_cur.png"}
        ListElement { name: "JCSAT-3A"; note: ""; icon: "qrc:/resource/png/icon_band_3a.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "JCSAT-4B"; note: ""; icon: "qrc:/resource/png/icon_band_4b.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "SCC-B"; note: ""; icon: "qrc:/resource/png/icon_band_b.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "SCC-C"; note: ""; icon: "qrc:/resource/png/icon_band_c.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "LTE"; note: ""; icon: "qrc:/resource/png/icon_band_lte.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "FM"; note: ""; icon: "qrc:/resource/png/icon_band_fm.png"; cursor: "qrc:/resource/png/menubar_cur.png" }

    }



    // 測定第 2 階層(Band)　constant.h の enum MenuBarBandIndexSingleMeasurement と同じ順にする
    ListModel {
        id: measurementSecondFloorSingleoptical
        property string title: "BAND"
        ListElement { name: "地上デジタル"; note: ""; icon: "qrc:/resource/png/icon_band_chidigi.png"; cursor: "qrc:/resource/png/menubar_cur.png"}
        ListElement { name: "BS"; note: ""; icon: "qrc:/resource/png/icon_band_bs.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "110°CS"; note: ""; icon: "qrc:/resource/png/icon_band_cs.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "BS\n110°CS"; note: ""; icon: "qrc:/resource/png/icon_band_bs_cs.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "CATV\n ALL"; note: ""; icon: "qrc:/resource/png/icon_band_catv_all.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "CATV\n 90-470"; note: ""; icon: "qrc:/resource/png/icon_band_catv_90-470.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "CATV\n 470-1000"; note: ""; icon: "qrc:/resource/png/icon_band_catv_470-1000.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "スカパー!\nプレミアム\nサービス光"; note: ""; icon: "qrc:/resource/png/icon_band_catv_sky.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "PILOT"; note: ""; icon: "qrc:/resource/png/icon_band_catv_pilot.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "CATV上り"; note: ""; icon: "qrc:/resource/png/icon_band_catv_up_stream.png"; cursor: "qrc:/resource/png/menubar_cur.png"}
        ListElement { name: "JCSAT-3A"; note: ""; icon: "qrc:/resource/png/icon_band_3a.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "JCSAT-4B"; note: ""; icon: "qrc:/resource/png/icon_band_4b.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "SCC-B"; note: ""; icon: "qrc:/resource/png/icon_band_b.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "SCC-C"; note: ""; icon: "qrc:/resource/png/icon_band_c.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "LTE"; note: ""; icon: "qrc:/resource/png/icon_band_lte.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "FM"; note: ""; icon: "qrc:/resource/png/icon_band_fm.png"; cursor: "qrc:/resource/png/menubar_cur.png" }

    }

    // 測定第 3 階層(偏波 BS/CS)
    ListModel {
        id: measurementThirdFloor1
        property string title: "偏波"
        ListElement { name: "右旋"; note: ""; index: 0; icon: ""; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "左旋"; note: ""; index: 1; icon: ""; cursor: "qrc:/resource/png/menubar_cur.png" }
    }

    // 測定第 3 階層(偏波 その他)
    ListModel {
        id: measurementThirdFloor2
        property string title: "偏波"
        ListElement { name: "水平"; note: ""; index: 0; icon: ""; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "垂直"; note: ""; index: 1; icon: ""; cursor: "qrc:/resource/png/menubar_cur.png" }
    }

    // 測定第 3 階層(変調方式)
    ListModel {
        id: measurementThirdFloor3
        property string title: "変調方式"
        ListElement { name: "ISDBT(OFDM)"; note: ""; index: 0; icon: ""; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "CATV(QAM)"; note: ""; index: 1; icon: ""; cursor: "qrc:/resource/png/menubar_cur.png" }
    }

    // 測定第 4 階層(局発周波数 JCSAT 水平垂直共に同じ)
    ListModel {
        id: measurementFourthFloor1
        property string title:　"局部発振周波数選択"
        ListElement { name: "10.678 GHz"; note: ""; icon: ""; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "11.2 GHz"; note: ""; icon: ""; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "11.3 GHz"; note: ""; icon: ""; cursor: "qrc:/resource/png/menubar_cur.png" }
    }

    // 測定第 4 階層(局発周波数 SCC, 水平垂直とも同じ)
    ListModel {
        id: measurementFourthFloor2
        property string title: "局部発振周波数選択"
        ListElement { name: "11.2 GHz"; note: ""; icon: ""; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "11.3 GHz"; note: ""; icon: ""; cursor: "qrc:/resource/png/menubar_cur.png" }
    }


    // 測定第 1 階層(Meunu)
    ListModel {
        id: fileListFirstFloor
        property string title: "USER設定呼び出し"
    }

    // 測定第 2 階層(Menu)
    ListModel {
        id: fileListSecondFloor
        property string title: "測定メニュー"
        ListElement { name: "シングル測定"; note: ""; icon: "qrc:/resource/png/icon_menu_single.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
        ListElement { name: "マルチ測定"; note: ""; icon: "qrc:/resource/png/icon_menu_multi.png"; cursor: "qrc:/resource/png/menubar_cur.png" }
    }

    /// @brief メニューバーに使用する model を返す
    /// @param type 0: 測定 1: 未定
    /// @param rank 階層
    /// @param index 測定は第 3 階層のみ 0(偏波), 1(変調方式)を指定
    function selectModel(type, rank, index)
    {
        if (type === 0) {
            // 測定
            if (rank < measurement.length && index < measurement[rank].length) {
                return measurement[rank][index]
            } else {
                return []
            }
        }
        else if (type === 1) {
            if( rank >= 2) {
                return []
            }
            return filelist[rank][index]
        }
                
        return [];
    }

    // MenuBarコンテンツを設定する
    function setMenuBarContents(contents)
    {

        for (var i = 0; i < contents.length; i++) {
          fileListFirstFloor.append({fileNo: contents[i].fileNo.toString(),
                                     fileName: contents[i].fileName,
                                     note: contents[i].note,
                                     icon: contents[i].icon,
                                     cursor: contents[i].cursor})
        }
    }
    // MenuBarコンテンツをクリアーする
    function clearMenuBarContents()
    {
        fileListFirstFloor.clear()
    }
}
