/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0

import "../parts"


// 光測定 View
Item {
    id:root
    objectName: "OpticalMeasurement"
    anchors.fill: parent

    width:800
    height:480
    signal request(int condition)

    MouseArea {
        anchors.fill: parent
        onClicked: {
            //root.request(0)
        }
    }

    Text {
        id: wltxt
        x: 354
        y: 31
        font.pixelSize: 20
        text: "光波長選択"
        color: "white"
        width: 100
    }

    Image {
        id: fram_wl
        x: 102
        y: 50
        source: "qrc:/resource/png/frame_wavelength.png"

    }

    Row {
        id:nm
        anchors.verticalCenterOffset: -113
        anchors.horizontalCenterOffset: 4

        anchors.centerIn: root
        spacing: 10
        //anchors.horizontalCenter: guidance.horizontalCenter

        SelectButton {
            id:wave1300
            objectName: "wl0"
            message:"1300\nnm"
            activebg: "wlbtn_sel.png"
            idlebg: "wlbtn.png"
            pressbg: "wlbtn_p.png"
            width:110
        }

        SelectButton {
            id:wave1310
            objectName: "wl1"
            message:"1310\nnm"
            activebg: "wlbtn_sel.png"
            idlebg: "wlbtn.png"
            pressbg: "wlbtn_p.png"
            width:110
        }

        SelectButton {
            id:wave1490
            objectName: "wl2"
            message:"1490\nnm"
            activebg: "wlbtn_sel.png"
            idlebg: "wlbtn.png"
            pressbg: "wlbtn_p.png"
            width:110
        }

        SelectButton {
            id:wave1550
            objectName: "wl3"
            message:"1550\nnm"
            activebg: "wlbtn_sel.png"
            idlebg: "wlbtn.png"
            pressbg: "wlbtn_p.png"
            width:110
        }

        SelectButton {
            id:wave1625
            objectName: "wl4"
            message:"1625\nnm"
            activebg: "wlbtn_sel.png"
            idlebg: "wlbtn.png"
            pressbg: "wlbtn_p.png"
            width:110
        }

    }

    Item {
        id:optical

        anchors.centerIn: root
        width:dccol.width
        height:dccol.height
        anchors.verticalCenterOffset: 0
        anchors.horizontalCenterOffset: 16

        Text {
            id: optitle
            x: -36
            y: 5
            font.pixelSize: 24
            text: "光レベル"
            color: "skyblue"
            width: 100
        }

        Rectangle {
            x: -36
            y: 112
            width:opticalpow.width + 40
            height:1
            color: "white"
        }

        Column {
            id: dccol
            x: 7
            y: 40
            spacing: 5

            Row {
                visible: false
                id: wavelength
                spacing: 20

                // 波長
                Text {
                    id: wvtitle
                    font.pixelSize: 24
                    text: "波長"
                    anchors.bottom: wavelength.bottom
                    color: "white"
                    width: optitle.width
                    font.family: defaultFontName
                }

                // 光パワー
                Text {
                    id: wvvalue
                    objectName: "wvvalue"
                    font.pixelSize: 36
                    text: "---"
                    anchors.bottom: wavelength.bottom
                    color: "white"
                    width: opvalue.width
                    horizontalAlignment: Text.AlignRight
                    font.family: defaultFontName
                }

                Text {
                    id: wvunit
                    font.pixelSize: 24
                    text: "nm"
                    anchors.bottom: wavelength.bottom
                    color: "white"
                    font.family: defaultFontName
                }
            }
            // 下線
//            Rectangle {
//                width:opticalpow.width // 光パワーと同じ長さの下線
//                height:1
//                color: "white"
//            }


            Row {
                id: opticalpow
                spacing: 20



                //   測定値
                Text {
                    id: opvalue
                    objectName: "opvalue"
                    font.pixelSize: 58
                    text: "---"
                    anchors.bottom: opticalpow.bottom
                    color: "white"
                    horizontalAlignment: Text.AlignRight
                    width: 200
                    font.family: defaultFontName
                }

                Text {
                    id: opunit
                    font.pixelSize: 24
                    text: "dBm"
                    anchors.bottom: opticalpow.bottom
                    color: "white"
                    font.family: defaultFontName
                }
            }

            // 下線
//            Rectangle {
//                width:opticalpow.width
//                height:1
//                color: "white"
//            }
        }
    }

    ScreenName {
        name : "光レベル測定"
    }

}
