/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import "../parts"

/**
 * @brief コンパス View
 */
Item {
    id:root
    width: 640
    objectName: "MeasurementAdLevel"

    property var azimuth: 0                         //!< 方位角
    property bool isEnabledCompass: true            //!< コンパス測定結果有効状態
    property bool isErrorOccurred: false            //!< 測定エラー発生の有無

    signal request(int condition)

    // コンパス
    Compass {
        id: compass
        anchors {
            horizontalCenter: parent.horizontalCenter
            verticalCenter: parent.verticalCenter
            verticalCenterOffset: -40
        }
        azimuth: (root.isEnabledCompass && !root.isErrorOccurred) ? root.azimuth : 0
        isEnabledCompass: root.isEnabledCompass
        isErrorOccurred: root.isErrorOccurred
    }

    Item {
        id: messageArea
        width: 480
        anchors {
            horizontalCenter: parent.horizontalCenter
            bottom: parent.bottom
            bottomMargin: 30
        }
        Text {
            id: title
            text: "注意"
            color:"#83BEFF"
            horizontalAlignment: Text.AlignLeft
            font.pixelSize: 22
            font.family: defaultFontName
            anchors {
                bottom: message1.top
                bottomMargin: 8
            }
        }
        Text {
            id: message1
            text: "・コンパスは水平にしてご使用ください。"
            color:"white"
            horizontalAlignment: Text.AlignLeft
            font.pixelSize: 20
            font.family: defaultFontName
            anchors {
                bottom: message2.top
                bottomMargin: 8
            }
        }
        Text {
            id: message2
            text: "・コンパスは磁気の影響を受けますのでご注意ください。"
            color:"white"
            horizontalAlignment: Text.AlignLeft
            font.pixelSize: 20
            font.family: defaultFontName
            anchors.bottom: parent.bottom
        }
    }
}
