/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
import QtQuick.Window 2.12
import QtQuick.Controls 2.12

Item {
    id: antennaGauge
    width: 364
    height: 364

    readonly property real minimum: 20.0    // 最小値
    readonly property real maximum: 120.0   // 最大値
    property double redZoneRatio: 0.2       // ゲージに表示する赤の割合(最大値 1.0 とする)
    property double yellowZoneRatio: 0.3    // ゲージに表示する青の割合(最大値 1.0 とする)
    property string level: "00.0"           // 測定レベルの値(小数点第 1 位まで)
    property real needlePosition: 0         // 針の位置(0〜140)
    property var scales: [20, 30, 40, 50, 60, 70, 80, 90, 100, 110, 120]    // 目盛り
    property string band: ""                // Band
    property string mer: "0.0"              // 測定レベルの値(小数点第 1 位まで)
    property string ber: "0.0E"             // 測定レベルの値(小数点第 1 位まで)
    property int selectCnMer : 1            // CNR/MER切替状態

    // 定数
    Item {
        id: constant
        readonly property double startAngle: -Math.PI * 1.19    // 円弧の開始角度
        readonly property double endAngle: Math.PI * 0.19       // 円弧の終了角度
    }

    Rectangle {
        width: 363
        height: 363
        x: (parent.width - width) / 2
        y: 12
        color: "transparent"

        // 通常のゲージ
        Canvas {
            id: gauge
            anchors.fill: parent
            onPaint: {
                var ctx = getContext("2d");
                ctx.save()

                ctx.beginPath()
                ctx.lineWidth = 32
                // 弧全体を塗る(赤)
                ctx.arc(width / 2, height / 2, width / 2.19, constant.startAngle, constant.endAngle, false)
                ctx.strokeStyle = "#AF052A"
                ctx.stroke()
                ctx.closePath()

                // 注意は使用していない

                // 受信可(青)
                var ctxSafe = getContext("2d");
                ctxSafe.save()

                ctxSafe.beginPath()
                ctxSafe.lineWidth = 32
                ctxSafe.arc(width / 2, height / 2, width / 2.19, constant.startAngle + (Math.PI * 1.38 *　antennaGauge.redZoneRatio), constant.startAngle + (Math.PI * 1.38 *　(antennaGauge.redZoneRatio + antennaGauge.yellowZoneRatio)), false)
                ctxSafe.strokeStyle = "#5A9AD7"
                ctxSafe.stroke()
                ctxSafe.closePath()
            }
        }
    }

    Rectangle{
        x: 101
        y: 175
        width: 180
        height: 3
        color:"#E4E6E5"
    }

    // 枠
    Image {
        id: antennaLevelFrame
        x: (parent.width - width) / 2
        y: 10
        width: 364
        height: 286
        source: ""
        clip: true


        // LEVEL
        Label {
            id: antennaLevelLabel
            width: 82
            height: 12
            x: 157
            y: 72
            text: "LEVEL"
            font.family: defaultFontName
            font.pixelSize: 18
            color: "#419FFF"
        }

        // LEVEL 値
        Text {
            id: antennaLevelValue
            width: 185
            height: 56
            x: 75
            y: 94
            text: antennaGauge.level
            font.family: defaultFontName
            font.pixelSize: 52
            horizontalAlignment: Text.AlignRight
            color: "#E4E6E5"
        }

        // LEVEL 単位
        Label {
            id: antennaLevelUnit
            width: 30
            height: 20
            x: 225
            y: 145
            text: "dBμV"
            font.family: defaultFontName
            font.pixelSize: 12
            color: "#E4E6E5"
        }

        // Band
        Label {
            id: antennaLevelBand
            width: 30
            height: 20
            x: 147
            y: 174
            text: antennaGauge.band
            font.family: defaultFontName
            font.pixelSize: 16
            color: "#E4E6E5"
        }

        // MER
        Label {
            id: antennaLevelMer
            width: 30
            height: 12
            x: 107
            y: 200
            text: (antennaGauge.selectCnMer === 1) ? "MER" : "CN"
            font.family: defaultFontName
            font.pixelSize: 18
            color: "#419FFF"
        }

        // MER 値
        Text {
            id: antennaMerValue
            width: 80
            height: 40
            x: 169
            y: 200
            text: antennaGauge.mer
            font.family: defaultFontName
            font.pixelSize: 28
            horizontalAlignment: Text.AlignRight
            color: "#E4E6E5"
        }

        // MER 単位
        Label {
            id: antennaMerUnit
            width: 30
            height: 20
            x: 255
            y: 213
            text: "dB"
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // BER
        Label {
            id: antennaLevelBer
            width: 30
            height: 12
            x: 107
            y: 257
            text: "BER"
            font.family: defaultFontName
            font.pixelSize: 18
            color: "#419FFF"
        }

        // BER 値
        Text {
            id: antennaBerValue
            width: 80
            height: 40
            x: 168
            y: 250
            text: antennaGauge.ber
            font.family: defaultFontName
            font.pixelSize: 28
            horizontalAlignment: Text.AlignRight
            color: "#E4E6E5"
        }

        // グラデーション
        Image {
            id: antennaLevelGradation
            width: 364
            height: 270
            anchors.verticalCenterOffset: 1
            anchors.horizontalCenterOffset: 0
            anchors.centerIn: parent
            fillMode: Image.PreserveAspectFit
            clip: true
            source: "qrc:/resource/png/level_gradation.png"
        }

        // 補助目盛り
        Image {
            id: antennaLevelStep
            width: 364
            height: 286
            anchors.centerIn: parent
            fillMode: Image.PreserveAspectFit
            clip: true
            source: "qrc:/resource/png/level_step.png"
            visible: false
        }

        //　目盛り
        Image {
            id: antennaLevelScale
            width: 364
            height: 286
            anchors.centerIn: parent
            fillMode: Image.PreserveAspectFit
            clip: true
            source: "qrc:/resource/png/level_scale.png"

        }

        // 目盛り 1
        Label {
            width: 20
            height: 16
            x: 52
            y: 263
            text: antennaGauge.scales[0]
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 目盛り 2
        Label {
            width: 20
            height: 16
            x: 24
            y: 202
            text: antennaGauge.scales[1]
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 目盛り 3
        Label {
            width: 20
            height: 16
            x: 26
            y: 132
            text: antennaGauge.scales[2]
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 目盛り 4
        Label {
            width: 20
            height: 16
            x: 60
            y: 72
            text: antennaGauge.scales[3]
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 目盛り 5
        Label {
            width: 20
            height: 16
            x: 110
            y: 36
            text: antennaGauge.scales[4]
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 目盛り 6
        Label {
            width: 20
            height: 16
            x: 174
            y: 24
            text: antennaGauge.scales[5]
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 目盛り 7
        Label {
            width: 20
            height: 16
            x: 238
            y: 36
            text: antennaGauge.scales[6]
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 目盛り 8
        Label {
            width: 20
            height: 16
            x: 286
            y: 72
            text: antennaGauge.scales[7]
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 目盛り 9
        Label {
            width: 20
            height: 16
            x: 310
            y: 132
            text: antennaGauge.scales[8]
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 目盛り 10
        Label {
            width: 20
            height: 16
            x: 312
            y: 202
            text: antennaGauge.scales[9]
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 目盛り 11
        Label {
            width: 20
            height: 16
            x: 286
            y: 263
            text: antennaGauge.scales[10]
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }
    }
    Image {
        id: antenna_meter
        x: -3
        y: 9
        width: 371
        height: 363
        source: "qrc:/resource/png/antenna_meter.png"
    }

    // 針
    Image {
        id: antennaLevelNeedle
        width: 16
        height: 350
        x: parent.width / 2
        y: 16
        source: "qrc:/resource/png/level_needle.png"
        fillMode: Image.PreserveAspectFit
        clip: true
        transform: Rotation {
            id: antennaLevelNeedleRotation
            angle: antennaGauge.needlePosition
            origin.x: antennaLevelNeedle.width / 2 - 8  // 回転の中心 X 座標の調整
            origin.y: antennaLevelNeedle.height / 2     // 回転の中心 Y 座標の調整
        }
    }

    function updateThreshold(red, yellow)
    {
        redZoneRatio = red
        yellowZoneRatio = yellow
        gauge.requestPaint()
    }

    function updateMeterValue(level, levelNeedlePosition)
    {
        antennaGauge.level = level
        antennaGauge.needlePosition = levelNeedlePosition
    }
}
