/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
import QtQuick.Window 2.12
import QtQuick.Controls 2.12

Item {
    id: berGauge
    width: 296
    height: 296
    readonly property int minimum: 2        // 最小値
    readonly property int maximum: 8        // 最大値
    property double redZoneRatio: 0.1       // ゲージに表示する赤の割合(最大値 1.0 とする)
    property double yellowZoneRatio: 0.4    // ゲージに表示する黃の割合(最大値 1.0 とする)
    property string value: "0.0E"           // 測定レベルの値(小数点第 1 位まで)
    property string exponential: "-0"       // 測定レベルの値の累乗
    property real needlePosition: 0         // 針の位置
    property var scales: ["E-2", "E-3", "E-4", "E-5", "E-6", "E-7", "0"]    // 目盛り
    property int blinkInterval: 0           //!< 点滅間隔
    onBlinkIntervalChanged: {
        if (blinkInterval == 0) {
            timer.stop()
            berValue.visible = true
        } else {
            timer.start()
        }
    }

    // 定数
    Item {
        id: constant
        readonly property double startAngle: -Math.PI * 0.50    // 円弧の開始角度
        readonly property double endAngle: Math.PI * 0.50     // 円弧の終了角度
    }

    Item {
        width: parent.width
        height: parent.height
        x: -width / 2
        y: 45

        // 反時計回りに描画する

        // ゲージ
        Canvas {
            id: gauge
            anchors.fill: parent
            onPaint: {
                var ctxGreen = getContext("2d");
                ctxGreen.save()

                ctxGreen.beginPath()
                ctxGreen.lineWidth = 32
                // 弧全体を塗る
                ctxGreen.arc(width / 2, height / 2, width / 2.32, constant.startAngle, constant.endAngle, false)
                ctxGreen.strokeStyle = "#198006"
                ctxGreen.stroke()
                ctxGreen.closePath()

                // 注意
                var ctxYellow = getContext("2d");
                ctxYellow.save()

                ctxYellow.beginPath()
                ctxYellow.lineWidth = 32
                // 赤の領域の分を加えたところから反時計回りに描画
                ctxYellow.arc(width / 2, height / 2, width / 2.32, constant.startAngle + (Math.PI * (berGauge.redZoneRatio)), constant.startAngle + (Math.PI * berGauge.yellowZoneRatio), false)
                ctxYellow.strokeStyle = "#9B9012"
                ctxYellow.stroke()
                ctxYellow.closePath()

                // 危険
                var ctxRed = getContext("2d");
                ctxRed.save()

                ctxRed.beginPath()
                ctxRed.lineWidth = 32
                // 黄色の領域から最後まで反時計回りに描画
                ctxRed.arc(width / 2, height / 2, width / 2.32, constant.startAngle + (Math.PI * berGauge.yellowZoneRatio), constant.endAngle, false)
                ctxRed.strokeStyle = "#AF052A"
                ctxRed.stroke()
                ctxRed.closePath()
            }
        }
    }


    // 枠
    Image {
        id: berFrame_old
        width: 150
        height: 296
        x: -5
        y: 45
        //source: "qrc:/resource/png/ber_frame.png"

        // BER
        Label {
            id: berLabel
            width: 80
            height: 20
            x: -6
            y: 100
            text: "BER"
            font.family: defaultFontName
            font.pixelSize: 20
            color: "#419FFF"
        }

        // 値
        Text {
            id: berValue
            width: 30
            height: 30
            x: -28
            y: 135
            text: berGauge.value
            font.family: defaultFontName
            font.pixelSize: 33
            color: "#E4E6E5"
        }

        // 累乗
        Text {
            id: exponential
            width: 50
            height: 40
            x: 42
            y: 125
            text: berGauge.exponential
            font.family: defaultFontName
            font.pixelSize: 36
            color: "#E4E6E5"
        }

        // グラデーション
        Image {
            id: berGradation
            anchors.verticalCenterOffset: 1
            anchors.horizontalCenterOffset: -2
            anchors.centerIn: parent
            source: "qrc:/resource/png/ber_gradation.png"
        }

        // 補助目盛り
        Image {
            id: berStep
            anchors.top: parent.top
            anchors.topMargin: 6
            anchors.left: parent.left
            anchors.leftMargin: 2
            source: "qrc:/resource/png/ber_step.png"
            visible: false
        }

        //　目盛り
        Image {
            id: berScale
            anchors.centerIn: parent
            source: "qrc:/resource/png/ber_scale.png"
        }

        // 目盛り 1
        Label {
            width: 20
            height: 16
            x: -6
            y: 252
            text: berGauge.scales[0]
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 目盛り 2
        Label {
            width: 20
            height: 16
            x: 47
            y: 234
            text: berGauge.scales[1]
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 目盛り 3
        Label {
            width: 20
            height: 16
            x: 84
            y: 194
            text: berGauge.scales[2]
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 目盛り 4
        Label {
            width: 20
            height: 16
            x: 104
            y: 140
            text: berGauge.scales[3]
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 目盛り 5
        Label {
            width: 20
            height: 16
            x: 84
            y: 84
            text: berGauge.scales[4]
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 目盛り 6
        Label {
            width: 20
            height: 16
            x: 47
            y: 44
            text: berGauge.scales[5]
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 目盛り 7
        Label {
            width: 20
            height: 16
            x: -8
            y: 26
            text: berGauge.scales[6]
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }
    }

    Image {
        id: merFrame
        //width: 149
        //height: 296
        sourceSize.width: 191
        x: -3
        y: 43
        source: "qrc:/resource/png/ber_meter.png"
    }


    // 針
    Image {
        id: berNeedle
        width: 16
        height: 286
        x: -8
        y: 50
        source: "qrc:/resource/png/ber_needle.png"
        transform: Rotation {
            id: berNeedleRotation
            angle: berGauge.needlePosition
            origin.x: berNeedle.width / 2 - 0     // 回転の中心 X 座標の調整
            origin.y: berNeedle.height / 2 - 0    // 回転の中心 Y 座標の調整
        }
    }

    // 点滅用タイマー
    Timer {
        id: timer
        interval: berGauge.blinkInterval
        running: false
        repeat: true
        onTriggered: {
            berValue.visible = !berValue.visible
        }
    }

    function updateBer(ber, berNeedlePosition) {
        berGauge.value = ber
        berGauge.needlePosition = berNeedlePosition
    }

    function updateThreshold(red, yellow)
    {
        redZoneRatio = red
        yellowZoneRatio = yellow
        gauge.requestPaint()
    }
}
