/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
import "../parts"

// USER データロガー設定のチャンネルリストの行
Item {
    id: root
    implicitHeight: 40
    implicitWidth: 507
    property bool active: false
    property bool edit: false

    property int editItemIndex: 0               // 選択されているアイテムのインデックス
    property bool selected: false               // 測定 ON なら true

    readonly property int rowHeight: 40         // 行の高さ

    readonly property int dataIndexChannel: 0   // アイテムのインデックス
    readonly property int dataIndexFrequency: 1
    readonly property int dataIndexBroadcast: 2
    readonly property int dataIndexLocalFreq: 3
    readonly property int dataIndexMer: 4
    readonly property int dataIndexBer: 5
    readonly property int dataIndexPowerSupply: 6

    Image {
        anchors.fill: parent
//        source: changeBackground()
        source: ""
    }

    Row {
        spacing: 2
        // CH
        Text {
            id: channel
            width: 62
            height: root.rowHeight
        }

        // 周波数
        SelectButton {
            id: frequency
            objectName: "frequency"
            width: 104
            height: root.rowHeight
            activebg: "user_datalogger_setting_26.png"
            active: editItemIndex == dataIndexFrequency
        }

        // 放送規格
        SelectButton {
            id: broadbandSystem
            objectName: "broadbandSystem"
            width: 104
            height: root.rowHeight
            activebg: "user_datalogger_setting_26.png"
            active: editItemIndex == dataIndexBroadcast
            useChannelEdit: true
            selected: root.selected
        }

        // 局発
        SelectButton {
            id: localFrequency
            objectName: "levelOffset"
            width: 89
            height: root.rowHeight
            activebg: "user_datalogger_setting_27.png"
            active: editItemIndex == dataIndexLocalFreq
            useChannelEdit: true
            selected: root.selected
        }

        // MER/CN
        SelectButton {
            id: mercnSelector
            objectName: "merCn"
            width: 45
            height: root.rowHeight
            activebg: "user_datalogger_setting_28.png"
            active: editItemIndex == dataIndexMer
            useChannelEdit: true
            selected: root.selected
        }

        // BER
        SelectButton {
            id: berSelector
            objectName: "ber"
            width: 46
            height: root.rowHeight
            activebg: "user_datalogger_setting_28.png"
            active: editItemIndex == dataIndexBer
            useChannelEdit: true
            selected: root.selected
        }

        // 給電
        SelectButton {
            id: powerSupplySelector
            objectName: "powerSupply"
            width: 46
            height: root.rowHeight
            activebg: "user_datalogger_setting_28.png"
            active: editItemIndex == dataIndexPowerSupply
            useChannelEdit: true
            selected: root.selected
        }
    }

    function changeBackground()
    {
//        if (root.edit) {
//            return (root.editBackgoundImage === "") ? "" : "qrc:/resource/png/" + root.editBackgoundImage
//        }
        if (root.active) {
            // 別部品として表示するため空とする
            return ""
        }
        return (root.idleBackgoundImage === "") ? "" : "qrc:/resource/png/" + root.idleBackgoundImage
    }
}
