/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import "../parts"

Item {
    id: root
    property int no: 0
    property int noWidth: 40
    property int bandWidth: 63
    property int broadbandSystemWidth: 63
    property int channelWidth: 63
    property int modulationWidth: 63
    property int leveloffsetWidth: 63
    property int mercnSwitchWidth: 38
    property int berSwitchWidth: 38
    property int powerSupplyWidth: 63
    property int trashWidth: 39

    property bool active: false
    property bool edit: false
    property string activebg: ""    // active 背景
    property string idlebg: ""      // idle 背景
    property string editbg: ""      // edit 背景
    property string band:""
    property string broadbandSystem:""
    property string channel:""
    property string modulation:""
    property string leveloffset:""
    property string mercn:""
    property string ber:""
    property string powerSupply:""
    property bool isTrashVisible
    property string trashIcon: "trash_disable.png"
    implicitHeight: 40
    implicitWidth: 560

    // 背景イメージ
    Image {
        id:bg
        source: changeBackground()
        onSourceChanged: {
            //console.log("bg.source:" + bg.source)
        }

        anchors {
            centerIn: parent
        }
    }

    Row {
        spacing:2
        Text {
            id: no
            text: root.no + " "
            horizontalAlignment: Text.AlignRight
            verticalAlignment: Text.AlignVCenter
            width: root.noWidth
            height: 40
            color: "skyblue"
            font.pixelSize: 13
            font.family: defaultFontName
        }

        // BAND
        SelectButton {
            id: band
            objectName: "band"
            width: root.bandWidth
            height: 40
            activebg:"datalogger_channeledit_cur_r.png"
            message:root.band
            fontsize: 13
        }

        // 放送規格
        SelectButton {
            id: broadbandSystem
            objectName: "broadbandSystem"
            width: root.broadbandSystemWidth
            height: 40
            activebg:"datalogger_channeledit_cur_lr.png"
            message:root.broadbandSystem
            fontsize: 13
        }

        // チャンネル
        SelectButton {
            id: channel
            objectName: "channel"
            width: root.channelWidth
            height: 40
            activebg:"datalogger_channeledit_cur_lr.png"
            message:root.channel
            fontsize: 13
        }

        // 変調方式
        SelectButton {
            id: modulation
            objectName: "modulation"
            width: root.modulationWidth
            height: 40
            activebg:"datalogger_channeledit_cur_lr.png"
            message:root.modulation
            fontsize: 13
        }

        // 局発
        SelectButton {
            id: leveloffset
            objectName: "levelOffset"
            width: root.leveloffsetWidth
            height: 40
            activebg:"datalogger_channeledit_cur_lr.png"
            message:root.leveloffset
            fontsize: 13
        }

        // MER/CN
        SelectButton {
            id: mercnSwitch
            objectName: "mercnSwitch"
            width: root.mercnSwitchWidth
            height: 40
            activebg:"datalogger_channeledit_w40_cur_lr.png"
            message:root.mercn
            fontsize: 13
        }

        // BER
        SelectButton {
            id: berSwitch
            objectName: "berSwitch"
            width: root.berSwitchWidth
            height: 40
            activebg:"datalogger_channeledit_w40_cur_lr.png"
            message:root.ber
            fontsize: 13
        }

        // 給電
        SelectButton {
            id: powerSupply
            objectName: "powerSupply"
            width: root.powerSupplyWidth
            height: 40
            activebg:"datalogger_channeledit_cur_lr.png"
            message:root.powerSupply
            fontsize: 13
        }

        // 削除 (ゴミ箱アイコン)
        IconButton {
            id: trash
            objectName: "trash"
            width: root.trashWidth
            height: 40
            activebg:"datalogger_channeledit_w40_cur_l.png"
            icon: root.trashIcon
            visible: isTrashVisible
        }
    }

    function changeBackground()
    {
        if (root.active) {
            if (root.edit) {
                return (root.editbg === "") ? "" : "qrc:/resource/png/" + root.editbg
            } else {
                return (root.activebg === "") ? "" : "qrc:/resource/png/" + root.activebg
            }
        } else {
            return (root.idlebg === "") ? "" : "qrc:/resource/png/" + root.idlebg
        }
    }
}
