/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
import "../parts"

// USER データロガー設定のチャンネルリストの行
Item {
    id: root
    implicitHeight: 40
    implicitWidth: 507
    property bool active: false
    property bool edit: false
    property var channel: "---"
    property var frequency: "---"
    property var selectBroadbandSystem: "---"
    property var localFrequency: "---"
    property var selectMerCn: "---"
    property var selectBer: "---"
    property var selectPowerSupply: "---"
    property bool isTop: false
    property bool isBottom: false
    property string activeBackgoundImage: isTop ? "datalogger_filemix_userlist_btn_active_rd.png"
                                                : isBottom ? "datalogger_filemix_userlist_btn_active_ur.png"
                                                           : "datalogger_filemix_userlist_btn_active_urd.png"
    property string idleBackgoundImage: ""
    property string editBackgoundImage: "datalogger_filemix_userlist_btn_edit.png"
    property var channelData: [ "", "", "", "", "", "", "", false ]
    property var channelDataColor: [ false, false, false, false, false, false, false, false ]   // true:白色 false:水色
    property int editItemIndex: 0
    property bool selected: false               // 測定 ON なら true
    property bool editing: false

    readonly property int rowHeight: 40         // 行の高さ
    readonly property int dataIndexChannel: 0
    readonly property int dataIndexFrequency: 1
    readonly property int dataIndexBroadcast: 2
    readonly property int dataIndexLocalFreq: 3
    readonly property int dataIndexMer: 4
    readonly property int dataIndexBer: 5
    readonly property int dataIndexPowerSupply: 6

    Image {
        anchors.fill: parent
        source: ""
    }

    Row {
        spacing: 2
        // CH
        Text {
            id: channel
            width: 62
            height: root.rowHeight
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            text: channelData[dataIndexChannel]
            color: (channelData[dataIndexChannel] === "---")
                                 ? "#5A5C63" : "#7EBEF5"
            font.pixelSize: 15
            font.family: defaultFontName
        }
        // 周波数
        SelectButton {
            id: frequency
            objectName: "frequency"
            width: 104
            height: root.rowHeight
            activebg: "user_datalogger_setting_11.png"
            message: channelData[dataIndexFrequency]
            fontsize: 15
            active: edit && editItemIndex == dataIndexFrequency
            useChannelEdit: true
            selected: root.selected
            editing: (channelData[dataIndexChannel] === "---")
                     ? false : channelDataColor[dataIndexFrequency]
        }
        // 放送規格
        SelectButton {
            id: broadbandSystem
            objectName: "broadbandSystem"
            width: 104
            height: root.rowHeight
            activebg: "user_datalogger_setting_11.png"
            message: channelData[dataIndexBroadcast]
            fontsize: 15
            active: edit && editItemIndex == dataIndexBroadcast
            useChannelEdit: true
            selected: root.selected
            editing: (channelData[dataIndexChannel] === "---")
                     ? false : channelDataColor[dataIndexBroadcast]
        }

        // 局発
        SelectButton {
            id: localFrequency
            objectName: "levelOffset"
            width: 89
            height: root.rowHeight
            activebg: "user_datalogger_setting_14.png"
            message: channelData[dataIndexLocalFreq]
            fontsize: 15
            active: edit && editItemIndex == dataIndexLocalFreq
            useChannelEdit: true
            selected: root.selected
            editing: (channelData[dataIndexChannel] === "---")
                     ? false : channelDataColor[dataIndexLocalFreq]
        }

        // MER/CN
        SelectButton {
            id: mercnSelector
            objectName: "merCn"
            width: 45
            height: root.rowHeight
            activebg: "user_datalogger_setting_30.png"
            message: channelData[dataIndexMer]
            fontsize: 15
            active: edit && editItemIndex == dataIndexMer
            useChannelEdit: true
            selected: root.selected
            editing: (channelData[dataIndexChannel] === "---")
                     ? false : channelDataColor[dataIndexMer]
        }

        // BER
        SelectButton {
            id: berSelector
            objectName: "ber"
            width: 46
            height: root.rowHeight
            activebg: "user_datalogger_setting_30.png"
            message: channelData[dataIndexBer]
            fontsize: 15
            active: edit && editItemIndex == dataIndexBer
            useChannelEdit: true
            selected: root.selected
            editing: (channelData[dataIndexChannel] === "---")
                     ? false : channelDataColor[dataIndexBer]
        }

        // 給電
        SelectButton {
            id: powerSupplySelector
            objectName: "powerSupply"
            width: 46
            height: root.rowHeight
            activebg: "user_datalogger_setting_30.png"
            message: channelData[dataIndexPowerSupply]
            fontsize: 15
            active: edit && editItemIndex == dataIndexPowerSupply
            useChannelEdit: true
            selected: root.selected
            editing: (channelData[dataIndexChannel] === "---")
                     ? false : channelDataColor[dataIndexPowerSupply]
        }
    }

    function changeBackground()
    {
        if (root.edit) {
            return (root.editBackgoundImage === "") ? "" : "qrc:/resource/png/" + root.editBackgoundImage
        }
        if (root.active) {
            // 別部品として表示するため空とする
            return ""
        }
        return (root.idleBackgoundImage === "") ? "" : "qrc:/resource/png/" + root.idleBackgoundImage
    }
}
