/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12

/**
 * @brief 円グラフ(針) QML
 * @note 検証（標準モード）向けに使用
 * @attention  開発モジュールで使用予定あり ※現時点では検証用コード含む
 */
Item {
    id: root
    width: 360
    height: width * 0.75

    property bool meter_background: false

    property color guideColor0: "red"
    property color guideColor1: "green"
    property color guideColor2: "red"
    property real guidePoint0: 0.17                     // anglePoint0で使用
    property real guidePoint1: 0.83                     // anglePoint1で使用
    property color levelColor: meter_background ? "red"  : "#8542f4"
    //property color levelColor: Qt.rgba(0.9, 0.0, 0.0, 0.3)    // 位置調整用

    property alias title: labelLevel.text
    property alias unit: labelUnit.text
    property bool floatPointPresentation: false
    property real value: 100.0
    property real minValue: 35.0
    property real maxValue: 120.0
    property real spanValue: maxValue - minValue

    property bool additionalMarks: false
    property real mark1Value: 65
    property real mark2Value: 90

    property int valueFontSize: 80
    property int valueTextXOffset: 0
    property int valueTextYOffset: 0
    property int unitTextOffset: 72

    property real angleStart: Math.round(1.2 * Math.PI)
    property real angleEnd: Math.round(2.2 * Math.PI)
    //property real angleValue: root.angleStart + root.maxAngle * Math.min(Math.max(root.value - root.minValue, 0.0) / (root.maxValue - root.minValue), 1.0)
    property real maxAngle: root.angleEnd - root.angleStart
    property real anglePoint0: root.angleStart + root.maxAngle * root.guidePoint0
    property real anglePoint1: root.angleStart + root.maxAngle * root.guidePoint1

    property real needleAngleStart: -117.0
    property real needleAngleEnd: 117.0
    property real needleAngleValue: root.needleAngleStart + root.needleMaxAngle * Math.min(Math.max(root.value - root.minValue, 0.0) / (root.maxValue - root.minValue), 1.0)
    property real needleMaxAngle: Math.abs(root.needleAngleStart - root.needleAngleEnd)

    // Meterグラフ描画 目盛り数
    // ex. 　10指定 -> グラフ描画領域に対して、10分割した目盛り数を描画する
    //     100指定 -> グラフ描画領域に対して、100分割した目盛り数を描画する
    //       0指定 -> グラフ描画領域の目盛り数を描画しない　（additionalMarksプロパティの指定に従う）
    readonly property real meterTickNumber: 0
    // Meterグラフ描画 目盛り線 On/Off (true:On)
    readonly property bool meterTickMark: false

    onValueChanged: {
        //canvasLevel.requestPaint()
    }

    Behavior on value {
        enabled: intrvalInfo.meterAnimationInterval > 0 ? true : false
        NumberAnimation {
            duration: intrvalInfo.meterAnimationInterval
            easing.type: Easing.OutCubic
        }
    }

    // ゲージライン
    Canvas {
        id: canvasBg
        width: root.width
        height: root.width
        visible: !meter_background

        property int radius: canvasBg.width / 2 - canvasBg.lineWidth
        property int lineWidth: 12
        property var ctx

        onPaint: {
            ctx = getContext("2d")
            ctx.strokeStyle = root.guideColor0
            ctx.lineWidth = canvasBg.lineWidth

            // background circle
            ctx.beginPath()
            ctx.arc(width / 2, height / 2, radius, root.angleStart, root.anglePoint0, false)
            ctx.stroke()
            ctx.closePath()

            ctx.strokeStyle = root.guideColor1
            ctx.beginPath()
            ctx.arc(width / 2, height / 2, radius, root.anglePoint0, root.anglePoint1, false)
            ctx.stroke()
            ctx.closePath()

            ctx.strokeStyle = root.guideColor2
            ctx.beginPath()
            ctx.arc(width / 2, height / 2, radius, root.anglePoint1, root.angleEnd, false)
            ctx.stroke()
            ctx.closePath()
            /*
            ctx.strokeStyle = "green"
            ctx.lineWidth = 1
            ctx.beginPath()
            ctx.moveTo(0, height / 2)
            ctx.lineTo(width, height / 2)
            ctx.moveTo(width / 2, 0)
            ctx.lineTo(width / 2, height)
            ctx.stroke()
            ctx.closePath()
            */
        }
    }

    // グラフ ： 描画なし
    Canvas {
        id: canvasLevel
        width: root.width
        height: root.width

        property int radius: canvasLevel.width / 2 - canvasLevel.margin - canvasLevel.lineWidth
        property int margin: 10
        property int lineWidth: 22
        property var ctx
        onPaint: {
            /*
            ctx = getContext("2d")
            ctx.clearRect(0, 0, width, height)
            ctx.strokeStyle = root.levelColor
            ctx.lineWidth = canvasLevel.lineWidth

            ctx.beginPath()
            ctx.arc(width / 2, height / 2, radius, root.angleStart, root.angleValue, false)
            ctx.stroke()
            ctx.closePath()
            */
        }
    }

    property real outerRadius: canvasBg.radius
    property real needleBaseHeight: meter_background ? outerRadius - 10 : outerRadius - (0.04 * outerRadius) * 1.25
    property real needleTipWidth: meter_background ? 6.5 : (0.02 * outerRadius)
    property real needleBaseWidth: meter_background ? 13.0 : (0.06 * outerRadius)
    property real needleLength: meter_background ? needleBaseHeight * 0.36 : canvasLevel.lineWidth * 1.5

    // 針
    Canvas {
        id: canvasLevelNeedle
        implicitWidth: needleBaseWidth
        implicitHeight: needleBaseHeight
        enabled: false

        property real xCenter: width / 2
        property real yCenter: height / 2

        x: canvasBg.width / 2 - xCenter
        y: canvasBg.height / 2 - height

        onPaint: {
            var ctx = getContext("2d");
            ctx.reset();

            if (meter_background) {
                ctx.beginPath()
                ctx.moveTo(xCenter - needleBaseWidth / 2, needleLength)
                ctx.lineTo(xCenter + needleBaseWidth / 2, needleLength)
                ctx.lineTo(xCenter + needleBaseWidth / 2, needleTipWidth)
                ctx.lineTo(xCenter, 0)
                ctx.lineTo(xCenter - needleBaseWidth / 2, needleTipWidth)
                ctx.closePath()
                ctx.strokeStyle = "black"
                ctx.fillStyle = levelColor
                ctx.fill()
                ctx.stroke()
            }
            else {
                ctx.beginPath();
                ctx.moveTo(xCenter, needleLength);
                ctx.lineTo(xCenter - needleBaseWidth / 2, needleLength - needleBaseWidth / 2);
                ctx.lineTo(xCenter - needleTipWidth / 2, 0);
                ctx.lineTo(xCenter, yCenter - needleBaseHeight);
                ctx.lineTo(xCenter, 0);
                ctx.closePath();
                ctx.fillStyle = levelColor
                ctx.fill();

                ctx.beginPath();
                ctx.moveTo(xCenter, needleLength)
                ctx.lineTo(width, needleLength - needleBaseWidth / 2);
                ctx.lineTo(xCenter + needleTipWidth / 2, 0);
                ctx.lineTo(xCenter, 0);
                ctx.closePath();
                ctx.fillStyle = levelColor
                ctx.fill();
            }
        }
        transform:Rotation {
            origin.x: canvasLevelNeedle.width / 2
            origin.y: canvasLevelNeedle.height
            angle: root.needleAngleValue
        }
    }

    // 目盛り線
    Canvas {
        id: canvasMark
        width: root.width
        height: root.width
        visible: !meter_background

        property int lineWidth: 1
        property int innerRadius: canvasLevel.radius - canvasLevel.lineWidth / 2 - margin
        property int outerRadius: canvasBg.radius + canvasBg.lineWidth / 2 + margin
        property int margin: 4
        property real angleMark1: root.angleStart + root.maxAngle * (root.mark1Value - root.minValue) / (root.maxValue - root.minValue) // Math.PI * 1.35
        property real angleMark2: root.angleStart + root.maxAngle * (root.mark2Value - root.minValue) / (root.maxValue - root.minValue) // Math.PI * 1.65
        property var ctx

        onPaint: {
            ctx = getContext("2d")
            ctx.strokeStyle = "black"
            ctx.lineWidth = canvasMark.lineWidth

            // start point
            ctx.beginPath()
            ctx.moveTo(width / 2 + canvasMark.outerRadius * Math.cos(root.angleStart),
                       height / 2 + canvasMark.outerRadius * Math.sin(root.angleStart))
            ctx.lineTo(width / 2 + canvasMark.innerRadius * Math.cos(root.angleStart),
                       height / 2 + canvasMark.innerRadius * Math.sin(root.angleStart))
            ctx.stroke()
            ctx.closePath()

            // end point
            ctx.beginPath()
            ctx.moveTo(width / 2 + canvasMark.outerRadius * Math.cos(root.angleEnd),
                       height / 2 + canvasMark.outerRadius * Math.sin(root.angleEnd))
            ctx.lineTo(width / 2 + canvasMark.innerRadius * Math.cos(root.angleEnd),
                       height / 2 + canvasMark.innerRadius * Math.sin(root.angleEnd))
            ctx.stroke()
            ctx.closePath()

            if (root.additionalMarks) {
                // mark 1
                ctx.beginPath()
                ctx.moveTo(width / 2 + canvasMark.outerRadius * Math.cos(canvasMark.angleMark1),
                           height / 2 + canvasMark.outerRadius * Math.sin(canvasMark.angleMark1))
                ctx.lineTo(width / 2 + canvasMark.innerRadius * Math.cos(canvasMark.angleMark1),
                           height / 2 + canvasMark.innerRadius * Math.sin(canvasMark.angleMark1))
                ctx.stroke()
                ctx.closePath()

                // mark 2
                ctx.beginPath()
                ctx.moveTo(width / 2 + canvasMark.outerRadius * Math.cos(canvasMark.angleMark2),
                           height / 2 + canvasMark.outerRadius * Math.sin(canvasMark.angleMark2))
                ctx.lineTo(width / 2 + canvasMark.innerRadius * Math.cos(canvasMark.angleMark2),
                           height / 2 + canvasMark.innerRadius * Math.sin(canvasMark.angleMark2))
                ctx.stroke()
                ctx.closePath()
            }

            if (meterTickMark === true) {
                ctx.strokeStyle = "grey"
                ctx.beginPath()
                for (var i = 0; i < meterTickNumber; ++i) {
                    var markValue = root.angleStart + root.maxAngle * ((i + 1) / meterTickNumber)
                    var angleMark = root.angleStart + root.maxAngle * (markValue - root.angleStart) / root.maxAngle
                    ctx.moveTo(width / 2 + canvasMark.outerRadius * Math.cos(angleMark),
                               height / 2 + canvasMark.outerRadius * Math.sin(angleMark))
                    ctx.lineTo(width / 2 + canvasMark.innerRadius * Math.cos(angleMark),
                               height / 2 + canvasMark.innerRadius * Math.sin(angleMark))
                }
                ctx.stroke()
            }
        }
    }

    Text {
        id: markMin
        visible: !meter_background
        x: root.width / 2 + canvasMark.outerRadius * Math.cos(root.angleStart) - 18
        y: root.height / 2 + canvasMark.outerRadius * Math.sin(root.angleStart) + 25
        text: root.minValue.toFixed(0)
        font.family: defaultFontName
        font.pixelSize: 12
        horizontalAlignment: Text.AlignRight
    }
    Text {
        id: markMax
        visible: !meter_background
        x: root.width / 2 + canvasMark.outerRadius * Math.cos(root.angleEnd) + 4
        y: root.height / 2 + canvasMark.outerRadius * Math.sin(root.angleEnd) + 25
        text: root.maxValue.toFixed(0)
        font.family: defaultFontName
        font.pixelSize: 12
        horizontalAlignment: Text.AlignLeft
    }
    Text {
        id: markInt1
        visible: !meter_background
        x: root.width / 2 + canvasMark.outerRadius * Math.cos(canvasMark.angleMark1) - 12
        y: root.height / 2 + canvasMark.outerRadius * Math.sin(canvasMark.angleMark1) + 30
        text: root.mark1Value.toFixed(0)
        font.family: defaultFontName
        font.pixelSize: 12
        horizontalAlignment: Text.AlignLeft
    }
    Text {
        id: markInt2
        visible: !meter_background
        x: root.width / 2 + canvasMark.outerRadius * Math.cos(canvasMark.angleMark2) + 0
        y: root.height / 2 + canvasMark.outerRadius * Math.sin(canvasMark.angleMark2) + 30
        text: root.mark2Value.toFixed(0)
        font.family: defaultFontName
        font.pixelSize: 12
        horizontalAlignment: Text.AlignLeft
    }

    Text {
        id: txtValue
        text: root.floatPointPresentation? root.value.toExponential(1) : root.value.toFixed(1)
        anchors.centerIn: parent
        anchors.verticalCenterOffset: root.height * 0.1 + root.valueTextYOffset
        anchors.horizontalCenterOffset: root.valueTextXOffset
        font.family: defaultFontName
        font.pixelSize: root.valueFontSize
        color: meter_background ? "white" : "black"
    }
    Text {
        id: labelLevel
        visible: !meter_background
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.bottom: txtValue.top
        anchors.bottomMargin: 8
        font.family: defaultFontName
        font.pixelSize: 32
    }
    Text {
        id: labelUnit
        visible: !meter_background
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: root.unitTextOffset
        anchors.top: txtValue.bottom
        anchors.topMargin: -10
        font.family: defaultFontName
        font.pixelSize: 20
    }
}
