/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import "../parts"

Item {
    id: root
    width:background.width
    height:background.height

    property bool active: false
    property bool edit  : false
    property string background: "" // 背景
    property string activebg: ""   // active 背景
    property string idlebg: ""     // idle   背景
    property string editbg: ""     // edit   背景

    // 背景画像
    Image {
        id: background
        anchors.centerIn: root
        source: "qrc:/resource/png/" + root.background
    }

    // 編集可能エリア背景画像
    Image {
        id: editAreabg
        anchors.centerIn: editingArea
        source: {
            if (root.active) {
                if (edit) {
                    return "qrc:/resource/png/" + root.editbg
                }
                return "qrc:/resource/png/" + root.activebg
            }
            return "qrc:/resource/png/" + root.idlebg
        }
    }

    onEditChanged: {
        if (edit == true) {
            // 最初の項目を編集可能にする
            yeardata.active    = true;
            monthdata.active   = false;
            daydata.active     = false;
            hourdata.active    = false;
            minutesdata.active = false;
        } else {
            // 項目毎の部品は全て非表示
            yeardata.active    = false;
            monthdata.active   = false;
            daydata.active     = false;
            hourdata.active    = false;
            minutesdata.active = false;
        }
    }

    // ヘッダーエリア
    Rectangle {
        id: listHeaderArea
        anchors {
            top: root.top
            left: root.left
        }
        color: "transparent"
        height: 45
        width: 450
        // 年ヘッダー
        Text {
            id: yearmessage
            anchors {
                left:   parent.left
                top:    parent.top
                bottom: parent.bottom
            }
            width: 120
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            text: "年"
            color: "skyblue"
            font.family: defaultFontName
        }
        // 日付ヘッダー
        Text {
            id: datemessage
            anchors {
                top: parent.top
                bottom: parent.bottom
            }
            x: 150
            width: 120
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            text: "日付"
            color: "skyblue"
            font.family: defaultFontName
        }
        // 時刻ヘッダー
        Text {
            id: timemessage
            anchors {
                top: parent.top
                bottom: parent.bottom
            }
            x: 300
            width: 150
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            text:"時刻"
            color: "skyblue"
            font.family: defaultFontName
        }
    }

    // 編集可能エリア
    Rectangle {
        id: editingArea
        anchors {
            top: listHeaderArea.bottom
            left: listHeaderArea.left
        }
        color: "transparent"
        width: 461
        height: 60
        // 年 編集ボタン
        SelectButton {
            id: yeardata
            objectName: "yeardata"
            anchors {
                top   : parent.top
                bottom: parent.bottom
                left  : parent.left
            }
            width: 131
            activebg: "datetime_year_btn_r.png"
            idlebg: ""
            message:"2020年"
        }

        // 月編集ボタン
        SelectButton {
            id: monthdata
            objectName: "monthdata"
            anchors {
                top    : parent.top
                bottom : parent.bottom
            }
            x : 142
            width: 80
            message:"4月"
            activebg: "datetime_btn_lr.png"
            idlebg: ""
        }
        // 日編集ボタン
        SelectButton {
            id: daydata
            objectName: "daydata"
            anchors {
                top    : parent.top
                bottom : parent.bottom
            }
            x: 202
            width: 80
            message:"1日"
            activebg: "datetime_btn_lr.png"
            idlebg: ""
        }

        // 時編集ボタン
        SelectButton {
            id: hourdata
            objectName: "hourdata"
            anchors {
                top    : parent.top
                bottom : parent.bottom
            }
            x: 292
            width:80
            message: "10"
            activebg: "datetime_btn_lr.png"
            idlebg: ""
        }

        // コロン
        Text {
            anchors {
                top    : parent.top
                bottom : parent.bottom
            }
            x: 360
            width: 30
            verticalAlignment: Text.AlignVCenter
            horizontalAlignment: Text.AlignHCenter
            text: ":"
            font.family: defaultFontName
            font.pixelSize: 24
            color: "white"
        }

        // 分編集ボタン
        SelectButton {
            id: minutesdata
            objectName: "minutesdata"
            anchors {
                top: parent.top
                bottom: parent.bottom
            }

            x: 379
            width:80
            message: "59"
            activebg: "datetime_btn_l.png"
            idlebg: ""
        }
    }
}
