/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0

Item {
    id:root
    property string value: ""
    property bool edit: false      // 編集中かどうか
    property int displayMode: 1    // 表示モード
    property string normalbg: ""   // 編集中以外の状態にて表示する背景
    property string edittingbg: "" // 編集中の状態にて表示する背景

    readonly property int modeFM: 0             // 表示モード (FM)
    readonly property int modeCATVUPSTREAM: 1   // 表示モード (CATV上り)

    width: bg.width
    height: bg.height

    // 背景イメージ
    Image {
        id: bg
        source: "qrc:/resource/png/" + (root.edit ? root.edittingbg : root.normalbg)
        anchors {
            centerIn: parent
        }
    }

    onValueChanged: {
        // [Memo]
        // プロパティ visible = falseの場合は以降の処理は実施しない
        if (root.visible == true) {
            if (root.displayMode == root.modeCATVUPSTREAM && value.length == 5) {
                    edit1.message = value.substr(0, 1)
                    edit2.message = value.substr(1, 1)
                    edit3.message = value.substr(2, 1)
                    edit4.message = value.substr(3, 1)
                    edit5.message = value.substr(4, 1)
            } else if (root.displayMode == root.modeFM && value.length == 4){
                edit1.message = value.substr(0, 1)
                edit2.message = value.substr(1, 1)
                edit3.message = value.substr(2, 1)
                edit4.message = value.substr(3, 1)
            } else {
                // nothing to do
            }
        }
    }

    onEditChanged: {
        if (edit == true) {
            if (displayMode == modeFM) {
                edit1.active = true
                edit2.active = false
                edit3.active = false
                edit4.active = false
            } else {
                edit1.active = true
                edit2.active = false
                edit3.active = false
                edit4.active = false
                edit5.active = false
            }
        } else {
            if (displayMode == modeFM) {
                edit1.active = false
                edit2.active = false
                edit3.active = false
                edit4.active = false
            } else {
                edit1.active = false
                edit2.active = false
                edit3.active = false
                edit4.active = false
                edit5.active = false
            }
        }
    }

    Row {
        anchors.top: bg.top
        anchors.left: bg.left
        spacing: 0

        SelectButton {
            id: edit1
            objectName: "edit1"
            width: (displayMode == modeFM) ? 42 : 35
            height: (displayMode == modeFM) ? 52 : 45
            activebg: displayMode == root.modeFM ? "frequencyEdit_FM_r.png" : "frequencyEdit_CatvUpstream_r.png" // 編集時の背景画像
            idlebg: ""
            editMode: true
        }

        // 一の位
        SelectButton {
            id: edit2
            objectName: "edit2"
            width: (displayMode == modeFM) ? 42 : 35
            height: (displayMode == modeFM) ? 52 : 45
            activebg: displayMode == root.modeFM ? "frequencyEdit_FM_lr.png" : "frequencyEdit_CatvUpstream_lr.png" // 編集時の背景画像
            editMode: true
        }

        // 小数点等
        SelectButton {
            id:edit3
            objectName: "edit3"
            width: 26
            height: (displayMode == modeFM) ? 52 : 45
            editMode: true
        }

        // 小数点第１位
        SelectButton {
            id: edit4
            objectName: "edit4"
            width: (displayMode == modeFM) ? 42 : 35
            height: (displayMode == modeFM) ? 52 : 45
            activebg: displayMode == root.modeFM ? "frequencyEdit_FM_l.png" : "frequencyEdit_CatvUpstream_lr.png" // 編集時の背景画像
            editMode: true
        }

        // 小数点第２
        // 表示モードがFMの場合は表示しない
        SelectButton {
            id: edit5
            objectName: "edit5"
            width: (displayMode == modeFM) ?  42 : 35
            height: (displayMode == modeFM) ? 52 : 45
            activebg: "frequencyEdit_CatvUpstream_l.png" // 編集時の背景画像
            visible: root.displayMode == root.modeCATVUPSTREAM
            editMode: true
        }
    }
}
