//
//      (c) 2020 DX ANTENNA CO.,LTD.
//

import QtQuick 2.12

/**
 * @brief コンスタレーショングラフ QML
 */
Item {
    id: root

    property real cellLineWidth : 1.0
    property real rectLineWidth : 3.0
    property real axisLineWidth : 2.0

    property int axisAreaCellCount : 4  // xy-axisで区切られたエリアの縦横のセル数（縦横で同じ数とする／グラフ全体のセル総数は「縦：(axisAreaCellCount*2) x 横：(axisAreaCellCount*2)」となる）
    property real cellWidth : (width - ((rectLineWidth * 2) + axisLineWidth + (cellLineWidth * (axisAreaCellCount - 1) * 2))) / (axisAreaCellCount * 2)
    property real cellHeight : (height - ((rectLineWidth * 2) + axisLineWidth + (cellLineWidth * (axisAreaCellCount - 1) * 2))) / (axisAreaCellCount * 2)

    property real maxX: 80.0
    property real maxY: 80.0
    property real minX: -80.0
    property real minY: -80.0

    property real dotWidth : (width - (rectLineWidth * 2)) / (maxX - minX)
    property real dotHeight : (height - (rectLineWidth * 2)) / (maxY - minY)
    property real dotRadius : (height - (rectLineWidth * 2)) / (maxY - minY) * 1.5

    property bool isClear: false
    property variant consteData

    // 枠
    Canvas {
        anchors.fill: root
        antialiasing: true
        visible: false
        onPaint: {
            var ctx = getContext("2d")

            var rectLineWidthHalf = rectLineWidth * 0.5
            var cellLineWidthHalf = cellLineWidth * 0.5
            var axisLineWidthHalf = axisLineWidth * 0.5

            ctx.save()
            ctx.strokeStyle = "black"

            // 外枠
            ctx.lineWidth = rectLineWidth
            ctx.beginPath()
            ctx.rect(rectLineWidthHalf, rectLineWidthHalf, width - rectLineWidth, height - rectLineWidth)
            ctx.closePath()
            ctx.stroke()

            // axis
            ctx.lineWidth = axisLineWidth
            ctx.beginPath()
            var xaxis = width / 2
            ctx.moveTo(xaxis, 0)
            ctx.lineTo(xaxis, height)
            var yaxis = height / 2
            ctx.moveTo(0, yaxis)
            ctx.lineTo(width, yaxis)
            ctx.closePath()
            ctx.stroke()

            // cell - line
            ctx.lineWidth = cellLineWidth
            var i = 0
            var xBaseCellPoint = cellWidth + cellLineWidth
            var yBaseCellPoint = cellHeight + cellLineWidth
            var xpoint = 0.0
            var ypoint = 0.0

            ctx.beginPath()
            for (i = 0; i < axisAreaCellCount - 1; ++i) {
                xpoint = xBaseCellPoint * (i + 1) - cellLineWidthHalf + rectLineWidth
                ctx.moveTo(xpoint, 0)
                ctx.lineTo(xpoint, height)
                xpoint = xBaseCellPoint * (i + 1) - cellLineWidthHalf + xaxis + axisLineWidthHalf
                ctx.moveTo(xpoint, 0)
                ctx.lineTo(xpoint, height)

                ypoint = yBaseCellPoint * (i + 1) - cellLineWidthHalf + rectLineWidth
                ctx.moveTo(0, ypoint)
                ctx.lineTo(width, ypoint)
                ypoint = yBaseCellPoint * (i + 1) - cellLineWidthHalf + yaxis + axisLineWidthHalf
                ctx.moveTo(0, ypoint)
                ctx.lineTo(width, ypoint)
            }
            ctx.closePath()
            ctx.stroke()

            // cell - color
            ctx.fillStyle = "lightgray"
            var j = 0
            var xAxisPoint = xaxis + axisLineWidthHalf
            var yAxisPoint = yaxis + axisLineWidthHalf
            var drawRect = true
            var isOddAxisAreaCellCount = axisAreaCellCount % 2 === 0 ? false : true
            ctx.beginPath()
            for (i = 0; i < axisAreaCellCount; ++i) {
                xpoint = xBaseCellPoint * i
                for (j = 0; j < axisAreaCellCount; ++j) {
                    ypoint = yBaseCellPoint * j

                    if (drawRect === true) {
                        ctx.fillRect(xpoint + rectLineWidth, ypoint + rectLineWidth, cellWidth, cellHeight)
                        ctx.fillRect(xpoint + xAxisPoint, ypoint + yAxisPoint, cellWidth, cellHeight)
                    }
                    if ((isOddAxisAreaCellCount === false && drawRect === true) || (isOddAxisAreaCellCount === true && drawRect === false)) {
                        ctx.fillRect(xpoint + rectLineWidth, ypoint + yAxisPoint, cellWidth, cellHeight)
                        ctx.fillRect(xpoint + xAxisPoint, ypoint + rectLineWidth, cellWidth, cellHeight)
                    }
                    drawRect = !drawRect
                }
                if (axisAreaCellCount % 2 === 0) drawRect = !drawRect
            }
            ctx.closePath()
            ctx.fill()
            ctx.restore()
        }
    }

    // グラフ
    Canvas {
        id: canvasConste
        anchors.fill: root
        antialiasing: true
        onPaint: {
            var ctx = getContext("2d")
            ctx.save()
            if (root.isClear === true) ctx.clearRect(0, 0, width, height)
            ctx.fillStyle = "white"
            ctx.lineWidth = 1
            if (root.consteData !== undefined) {
                var graphAreaWidth = (width - (rectLineWidth * 2))
                var graphAreaHeight = (height - (rectLineWidth * 2))
                for (var i = 0; i < root.consteData.length; ++i) {
                    var data_x = (root.consteData[i].x - root.minX) * (graphAreaWidth / (root.maxX - root.minX)) + rectLineWidth
                    var data_y = graphAreaHeight - ((root.consteData[i].y - root.minY) * (graphAreaHeight / (root.maxY - root.minY))) + rectLineWidth
                    ctx.beginPath()
                    ctx.arc(data_x, data_y, dotRadius, 0, 360, false)
                    ctx.closePath()
                    ctx.fill()
                }
            }
            ctx.restore()
        }
    }
    function requestDrawConste() {canvasConste.requestPaint()}
}
