/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
import QtQuick.Controls 2.12

Item {
    id: root
    width: 120
    height: 40
    // パーツの描画範囲外に画像がはみ出しているため、Zオーダーの都合で、後から配置したパーツにより
    // 画像が隠されてしまう（下向きの矢印部分）
    // それを避けるため、アクティブになっているときだけZオーダーを上げ、他のパーツに隠されないようにする
    z: active ? 2 : 1

    property bool active: false
    property bool disable: false
    property bool light: true
    property bool pressed: false
    property bool selected: false
    property string message: ""
    property string activeBackgroundImage: ""
    property string backgroundColor: (light) ? "#626672" : "#5A5E6A"
    property string iconImage: ""
    property bool backspace: false
    property string text: ""
    property bool leftPosition: false

    readonly property int fontSize: 15
    readonly property string activeBackgroundColor: "transparent"
    readonly property string pressedBackgroundColor: "#80BFFF"
    readonly property string selectedBackgroundColor: "#275B94"

    onActiveChanged: {
        if (active) {
            base.color = root.activeBackgroundColor
        } else {
            base.color = (selected) ? root.selectedBackgroundColor : root.backgroundColor
        }
    }

    onPressedChanged: {
        if (pressed === true) {
            base.color = root.pressedBackgroundColor
        } else {
            base.color = root.activeBackgroundColor
        }
    }

    onSelectedChanged: {
        if (selected) {
            base.color = (active) ? root.activeBackgroundColor : root.selectedBackgroundColor
        } else {
            base.color = root.backgroundColor
        }
    }

    Rectangle {
        id: foundation
        anchors.fill: parent
        clip: false

        // アクティブ時の枠
        Image {
            id: activeBackground
            width: 130
            height: 56
            x: 0
            y: -8
            source: root.activeBackgroundImage
            visible: root.active
        }

        Rectangle {
            id: base
            anchors.fill: parent
            color: root.backgroundColor
            // アイコン(BS, 矢印)
            Image {
                id: icon
                source: root.iconImage
                width: (root.iconImage === "") ? 0 : (root.backspace) ? 39 : 20
                height: (root.iconImage === "") ? 0 : (root.backspace) ? 26 : 20
                x: 10
                y: (parent.height - icon.height) / 2
            }

            // ラベル
            Label {
                id: message
                width: parent.width - icon.width
                height: parent.height
                anchors.top: parent.top
                anchors.left: icon.right
                anchors.leftMargin: (!leftPosition) ? 8 : 32
                color: "#E6E6E6"
                text: root.text
                verticalAlignment: Text.AlignVCenter
                font.pixelSize: root.fontSize
                font.family: defaultFontName
                font.underline: root.selected
            }
        }
    }

    // disable
    Rectangle {
        id: disable_cover
        anchors.fill: parent
        visible: root.disable
        color: "#18191D"
        opacity: 0.5
    }
}
