/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
import QtQuick.Window 2.12
import QtQuick.Controls 2.12

Item {
    id: levelGauge
    width: 398
    height: 398
    property alias levelGradation: levelGradation
    readonly property real minimum: 20.0        // 最小値
    readonly property real maximum: 120.0       // 最大値
    property double redZoneRatio: 0.2           // ゲージに表示する赤の割合(最大値 1.0 とする)
    property double yellowZoneRatio: 0.3        // ゲージに表示する青の割合(最大値 1.0 とする)
    property string value: "00.0"               // 測定レベルの値(小数点第 1 位まで)
    property real needlePosition: 0             // 針の位置(0〜140)
    property string band: "地上デジタル"                                      // バンド
    property string channel: ""                                             // チャンネル
    property string frequency: "473.143"                                    // 中心周波数周波数
    property string displayfrequencyUnit: "MHz"                             // 中心周波数表示単位
    property string modulation:   ""                                        // 変調方式
    property string modulationPrefix: ""                                    // 変調方式の接頭句
    property string hierarchy:    "B"                                       // 階層
    property bool isSatelliteBroadCasting: false                            // 衛星放送かどうか
    property bool isDisplaylevelHierarchyPolarization: true                 // 階層/ 偏波を表示するかどうか
    property string localFrequency: ""                                      // 局部発振周波数
    property string polarization: ""                                        // 偏波
    property var scales: [20, 30, 40, 50, 60, 70, 80, 90, 100, 110, 120]    // 目盛り
    property bool isModulationVisible: true                                 // 変調方式表示,非表示切り替えフラグ (True: 表示, False: 非表示)

    property int displayModulationPrefixMode: 0            //!< 変調方式 表示モード 接頭句と変調方式をどのように表示するかを決める
    readonly property int modulationDisplayModeTogether: 0 //!< 変調方式 表示モード 接頭句 変調方式を１つのラベルに纏めて表示する
    readonly property int modulationDisplayModeSeparate: 1 //!< 変調方式 表示モード 接頭句 変調方式を個別のラベルに分けて表示する
    property bool frequencyComboboxVisible: false          //!< 変調方式変更部品を表示するかどうか
    property bool editFrequencyCombobox: false             //!< 周波数コンボボックスを操作中かどうか
    property int blinkInterval: 0                          //!< 点滅間隔
    onBlinkIntervalChanged: {
// Level の点滅をコメントアウト
//        if (blinkInterval == 0) {
//            timer.stop()
//            levelValue.visible = true
//        } else {
//            timer.start()
//        }
    }

    // 定数
    Item {
        id: constant
        readonly property double startAngle: -Math.PI * 1.196    // 円弧の開始角度
        readonly property double endAngle: Math.PI * 0.196       // 円弧の終了角度
    }

    Rectangle {
        width: 398
        height: 398
        x: (parent.width - width) / 2
        y: 11
        color: "transparent"

        // 通常のゲージ
        Canvas {
            id: gauge
            anchors.fill: parent
            onPaint: {
                var ctx = getContext("2d");
                ctx.save()

                ctx.beginPath()
                ctx.lineWidth = 32
                // 弧全体を塗る(赤)
                ctx.arc(width / 2, height / 2, width / 2.18, constant.startAngle, constant.endAngle, false)
                ctx.strokeStyle = "#AF052A"
                ctx.stroke()
                ctx.closePath()

                // 注意は使用していない

                // 受信可(青)
                var ctxSafe = getContext("2d");
                ctxSafe.save()

                ctxSafe.beginPath()
                ctxSafe.lineWidth = 32
                ctxSafe.arc(width / 2, height / 2, width / 2.18, constant.startAngle + (Math.PI * 1.392 *　levelGauge.redZoneRatio), constant.startAngle + (Math.PI * 1.392 *　(levelGauge.redZoneRatio + levelGauge.yellowZoneRatio)), false)
                ctxSafe.strokeStyle = "#5A9AD7"
                ctxSafe.stroke()
                ctxSafe.closePath()
            }
        }
    }



    Rectangle{
        x: 100
        y: 192
        width: 200
        height: 3
        color:"#E4E6E5"
    }

    Image {
        id: levelmeter
        x: -3
        y: 9
        width: 404
        height: 402
        source: "qrc:/resource/png/level_meter.png"
    }
    // 枠
    Image {
        id: levelFrame
        x: -5
        y: 10
        //source: "qrc:/resource/png/level_frame.png"

        // LEVEL
        Label {
            id: levelLabel
            width: 80
            height: 20
            x: 174
            y: 80
            text: "LEVEL"
            font.family: defaultFontName
            font.pixelSize: 20
            color: "#419FFF"
        }

        // 値
        Text {
            id: levelValue
            width: 180
            height: 62
            x: 113
            y: 100
            text: levelGauge.value
            font.family: defaultFontName
            font.pixelSize: 64
            horizontalAlignment: Text.AlignRight
            color: "#E4E6E5"
        }

        // 単位
        Label {
            id: levelUnit
            width: 30
            height: 20
            x: 260
            y: 162
            text: "dBμV"
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // Band
        Label {
            id: levelBand
            width: 100
            height: 16
            x: 152
            y: 192
            text: levelGauge.band
            horizontalAlignment: Qt.AlignHCenter
            font.family: defaultFontName
            font.pixelSize: 16
            color: "#E4E6E5"
        }

        // チャンネル/周波数
        Text {
            id: levelChannel
            width: 128
            height: 48
            x: (levelGauge.band != "PILOT" && levelGauge.band != "CATV上り") ? 134 : 120
            y: 212
            text: levelGauge.channel
            horizontalAlignment: Text.AlignHCenter
            font.family: defaultFontName
            font.pixelSize: 48
            color: "#E4E6E5"
            visible: !levelGauge.frequencyComboboxVisible
        }

        // 周波数選択コンボボックス
        FrequencyCombobox {
            id: frequencyCombobox
            objectName: "frequencyCombobox"
            x: 110
            y: 212
            edit: levelGauge.editFrequencyCombobox
            normalbg: (levelGauge.band == "FM") ? "frequency_FM_active.png" : "frequency_CatvUpstream_active.png"
            edittingbg: (levelGauge.band == "FM") ? "frequency_FM_edit.png" : "frequency_CatvUpstream_edit.png"
            displayMode: (levelGauge.band == "FM") ? 0 : 1
            visible: levelGauge.frequencyComboboxVisible
        }

        // チャンネル/周波数 単位
        Label {
            id: levelChannelUnit
            width: 30
            height: 16
            x: (levelGauge.band != "PILOT" && levelGauge.band != "CATV上り" && levelGauge.band != "FM") ? 275 : 285
            y: 243
            text: (levelGauge.band != "FM" && levelGauge.band != "PILOT" && levelGauge.band != "CATV上り") ? "CH" : "CH"  // FM、PILOT、CATV上りのときは MHz
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 周波数
        Label {
            id: levelFrequencyLabel
            width: contentWidth
            height: 16
            x: 120
            y: 264
            text: "周波数"
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 周波数 コロン
        Text {
            id: levelFrequencyCoron
            anchors {
                top: levelFrequencyLabel.top
                left: levelFrequencyLabel.right
                leftMargin: 20
            }
            width: contentWidth
            height:16
            text: ":"
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 周波数 値
        Text {
            id: levelFrequency
            anchors {
                top: levelFrequencyLabel.top
                left: levelFrequencyCoron.right
                leftMargin: 10
            }

            width: contentWidth
            height: 16
            text: levelGauge.frequency
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 周波数単位
        Label {
            id: levelFrequencyUnit
            anchors {
                top: levelFrequency.top
                left: levelFrequency.right
                leftMargin: 10
            }
            width: 30
            height: 16
            text: levelGauge.displayfrequencyUnit
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 変調方式ラベル
        Label {
            id: levelModulationLabel
            width: contentWidth
            height: 16
            anchors.left :levelFrequencyLabel.left
            y: 282
            text: "変調方式"
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
            visible: levelGauge.isModulationVisible
        }

        // 変調方式 コロン
        Text {
            id: levelModulationCoron
            anchors {
                top: levelModulationLabel.top
                left: levelFrequencyCoron.left
            }
            width: contentWidth
            height:16
            text: ":"
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
            visible: levelGauge.isModulationVisible
        }

        // 変調方式 接頭句
        Text {
            id: levelModulationPrefix
            anchors {
                top: levelModulationLabel.top
                left: levelFrequency.left
            }
            width: contentWidth
            height: visible ? 16 : 0
            text: levelGauge.modulationPrefix
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
            visible: (text == "") ? false : true
        }

        // 変調方式 設定値
        Text {
            id: levelModulation
            anchors {
                top: levelModulationPrefix.bottom
                left: levelFrequency.left
            }
            width: contentWidth
            height: 16
            text: levelGauge.modulation
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
            visible: levelGauge.isModulationVisible
        }

        // 階層/偏波ラベル
        Label {
            id: levelHierarchyPolarizationLabel
            width: contentWidth
            height: 16
            anchors.left: levelFrequencyLabel.left
            y: levelModulationPrefix.visible ? 318 : 300
            text: levelGauge.isSatelliteBroadCasting ? "偏波" : "階層"
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
            verticalAlignment: Text.AlignVCenter
            visible: levelGauge.isDisplaylevelHierarchyPolarization
        }

        // 階層/偏波 コロン
        Text {
            id: levelHierarchyPolarizationCoron
            anchors {
                top: levelHierarchyPolarizationLabel.top
                left: levelFrequencyCoron.left
            }
            width: contentWidth
            height:16
            text: ":"
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
            visible: levelHierarchyPolarizationLabel.visible
        }

        // 階層/偏波
        Text {
            id: levelHierarchyPolarization
            width: contentWidth
            height: 16
            anchors {
                top: levelHierarchyPolarizationLabel.top
                left: levelFrequency.left
            }
            y: 300
            text: levelGauge.isSatelliteBroadCasting ? levelGauge.polarization : levelGauge.hierarchy
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
            verticalAlignment: Text.AlignVCenter
            visible: levelHierarchyPolarizationLabel.visible
        }

        // 局発周波数ラベル
        Label {
            id: levelLocalOscillatorLabel
            width: contentWidth
            height: 16
            anchors.left: levelFrequencyLabel.left
            y: levelHierarchyPolarizationLabel.visible ? 318 : 300
            text: "局発"
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
            verticalAlignment: Text.AlignVCenter
            visible: levelGauge.isSatelliteBroadCasting
        }

        // 局発周波数 コロン
        Text {
            id: levelLocalOscillatorCoron
            anchors {
                top: levelLocalOscillatorLabel.top
                left: levelFrequencyCoron.left
            }
            width: contentWidth
            height:16
            text: ":"
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
            visible: levelLocalOscillatorLabel.visible
        }

        // 局発周波数
        Text {
            id: levelLocalOscillator
            width: contentWidth
            height: 16
            anchors {
                top: levelLocalOscillatorLabel.top
                left: levelFrequency.left
            }
            text: levelGauge.localFrequency
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
            verticalAlignment: Text.AlignVCenter
            visible: levelLocalOscillatorLabel.visible
        }

        // 局部発振周波数単位
        Text {
            id: levelLocalOscillatorUnit
            width: contentWidth
            height: 16
            anchors {
                top: levelLocalOscillatorLabel.top
                left: levelFrequencyUnit.left
            }
            text: "GHz"
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
            visible: levelLocalOscillatorLabel.visible
        }

        // グラデーション
        Image {
            id: levelGradation
            width: 387
            height: 311
            anchors.verticalCenterOffset: 160
            anchors.horizontalCenterOffset: 205
            anchors.centerIn: parent
            source: "qrc:/resource/png/level_gradation.png"
        }

        // 補助目盛り
        Image {
            id: levelStep
            anchors.verticalCenterOffset: 160
            anchors.horizontalCenterOffset: 204
            anchors.centerIn: parent
            source: "qrc:/resource/png/level_step.png"
            //visible: false
        }

        //　目盛り
        Image {
            id: levelScale
            anchors.centerIn: parent
            source: "qrc:/resource/png/level_scale.png"
            visible:false
        }

        // 目盛り 1
        Label {
            width: 20
            height: 16
            x: 60
            y: 290
            text: levelGauge.scales[0]
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 目盛り 2
        Label {
            width: 20
            height: 16
            x: 34
            y: 222
            text: levelGauge.scales[1]
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 目盛り 3
        Label {
            width: 20
            height: 16
            x: 34
            y: 148
            text: levelGauge.scales[2]
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 目盛り 4
        Label {
            width: 20
            height: 16
            x: 64
            y: 86
            text: levelGauge.scales[3]
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 目盛り 5
        Label {
            width: 20
            height: 16
            x: 122
            y: 41
            text: levelGauge.scales[4]
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 目盛り 6
        Label {
            width: 20
            height: 16
            x: 195
            y: 28
            text: levelGauge.scales[5]
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 目盛り 7
        Label {
            width: 20
            height: 16
            x: 264
            y: 41
            text: levelGauge.scales[6]
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 目盛り 8
        Label {
            width: 20
            height: 16
            x: 324
            y: 86
            text: levelGauge.scales[7]
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 目盛り 9
        Label {
            width: 20
            height: 16
            x: 350
            y: 148
            text: levelGauge.scales[8]
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 目盛り 10
        Label {
            width: 20
            height: 16
            x: 350
            y: 222
            text: levelGauge.scales[9]
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 目盛り 10
        Label {
            width: 20
            height: 16
            x: 324
            y: 290
            text: levelGauge.scales[10]
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }
    }

    // 針
    Image {
        id: levelNeedle
        width: 16
        height: 396
        x: parent.width / 2
        y: 16
        source: "qrc:/resource/png/level_needle.png"
        transform: Rotation {
            id: levelNeedleRotation
            angle: levelGauge.needlePosition
            origin.x: levelNeedle.width / 2 - 9     // 回転の中心 X 座標の調整
            origin.y: levelNeedle.height / 2 - 4    // 回転の中心 Y 座標の調整
        }

    }

    // 点滅用タイマー
    Timer {
        id: timer
        interval: levelGauge.blinkInterval
        running: false
        repeat: true
        onTriggered: {
            levelValue.visible = !levelValue.visible
        }
    }

    function updateLevel(level, levelNeedlePosition) {
        levelGauge.value = level
        levelGauge.needlePosition = levelNeedlePosition
    }

    function updateThreshold(red, yellow)
    {
        redZoneRatio = red
        yellowZoneRatio = yellow
        gauge.requestPaint()
    }
}
