import QtQuick 2.0

// LevelNeedle は初期状態は横長の矩形
// 幅は中心点から needle の先端までの長さで outerRadius に設定する
// 高さは needleBaseHeight
// 先端部分に needle の矩形を横向きに描画する
// 実際の表示は angleValue による回転をおこなっている

Item {
    readonly property int outerRadius: 180                  // LevelNeedle の幅
    readonly property int needleTipLength: 10               // 針の先端の長さ
    readonly property int needleBaseHeight: 12              // 針の高さ
    readonly property int needleLength: 40                  // 針の長さ
    readonly property real angleStart: -Math.PI * 1.19      // 針の開始位置
    readonly property real angleEnd: Math.PI * 0.16         // 針の終了位置
    readonly property real maxAngle: angleEnd - angleStart  // 針の角度

    property real minimum: 20.0                             // 最小値
    property real maximum: 120.0                            // 最大値
    property real value: 0.0                                // 針の値
    property real angleValue: angleStart + maxAngle * Math.min(Math.max(value - minimum, 0.0) / (maximum - minimum), 1.0)

    width: outerRadius
    height: needleBaseHeight

    x: levelFrame.x + levelFrame.width / 2
    y: levelFrame.y + levelFrame.height / 2 - height / 2 + 50　// 50は位置補正のための数値

    onValueChanged: {
        canvasLevelNeedle.requestPaint()
    }

    // 針
    Canvas {
        id: canvasLevelNeedle
        width: needleLength
        height: needleBaseHeight
        x: parent.width - needleLength
        y: 0
        enabled: false

        onPaint: {
            var ctx = getContext("2d");
            ctx.reset();
            ctx.beginPath()
            ctx.lineTo(needleLength - needleTipLength, 0)
            ctx.lineTo(needleLength, needleBaseHeight / 2)
            ctx.lineTo(needleLength - needleTipLength, needleBaseHeight)
            ctx.lineTo(0, needleBaseHeight)
            ctx.lineTo(0, 0)
            ctx.closePath()
            ctx.strokeStyle = "#95989D"
            ctx.fillStyle = "#FBF9FA"
            ctx.fill()
            ctx.stroke()
        }
    }
    transform:Rotation {
        angle: (angleValue) * (180) / Math.PI
    }
}
