/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import "../parts"

Item {
    id: root
    width: 608
    height: 105

    property bool active: false
    property bool edit: false
    property string background: "" // 背景
    property string activebg: ""   // active 背景
    property string idlebg: ""     // idle 背景
    property string editbg: ""     // edit 背景

    // 背景画像
    Image {
        id: background
        anchors {
            top: listHeaderArea.top
            left: listHeaderArea.left
        }
        source: "qrc:/resource/png/" + root.background
    }

    // 編集可能エリア背景画像
    Image {
        id: editAreabg
        anchors {
            top: editList.top
            left: editList.left
        }
        source: {
            if (root.active) {
                if (edit) {
                    return "qrc:/resource/png/" + editbg
                }
                return "qrc:/resource/png/" + activebg
            }
            return "qrc:/resource/png/" + idlebg
        }
    }

    onEditChanged: {
        if (edit == true) {
            // 最初の項目を編集可能にする
            correctswitch.active = true
            levelvalue1.active = false
            levelvalue2.active = false
            levelvalue3.active = false
            levelvalue4.active = false
        } else {
            // 項目毎の部品は全て非表示
            correctswitch.active = false
            levelvalue1.active = false
            levelvalue2.active = false
            levelvalue3.active = false
            levelvalue4.active = false
        }
    }

    // ヘッダーエリア
    Rectangle {
        id: listHeaderArea
        anchors {
            left: background.left
        }

        height: 45
        width: 600
        color: "transparent"

        // 補正 ヘッダー
        Text {
            id: correctmessage
            anchors {
                left:   parent.left
                top:    parent.top
                bottom: parent.bottom
            }
            width: 120
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            text: "補正"
            color: "skyblue"
            font.family: defaultFontName
            font.pixelSize: 21
        }

        // 10MHz ヘッダー
        Text {
            id: level1Header
            anchors {
                top: parent.top
                bottom: parent.bottom
                left: correctmessage.right
            }
            width: 120
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            text : "10MHz"
            color: "skyblue"
            font.family: defaultFontName

            font.pixelSize: 21
        }

        // 770MHz ヘッダー
        Text {
            id: level2Header
            anchors {
                top: parent.top
                bottom: parent.bottom
                left: level1Header.right
            }
            width: 120
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            text: "770MHz"
            color: "skyblue"
            font.family: defaultFontName
            font.pixelSize: 21
        }

        // 950MHzヘッダー
        Text {
            id: level3Header
            anchors {
                top: parent.top
                bottom: parent.bottom
                left: level2Header.right
            }
            width: 120
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            text: "950MHz"
            color: "skyblue"
            font.family: defaultFontName
            font.pixelSize: 21
        }

        // 3224MHzヘッダー
        Text {
            id: level4Header
            anchors {
                top:parent.top
                bottom: parent.bottom
                left: level3Header.right
                right: parent.right
            }
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            text: "3224MHz"
            color: "skyblue"
            font.family: defaultFontName
            font.pixelSize: 21
        }
    }

    Rectangle {
        id: editList
        objectName: "editList"
        anchors {
            top: listHeaderArea.bottom
            left: listHeaderArea.left
        }
        width: 600
        height: 60
        color: "transparent"

        // 補正 ボタン
        SelectButton {
            id: correctswitch
            objectName: "correctswitch"
            anchors {
                top: parent.top
                bottom: parent.bottom
                left: parent.left

            }
            leftpos:-9
            width: 130
            activebg: "leveloffset_cur_r.png"
            idlebg: ""
            message:"ON"
        }

        // 10MHz ボタン
        SelectButton {
             id: levelvalue1
             objectName: "levelvalue1"
             anchors {
                 top: parent.top
                 bottom: parent.bottom
             }
             leftpos:-9
             x: 115
             width: 140
             message:"0.1 db"
             activebg: "leveloffset_cur_lr.png"
             idlebg: ""
         }

        // 770MHz ボタン
         SelectButton {
             id: levelvalue2
             objectName: "levelvalue2"
             anchors {
                 top: parent.top
                 bottom: parent.bottom
             }
             leftpos:-9
             x: 235
             width: 140
             message:"0.1 db"
             activebg: "leveloffset_cur_lr.png"
             idlebg: ""
         }

         // 950MHz ボタン
         SelectButton {
             id: levelvalue3
             objectName: "levelvalue3"
             anchors {
                 top: parent.top
                 bottom: parent.bottom
             }
             leftpos:-9
             x: 355
             width: 140
             message:"0.1 db"
             activebg: "leveloffset_cur_lr.png"
             idlebg: ""
         }

         // 3224MHz ボタン
         SelectButton {
             id: levelvalue4
             objectName: "levelvalue4"
             anchors {
                 top: parent.top
                 bottom: parent.bottom
             }
             leftpos:-9
             x: 480
             width: 130
             message:"0.1 db"
             activebg: "leveloffset_cur_l.png"
             idlebg: ""
         }
    }
}
