/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import QtQuick.Controls 2.12

/**
 * @brief 局部発振周波数 項目内容
 */
Item {
    id: root
    property string value: ""
    property bool active: false
    property bool edit: false
    property int itemHeight
    property string activebg // active 背景
    property string idlebg   // idle 背景
    property string editbg   // edit 背景
    property bool isTop
    property string number: ""
    property string broadcasting: ""
    property bool dataExist: true
    height : itemHeight
    //背景イメージ
    Image {
        id: backgroundImage
        source: root.active ? ("qrc:/resource/png/" + (root.edit ? root.editbg : root.activebg)) : ""
        anchors {
            left: root.left
            top: root.top
            topMargin: root.isTop ? 0 : -8
        }
    }

    // 1行のデータ
    Row {
        // 番号項目
        Label {
            id: numberlabel
            text: root.number
            verticalAlignment: Text.AlignVCenter
            horizontalAlignment: Text.AlignHCenter
            font.pixelSize: 16
            font.family: defaultFontName
            width: 50
            height: root.itemHeight
            color: "skyblue"
        }

        // 放送方式項目
        Label {
            id: broadcastinglabel
            width: 278
            height: root.itemHeight
            verticalAlignment: Text.AlignVCenter
            horizontalAlignment: Text.AlignLeft
            font.pixelSize: 16
            font.family: defaultFontName
            color: "skyblue"
            text: root.broadcasting
        }

        // 局部発振周波数 (編集領域)
        LocalOscillatorEdit {
            id : editArea
            value : root.value
            edit : root.edit
            edit1idlebg: ""
            edit1activebg: "threshold_number_cur_r.png"
            edit2idlebg: ""
            edit2activebg: "threshold_number_cur_lr.png"
            edit3idlebg: ""
            edit3activebg: "threshold_number_cur_lr.png"
            edit4idlebg: ""
            edit4activebg: "threshold_number_cur_lr.png"
            edit5idlebg: ""
            edit5activebg: "threshold_number_cur_lr.png"
            edit6idlebg: ""
            edit6activebg: "threshold_number_cur_l.png"

            onValueChanged: {
                root.value = editArea.value
            }
            visible: dataExist
        }

        // 局部周波数単位ラベル
        Label {
            id: broadcastingUnitLabel
            height: root.itemHeight
            width: 80
            verticalAlignment: Text.AlignVCenter
            horizontalAlignment: Text.AlignHCenter
            leftPadding: 20
            font.pixelSize: 16
            font.family: defaultFontName
            color: "white"
            text: "GHz"
            visible: dataExist
        }
    }
}
