/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
import QtQuick.Window 2.12
import QtQuick.Controls 2.12

Item {
    id: merGauge
    width: 296
    height: 296
    readonly property real minimum: 5.0         // 最小値
    readonly property real maximum: 35.0        // 最大値
    property int selectCnMer: 1                 // CN/MERの選択状態
    property double redZoneRatio: 0.3           // ゲージに表示する赤の割合(最大値 1.0 とする)
    property double yellowZoneRatio: 0.2        // ゲージに表示する黃の割合(最大値 1.0 とする)
    property string value: "---"                // 測定レベルの値(小数点第 1 位まで)
    property real needlePosition: 0             // 針の位置
    property var scales: []                     // 目盛りに表示する文字列リスト
    property string band: "地上デジタル"          // バンド
    property int blinkInterval: 0               //!< 点滅間隔
    onBlinkIntervalChanged: {
        if (blinkInterval == 0) {
            timer.stop()
            merValue.visible = true
        } else {
            timer.start()
        }
    }

    onScalesChanged: {
        if (merGauge.scales.length == 0) {
            // Stepラベルを非表示にする
            scaleLabel1.text = ""
            scaleLabel2.text = ""
            scaleLabel3.text = ""
            scaleLabel4.text = ""
            scaleLabel5.text = ""
            scaleLabel6.text = ""
            scaleLabel7.text = ""
            scaleLabel8.text = ""
            scaleLabel9.text = ""

            scaleLabel1.visible = false
            scaleLabel2.visible = false
            scaleLabel3.visible = false
            scaleLabel4.visible = false
            scaleLabel5.visible = false
            scaleLabel6.visible = false
            scaleLabel7.visible = false
            scaleLabel8.visible = false
            scaleLabel9.visible = false
        }else if (merGauge.scales.length == 7) {
            // 目盛りに対して表示文字列の切り替え
            scaleLabel1.text = merGauge.scales[0]
            scaleLabel2.text = merGauge.scales[1]
            scaleLabel4.text = merGauge.scales[2]
            scaleLabel5.text = merGauge.scales[3]
            scaleLabel6.text = merGauge.scales[4]
            scaleLabel8.text = merGauge.scales[5]
            scaleLabel9.text = merGauge.scales[6]

            // 目盛りに対してvisibleの切り替え
            scaleLabel1.visible = true
            scaleLabel2.visible = true
            scaleLabel3.visible = false
            scaleLabel4.visible = true
            scaleLabel5.visible = true
            scaleLabel6.visible = true
            scaleLabel7.visible = false
            scaleLabel8.visible = true
            scaleLabel9.visible = true

            merStep.source  = "qrc:/resource/png/mer_step_7.png"
            merScale.source = "qrc:/resource/png/mer_scale_7.png"
            merFrame.source = "qrc:/resource/png/mer_meter_7.png"
        } else if (merGauge.scales.length == 5) {
            // 目盛りに対して表示文字列の切り替え
            scaleLabel1.text = merGauge.scales[0]
            scaleLabel3.text = merGauge.scales[1]
            scaleLabel5.text = merGauge.scales[2]
            scaleLabel7.text = merGauge.scales[3]
            scaleLabel9.text = merGauge.scales[4]

            // 目盛りに対してvisibleの切り替え
            scaleLabel1.visible = true
            scaleLabel2.visible = false
            scaleLabel3.visible = true
            scaleLabel4.visible = false
            scaleLabel5.visible = true
            scaleLabel6.visible = false
            scaleLabel7.visible = true
            scaleLabel8.visible = false
            scaleLabel9.visible = true

            merStep.source  = "qrc:/resource/png/mer_step_5.png"
            merScale.source = "qrc:/resource/png/mer_scale_5.png"
            merFrame.source = "qrc:/resource/png/mer_meter_5.png"
        } else {
            // nothing to do
        }
    }

    // 定数
    Item {
        id: constant
        readonly property double startAngle: Math.PI * 0.51     // 円弧の開始角度
        readonly property double endAngle: -Math.PI * 0.51      // 円弧の終了角度
    }

    Item {
        width: parent.width
        height: parent.height
        x: (parent.width - width) / 2
        y: 45
        // 通常のゲージ
        Canvas {
            id: gauge
            anchors.rightMargin: 0
            anchors.bottomMargin: 0
            anchors.leftMargin: 0
            anchors.topMargin: 0
            anchors.fill: parent
            onPaint: {
                // 通常
                var ctxGreen = getContext("2d");
                ctxGreen.save()

                ctxGreen.beginPath()
                ctxGreen.lineWidth = 32
                ctxGreen.arc(width / 2, height / 2, width / 2.32, constant.startAngle, constant.endAngle, false)
                ctxGreen.strokeStyle = "#198006"
                ctxGreen.stroke()
                ctxGreen.closePath()

                // 注意
                var ctxYellow = getContext("2d");
                ctxYellow.save()
                ctxYellow.beginPath()
                ctxYellow.lineWidth = 32
                ctxYellow.arc(width / 2, height / 2, width / 2.32, constant.startAngle + (Math.PI * 0.98 *　merGauge.redZoneRatio), constant.startAngle + (Math.PI * 0.98 * merGauge.yellowZoneRatio), false)
                ctxYellow.strokeStyle = "#9B9012"
                ctxYellow.stroke()
                ctxYellow.closePath()

                // 危険
                var ctxRed = getContext("2d");
                ctxRed.save()

                ctxRed.beginPath()
                ctxRed.lineWidth = 32
                ctxRed.arc(width / 2, height / 2, width / 2.32, constant.startAngle, constant.startAngle + (Math.PI * 0.98 * merGauge.redZoneRatio), false)
                ctxRed.strokeStyle = "#AF052A"
                ctxRed.stroke()
                ctxRed.closePath()
            }
        }
    }


    // 枠
    Image {
        id: levelFrame
        width: 150
        height: 296
        sourceSize.width: 191
        x: 1
        y: 44
        //source: "qrc:/resource/png/mer_meter_mix.png"
        //visible: false
        // MER/CNラベル
        Label {
            id: mercnLabel
            width: 80
            height: 20
            x: 114
            y: 100
            text: (merGauge.selectCnMer=== 1) ? "MER" : "CN"
            font.family: defaultFontName
            font.pixelSize: 20
            color: "#419FFF"
        }

        // 値
        Text {
            id: merValue
            width: 80
            height: 40
            x: 96
            y: 135
            text: merGauge.value
            font.family: defaultFontName
            font.pixelSize: 34
            horizontalAlignment: Text.AlignRight
            color: "#E4E6E5"
        }

        // dB
        Label {
            id: merDB
            width: 20
            height: 20
            x: 156
            y: 172
            text: "dB"
            font.family: defaultFontName
            font.pixelSize: 14
            font.bold: true
            color: "#E4E6E5"
        }

        // グラデーション
        Image {
            id: merGradation
            x: 17
            width: 136
            height: 279
            anchors.verticalCenterOffset: 2
            anchors.horizontalCenterOffset: 2
            anchors.centerIn: parent
            source: "qrc:/resource/png/mer_gradation.png"
        }

        // 補助目盛り
        Image {
            id: merStep
            anchors.centerIn: parent
            source: "qrc:/resource/png/mer_step_5.png"
            visible:false
        }

        //　目盛り
        Image {
            id: merScale
            width: 137
            height: 284
            anchors.verticalCenterOffset: 1
            anchors.horizontalCenterOffset: 0
            anchors.centerIn: parent
            source: "qrc:/resource/png/mer_scale_5.png"

        }

        // 目盛り 1
        Label {
            id: scaleLabel1
            width: 20
            height: 16
            x: 134
            y: 252
            text: ""
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 目盛り 2
        Label {
            id: scaleLabel2
            width: 20
            height: 16
            x: 84
            y: 234
            text: ""
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 目盛り 3
        Label {
            id: scaleLabel3
            width: 20
            height: 16
            x: 60
            y: 218
            text: ""
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 目盛り 4
        Label {
            id: scaleLabel4
            width: 20
            height: 16
            x: 47
            y: 194
            text: ""
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 目盛り 5
        Label {
            id: scaleLabel5
            width: 20
            height: 16
            x: 26
            y: 140
            text: ""
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 目盛り 6
        Label {
            id: scaleLabel6
            width: 20
            height: 16
            x: 47
            y: 84
            text: ""
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 目盛り 7
        Label {
            id: scaleLabel7
            width: 20
            height: 16
            x: 60
            y: 60
            text: ""
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }
        // 目盛り 8
        Label {
            id: scaleLabel8
            width: 20
            height: 16
            x: 84
            y: 44
            text: ""
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }

        // 目盛り 9
        Label {
            id: scaleLabel9
            width: 20
            height: 16
            x: 134
            y: 26
            text: ""
            font.family: defaultFontName
            font.pixelSize: 14
            color: "#E4E6E5"
        }
    }

    Image {
        id: merFrame
        width: 149
        height: 296
        sourceSize.width: 191
        x: -2
        y: 45
        source: "qrc:/resource/png/mer_meter_7.png"
    }

    // 針
    Image {
        id: merNeedle
        width: 16
        height: 284
        x: (parent.width / 2) - 12
        y: 51
        source: "qrc:/resource/png/mer_needle.png"
        transform: Rotation {
            id: merNeedleRotation
            angle: merGauge.needlePosition
            origin.x: merNeedle.width / 2 - 0     // 回転の中心 X 座標の調整
            origin.y: merNeedle.height / 2 - 0    // 回転の中心 Y 座標の調整
        }
    }

    // 点滅用タイマー
    Timer {
        id: timer
        interval: merGauge.blinkInterval
        running: false
        repeat: true
        onTriggered: {
            merValue.visible = !merValue.visible
        }
    }

    function updateMer(mer, merNeedlePosition) {
        merGauge.value = mer
        merGauge.needlePosition = merNeedlePosition
    }

    function updateThreshold(red, yellow)
    {
        //console.log("### MER Threshold Red:" + red + " Yellow:" + yellow)
        redZoneRatio = red
        yellowZoneRatio = yellow
        gauge.requestPaint()
    }
}
