/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
import QtQuick.Controls 2.12
import jp.co.dxantenna.levelchecker.scanResultGroupModel 1.0
import jp.co.dxantenna.levelchecker.scanResultModel 1.0
import "../parts/"

Item {
    id: scanResult

    property alias scanResultListModel: scanResultList.model
    property string channelRange: ""
    readonly property int listElementHeight: 40

    Label {
        id: scanResultTitle
        anchors {
            top: parent.top
            topMargin: 12
            left: parent.left
            leftMargin: 20
            right: parent.right
            rightMargin: 20
        }
        height: 20
        text: "スキャン結果"
        horizontalAlignment: Text.AlignHCenter
        verticalAlignment: Text.AlignVCenter
        color: "#E6E6E6"
        font.pixelSize: 20
    }
    Label {
        id: scanResultChannelTitle
        anchors {
            top: scanResultTitle.bottom
            topMargin: 8
            left: scanResultTitle.left
            right: scanResultTitle.right
        }
        height: 18
        text: message
        horizontalAlignment: Text.AlignHCenter
        verticalAlignment: Text.AlignVCenter
        color: "#E6E6E6"
        font.pixelSize: 18
    }

    // スキャン結果リスト
    ListView {
        id: scanResultList
        anchors {
            top: scanResultChannelTitle.bottom
            topMargin: 8
            left: scanResultChannelTitle.left
            right: scanResultChannelTitle.right
            rightMargin: 20
        }
        property int totalRowcount: 0
        displayMarginBeginning: contentHeight
        height: listElementHeight * 7   // 7行分のリスト
        clip: true

        model: scanResultModel
        delegate: Component {
            Item {
                width: scanResultList.width
                height: groupTitle.height + scanResultChannelGrid.height
                // グループ名
                Rectangle {
                    id: groupTitle
                    width: scanResultList.width
                    height: listElementHeight
                    color: getRowColor(titleRowColor)
                    Label {
                        id: groupTitleLabel
                        anchors.fill: parent
                        text: model.groupName
                        horizontalAlignment: Text.AlignHCenter
                        verticalAlignment: Text.AlignVCenter
                        color: "#80BFFF"
                        font.pixelSize: 18
                    }
                }

                // グループに属するチャンネルのグリッド
                GridView {
                    id: scanResultChannelGrid
                    anchors.top: groupTitle.bottom
                    width: groupTitle.width
                    height: contentHeight
                    cellWidth: 100
                    cellHeight: listElementHeight
                    model: groupModel
                    delegate: Component {
                        Rectangle {
                            id: scanResultElement
                            width: scanResultChannelGrid.cellWidth
                            height: scanResultChannelGrid.cellHeight
                            Label {
                                id: scanResultChannelNumberLabel
                                anchors.fill: parent
                                text: model.channelNumber
                                horizontalAlignment: Text.AlignHCenter
                                verticalAlignment: Text.AlignVCenter
                                color: "#E6E6E6"
                                font.pixelSize: 16
                            }
                            color: getRowColor(channelColor)
                        }
                    }
                }

            }
        }
        onContentHeightChanged: {
            // リストのサイズが変化したら、スクロールバーの長さを調整する
            if (scanResultList.height > scanResultList.contentHeight) {
                scrollBarCurrentPosition.height = scrollBarArea.height
            } else {
                scrollBarCurrentPosition.height = scrollBarArea.height * (scanResultList.height / scanResultList.contentHeight)
            }
            if (scanResultList.contentHeight < scanResultList.height) {
                scrollBarArea.maxStep = 0
            } else {
                scrollBarArea.maxStep = (scanResultList.contentHeight - scanResultList.height) / listElementHeight
            }
            scrollBarArea.scrollStep = 0
        }
    }

    // スクロールバー
    Item {
        id: scanResultListtScrollBar
        anchors {
            top: scanResultList.top
            bottom: scanResultList.bottom
            left: scanResultList.right
            leftMargin: 15
        }
        width: 14

        // スクロールバーエリア
        Rectangle {
            id: scrollBarArea
            anchors.fill: parent

            property int stepDistance: 0        // 上下押下時のスクロールバーの移動量
            property int maxStep: 0             // 上下移動可能な移動回数の上限
            onMaxStepChanged: {
                if (maxStep === 0) {
                    stepDistance = 0
                } else {
                    // 上下の押下回数によって、移動量を決定する
                    stepDistance = (scrollBarArea.height - scrollBarCurrentPosition.height) / maxStep
                }
            }
            property int scrollStep: 0          // スクロールバーの位置(maxStepを最大値とした位置)
            onScrollStepChanged: scrollBarCurrentPosition.y = -(stepDistance * scrollStep)

            color: "#4E525B"

            // スクロールバーのつまみ
            Rectangle {
                id: scrollBarCurrentPosition
                color: "#187FE6"
                border {
                    width:2
                    color: "#7FBFFC"
                }
                width: parent.width
                height: parent.height
            }
        }
    }

    function getRowColor(colorType) {
        if (colorType === 0) {
            return "#606672"
        } else {
            return "#4E525B"
        }
    }

    function settingRowCount(rowCount) {
        scanResultList.totalRowcount = rowCount
    }

    function scrollUp()
    {
        if (scanResultList.originY >= scanResultList.contentY) {
            // 上限ならそれ以上は移動しない
            return
        }

        scanResultList.contentY = scanResultList.contentY - listElementHeight
        scrollBarArea.scrollStep = scrollBarArea.scrollStep + 1
    }

    function scrollDown()
    {
        if ((scanResultList.originY + (scanResultList.totalRowcount * listElementHeight) - scanResultList.height) < scanResultList.contentY) {
            // 下限ならそれ以上は移動しない
            return
        }

        scanResultList.contentY = scanResultList.contentY + listElementHeight
        scrollBarArea.scrollStep = scrollBarArea.scrollStep - 1
    }
}
