/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
import QtQuick.Controls 2.12

Item {
    id:root

    property bool active: false
    property bool disable: false
    property bool press: false
    property string activebg: ""    // active 背景
    property string idlebg: ""      // idle 背景
    property string pressbg: ""     // press 背景
    property string message: ""
    property string unit: ""
    default property int fontsize: 21

    property bool keyPressed: false
    property string activeKeyImage: "qrc:/resource/png/kb_key_cur.png"
    property bool light: true
    property bool keyboard: false
    property bool editMode: false
    property string icon:   ""
    property bool useChannelEdit: false
    property bool selected: false
    property bool editing: false            // true:白色 false:水色
    property bool userOnOff: false          // USER/データロガー設定呼び出しのみで使用(true:文字の色[黄色と白]、false:文字の色[白とグレー])
    property int leftpos: 0
    property int toppos: 0

    onDisableChanged: {
        if (disable) {
            if (editMode == false){
                // editMode中はdisableにしてもdisable_coverは表示しない
                disable_cover.visible = true
                bg.visible = false;
            }
            message.opacity = 0.5;
            bg.opacity = 0.5;
        } else {
            disable_cover.visible = false;
            bg.visible = true;
            message.opacity = 1.0;
            bg.opacity = 1.0;
        }
    }

    onKeyPressedChanged: {
        if (keyPressed) {
            background.color = "#80BFFF"
        } else {
            background.color = (root.light) ? "#616673" : "#595E6A"
        }
    }

    implicitWidth: 225
    implicitHeight: 80

    // background
    Image {
        id: bg
        // 画像指定がない場合に NULL イメージをロードする
        source: (parent.press && root.pressbg != "") ?
                     "qrc:/resource/png/" + root.pressbg :
                     (root.active && root.activebg != "") ?
                          "qrc:/resource/png/" + root.activebg :
                         (root.idlebg && root.idlebg != "") ? "qrc:/resource/png/" + root.idlebg : ""

        anchors {
            centerIn: parent
        }
        visible: !root.keyboard
    }

    // iconimage
    Image {
        id: icon
        source: (parent.icon === "") ? "" : "qrc:/resource/png/" + parent.icon
        anchors {
            top: bg.top
            horizontalCenter:bg.horizontalCenter
        }
        height: parent.height / 2
    }

    // background(キーボード用背景画像なし)
    Rectangle {
        id: background
        anchors.fill: parent
        color: (root.light) ? "#616673" : "#595E6A"
        Image {
            id: image
            source: root.activeKeyImage
            anchors {
                centerIn: parent
            }
            visible: root.keyboard && root.active && !root.keyPressed && !root.disable
        }
        visible: root.keyboard
    }

    // message
    Label {
        id: message
        anchors {
            top: (parent.icon === "") ? parent.top : icon.bottom
            left: parent.left
            right: parent.right
            bottom: parent.bottom
            topMargin: toppos
            leftMargin: leftpos
        }
        color: {
            if(userOnOff == true) {
                // 測定ON/OFFのときのみ別色とする
                !useChannelEdit ? "white" : selected ? "yellow" : "#E6E6E6"
            } else {
                !useChannelEdit ? "white" : editing ? "#E6E6E6" : "#80BFFF"
            }
        }
        text: (root.unit === "") ? root.message : root.message + " " + root.unit
        horizontalAlignment: Text.AlignHCenter
        verticalAlignment: Text.AlignVCenter
        font.pixelSize: root.fontsize
        font.family: defaultFontName
    }

    // disable
    Rectangle {
        id: disable_cover
        anchors {
            //上下左右三角分の8ピクセル小さくする。
            fill: parent
            margins: 8
        }
        visible:false
        color:"#18191D"
        opacity: 0.5
    }
}
