/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0

Item {
    id:root
    property string value: ""
    property bool exp: false
    property bool active: false
    property bool disable: false
    property bool edit: false;      // 編集状態
    property bool isFirstFixed: false // 先頭は編集不可

    property string activebg: ""    // active 背景
    property string idlebg: ""      // idle 背景
    property string editbg: ""      // edit 背景

    property string edit1idlebg: ""
    property string edit1activebg: ""
    property string edit2idlebg: ""
    property string edit2activebg: ""
    property string edit3idlebg: ""
    property string edit3activebg: ""
    property string edit4idlebg: ""
    property string edit4activebg: ""
    property string edit5idlebg: ""
    property string edit5activebg: ""

    onDisableChanged: {
        if (disable) {
            edit1.disable = true
            edit2.disable = true
            edit3.disable = true
            edit4.disable = true
            edit5.disable = true
        } else {
            edit1.disable = false
            edit2.disable = false
            edit3.disable = false
            edit4.disable = false
            edit5.disable = false
        }
    }

    onActiveChanged: {        
        if (active == false) {
            // 別の項目へカーソルが移動した時
            edit = false;
        }
        else {
            // 項目選択
        }
    }

    onEditChanged: {
        // [Memo]
        // プロパティ disable == trueの場合は以降の処理は実施しない
        if (root.disable == false) {
            if (edit == true) {
                // 最初の項目を編集可能にする
                if (isFirstFixed) {
                    // 先頭が編集不可の場合は2つ目の項目を編集対象にする
                    edit1.active = false
                    edit2.active = true
                    edit2.disable = false
                } else {
                    edit1.active = true
                    edit1.disable = false
                    edit2.active = false
                    edit2.disable = false
                }
                edit3.active = false
                edit3.disable = false
                edit4.active = false
                edit4.disable = false
                edit5.active = false
                edit5.disable = false
            }
            else {
                // 項目毎の部品は全て非表示
                edit1.active = false;
                edit2.active = false;
                edit3.active = false;
                edit4.active = false;
                edit5.active = false;

                // 入力された値を保持
                if (exp == false) {
                    value = ""
                    value = edit1.message + edit2.message + edit3.message + edit5.message
                }
                else {
                    value = edit1.message + edit3.message + edit5.message
                }
            }
        }
    }

    onValueChanged: {
        // [Memo]
        // プロパティ disable == trueの場合は以降の処理は実施しない
        if (root.disable == false) {
            // 設定値を各SelectButtonに設定する
            if (exp == false) {
                if (value.length == 4) {
                    edit1.message = value.substr(0, 1);
                    edit1.message == "0" ? edit1.disable = true : edit1.disable = false

                    edit2.message = value.substr(1, 1);
                    edit3.message = value.substr(2, 1);
                    edit5.message = value.substr(3, 1);
                }
                else if (value.length == 3) {
                    edit1.message = "0"
                    edit1.disable = true;
                    edit2.message = value.substr(0, 1);
                    edit2.message == "0" ? edit2.disable = true : edit2.disable = false
                    edit3.message = value.substr(1, 1);
                    edit5.message = value.substr(2, 1);
                }
                else if (value.length == 2) {
                    edit1.message = "0"
                    edit1.disable = true;
                    edit2.message = "0"
                    edit2.disable = true;
                    edit3.message = value.substr(0, 1);
                    edit3.message == "0" ? edit3.disable = true : edit3.disable = false
                    edit5.message = value.substr(1, 1);
                }
                else if (value.length == 1) {
                    edit1.message = "0"
                    edit1.disable = true;
                    edit2.message = "0"
                    edit2.disable = true;
                    edit3.message = "0"
                    edit3.disable = true;
                    edit5.message = value.substr(0, 1);
                }
                else {
                }
            }
            else {
                if (value.length == 3) {
                    edit1.message = value.substr(0, 1);
                    edit3.message = value.substr(1, 1);
                    edit5.message = value.substr(2, 1);
                }
                else if (value.length == 2) {
                    edit1.message = "0"
                    edit3.message = value.substr(0, 1);
                    edit5.message = value.substr(1, 1);
                }
                else if (value.length == 1) {
                    edit1.message = "0"
                    edit3.message = "0"
                    edit5.message = value.substr(0, 1);
                }
                else {
                }
            }
        }

        if (exp == false) {
            updateDisableStatus()
        }
    }

    // 値に応じて無効表示に切り替える
    function updateDisableStatus() {
        if (edit1.message !== "0") {
            return
        }
        edit1.disable = true

        if (edit2.message !== "0") {
            return
        }
        edit2.disable = true

        // 3桁目以降は、「0.0」などの表示になるため、0でも無効にしない
    }

    implicitWidth: 160
    implicitHeight: 66

    // 背景イメージ
    Image {
        id:bg
        source: "qrc:/resource/png/" + (parent.active ? (parent.edit ? root.editbg : root.activebg) : parent.idlebg)
        anchors {
            centerIn: parent
        }
    }

    Row {
        anchors.fill:root
        spacing: -10

        SelectButton {
            id:edit1
            objectName: "edit1"
            width: (exp == false) ? 49 : 38
            height: root.height
            activebg: root.edit1activebg    // 編集時の背景画像
            idlebg: root.edit1idlebg
            editMode: true
            message: "0"
        }
        SelectButton {
            id:edit2
            objectName: "edit2"
            width: (exp == false) ? 38 : 28
            height: root.height
            activebg: root.edit2activebg
            idlebg: root.edit2idlebg
            editMode: true
            message: root.exp ? "." : "0"
        }
        SelectButton {
            id:edit3
            objectName: "edit3"
            width: (exp == false) ? 38 : 38
            height: root.height
            activebg: root.edit3activebg
            idlebg: root.edit3idlebg
            editMode: true
            message: "0"
        }
        SelectButton {
            id:edit4
            objectName: "edit4"
            width: (exp == false) ? 28 : 49
            height: root.height
            activebg: root.edit4activebg
            idlebg: root.edit4idlebg
            editMode: true
            message: root.exp ? "E-" : "."
        }

        SelectButton {
            id:edit5
            objectName: "edit5"
            width: (exp == false) ? 49 : 49
            height: root.height
            activebg: root.edit5activebg
            idlebg: root.edit5idlebg
            editMode: true
            message: "0"
        }
    }
}
