/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
import QtQuick.Controls 2.12
import jp.co.dxantenna.levelchecker.scanResultGroupModel 1.0
import jp.co.dxantenna.levelchecker.scanResultModel 1.0
import jp.co.dxantenna.levelchecker.scanLockModel 1.0

import "../parts/"

// 通常のポップアップ表示(この上に StrongPopup を表示する)
Popup {
    id: popup
    objectName: "BasicPopup"
    x: (parent.width - popup.width) / 2
    modal: true
    focus: true
    closePolicy: Popup.CloseOnEscape | Popup.NoAutoClose

    // [memo] popupmanager.hに定義しているenum PopupLayoutTypeと
    //        連動しています。更新時は注意！！！！！！
    // レイアウトのTypeを定義
    readonly property int normal_layout: 1
    readonly property int one_button_layout: 2
    readonly property int progressbar_layout: 3
    readonly property int keyborad_layout: 4
    readonly property int message_layout: 5
    readonly property int power_supply_select_layout: 6
    readonly property int scan_result_layout: 7
    readonly property int three_button_layout: 8
    readonly property int progressbar_labelbutton_layout: 9
    readonly property int confirm_update_layout: 10
    readonly property int update_layout: 11

    // SCAN 選択は layoutType 5
    property int layoutType: popup.normal_layout
    property alias message: messageArea.text
    property alias leftButtonMessage: leftButtonText.text
    property alias leftButtonCaption: leftButton.message
    property alias centerButtonMessage: centerButtonText.text
    property alias centerButtonCaption: centerButton.message
    property alias rightButtonMessage: rightButtonText.text
    property int buttonType: -1
    property bool strong: false
    property alias fileName: fileName.text
    property alias cursorPosition: fileName.cursorPosition
    property double progressingValue: 0
    property bool noValidScanResult: false
    property alias scanLockGridViewModel: scanLockGridView.model

    onFileNameChanged: {
        enteredWordCount.text = fileName.length
    }

    width: {
        if (layoutType === popup.keyborad_layout) {
            700
        } else if (layoutType === popup.power_supply_select_layout ||
                   layoutType === popup.confirm_update_layout) {
            570
        } else if (layoutType === popup.three_button_layout) {
            600
       } else if (layoutType === popup.progressbar_layout || layoutType === popup.scan_result_layout) {
            760
        } else {
            460
        }
    }
    height: {
        if (layoutType === popup.progressbar_labelbutton_layout) {
            220
        } else if (layoutType === popup.keyborad_layout) {
            350
        } else if (layoutType === popup.power_supply_select_layout ||
                   layoutType === popup.confirm_update_layout) {
            180
        } else if (layoutType === popup.progressbar_layout || layoutType === popup.scan_result_layout) {
            //420
            320
        } else if (layoutType === popup.update_layout) {
            250
        } else {
            160
        }
    }
    y: {
        if (layoutType === popup.keyborad_layout) {
            150
        } else if (layoutType === popup.scan_result_layout || layoutType === popup.progressbar_layout) {
            //50
            70
        } else {
            120
        }
    }

    signal accept(bool okOnly)
    signal reject()
    signal select(int index)
    signal keyInput(string message)

    background: Rectangle {
       anchors.fill: parent
       radius: 10
       //color: "#41444d"
       //border.color: "#333333"
       color: (layoutType === popup.progressbar_layout) || (layoutType === popup.scan_result_layout) ? "transparent" : "#41444d"
       border.color: (layoutType === popup.progressbar_layout) || (layoutType === popup.scan_result_layout) ? "transparent" : "#333333"
       Image {
           anchors.fill: parent
           source:(layoutType === popup.progressbar_layout) || (layoutType === popup.scan_result_layout) ?  "qrc:/resource/png/dialog_scanning.png" : ""
           visible: (layoutType === popup.progressbar_layout) || (layoutType === popup.scan_result_layout) ? true : false
       }
       Label {
           id: messageArea
           anchors {
               horizontalCenter: parent.horizontalCenter
               top: (layoutType === popup.message_layout) ? undefined : parent.top
               topMargin: (layoutType === popup.message_layout) ? undefined : 40
               // [memo]
               //   verticalCenterを一番下に記載すること、verticalCenterを先に設定してから、
               //   topにundefinedを設定するとverticalCenterの設定が上書き？されてしまう
               verticalCenter: (layoutType === popup.message_layout) ? parent.verticalCenter : undefined
           }
           color: "white"
           font.family: defaultFontName
           font.pixelSize: 18
           horizontalAlignment: Text.AlignLeft
           text: message
           visible: {
               if (layoutType === popup.keyborad_layout || layoutType === popup.progressbar_layout || layoutType === popup.scan_result_layout) {
                   false
               } else {
                   true
               }
           }
       }

       Label {
           id: messageAreaScan
           anchors {
               horizontalCenter: (layoutType === popup.progressbar_layout) ? undefined : parent.horizontalCenter
               top: parent.top
               topMargin: 20
               left: (layoutType === popup.progressbar_layout) ? parent.left : undefined
               leftMargin: (layoutType === popup.progressbar_layout) ? 150 : undefined
           }
           color: "white"
           font.family: defaultFontName
           font.pixelSize: 18
           horizontalAlignment: (layoutType === popup.scan_result_layout) ? Text.AlignHCenter : Text.AlignLeft
           text: message
           visible: (layoutType === popup.progressbar_layout || layoutType === popup.scan_result_layout) ? true : false
       }

       Row {
           id: row
           anchors {
               horizontalCenter: parent.horizontalCenter
               bottom: parent.bottom
               bottomMargin: (layoutType === popup.power_supply_select_layout) ? 20 : 30
           }
           visible: {
               if (layoutType === popup.keyborad_layout) {
                   false
               } else if (layoutType === popup.message_layout) {
                   // メッセージレイアウトの場合はボタン不要
                   false
               } else {
                   true
               }
           }
           spacing: (layoutType === popup.power_supply_select_layout) ? 12 : 25

           MenuButton {
               id: leftButton
               objectName: "m1"
               activebg: (layoutType === popup.one_button_layout || layoutType === popup.progressbar_layout  || layoutType === popup.progressbar_labelbutton_layout) ? "dialogbtn156_one.png" : (layoutType === power_supply_select_layout) ? "icon_fixed15v_active" : "dialogbtn156_r.png"
               idlebg: (layoutType === power_supply_select_layout) ? "icon_fixed15v_inactive" : "dialogbtn156_n.png"
               pressbg: (layoutType === power_supply_select_layout) ? "icon_fixed15v_press" : "dialogbtn156_p.png"
               width: 166
               height: (layoutType === popup.power_supply_select_layout) ? 60 : 40
               active: true
               messageBottomMargin: (layoutType === power_supply_select_layout) ? 30 : 15
               Text {
                   id: leftButtonText
                   text: leftButtonMessage
                   color: "#e6e6e4"
                   anchors.centerIn: parent
                   anchors {
                       horizontalCenter: parent.horizontalCenter
                       verticalCenter: parent.verticalCenter
                   }
                   font.family: defaultFontName
                   font.pixelSize: (layoutType === power_supply_select_layout) ? 15 : 18
               }
           }
           MenuButton {
               id: centerButton
               objectName: "m3"
               activebg: (layoutType === power_supply_select_layout) ? "icon_h15v11_active" : "dialogbtn156_l.png"
               idlebg: (layoutType === power_supply_select_layout) ? "icon_h15v11_inactive" : "dialogbtn156_n.png"
               pressbg: (layoutType === power_supply_select_layout) ? "icon_h15v11_press" : "dialogbtn156_p.png"
               width: 166
               height: (layoutType === popup.three_button_layout) ? 40 : 60
               active: false
               messageBottomMargin: (layoutType === popup.power_supply_select_layout) ? 10 : 15
               Text {
                   id: centerButtonText
                   text: centerButtonCaption
                   color: "#e6e6e4"
                   anchors {
                       horizontalCenter: parent.horizontalCenter
                       verticalCenter: parent.verticalCenter
                   }
                   font.family: defaultFontName
                   font.pixelSize: (layoutType === power_supply_select_layout) ? 15 : 18
               }
               visible: (layoutType === popup.power_supply_select_layout || layoutType === popup.three_button_layout)
           }
           MenuButton {
                id: rightButton
                objectName: "m2"
                activebg: (layoutType === power_supply_select_layout) ? "icon_no_power_supply_active" : "dialogbtn156_l.png"
                idlebg: (layoutType === power_supply_select_layout) ? "icon_no_power_supply_inactive" : "dialogbtn156_n.png"
                pressbg: (layoutType === power_supply_select_layout) ? "icon_no_power_supply_press" : "dialogbtn156_p.png"
                width: 166
                height: (layoutType === popup.power_supply_select_layout) ? 60 : 40
                active: false
                messageBottomMargin: (layoutType === power_supply_select_layout) ? 10 : 15
                Text {
                    id: rightButtonText
                    text: rightButtonMessage
                    color: "#e6e6e4"
                    anchors.centerIn: parent
                    font.family: defaultFontName
                    font.pixelSize: (layoutType === power_supply_select_layout) ? 15 : 18
                }
                visible: !(layoutType === popup.one_button_layout || layoutType === popup.progressbar_layout || layoutType === popup.progressbar_labelbutton_layout)
           }
        }

        ProgressBar {
            id: progress
            width: (layoutType === progressbar_layout) ? 350 : 400
            height: (layoutType === progressbar_layout) ? 20 : 30
            anchors {
                horizontalCenter: (layoutType === progressbar_layout) ? undefined : parent.horizontalCenter
                top: parent.top
                topMargin: (layoutType === progressbar_layout) ? 20 : 90
                left: (layoutType === progressbar_layout) ? parent.left : undefined
                leftMargin: (layoutType === progressbar_layout) ? 220 : undefined
            }
            from: 0
            to: 100
            value: popup.progressingValue
            visible: (layoutType === popup.progressbar_layout) || (layoutType === popup.progressbar_labelbutton_layout)
            background: Rectangle {
                implicitWidth: progress.visualPosition * parent.width
                implicitHeight: (layoutType === progressbar_layout) ? 20 : 30
                color: "#35383F"
                border.color: "#35383F"
                border.width: 5
            }

            contentItem: Item {
                Rectangle {
                    implicitWidth: progress.visualPosition * parent.width
                    implicitHeight: (layoutType === progressbar_layout) ? 20 : 30
                    color: "#177EE7"
                    border.color: "#35383F"
                    border.width: 5
                }
            }
        }

        Item {
            width: 672
            height: 220
            anchors {
                horizontalCenter: parent.horizontalCenter
                top: parent.top
                topMargin: 45
            }
            visible: (layoutType === popup.progressbar_layout) || (layoutType === popup.scan_result_layout)
            GridView {
                id: scanLockGridView
                anchors.top: parent.top
                width: parent.width
                height: parent.height
                cellWidth: 48
                cellHeight: 20
                model: scanLockModel
                delegate: Component {
                    Item {
                        width: 48
                        height: 20
                        Label {
                            anchors.fill: parent
                            text: model.channel
                            horizontalAlignment: Text.AlignRight
                            verticalAlignment: Text.AlignVCenter
                            color: "white"
                            font.pixelSize: 14
                        }
                    }
                }
            }
        }

        Label {
            id: buttonLabel
            visible: popup.layoutType === popup.progressbar_labelbutton_layout
            color: "white"
            font.family: defaultFontName
            font.pixelSize: 18
            horizontalAlignment: Text.AlignRight
            //text: "ログ収集を"
            text: ""
            anchors{
                right: row.left
                verticalCenter: row.verticalCenter
            }
        }

        Column {
            id: keyboardbase
            anchors {
                horizontalCenter: parent.horizontalCenter
                top: parent.top
                topMargin: 0
            }
            visible: layoutType === popup.keyborad_layout ? true : false

            Rectangle {
                id: ward1
                width: 800
                height: 115
                color: "#41444d"

                Text {
                    id: messageLabel
                    text: "ファイル名を入力してください。"
                    color: "white"
                    font.family: defaultFontName
                    font.pixelSize: 18
                    //anchors.horizontalCenter: parent.horizontalCenter
                    anchors {
                        horizontalCenter: parent.horizontalCenter
                        top:parent.top
                        topMargin: 15
                    }
                }

                Text {
                    id: enteredWardCountLabel
                    text: "入力文字数 : "
                    color: "white"
                    font.family: defaultFontName
                    font.pixelSize: 15
                    anchors {
                        horizontalCenter: parent.horizontalCenter
                        top: messageLabel.bottom
                        topMargin: 4
                    }
                }

                Text {
                    id: enteredWordCount
                    color: "white"
                    text: "0"
                    font.family: defaultFontName
                    font.pixelSize: 15
                    anchors {
                        top: enteredWardCountLabel.top
                        left: enteredWardCountLabel.right
                        leftMargin: 5
                    }
                }

                Rectangle {
                    color: "#626672"
                    width: 480
                    height: 40
                    anchors {
                        horizontalCenter: parent.horizontalCenter
                        bottom: parent.bottom
                        bottomMargin: 15
                    }
                    TextInput {
                        id: fileName
                        objectName: "FileNameInput"
                        text: ""
                        cursorVisible: true
                        color: "white"
                        font.family: defaultFontName
                        font.pixelSize: 20
                        anchors.verticalCenter: parent.verticalCenter
                        leftPadding: 5
                    }
                }
            }

            Row {
                Rectangle {
                    id:ward3
                    width: 654
                    height: 215
                    color: "#41444d"

                    Column{
                        leftPadding: 15
                        Row {
                            SelectButton {
                                id: m101
                                objectName: "m101"
                                light: true
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m102
                                objectName: "m102"
                                light: false
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m103
                                objectName: "m103"
                                light: true
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m104
                                objectName: "m104"
                                light: false
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m105
                                objectName: "m105"
                                light: true
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m106
                                objectName: "m106"
                                light: false
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m107
                                objectName: "m107"
                                light: true
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m108
                                objectName: "m108"
                                light: false
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m109
                                objectName: "m109"
                                light: true
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m110
                                objectName: "m110"
                                light: false
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m111
                                objectName: "m111"
                                light: true
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m112
                                objectName: "m112"
                                light: false
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m113
                                objectName: "m113"
                                light: true
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                        }
                        Row {
                            SelectButton {
                                id: m201
                                objectName: "m201"
                                light: false
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m202
                                objectName: "m202"
                                light: true
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m203
                                objectName: "m203"
                                light: false
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m204
                                objectName: "m204"
                                light: true
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m205
                                objectName: "m205"
                                light: false
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m206
                                objectName: "m206"
                                light: true
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m207
                                objectName: "m207"
                                light: false
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m208
                                objectName: "m208"
                                light: true
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m209
                                objectName: "m209"
                                light: false
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m210
                                objectName: "m210"
                                light: true
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m211
                                objectName: "m211"
                                light: false
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m212
                                objectName: "m212"
                                light: true
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m213
                                objectName: "m213"
                                light: false
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                        }
                        Row {
                            SelectButton {
                                id: m301
                                objectName: "m301"
                                light: true
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m302
                                objectName: "m302"
                                light: false
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m303
                                objectName: "m303"
                                light: true
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m304
                                objectName: "m304"
                                light: false
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m305
                                objectName: "m305"
                                light: true
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m306
                                objectName: "m306"
                                light: false
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m307
                                objectName: "m307"
                                light: true
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m308
                                objectName: "m308"
                                light: false
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m309
                                objectName: "m309"
                                light: true
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m310
                                objectName: "m310"
                                light: false
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m311
                                objectName: "m311"
                                light: true
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m312
                                objectName: "m312"
                                light: false
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m313
                                objectName: "m313"
                                light: true
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                        }
                        Row {
                            SelectButton {
                                id: m401
                                objectName: "m401"
                                light: false
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m402
                                objectName: "m402"
                                light: true
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m403
                                objectName: "m403"
                                light: false
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m404
                                objectName: "m404"
                                light: true
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m405
                                objectName: "m405"
                                light: false
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m406
                                objectName: "m406"
                                light: true
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m407
                                objectName: "m407"
                                light: false
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m408
                                objectName: "m408"
                                light: true
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m409
                                objectName: "m409"
                                light: false
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m410
                                objectName: "m410"
                                light: true
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m411
                                objectName: "m411"
                                light: false
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m412
                                objectName: "m412"
                                light: true
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m413
                                objectName: "m413"
                                light: false
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                        }
                        Row {
                            SelectButton {
                                id: m501
                                objectName: "m501"
                                light: true
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m502
                                objectName: "m502"
                                light: false
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m503
                                objectName: "m503"
                                light: true
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m504
                                objectName: "m504"
                                light: false
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m505
                                objectName: "m505"
                                light: true
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m506
                                objectName: "m506"
                                light: false
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m507
                                objectName: "m507"
                                light: true
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m508
                                objectName: "m508"
                                light: false
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m509
                                objectName: "m509"
                                light: true
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m510
                                objectName: "m510"
                                light: false
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m511
                                objectName: "m511"
                                light: true
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m512
                                objectName: "m512"
                                light: false
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                            SelectButton {
                                id: m513
                                objectName: "m513"
                                light: true
                                message: ""
                                width:48
                                height:40
                                fontsize: 20
                                keyboard: true
                            }
                        }
                    }
                }
                Rectangle {
                    id:ward4
                    width: 145
                    height: 215
                    color: "#41444d"
                    Column {
                        KeyboardOperationButton {
                            id: right1
                            objectName: "right1"
                            light: true
                            activeBackgroundImage: "qrc:/resource/png/128x56_btn_cur_active.png"
                            //iconImage: "qrc:/resource/png/39x26_delKey.png"
                            text: ""
                            //backspace: true
                            width:130
                            height:40
                        }
                        KeyboardOperationButton {
                            id: right2
                            objectName: "right2"
                            light: false
                            activeBackgroundImage: "qrc:/resource/png/128x56_btn_cur_active.png"
                            iconImage: "qrc:/resource/png/39x26_delKey.png"
                            text: ""
                            backspace: true
                            width:130
                            height:40
                        }
                        KeyboardOperationButton {
                            id: right3
                            objectName: "right3"
                            light: true
                            activeBackgroundImage: "qrc:/resource/png/128x56_btn_cur_active.png"
                            iconImage: "qrc:/resource/png/18x18_left_arrow.png"
                            text: "前の文字"
                            width:130
                            height:40
                        }
                        KeyboardOperationButton {
                            id: right4
                            objectName: "right4"
                            light: false
                            activeBackgroundImage: "qrc:/resource/png/128x56_btn_cur_active.png"
                            iconImage: "qrc:/resource/png/18x18_right_arrow.png"
                            text: "次の文字"
                            width:130
                            height:40
                        }
                        KeyboardOperationButton {
                            id: right5
                            objectName: "right5"
                            light: true
                            activeBackgroundImage: "qrc:/resource/png/128x56_btn_cur_active.png"
                            text: "保存"
                            width:130
                            height:40
                        }
                    }
                }
            }
        }

        // スキャン結果(リスト表示用)
        ScanResultModel {
            id: scanResultModel
            objectName: "scanResultModel"
        }

        // スキャンロック(リスト表示用)
        ScanLockModel {
            id: scanLockModel
            objectName: "scanLockModel"
        }

        ScanResultListLayout {
            id: scanResultListLayout
            width: parent.width
            height: parent.height
            //visible: layoutType === popup.scan_result_layout ? true : false
            visible: false
            scanResultListModel: scanResultModel
            channelRange: message
        }
    }

    function closePopup()
    {
        // キーボードを閉じたときに操作系のボタンを非アクティブにする
        if (layoutType === popup.keyborad_layout) {
            right1.active =false
            right2.active =false
            right3.active =false
            right4.active =false
            right5.active = false
        }
        // スキャン結果リストをクリアする
        scanLockGridViewModel = null
        scanLockGridViewModel = scanLockModel

        popup.layoutType = 0
        popup.progressingValue = 0
        popup.leftButtonCaption = ""
        popup.centerButtonCaption = ""
        popup.noValidScanResult = false
        close()
    }

    function setTextInputFocus()
    {
        fileName.forceActiveFocus()
    }

    function settingRowCount(rowCount)
    {
        scanResultListLayout.settingRowCount(rowCount)
    }

    function scrollUp()
    {
        scanResultListLayout.scrollUp()
    }

    function scrollDown()
    {
        scanResultListLayout.scrollDown()
    }
}
