/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
import QtQuick.Controls 2.12
import "../parts/"

// ポップアップの上に表示するポップアップ
Popup {
    id: popup
    objectName: "ErrorPopup"
    width: 460
    height: buttonMessage === "" ? 120 : 160
    x: (parent.width - popup.width) / 2
    y: buttonMessage === "" ? 140 : 100
    modal: true
    focus: true
    closePolicy: Popup.CloseOnEscape | Popup.NoAutoClose
    property bool isOverlay : false

    property alias message: messageArea.text
    property alias buttonMessage: centerButtonText.text

    background: Rectangle {
       anchors.fill: parent
       radius: 10
       color: "#41444d"
       border.color: "#333333"

       Label {
           id: messageArea
           anchors {
               horizontalCenter: parent.horizontalCenter
               top: parent.top
               topMargin: 40
           }
           color: "white"
           font.family: defaultFontName
           font.pixelSize: 18
           horizontalAlignment: Text.AlignLeft
           text: message
       }

       MenuButton {
           id: centerButton
           objectName: "m1"
           activebg: "dialogbtn156_one.png"
           idlebg: "dialogbtn156_n.png"
           pressbg: "dialogbtn156_p.png"
           anchors {
               horizontalCenter: parent.horizontalCenter
               bottom: parent.bottom
               bottomMargin: 10
           }
           width: 220
           height: 60
           active: true
           messageBottomMargin: 15
           Text {
               id: centerButtonText
               text: buttonMessage
               color: "#e6e6e4"
               anchors {
                   horizontalCenter: parent.horizontalCenter
                   verticalCenter: parent.verticalCenter
                   verticalCenterOffset: 0
               }
               font.family: defaultFontName
               font.pixelSize: 18
           }
           visible: buttonMessage !== ""
       }

    }
    // 二重にトーンダウンしないようにする
    Overlay.modal: Rectangle {
        color: isOverlay ? "transparent" : "#66333333"
    }

    function closePopup()
    {
        close()
    }
}
