/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
import QtQuick.Controls 2.12
import "../parts/"

// バッテリ低下状態時に表示するポップアップ
// エラー以外のポップアップ表示中でもその上に表示する
Popup {
    id: popup
    objectName: "LowBatteryPopup"
    width: 460
    height: 120
    x: (parent.width - popup.width) / 2
    y: 150
    modal: true
    focus: true
    closePolicy: Popup.CloseOnEscape | Popup.NoAutoClose
    property bool isOverlay: false

    background: Rectangle {
        anchors.fill: parent
        radius: 10
        color: "#41444d"
        border.color: "#333333"

        Label {
            id: messageArea
            anchors {
                horizontalCenter: parent.horizontalCenter
                top: parent.top
                topMargin: 40
            }
            color: "white"
            font.family: defaultFontName
            font.pixelSize: 18
            horizontalAlignment: Text.AlignLeft
            text: "バッテリー不足、充電して下さい。\nシャットダウンします。"
        }

        Row {
            id: row
            anchors {
                horizontalCenter: parent.horizontalCenter
                bottom: parent.bottom
                bottomMargin: 10
            }
            spacing: 25

            MenuButton {
                id: leftButton
                objectName: "m1"
                activebg: "dialogbtn156_one.png"
                idlebg: "dialogbtn156_n.png"
                pressbg: "dialogbtn156_p.png"
                width: 140
                height: 40
                active: true
                Text {
                    id: leftButtonText
                    text: "OK"
                    color: "#e6e6e4"
                    anchors.centerIn: parent
                    font.family: defaultFontName
                    font.pixelSize: 18
                }
                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        closePopup()
                    }
                }
                visible: false
            }
        }
    }

    function closePopup()
    {
        close()
        popup.visible = false
    }
    // 二重にトーンダウンしないようにする
    Overlay.modal: Rectangle {
        color: isOverlay ? "transparent" : "#66333333"
    }
}
