/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
import QtQuick.Controls 2.12
import "../parts"

/**
 * @brief バージョン情報 View
 */
Item {
    id:root
    width: 640
    objectName: "ModelInformation"

    property string modelCode                           // 機種コード
    property string optionCode                          // オプション情報
    property string serialNo                            // シリアル番号
    property string bootProgramVersion                  // ブートバージョン
    property string mainProgramVersion                  // メインプログラムバージョン
    property string subProgramVersion                   // サブプログラムバージョン
    property string qtVersion                           // Qtバージョン
    property string productVersion                      // 製品バージョン

    readonly property int fontSize: 20                  // 文字サイズ(説明文ラベル以外)
    readonly property int descriptionLabelFontSize: 18  // 文字サイズ(説明文ラベル)
    signal request(int condition)

    // 機種コードラベル
    Label {
        id:modelCodeLabel
        anchors {
            top: root.top
            left: root.left
            topMargin: 30
            leftMargin: 70
        }
        text: "MODEL"
        font.pixelSize: root.fontSize
        font.family: defaultFontName
        color:"#83BEFF"
        width: 120
        height: 20
    }

    // 機種コード詳細ラベル
    Label {
        id: modelCodeDetailLabel
        anchors {
            top: modelCodeLabel.top
            left: modelCodeLabel.right
            leftMargin: 20
        }
        text: root.modelCode
        font.pixelSize: root.fontSize
        font.family:    defaultFontName
        color:  "#E4E4E4"
        width:  200
        height: 20
    }

    // シリアル番号ラベル
    Label {
        id: serialNumberLabel
        anchors {
            top: modelCodeLabel.bottom
            topMargin: 40
            left: modelCodeLabel.left
        }
        text: "S/N"
        font.pixelSize: root.fontSize
        font.family:    defaultFontName
        color:  "#83BEFF"
        width:  120
        height: 20
    }

    // シリアル番号詳細ラベル
    Label {
        id: serialNumberDetailLabel
        anchors {
            top: serialNumberLabel.top
            left: modelCodeDetailLabel.left
        }
        text: root.serialNo
        font.pixelSize: root.fontSize
        font.family:    defaultFontName
        color:  "#E4E4E4"
        width:  200
        height: 20
    }

    // バージョンラベル
    Label {
        id: versionLabel
        anchors {
            top: serialNumberLabel.bottom
            topMargin: 40
            left: modelCodeLabel.left
        }
        text: "VERSION NUMBER"
        font.pixelSize: root.fontSize
        font.family:    defaultFontName
        color:  "#83BEFF"
        width:  330
        height: 20
    }

    // 製品ラベル
    Label {
        id: productLabel
        anchors {
            top: versionLabel.bottom
            topMargin: 10
            left: versionLabel.left
            leftMargin: 25
        }
        text: "製品"
        font.pixelSize: root.fontSize
        font.family:    defaultFontName
        color:  "#E4E4E4"
        width:  100
        height: 20
    }

    // 製品バージョンラベル
    Label {
        id: productVersionLabel
        anchors {
            top: productLabel.top
            left: detailLabel.right
            leftMargin: 25
        }
        text: root.productVersion
        font.pixelSize: root.fontSize
        font.family:    defaultFontName
        color : "#E4E4E4"
        width:  200
        height: 20
    }

    // 区切り線
    Rectangle {
        id: separator
        anchors {
            top: productLabel.bottom
            topMargin: 10
            left: productLabel.left
        }

        width: 360
        height: 2
        border.color: "#E6E6E6"
        border.width: 2
    }

    // 内訳ラベル
    Label {
        id: detailLabel
        anchors {
            top: separator.bottom
            topMargin: 10
            left: versionLabel.left
            leftMargin: 25
        }
        text: "内訳"
        font.pixelSize: root.fontSize
        font.family:    defaultFontName
        color:  "#E4E4E4"
        width: 40
        height: 20
    }


    // ブートラベル
    Label {
        id: bootLabel
        anchors {
            top: separator.bottom
            topMargin: 10
            left: detailLabel.right
            leftMargin: 25
        }
        text: "BOOT"
        font.pixelSize: root.fontSize
        font.family:    defaultFontName
        color:  "#E4E4E4"
        width:  30
        height: 20
    }

    // ブートプログラムバージョンラベル
    Label {
        id: bootProgramVersionLabel
        anchors {
            top: bootLabel.top
            left: displayLabel.right
        }
        text: root.bootProgramVersion
        font.pixelSize: root.fontSize
        font.family:    defaultFontName
        color : "#E4E4E4"
        width:  200
        height: 20
    }

    // メインラベル
    Label {
        id: mainLabel
        anchors {
            top: bootLabel.bottom
            topMargin: 10
            left: bootLabel.left
        }
        text: "MAIN"
        font.pixelSize: root.fontSize
        font.family:    defaultFontName
        color:  "#E4E4E4"
        width:  100
        height: 20
    }

    // メインプログラムバージョンラベル
    Label {
        id: mainProgramVersionLabel
        anchors {
            top: mainLabel.top
            left: displayLabel.right
        }
        text: root.mainProgramVersion
        font.pixelSize: root.fontSize
        font.family:    defaultFontName
        color:  "#E4E4E4"
        width:  200
        height: 20
    }

    // サブラベル
    Label {
        id: subLabel
        anchors {
            top: mainLabel.bottom
            topMargin: 10
            left: bootLabel.left
        }
        text: "SUB"
        font.pixelSize: root.fontSize
        font.family:    defaultFontName
        color:  "#E4E4E4"
        width:  100
        height: 20
    }

    // サブプログラムバージョンラベル
    Label {
        id: subProgramVersionLabel
        anchors {
            top: subLabel.top
            left: displayLabel.right
        }
        text: root.subProgramVersion
        font.pixelSize: root.fontSize
        font.family:    defaultFontName
        color:  "#E4E4E4"
        width:  200
        height: 20
    }

    // ディスプレイラベル
    Label {
        id: displayLabel
        anchors {
            top: subLabel.bottom
            topMargin: 10
            left: bootLabel.left
        }
        text: "DISPLAY"
        font.pixelSize: root.fontSize
        font.family: defaultFontName
        color: "#E4E4E4"
        width:  100
        height: 20
    }

    // ディスプレイバージョンラベル
    Label {
        id: displayVersionLabel
        anchors {
            top: displayLabel.top
            left: displayLabel.right
        }
        text: root.qtVersion
        font.pixelSize: root.fontSize
        font.family:    defaultFontName
        color:  "#E4E4E4"
        width:  200
        height: 20
    }

    // オプションラベル
    Label {
        id: optionLabel
        anchors {
            top: displayLabel.bottom
            topMargin: 20
            left: modelCodeLabel.left
        }
        text: "OPTION ID"
        font.pixelSize: root.fontSize
        font.family:    defaultFontName
        color:  "#83BEFF"
        width:  120
        height: 20
    }

    // オプションコードラベル
    Label {
        id: optionCodeLabel
        anchors {
            top: optionLabel.top
            left: modelCodeDetailLabel.left
        }
        text: root.optionCode
        font.pixelSize: root.fontSize
        font.family: defaultFontName
        color: "#E4E4E4"
        width:  200
        height: 20
    }

    // 説明文ラベル
    Label {
        id: descriptionLabel
        anchors {
            top: root.top
            topMargin: 10
            left: modelCodeDetailLabel.right
            leftMargin:130
        }
        text: "下記 WEB サイトで\n詳しい使い方や設定\nなどを確認できます。"
        font.pixelSize: root.descriptionLabelFontSize
        font.family: defaultFontName
        color: "#E4E4E4"
        width: 170
        height: 70
    }

    // QRコード
    Image {
        id: qrcode
        source: "qrc:/resource/png/qrcode.png"
        anchors {
            top: descriptionLabel.bottom
            topMargin: 20
            left: modelCodeDetailLabel.right
            leftMargin: 140
        }
        width: 160
        height: 160
    }

    // アップデートボタン
    SelectButton {
        id: m0
        anchors {
            top: qrcode.bottom
            topMargin: 30
            left: modelCodeDetailLabel.right
            leftMargin: 105
        }

        objectName: "updateButton"
        activebg: "combtn_sel.png"
        idlebg: "combtn.png"
        pressbg: "combtn_p.png"
        message: "最新にアップデート"
        width: 216
        height: 82
        visible: false
    }
    ScreenName {
        name: "バージョン情報"
    }
}
