/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
import QtQuick.Controls 2.12
import "../parts"

/**
 * @brief 登録ファイル選択 View
 */
Item {
    id:root
    objectName: "FileSelection"
    implicitWidth: 800
    implicitHeight: 480

    signal request(int condition)

    // 前画面の設定値を受け取るための仕組み
    // ここから
    function backup(key, value) {
        var temporary = attributes.takeOver
        temporary[key] = value
        attributes.takeOver = temporary
    }
    Item {
        id: takeOverData
        objectName: "takeOverData"
        property int fileselectionListIndex: 0
    }

    Rectangle {
        id:base2
        anchors.fill:parent
        color: "#41444d"
        opacity: 0.5
    }

    Rectangle {
        id:bg2
        anchors.centerIn: parent
        radius: 10
        color: "#41444d"
        border.color: "#333333"

        width: 760
        height: 380

        Text {
            text: "ファイル保存先選択"
            height:40
            width: parent.width
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            color: "white"
            font.pixelSize: 20
            font.family: defaultFontName
        }

        // ユーザデータ選択用リスト
        Image {
            source: "qrc:/resource/png/fileselection_filelist_bg.png"
            y: userSelectList.y + userdataPage.height + 10
        }

        Column {
            id:userSelectList
            y: 60

            Text {
                id: userdataPage
                objectName: "userfilelistpage"
                text: "ファイル保存先 1/10"
                width: parent.width
                horizontalAlignment: Text.AlignHCenter
                color: "white"
                font.pixelSize: 16
                font.family: defaultFontName
            }
            Item {
                width: 10
                height: 10
            }
            ListItem {
                id: userdata0
                objectName: "userdata0"
                activebg: "fileselection_userlist_btn_active_rd.png"
                idlebg: ""
                width:175
                height:40
                fontsize:14
                message: "userdata0"
            }
            ListItem {
                id: userdata1
                objectName: "userdata1"
                activebg: "fileselection_userlist_btn_active_urd.png"
                idlebg: ""
                width:175
                height:40
                fontsize:14
                message: ""
            }
            ListItem {
                id: userdata2
                objectName: "userdata2"
                activebg: "fileselection_userlist_btn_active_urd.png"
                idlebg: ""
                width:175
                height:40
                fontsize:14
                message: ""
            }
            ListItem {
                id: userdata3
                objectName: "userdata3"
                activebg: "fileselection_userlist_btn_active_urd.png"
                idlebg: ""
                width:175
                height:40
                fontsize:14
                message: ""
            }
            ListItem {
                id: userdata4
                objectName: "userdata4"
                activebg: "fileselection_userlist_btn_active_urd.png"
                idlebg: ""
                width:175
                height:40
                fontsize:14
                message: ""
            }
            ListItem {
                id: userdata5
                objectName: "userdata5"
                activebg: "fileselection_userlist_btn_active_urd.png"
                idlebg: ""
                width:175
                height:40
                fontsize:14
                message: ""
            }
            ListItem {
                id: userdata6
                objectName: "userdata6"
                activebg: "fileselection_userlist_btn_active_ur.png"
                idlebg: ""
                width:175
                height:40
                fontsize:14
                message: ""
            }
        }
        // チャンネルリスト
        // 6つのアイテム
        Item {
            id: channelListBase
            anchors.left: userSelectList.right
            anchors.leftMargin: 20
            width: children.width
            height: children.height
            y: 60

            Image {
                source: "qrc:/resource/png/fileselection_displayinfo_bg.png"
                y: listHeader.y + 4
            }

            Column {
                id: channelList
                Text {
                    id:channelListPage
                    objectName: "channelListPage"
                    width: 440
                    text: "x. xxxxxxxx に登録されているCH：1/xx ページ"
                    horizontalAlignment: Text.AlignHCenter
                    verticalAlignment: Text.AlignVCenter
                    color: "white"
                    font.pixelSize: 15
                    font.family: defaultFontName
                }
                Item {
                    width: 10
                    height: 10
                }

                Row {
                    id: listHeader
                    height:35
                    spacing:2

                    Text {
                        text: "No."
                        height:listHeader.height
                        width: 40
                        horizontalAlignment: Text.AlignHCenter
                        verticalAlignment: Text.AlignVCenter
                        color: "skyblue"
                        font.pixelSize: 14
                        font.family: defaultFontName
                    }
                    Text {
                        text: "BAND"
                        height:listHeader.height
                        width: 78
                        horizontalAlignment: Text.AlignHCenter
                        verticalAlignment: Text.AlignVCenter
                        color: "skyblue"
                        font.pixelSize: 14
                        font.family: defaultFontName
                    }
                    Text {
                        text: "放送規格"
                        height:listHeader.height
                        width: 78
                        horizontalAlignment: Text.AlignHCenter
                        verticalAlignment: Text.AlignVCenter
                        color: "skyblue"
                        font.pixelSize: 14
                        font.family: defaultFontName
                    }
                    Text {
                        text: "CH"
                        height:listHeader.height
                        width: 78
                        horizontalAlignment: Text.AlignHCenter
                        verticalAlignment: Text.AlignVCenter
                        color: "skyblue"
                        font.pixelSize: 14
                        font.family: defaultFontName
                    }
                    Text {
                        text: "変調方式"
                        height:listHeader.height
                        width: 78
                        horizontalAlignment: Text.AlignHCenter
                        verticalAlignment: Text.AlignVCenter
                        color: "skyblue"
                        font.pixelSize: 14
                        font.family: defaultFontName
                    }
                    Text {
                        text: "局発"
                        height:listHeader.height
                        width: 78
                        horizontalAlignment: Text.AlignHCenter
                        verticalAlignment: Text.AlignVCenter
                        color: "skyblue"
                        font.pixelSize: 14
                        font.family: defaultFontName
                    }
                }

                ChannelListEdit {
                    id:list0
                    objectName: "list0"
                    idlebg:""
                }
                ChannelListEdit {
                    id:list1
                    objectName: "list1"
                    idlebg:""
                }
                ChannelListEdit {
                    id:list2
                    objectName: "list2"
                    idlebg:""
                }
                ChannelListEdit {
                    id:list3
                    objectName: "list3"
                    idlebg:""
                }
                ChannelListEdit {
                    id:list4
                    objectName: "list4"
                    idlebg:""
                }
                ChannelListEdit {
                    id:list5
                    objectName: "list5"
                    idlebg:""
                }
            }
        }

        // 実行ボタンリスト
        Column {
            id: executeList
            width:children.width
            x: 670
            y: 60
            SelectButton {
                id: execute1
                objectName: "execute1"
                message: "決\n定"
                width:63
                height:314
                activebg:"fileselection_action_btn_active_l.png"
                idlebg: "fileselection_action_btn.png"
                pressbg: "fileselection_action_btn_p.png"
                fontsize:20
            }
        }
    }

    ScreenName {
        name:""
    }
}
