/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12
import jp.co.dxantenna.levelchecker.BandModel 1.0

import "../parts"

/**
 * @brief USER/データロガー設定呼び出し
 */
Item {
    id: userDataLoggerSetting
    objectName: "UserDataLoggerSetting"
    anchors.fill: parent

    // 最大登録件数
    readonly property int userMaximumNumberOfRegistration: 150                  // 最大登録件数
    readonly property int dataLoggerMaximumNumberOfRegistration: 50             // 最大登録件数

    // チャンネルリストのヘッダー列の定義
    readonly property int channelColumns: 7                                     // チャンネルリストの列数
    readonly property int headerWidth: 507                                      // チャンネルリスト全体の幅
    readonly property var headerColumnWidth: [ 63, 104, 104, 88, 45, 45, 45 ]   // チャンネルリストの各列の幅
    readonly property int headerSpacing: 2                                      // チャンネルリストの各列の間隔
    readonly property var headerColumnName: [ "CH", "周波数(MHz)", "放送規格", "局発(GHz)", "MER\n/CN", "BER", "給電" ]    // チャンネルリストの列名
    readonly property int headerColumnHeight: 34                                // チャンネルリストのヘッダーの高さ
    readonly property string headerColumnBackgroundColor: "#32324B"             // チャンネルリストのヘッダーの背景色
    readonly property string headerColumnTextColor: "#80BFFF"                   // チャンネルリストのヘッダーのテキスト色
    readonly property string onOffColumnBackgroundColor: "transparent"          // 測定 ON/OFFの背景色
    readonly property int onOffWidth: 45                                        // 測定 ON/OFF 列の幅

    // チャンネルリストの行の定義
    readonly property int channelListHeight: 200                                // チャンネルリスト全行の高さ
    readonly property var channelRowTextColors: [ "#80BFFF", "#E4E5E6", "#E4E5E6", "#E4E5E6", "#E4E5E6", "#E4E5E6", "#E4E5E6" ] // チャンネルリストの各行のテキスト色
    readonly property int channelRowHeight: 40                                  // チャンネルリストの行の高さ
    readonly property int channelRows: 5                                        // チャンネルリストの行数
    readonly property var activeBackgoundImages: [ "user_datalogger_setting_5.png", "user_datalogger_setting_48.png", "user_datalogger_setting_48.png", "user_datalogger_setting_48.png", "user_datalogger_setting_47.png" ]  // チャンネルリストの行がアクティブな場合の背景画像
    readonly property var idleBackgoundImages: [ "user_datalogger_setting_2.png", "user_datalogger_setting_3.png", "user_datalogger_setting_2.png", "user_datalogger_setting_3.png", "user_datalogger_setting_2.png" ] // チャンネルリストの行が非アクティブな場合の背景画像
    readonly property var editBackgoundImages: [ "datalogger_channellist_cur_edit.png", "datalogger_channellist_cur_edit.png", "datalogger_channellist_cur_edit.png", "datalogger_channellist_cur_edit.png", "datalogger_channellist_cur_edit.png" ]    // チャンネルリストの行を編集中の場合の背景画像
    readonly property string selectedBackgroundImage: "user_datalogger_setting_6.png"
    readonly property var targetActiveBackgoundImages: [ "user_datalogger_setting_28.png", "user_datalogger_setting_28.png", "user_datalogger_setting_28.png", "user_datalogger_setting_28.png", "user_datalogger_setting_28.png" ]  // 測定 ON/OFF リストの行がアクティブな場合の背景画像


    readonly property var dummyChannelData: [ "---", "---", "---", "---", "---", "---", "---", false ]  // ダミー行の測定内容
    readonly property int channelListIndexChannel: 0            // チャンネルリスト中の測定チャンネルのインデックス
    readonly property int channelListIndexFrequency: 1          // チャンネルリスト中の周波数のインデックス
    readonly property int channelListIndexBroadbandSystem: 2    // チャンネルリスト中の放送規格のインデックス
    readonly property int channelListIndexLocalFrequency: 3     // チャンネルリスト中の局発周波数のインデックス
    readonly property int channelListIndexMerCn: 4              // チャンネルリスト中の MER/CN のインデックス
    readonly property int channelListIndexBer: 5                // チャンネルリスト中の BER のインデックス
    readonly property int channelListIndexPowerSupply: 6        // チャンネルリスト中の給電のインデックス
    readonly property int channelListIndexTarget: 7             // チャンネルリスト中の測定 ON/OFF のインデックス

    readonly property int filelistArea: 1           // ファイルリストにフォーカスがある(ファイルリストの中の行移動可能)
    readonly property int channelListArea: 2        // 測定内容リストにフォーカスがある(測定内容の中の行移動可能)
    readonly property int channelEditArea: 3        // 測定内容の編集可能項目にフォーカスがある(編集可能項目の値変更可能)
    readonly property int targetListArea: 4         // 測定 ON/OFF リストにフォーカスがある(測定 ON/OFF の中の行移動可能)
    readonly property int targetEditArea: 5         // 測定 ON/OFF の編集可能項目にフォーカスがある(ON/OFF 変更可能)
    readonly property int actionArea: 6             // 右端のボタンにフォーカスがある(ボタン間の移動可能)
    readonly property int popupArea: 7              // ポップアップにフォーカスがある
    readonly property int targetAllArea: 8          // 測定 全てON/OFF にフォーカスがある
    readonly property int targetAllEditArea: 9     // 測定 全てON/OFF の編集可能項目にフォーカスがある(ON/OFF 変更可能)

    readonly property int actionIndexAllDelete: 1     // 右端のボタンエリア内の一括削除ボタンのインデックス
    readonly property int actionIndexSave: 2        // 右端のボタンエリア内の保存ボタンのインデックス
    readonly property int actionIndexDelete: 3      // 右端のボタンエリア内の削除ボタンのインデックス
    readonly property int actionIndexDecision: 4    // 右端のボタンエリア内の決定ボタンのインデックス

    property int mode: 0                                                // 0: USER 設定呼び出し 1: データロガー設定呼び出し 2: 保存先選択
    property int activeArea: userDataLoggerSetting.filelistArea             // フォーカスを持つ領域
    property int fileListCount: 10                                      // USERデータロガー設定ファイルのリストの表示行数
    property var fileList: [ "", "", "", "", "", "", "", "", "", "" ]   // USERデータロガー設定ファイルのリストに表示するファイル名
    property int currentTopFileListIndex: 1                             // USERデータロガー設定ファイルのリストの先頭のインデックス(ページの変更により増減)
    property string page: "ページ 1/14"　                                // USERデータロガー設定ファイルのリストのページ
    property int currentSelectedFileListIndex: 0                        // USERデータロガー設定ファイルのリストの現在選択されているインデックス
    property var channelList: [
        [ "---", "---", "---", "---", "---", "---", "---", false ],
        [ "---", "---", "---", "---", "---", "---", "---", false ],
        [ "---", "---", "---", "---", "---", "---", "---", false ],
        [ "---", "---", "---", "---", "---", "---", "---", false ],
        [ "---", "---", "---", "---", "---", "---", "---", false ],
    ]
    property var channelTargetAll: false                                // 測定 全てON/OFFの選択状況

    property int channelListCount: 5                                       // チャンネルリストの表示行数
    property int currentSelectedChannelListIndex: 0                        // チャンネルリストの現在選択されているインデックス
    property int currentTopChannelListIndex: 0                             // チャンネルリストのリストの先頭のインデックス
    property int currentSelectedTargetListIndex: 0                         // 測定 ON/OFF リストの現在選択されているインデックス
    property int currentTopTargetListIndex: 0                              // 測定 ON/OFF リストのリストの先頭のインデックス
    property int currentEditItemIndex: 0                                   // チャンネルリストの現在選択中の行の中で、現在編集中の列のインデックス
    property int currentActionIndex: 0                                     // 右端のボタンエリア内の現在選択されているインデックス
    property bool isFileEditing: false                                     // 現在選択中のファイルが編集中かどうか
    property int channelCount: 0                                           // 測定 ON のチャンネル数
    property bool isUSBMemoryFound: false                                  // データロガー設定で USB メモリーが装着されていない

    property var channelListColor: [ false, false, false, false, false, false, false, false ] // チャンネルリストの文字色 true:白色 false:水色

    // enum ChannelEditMode と同期させる
    readonly property int  channelEditUser : 0
    readonly property int  channelEditUserUsb1: 1
    readonly property int  channelEditUserUsb2: 2
    readonly property int  channelEditDataLogger: 3
    readonly property int  channelEditDataLoggerUsb1: 4
    readonly property int  channelEditDataLoggerUsb2: 5
    readonly property int  channelEditSelectDestination: 6

    signal request(int condition)

    function backup(key, value) {
        var temporary = attributes.takeOver
        temporary[key] = value
        attributes.takeOver = temporary
    }

    // 引き継ぎデータの中継
    Item {
        id: takeOverData
        objectName: "takeOverData"
        property int userDataloggerFunction: 0
    }

    // Band 表示用データ
    BandModel {
        id: bandModel
        objectName: "bandModel"
    }

    // USERデータロガー設定ファイルページ数
    Text {
        id: userdataPage
        text: userDataLoggerSetting.page
        anchors {
            top: parent.top
            left: parent.left
        }
        width: 185
        height: 33
        verticalAlignment: Text.AlignVCenter
        horizontalAlignment: Text.AlignHCenter
        color: "white"
        font.pixelSize: 16
        font.family: defaultFontName
    }

    // ファイル一覧の背景
//    Image {
//        source: "qrc:/resource/png/datalogger_userlist_base.png"
//        anchors {
//            top: userdataPage.bottom
//            left: parent.left
//        }
//    }

    // 設定ファイルリスト表示
    Column {
        id: userSelectList
        objectName: "userSelectList"
        width: 131
        anchors {
            top: userdataPage.bottom
            left: parent.left
            leftMargin: 20
        }

        Repeater {
            model: userDataLoggerSetting.fileListCount

            // 各行
            ListItem {
                id: fileList
                activebg: userDataLoggerSetting.activeArea == userDataLoggerSetting.filelistArea
                            ? model.index === 0
                                ? "datalogger_userlist_btn_active.png"
                                : model.index === (fileListCount - 1)
                                    ? "datalogger_userlist_btn_active.png"
                                    : "datalogger_userlist_btn_active.png"
                            : "datalogger_userlist_btn_edit.png"
                idlebg: "datalogger_userlist_btn"
                width: userSelectList.width
                height: 34
                fontsize:15
                type: 0
                message: userDataLoggerSetting.fileList[model.index]
                listItemNumber: userDataLoggerSetting.currentTopFileListIndex + model.index
                disable: (message === "" || message === null)
                active: (model.index === userDataLoggerSetting.currentSelectedFileListIndex) ? true : false
            }
        }
    }

    // ファイル名表示
    Text {
        id: fileName
        objectName: "fileName"
        anchors {
            top: parent.top
            left: channelListHeader.left
        }

        width: 125
        height: 34
        horizontalAlignment: Text.AlignLeft
        verticalAlignment: Text.AlignVCenter
        color: "white"
        text: "ファイル名  " + userDataLoggerSetting.fileList[currentSelectedFileListIndex]
        font.pixelSize: 16
        font.family: defaultFontName
        visible: {
            if((userDataLoggerSetting.mode === channelEditSelectDestination) && (fileList[currentSelectedFileListIndex] === "未設定") ){
                false
            } else {
                true
            }
        }
    }

    // チャンネルリストの選択件数
    Text {
        id: channelListPage
        objectName: "channelListPage"
        anchors {
            top: parent.top
            right: channelList.right
        }

        width: 125
        height: 34
        horizontalAlignment: Text.AlignRight
        verticalAlignment: Text.AlignVCenter
        color: "#C30000"
        text: (mode === channelEditDataLogger || mode === channelEditDataLoggerUsb1 || mode === channelEditDataLoggerUsb2)
              ? "測定チャンネル数  " + userDataLoggerSetting.channelCount + "/" + userDataLoggerSetting.dataLoggerMaximumNumberOfRegistration
              : "測定チャンネル数  " + userDataLoggerSetting.channelCount + "/" + userDataLoggerSetting.userMaximumNumberOfRegistration
        font.pixelSize: 16
        font.family: defaultFontName
        visible: {
            if((userDataLoggerSetting.mode === channelEditSelectDestination) && (fileList[currentSelectedFileListIndex] === "未設定") ){
                false
            } else {
                true
            }
        }
    }

    // チャンネルリストのヘッダー行の区画
    Rectangle {
        id: channelListHeader
        width: userDataLoggerSetting.headerWidth
        height: userDataLoggerSetting.headerColumnHeight
        anchors {
            top: channelListPage.bottom
            left: userSelectList.right
            leftMargin: 8
        }
        color: userDataLoggerSetting.headerColumnBackgroundColor
        visible: {
            if((userDataLoggerSetting.mode === channelEditSelectDestination) && (fileList[currentSelectedFileListIndex] === "未設定") ){
                false
            } else {
                true
            }
        }

        // チャンネルリストのヘッダー行
        Row {
            spacing: userDataLoggerSetting.headerSpacing
            Repeater {
                model: userDataLoggerSetting.channelColumns

                Rectangle {
                    width: userDataLoggerSetting.headerColumnWidth[model.index]
                    height: userDataLoggerSetting.headerColumnHeight
                    color: userDataLoggerSetting.headerColumnBackgroundColor
                    Text {
                        objectName: "row" + String(model.index + 1)
                        text: userDataLoggerSetting.headerColumnName[model.index]
                        anchors.fill: parent
                        horizontalAlignment: Text.AlignHCenter
                        verticalAlignment: Text.AlignVCenter
                        color: userDataLoggerSetting.headerColumnTextColor
                        font.pixelSize: 15
                        font.family: defaultFontName
                    }
                }
            }
        }
    }

    // チャンネルリストの区画
    Rectangle {
        id: channelList
        objectName: "channelList"
        width: userDataLoggerSetting.headerWidth
        height: userDataLoggerSetting.channelListHeight
        anchors {
            top: channelListHeader.bottom
            topMargin: 3
            left: userSelectList.right
            leftMargin: 8
        }
        color: "transparent"
        visible: {
            if((userDataLoggerSetting.mode === channelEditSelectDestination) && (fileList[currentSelectedFileListIndex] === "未設定") ){
                false
            } else {
                true
            }
        }

        Repeater {
            model: userDataLoggerSetting.channelRows
            Image {
                source: "qrc:/resource/png/" + userDataLoggerSetting.idleBackgoundImages[model.index]
                anchors.top: parent.top
                anchors.topMargin: (40 * model.index) + 1
            }
        }

        Repeater {
            model: userDataLoggerSetting.channelRows
            ChannelFocus {
                id: channelActiveFocusEdit
                objectName: "channel" + String(model.index)
                anchors.top: parent.top
                anchors.topMargin: 40 * currentSelectedTargetListIndex
                active: (model.index === userDataLoggerSetting.currentSelectedChannelListIndex &&
                         userDataLoggerSetting.activeArea === userDataLoggerSetting.channelListArea)
                        ? true : false
                edit: userDataLoggerSetting.activeArea === userDataLoggerSetting.channelListArea
                        && model.index === currentSelectedChannelListIndex
                editItemIndex: userDataLoggerSetting.currentEditItemIndex
            }
        }

        // チャンネルリスト
        Column {
            id: channelRows
            objectName: "channelRows"
            Repeater {
                id: channelRowsRepeater
                objectName: "channelRowsRepeater"
                model: userDataLoggerSetting.channelRows
                ChannelRowEdit {
                    id: channelRowEdit
                    objectName: "channel" + String(model.index)
                    channelData: (currentTopChannelListIndex + model.index) < userDataLoggerSetting.channelList.length
                                 ? userDataLoggerSetting.channelList[(currentTopChannelListIndex + model.index)]
                                 : dummyChannelData
                    // チャンネルリストが編集中のとき active とする
                    active: (model.index === userDataLoggerSetting.currentSelectedChannelListIndex &&
                             userDataLoggerSetting.activeArea === userDataLoggerSetting.channelEditArea)
                            ? true : false
                    channelDataColor: userDataLoggerSetting.channelListColor
                    isTop: model.index === 0
                    isBottom: model.index === (channelListCount - 1)
                              || (currentTopChannelListIndex + model.index) === userDataLoggerSetting.channelList.length - 1
                    editItemIndex: userDataLoggerSetting.currentEditItemIndex
                    edit: userDataLoggerSetting.activeArea === userDataLoggerSetting.channelEditArea
                            && model.index === currentSelectedChannelListIndex
                    selected : (userDataLoggerSetting.channelList[(currentTopChannelListIndex + model.index)] === undefined) ? false :
                        (userDataLoggerSetting.channelList[(currentTopChannelListIndex + model.index)][channelListIndexTarget] === "ON") ? true : false
                }
            }
        }
    }

    // 測定 ON/OFF リストのヘッダー行の区画
    Rectangle {
        id: targetListHeader
        width: userDataLoggerSetting.onOffWidth
        height: userDataLoggerSetting.headerColumnHeight
        anchors {
            top: channelListHeader.top
            left: channelListHeader.right
            leftMargin: 8
        }
        color: userDataLoggerSetting.headerColumnBackgroundColor
        visible: {
            if((userDataLoggerSetting.mode === channelEditSelectDestination) && (fileList[currentSelectedFileListIndex] === "未設定") ){
                false
            } else {
                true
            }
        }

        // 測定 ON/OFF リストのヘッダー行
        Rectangle {
            width: userDataLoggerSetting.onOffWidth
            height: userDataLoggerSetting.headerColumnHeight
            color: userDataLoggerSetting.onOffColumnBackgroundColor
            Text {
                text: "測定"
                anchors.fill: parent
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
                color: userDataLoggerSetting.headerColumnTextColor
                font.pixelSize: 15
                font.family: defaultFontName
            }
        }
    }

    // 測定 全てON/OFF ボタンの区画
    Rectangle {
        id: targetButton
        width: userDataLoggerSetting.onOffWidth
        height: 40
        anchors {
            bottom: targetListHeader.top
            bottomMargin: 1
            left: targetListHeader.left
        }
        color: userDataLoggerSetting.onOffColumnBackgroundColor
        visible: {
            if((userDataLoggerSetting.mode === channelEditSelectDestination) && (fileList[currentSelectedFileListIndex] === "未設定") ){
                false
            } else {
                true
            }
        }

        Image {
            source: "qrc:/resource/png/" + "user_datalogger_setting_24.png"
            anchors.top: parent.top
            anchors.left: parent.left
        }

        Image {
            // 26, 27, 28 は選択、30 は編集用
            source: userDataLoggerSetting.activeArea === userDataLoggerSetting.targetAllEditArea
                        ? "qrc:/resource/png/user_datalogger_setting_30.png"
                        : userDataLoggerSetting.activeArea === userDataLoggerSetting.targetAllArea
                          ? "qrc:/resource/png/" + "user_datalogger_setting_28.png"
                            : ""
            anchors.top: parent.top
            anchors.left: parent.left
        }

        // 測定 全てON/OFF
        SelectButton {
            objectName: "allOnOff"
            width: userDataLoggerSetting.onOffWidth
            height: targetButton.height
            anchors.fill: parent
            message: userDataLoggerSetting.channelTargetAll ? "全て\nする" : "全て\nしない"
            fontsize: 13
            // 測定 全てON/OFF がフォーカスを持つとき active とする
            active: (userDataLoggerSetting.activeArea === userDataLoggerSetting.targetAllArea ||
                     userDataLoggerSetting.activeArea === userDataLoggerSetting.targetAllEditArea
                     ) ? true : false
            useChannelEdit: true
            selected : channelTargetAll
            userOnOff: true
        }
    }

    // 測定 ON/OFF リストの区画
    Rectangle {
        id: targetList
        width: userDataLoggerSetting.onOffWidth
        height: userDataLoggerSetting.channelListHeight
        anchors {
            top: targetListHeader.bottom
            topMargin: 3
            left: channelList.right
            leftMargin: 8
        }
        color: userDataLoggerSetting.onOffColumnBackgroundColor
        visible: {
            if((userDataLoggerSetting.mode === channelEditSelectDestination) && (fileList[currentSelectedFileListIndex] === "未設定") ){
                false
            } else {
                true
            }
        }

        Repeater {
            model: userDataLoggerSetting.channelRows
            Image {
                source: "qrc:/resource/png/" + ((model.index %2 > 0) ? "user_datalogger_setting_23.png" : "user_datalogger_setting_24.png")
                anchors.top: parent.top
                anchors.topMargin: channelRowHeight * model.index
            }
        }

        // 測定 ON/OFF の編集時に表示するアイコン
        Repeater {
            x: 0
            y: 0
            model: userDataLoggerSetting.channelRows
            Image {
                // 26, 27, 28 は選択、30 は編集用
                source: (model.index % userDataLoggerSetting.channelRows) === userDataLoggerSetting.currentSelectedTargetListIndex
                        ? userDataLoggerSetting.activeArea === userDataLoggerSetting.targetEditArea
                          ? "qrc:/resource/png/user_datalogger_setting_30.png"
                              : ""
                : ""
                anchors.top: parent.top
                anchors.topMargin: (40 * model.index) + 1
                visible: (userDataLoggerSetting.activeArea === userDataLoggerSetting.targetEditArea)
            }
        }

        Repeater {
            model: userDataLoggerSetting.channelRows
            Image {
                x: 0
                y: 40 * currentSelectedTargetListIndex

                source: "qrc:/resource/png/" + userDataLoggerSetting.targetActiveBackgoundImages[currentSelectedTargetListIndex]
                visible: (activeArea == targetListArea) ? true : false
            }
        }

        // 測定 ON/OFF リスト
        Column {
            Repeater {
                model: userDataLoggerSetting.channelRows
                // ON/OFF
                SelectButton {
                    objectName: "onOff" + String(model.index)
                    width: userDataLoggerSetting.onOffWidth
                    height: userDataLoggerSetting.channelRowHeight
                    message: (currentTopTargetListIndex + model.index) < userDataLoggerSetting.channelList.length
                                && userDataLoggerSetting.channelList[(currentTopTargetListIndex + model.index)][channelListIndexTarget] === "する" ? "する" : "しない"
                    fontsize: 13
                    // 測定 ON/OFF リストあるいはチャンネルリストがフォーカスを持つとき active とする
                    active: ((model.index % userDataLoggerSetting.channelRows) === userDataLoggerSetting.currentSelectedTargetListIndex &&
                             (userDataLoggerSetting.activeArea === userDataLoggerSetting.targetListArea ||
                              userDataLoggerSetting.activeArea === userDataLoggerSetting.targetEditArea ||
                              userDataLoggerSetting.activeArea === userDataLoggerSetting.channelListArea ||
                              userDataLoggerSetting.activeArea === userDataLoggerSetting.channelEditArea
                              )
                             ) ? true : false
                    activebg: ""
                    useChannelEdit: true
                    selected : (userDataLoggerSetting.channelList[(currentTopChannelListIndex + model.index)] === undefined) ? false :
                        (userDataLoggerSetting.channelList[(currentTopChannelListIndex + model.index)][channelListIndexTarget] === "する") ? true : false
                    userOnOff: true
                }
            }
        }
    }

    // 説明アイコン
    Image {
        id: explanationIcon
        width: 29
        height: 14
        anchors.top: channelList.bottom
        anchors.topMargin: 10
        anchors.left: channelList.left
        source: "qrc:/resource/png/user_datalogger_setting_57.png"
        visible: {
            if((userDataLoggerSetting.mode === channelEditSelectDestination) && (fileList[currentSelectedFileListIndex] === "未設定") ){
                false
            } else {
                true
            }
        }
    }

    // 説明
    Text {
        id: explanationText
        anchors.bottom: explanationIcon.bottom
        anchors.left: explanationIcon.right
        anchors.leftMargin: 7
        width: 100

        color: "#80BFFF"
        text: "BAND ボタン：バンド切替"
        font.pixelSize: 15
        font.family: defaultFontName
        visible: {
            if((userDataLoggerSetting.mode === channelEditSelectDestination) && (fileList[currentSelectedFileListIndex] === "未設定") ){
                false
            } else {
                true
            }
        }
    }

    // Band タブ一覧
    TableView {
        anchors.top: explanationText.bottom
        anchors.topMargin: 9
        anchors.left: channelList.left
        anchors.leftMargin: 4
        width: 560
        height: 84
        visible: {
            if((userDataLoggerSetting.mode === channelEditSelectDestination) && (fileList[currentSelectedFileListIndex] === "未設定") ){
                false
            } else {
                true
            }
        }
        columnSpacing: 8
        rowSpacing: 6
        clip: true

        model: bandModel

        delegate: Image {
            source: (model.selection)
                    ? "qrc:/resource/png/user_datalogger_setting_53.png" : (model.recordCount > 0)
                      ? "qrc:/resource/png/user_datalogger_setting_54.png" : "qrc:/resource/png/user_datalogger_setting_55.png"
            Text {
                anchors.centerIn: parent
                text: bandName

                // どの Band も選択されていなければ通常のテキスト色にして見えやすくする
                color: (model.selection || model.allUnselected) ? "#E6E6E6" : (model.recordCount > 0) ? "#E6E6E6" : "#5A5F64"
                font.pixelSize: 10
                font.family: defaultFontName
            }
            visible: (model.bandName !== "")
        }
    }

    // 保存ボタン
    SelectButton {
        id: saveButton
        objectName: "saveButton"
        width: 47
        height: 119
        anchors {
            top: targetListHeader.top
            topMargin: -5
            left: targetListHeader.right
            leftMargin: 8
        }
        active: activeArea == actionArea && currentActionIndex == actionIndexSave
        press: false
        disable: channelCount === 0
        message: "保\n存"
        activebg: "user_datalogger_setting_56.png"
        idlebg: "user_datalogger_setting_52.png"
        pressbg: "user_datalogger_setting_49.png"
        visible: (userDataLoggerSetting.mode != channelEditSelectDestination)
    }

    // 削除ボタン
    SelectButton {
        id: deleteButton
        objectName: "deleteButton"
        width: 47
        height: 119
        anchors {
            top: saveButton.bottom
            topMargin: 10
            left: saveButton.left
        }
        active: activeArea == actionArea && currentActionIndex == actionIndexDelete
        press: false
        disable: fileList[currentSelectedFileListIndex] === "未設定"
        message: "削\n除"
        activebg: "user_datalogger_setting_56.png"
        idlebg: "user_datalogger_setting_52.png"
        pressbg: "user_datalogger_setting_49.png"
        visible: (userDataLoggerSetting.mode != channelEditSelectDestination)
    }

    // 一括削除ボタン
    SelectButton {
        id: allDeleteButton
        objectName: "allDeleteButton"
        width: 47
        height: 119
        anchors {
            top: deleteButton.bottom
            topMargin: 10
            left: deleteButton.left
        }
        active: activeArea == actionArea && currentActionIndex == actionIndexAllDelete
        press: false
        disable: false
        message: "一\n括\n削\n除"
        activebg: "user_datalogger_setting_56.png"
        idlebg: "user_datalogger_setting_52.png"
        pressbg: "user_datalogger_setting_49.png"
        visible: (userDataLoggerSetting.mode != channelEditSelectDestination)
    }

    // 保存ボタン(保存先選択画面の場合のみ)
    SelectButton {
        id: determinationButton
        objectName: "determinationButton"
        width: 55
        height: 340
        anchors {
            top: targetListHeader.top
            left: targetListHeader.right
            leftMargin: 10
        }
        active: activeArea == actionArea && currentActionIndex == actionIndexDecision
        press: false
        message: "保\n存"
        activebg: "user_datalogger_setting_33.png"
        idlebg: "user_datalogger_setting_35.png"
        pressbg: "user_datalogger_setting_34.png"
        visible: (userDataLoggerSetting.mode === channelEditSelectDestination)
    }

    // 画面名
    ScreenName {
        objectName: "screenName"
        name: {
            if ( (mode === channelEditUser) ||
                 (mode === channelEditUserUsb1) ||
                 (mode === channelEditUserUsb2) ) {
                "USER測定設定"
            } else if ( (mode === channelEditDataLogger) ||
                        (mode === channelEditDataLoggerUsb1) ||
                        (mode === channelEditDataLoggerUsb2) ) {
                "データロガー設定"
            } else if (mode === channelEditSelectDestination) {
                "保存先選択"
            } else {
                ""
            }
        }
    }

    Item {
        id:dgPopup
        objectName:"dgPopup"
        width:userDataLoggerSetting.width
        height:userDataLoggerSetting.height + 50
        y: -50
        visible: false

        // type 0 ... 取得開始POPUP
        // type 1 ... 日時設定POPUP
        // type 2 ... 取得間隔POPUP
        // type 3 ... 待機中POPUP
        // type 4 ... キャンセル確認POPUP
        property int popupType: -1
        property string rightButtonMessage: ""
        property string leftButtonMessage: ""

        property string message:""
        property int interval: 0
        property int rsvInterval: 0
        property int cycle: 0
        property int rsvCycle: 0

        onPopupTypeChanged: {
            bg.popupType = popupType
        }

        onRsvIntervalChanged: {
            interval = rsvInterval
            rsvintervaldata.interval = rsvInterval
        }

        onRsvCycleChanged: {
            cycle = rsvCycle
            rsvcycledata.cycle = rsvCycle
        }

        Rectangle {
            id:base
            anchors.fill:parent
            color: "#41444d"
            opacity: 0.5
        }

        Rectangle {
            id:bg
            anchors.centerIn: parent
            radius: 10
            color: "#41444d"
            border.color: "#333333"

            property int popupType: -1

            onPopupTypeChanged: {
                row.popupType = popupType
            }

            // popupType 毎の大きさ定義
            property var wArray: [460, 580, 500, 580, 460, 460]
            property var hArray: [160, 340, 240, 160, 160, 160]

            width:  wArray[dgPopup.popupType]
            height: hArray[dgPopup.popupType]

            // メッセージ領域
            Text {
                id: messageArea
                anchors {
                    horizontalCenter: parent.horizontalCenter
                    top: parent.top
                    topMargin: (dgPopup.popupType === 3) ? 50 : 15
                }
                color: "white"
                font.family: defaultFontName
                font.pixelSize: 18
                horizontalAlignment: (dgPopup.popupType === 3) ? Text.Center : Text.AlignLeft
                text: dgPopup.message
            }

            // ボタン領域
            Rectangle { // 区切り線
                width: bg.wArray[dgPopup.popupType] - 60
                height:1
                color:"gray"
                anchors {
                    bottom:row.top
                    bottomMargin: 10
                    horizontalCenter: bg.horizontalCenter
                }
                visible: dgPopup.popupType != 0 && dgPopup.popupType != 3 && dgPopup.popupType != 4
            }

            Text {
                id: settinga
                text: qsTr("設定、予約設定を選択してください。")
                color: "white"
                visible: dgPopup.popupType == 0
                x:90
                y:30
            }

            Text {
                text: qsTr("データロガー予約設定をキャンセルしますか？")
                color: "white"
                visible: dgPopup.popupType == 4
                anchors.horizontalCenter: parent.horizontalCenter
                y:30
            }

            Row {
                id: row
                property int popupType:-1

                onPopupTypeChanged: {
                    if (popupType == 0) {
                        leftButton.activebg = "dialogbtn156_l.png"
                        leftButton.idlebg = "dialogbtn156_n.png"
                        leftButton.width = 176
                        leftButton.height = 60

                        rightButton.activebg = "dialogbtn156_l.png"
                        rightButton.idlebg = "dialogbtn156_n.png"
                        rightButton.width = 176
                        rightButton.height = 60
                    }
                    else if (popupType === 1) {
                        leftButton.activebg = "selectbtn_u.png"
                        leftButton.idlebg = "selectbtn.png"
                        leftButton.width = 168
                        leftButton.height = 60
                    }
                    else if (popupType == 2) {
                        leftButton.activebg = "selectbtn_u.png"
                        leftButton.idlebg = "selectbtn.png"
                        leftButton.width = 168
                        leftButton.height = 60
                        leftButton.active = false
                    }
                    else if (popupType == 3) {
                        leftButton.activebg = "dialogbtn156_one.png"
                        leftButton.idlebg = "dialogbtn156_n.png"
                        leftButton.width = 140
                        leftButton.height = 42
                    }
                    else if (popupType == 4) {
                        leftButton.activebg = "dialogbtn156_l.png"
                        leftButton.idlebg = "dialogbtn156_n.png"
                        leftButton.width = 176
                        leftButton.height = 60

                        rightButton.activebg = "dialogbtn156_l.png"
                        rightButton.idlebg = "dialogbtn156_n.png"
                        rightButton.width = 176
                        rightButton.height = 60
                    }
                    else {
                        leftButton.activebg = "dialogbtn156_one.png"
                        leftButton.idlebg = "dialogbtn156_n.png"
                    }
                }

                anchors {
                   horizontalCenter: bg.horizontalCenter
                   bottom: bg.bottom
                   bottomMargin: (dgPopup.popupType === 0 || dgPopup.popupType === 4) ? (bg.height / 2) - (leftButton.height / 2) : 20
                }
                spacing: 25

                SelectButton {
                    id: leftButton
                    objectName: "m1"
                    activebg:""
                    idlebg: ""
                    width: 140
                    height: 40
                    fontsize: 18
                    active: false
                    message: dgPopup.leftButtonMessage
                    visible: dgPopup.popupType != 3
                    y: (dgPopup.popupType === 0 || dgPopup.popupType === 4) ? 20 : 0
                    //y: (dgPopup.popupType === 0 ) ? 20 : (dgPopup.popupType === 4) ? 35 : 0
                }
                SelectButton {
                     id: rightButton
                     objectName: "m2"
                     activebg: ""
                     idlebg: ""
                     width: 140
                     height: 40
                     fontsize: 18
                     active: false
                     message: dgPopup.rightButtonMessage
                     visible: (dgPopup.popupType === 0 || dgPopup.popupType === 4)
                     y:20
                     //y: (dgPopup.popupType === 4) ? 25 : 20
                 }
             }

            // データロガー　データ取得開始日時設定部品
            Item {
                id: editDate
                width:bg.width
                visible: (dgPopup.popupType === 1)

                anchors.fill: bg

                Image {
                    id: datetimebuck
                    source: "qrc:/resource/png/datalogger_datetimeset_starttime_cur_edit.png"
                    x:140
                    y:72
                }

                Image {
                    id: startDatetimeBackground
                    objectName: "startDatetimeBackground"
                    anchors.horizontalCenter: editDate.horizontalCenter
                    anchors.top: editDate.top
                    anchors.topMargin: 72
                    width: 300
                    height: 60
                    property string startDatetimeBackgroundImage: ""
                    source: startDatetimeBackgroundImage
                }

                Column {
                    anchors.horizontalCenter: parent.horizontalCenter
                    y: 30
                    Text {
                        id: measurableTime
                        objectName: "measurableTime"
                        width:525
                        color: dgPopup.popupType === 1 ?"#72A3D6": "white"
                        font.family: defaultFontName
                        font.pixelSize: 20
                        horizontalAlignment: Text.Center
                        text: "測定可能時間は約 12 時間"
                    }
                    Item {
                        width: 10
                        height: 21
                    }
                    Item {
                        anchors.horizontalCenter: parent.horizontalCenter
                        width: 300
                        height: 60
                        Row {
                            id: startdaterow
                            anchors.fill: parent
                            spacing: 2

                            ListItem {
                                id: startmonthdata
                                objectName: "startmonthdata"
                                property string activebgImage: ""
                                message:"4月"
                                width: 59
                                height:60
                                activebg: activebgImage
                                idlebg: ""
                                type: 2
                                fontsize: 20
                            }

                            ListItem {
                                id: startdaydata
                                objectName: "startdaydata"
                                message:"1日"
                                width: 59
                                height:60
                                activebg: "datetime_btn.png"
                                idlebg: ""
                                type: 2
                                fontsize: 20
                            }

                            Item {
                                width:26
                                height:60
                            }

                            ListItem {
                                id: starthourdata
                                objectName: "starthourdata"
                                message: "10"
                                width: 59
                                height:60
                                activebg: "datetime_btn.png"
                                idlebg: ""
                                type: 2
                                fontsize: 20
                            }

                            Text {
                                text: ":"
                                verticalAlignment: Text.AlignVCenter
                                horizontalAlignment: Text.AlignHCenter
                                height: 60
                                width: 28
                                font.family: defaultFontName
                                font.pixelSize: 20
                                color: "white"
                            }

                            ListItem {
                                id: startminutesdata
                                objectName: "startminutesdata"
                                message: "59"
                                width: 59
                                height:60
                                activebg: "datetime_btn.png"
                                idlebg: ""
                                type: 2
                                fontsize: 20
                            }
                        }
                    }
                    Item {
                        width: 10
                        height: 20
                    }
                    Row{
                       //anchors.topMargin:  root.top

                        spacing: 60
                        x:72

                        Image {
                            id: rsvcollectminbg
                            source: "qrc:/resource/png/datalogger_collect_interval_min_bg.png"
                            visible: dgPopup.popupType === 1
                            Image {
                                objectName: "rsvintervaldataCur"
                                anchors.fill: parent
                                source: "qrc:/resource/png/datalogger_interval_btn_d.png"
                                visible: rsvintervaldata.active
                            }

                            Column {
                                anchors.fill: parent

                                Item {
                                    width: 10
                                    height: 8
                                }
                                Text {
                                    id: rsvintervalMessage
                                    text: "間隔"
                                    width: rsvintervaldata.width
                                    height: 28
                                    horizontalAlignment: Text.AlignHCenter
                                    verticalAlignment: Text.AlignVCenter
                                    font.family: defaultFontName
                                    color: "skyblue"
                                }
                                ListItem {
                                    id: rsvintervaldata
                                    objectName: "rsvintervaldata"
                                    message: "連続"
                                    messageAlign: Text.AlignHCenter
                                    x: 0
                                    width: parent.width
                                    height: 50
                                    idlebg: ""
                                    type: 2
                                    fontsize: 18
                                    property int interval: dgPopup.interval
                                    onIntervalChanged: {
                                        switch(interval) {
                                        case 0:
                                            message = "連続"
                                            break;
                                        case 1:
                                            message = "5分"
                                            break;
                                        case 2:
                                            message = "15分"
                                            break;
                                        case 3:
                                            message = "30分"
                                            break;
                                        case 4:
                                            message = "60分"
                                            break;
                                        default:
                                            message = "連続"
                                            break;
                                        }
                                    }
                                }
                            }

                        }

                        Image {
                            id: rsvcollectminbg1
                            source: "qrc:/resource/png/datalogger_collect_interval_min_bg.png"
                            visible: dgPopup.popupType === 1
                            Image {
                                objectName: "rsvcycledataCur"
                                anchors.fill: parent
                                source: "qrc:/resource/png/datalogger_interval_btn_d.png"
                                visible: rsvcycledata.active
                            }
                            Column {
                                anchors.fill: parent

                                Item {
                                    width: 10
                                    height: 8
                                }
                                Text {
                                    id: rsvcyclemessage
                                    text: "取得サイクル"
                                    width: parent.width
                                    height: 28
                                    horizontalAlignment: Text.AlignHCenter
                                    verticalAlignment: Text.AlignVCenter
                                    font.family: defaultFontName
                                    color: "skyblue"
                                }
                                ListItem {
                                    id: rsvcycledata
                                    objectName: "rsvcycledata"
                                    message: "100"
                                    messageAlign: Text.AlignHCenter
                                    x: 0
                                    width: parent.width
                                    height: 50
                                    idlebg: ""
                                    type: 2
                                    fontsize: 18
                                    property int cycle: dgPopup.cycle
                                    onCycleChanged: {
                                        switch(cycle) {
                                        case 0:
                                            message = "100"
                                            break;
                                        case 1:
                                            message = "200"
                                            break;
                                        case 2:
                                            message = "300"
                                            break;
                                        case 3:
                                            message = "400"
                                            break;
                                        case 4:
                                            message = "500"
                                            break;
                                        case 5:
                                            message = "600"
                                            break;
                                        case 6:
                                            message = "700"
                                            break;
                                        case 7:
                                            message = "800"
                                            break;
                                        case 8:
                                            message = "900"
                                            break;
                                        case 9:
                                            message = "1000"
                                            break;
                                        default:
                                            message = "100"
                                            break;
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }

            Row{
                spacing: 60
                x:58
                y:40
                Image {
                    id: collectminbg
                    source: "qrc:/resource/png/datalogger_collect_interval_min_bg.png"
                    visible: dgPopup.popupType === 2

                    Image {
                        objectName: "intervaldataCur"
                        anchors.fill: parent
                        source: "qrc:/resource/png/datalogger_interval_btn_d.png"
                        visible: intervaldata.active
                    }

                    Column {
                        anchors.fill: parent

                        Item {
                            width: 10
                            height: 8
                        }
                        Text {
                            id: intervalMessage
                            text: "間隔"
                            width: intervaldata.width
                            height: 28
                            horizontalAlignment: Text.AlignHCenter
                            verticalAlignment: Text.AlignVCenter
                            font.family: defaultFontName
                            color: "skyblue"
                        }
                        ListItem {
                            id: intervaldata
                            objectName: "intervaldata"
                            message: "連続"
                            messageAlign: Text.AlignHCenter
                            x: 0
                            width: parent.width
                            height: 50
                            idlebg: ""
                            type: 2
                            fontsize: 18
                            property int interval: dgPopup.interval
                            onIntervalChanged: {
                                switch(interval) {
                                case 0:
                                    message = "連続"
                                    break;
                                case 1:
                                    message = "5分"
                                    break;
                                case 2:
                                    message = "15分"
                                    break;
                                case 3:
                                    message = "30分"
                                    break;
                                case 4:
                                    message = "60分"
                                    break;
                                default:
                                    message = "連続"
                                    break;
                                }
                            }
                        }
                    }

                }

                Image {
                    id: collectminbg1
                    source: "qrc:/resource/png/datalogger_collect_interval_min_bg.png"
                    visible: dgPopup.popupType === 2

                    Image {
                        objectName: "cycledataCur"
                        anchors.fill: parent
                        source: "qrc:/resource/png/datalogger_interval_btn_d.png"
                        visible: cycledata.active
                    }

                    Column {
                        anchors.fill: parent

                        Item {
                            width: 10
                            height: 8
                        }
                        Text {
                            id: cyclemessage
                            text: "取得サイクル"
                            width: parent.width
                            height: 28
                            horizontalAlignment: Text.AlignHCenter
                            verticalAlignment: Text.AlignVCenter
                            font.family: defaultFontName
                            color: "skyblue"
                        }
                        ListItem {
                            id: cycledata
                            objectName: "cycledata"
                            message: "100"
                            messageAlign: Text.AlignHCenter
                            x: 0
                            width: parent.width
                            height: 50
                            idlebg: ""
                            type: 2
                            fontsize: 18
                            property int cycle: dgPopup.cycle
                            onCycleChanged: {
                                switch(cycle) {
                                case 0:
                                    message = "100"
                                    break;
                                case 1:
                                    message = "200"
                                    break;
                                case 2:
                                    message = "300"
                                    break;
                                case 3:
                                    message = "400"
                                    break;
                                case 4:
                                    message = "500"
                                    break;
                                case 5:
                                    message = "600"
                                    break;
                                case 6:
                                    message = "700"
                                    break;
                                case 7:
                                    message = "800"
                                    break;
                                case 8:
                                    message = "900"
                                    break;
                                case 9:
                                    message = "1000"
                                    break;
                                default:
                                    message = "100"
                                    break;
                                }
                            }
                        }
                    }
                }
            }
        }
    }
}
