//
//      (c) 2020 DX ANTENNA CO.,LTD.
//

#include "dataloggerviewmodel.h"
#include "correcter.h"
#include "usboperation.h"

const char *DataLoggerViewModel::EMPTY_VALUE = "-";

const int DataLoggerViewModel::USER_LIST_PART1_COLUMN_NUMBER = 10;
const int DataLoggerViewModel::USER_LIST_PART2_COLUMN_NUMBER = 7;
const int DataLoggerViewModel::USER_LIST_ROW_NUMBER = 1;

const int DataLoggerViewModel::CHANNEL_LIST_COLUMN_NUMBER = 6;
const int DataLoggerViewModel::CHANNEL_LIST_ROW_NUMBER = 1;

const int DataLoggerViewModel::CHANNEL_EDIT_COLUMN_NUMBER = 1;
const int DataLoggerViewModel::CHANNEL_EDIT_ROW_NUMBER = 9;

const int DataLoggerViewModel::ACTION_COLUMN_NUMBER = 2;
const int DataLoggerViewModel::ACTION_ROW_NUMBER = 1;

const unsigned int DataLoggerViewModel::LOCAL_FREQ_UNDEFINED_DATA = 429467295;

const QString DataLoggerViewModel::CANNOT_SELECTION_MESSAGE = "- 選択不可 -";

constexpr int DataLoggerViewModel::USER_SETTING_DATA_DETAIL_NUMBER = 120;

const QMap<int, LC70_BAND_T> DataLoggerViewModel::BAND_LIST_INDEX_MAP = {
    {0,  LC70_BAND_UHF            },
    {1,  LC70_BAND_BS             },
    {2,  LC70_BAND_CS             },
    {3,  LC70_BAND_JCSAT3         },
    {4,  LC70_BAND_JCSAT4         },
    {5,  LC70_BAND_SCCB           },
    {6,  LC70_BAND_SCCC           },
    {7,  LC70_BAND_CATV_ALL       },
    {8,  LC70_BAND_PILOT          },
    {9,  LC70_BAND_SKYP           },
    {10, LC70_BAND_LTE            },
    {11, LC70_BAND_FM             },
    {12, LC70_BAND_CATV_UP_STREAM },
};

// todo : (byte)設定ファイルに定義された、1CHのデータ量
static constexpr int MEASUREMENT_1CH_DATA_SIZE = 50;

// todo : データロガー -> 測定開始 -> 開始終了日時 からの取得開始時の
//        空き容量計算とチェック（暫定）
//        測定可能時間の動的表示(未実装)
//        取得中に失敗したケース(未検討)
//        最大データ数取得した後の停止処理(未実装)

DataLoggerViewModel::DataLoggerViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent)
    : AbstractViewModel(screenId, model, parent)
    , _userListCurrentPage(1)
    , _settingListCurrentPage(1)
    , _dataloggerExecuteInterval(0)
    , _userSettingListNum(0)
    , _yyyy(0)
    , _start_mm(0)
    , _start_dd(0)
    , _start_HH(0)
    , _start_MM(0)
    , _end_mm(0)
    , _end_dd(0)
    , _end_HH(0)
    , _end_MM(0)
    , _end_yyyy(0)
    , _duplicateFileName()
    , _reserveTimer(nullptr)
    , _fileselectionInedx(0)
    , _userListOperationProhibited(false)
    , _channellistMaxCheckCount(0)
    , _modifyCheck()
    , _filemixFileIndex()
    , _backToScreen(SCREEN_ID_COUNT)
    , _loggingStarted(false)
    , _powerSupplySettingMap()
    , _merSettingMap()
    , _berSettingMap()
    , _selectArea(USERLIST_AREA)
    , _mode(UNKNOWN)
    , _editType(EDIT_UNKNOWN)
    , _filemixState(FILEMIX_UNKNOWN)
    , _popupType(TYPEUNKNOWN)
    , _popupState(SELECT)
{
    setObjectName("dataLoggerViewModel");

    // ユーザリスト
    _dataLoggerUserListPart1ButtonData = {
        {"userdata0"},
        {"userdata1"},
        {"userdata2"},
        {"userdata3"},
        {"userdata4"},
        {"userdata5"},
        {"userdata6"},
        {"userdata7"},
        {"userdata8"},
        {"userdata9"},
    };

    _dataLoggerUserListPart2ButtonData = {
        {"userdata0"},
        {"userdata1"},
        {"userdata2"},
        {"userdata3"},
        {"userdata4"},
        {"userdata5"},
        {"userdata6"},
    };

    // チャンネルリスト
    dataLoggerChannelListButtonData = {
        {"list0"},
        {"list1"},
        {"list2"},
        {"list3"},
        {"list4"},
        {"list5"},
    };

    _channelListButtonOperation.setButtonName(
        CHANNEL_LIST_COLUMN_NUMBER,
        CHANNEL_LIST_ROW_NUMBER,
        dataLoggerChannelListButtonData);

    _channelListButtonOperation.setActiveObject(dataLoggerChannelListButtonData[0][0]);
    _channelListActiveButton = dataLoggerChannelListButtonData[0][0];

    // チャンネル編集
    dataLoggerChannelEditButtonData = {
        {
            "band", "broadbandSystem", "channel", "modulation", "levelOffset",
            "mercnSwitch",
            "berSwitch", "powerSupply", "trash"
        }
    };

    _channelEditButtonOperation.setButtonName(
        CHANNEL_EDIT_COLUMN_NUMBER,
        CHANNEL_EDIT_ROW_NUMBER,
        dataLoggerChannelEditButtonData);

    _channelEditButtonOperation.setActiveObject(dataLoggerChannelEditButtonData[0][0]);
    _channelEditActiveButton = dataLoggerChannelEditButtonData[0][0];

    // アクションボタン
    _dataLoggerActionButtonData = {
        {"execute1"},
        {"execute2"}        // 下段のボタンは非表示
    };

    _actionButtonOperation.setButtonName(
        ACTION_COLUMN_NUMBER,
        ACTION_ROW_NUMBER,
        _dataLoggerActionButtonData);

    _actionButtonOperation.setActiveObject(_dataLoggerActionButtonData[0][0]);
    _actionButtonActiveButton = _dataLoggerActionButtonData[0][0];


    _dataLoggerPopupType1ButtonData = {
        {{"m1", "m2"}}
    };

    _dataLoggerPopupType2ButtonData = {
        {{"intervaldata"}},
        {{"m1"}}
    };

    _dataLoggerPopupType3ButtonData = {
        {{"startmonthdata", "startdaydata", "starthourdata", "startminutesdata", ""}},
        {{"endmonthdata", "enddaydata", "endhourdata", "endminutesdata", "datetimeintervaldata"}},
        {{"m1", "", "", "", ""}}
    };

    _dataLoggerPopupType4ButtonData = {
        {{"m1"}}
    };

    _popupButtonOperation.setActiveObject(_dataLoggerPopupType1ButtonData[0][0]);
    _popupActiveButton = _dataLoggerPopupType1ButtonData[0][0];

    QDateTime currentDateTime = QDateTime::currentDateTime();
    _yyyy = currentDateTime.date().year();
    _start_mm = 1;
    _start_dd = 1;
    _start_HH = 0;
    _start_MM = 0;
    _end_mm = 1;
    _end_dd = 1;
    _end_HH = 0;
    _end_MM = 0;
    _end_yyyy = _yyyy;

    _fileselectionInedx = 0;
    _userListOperationProhibited = false;
    _channellistMaxCheckCount = 0;

    _reserveTimer = new QTimer(this);
    connect(_reserveTimer, SIGNAL(timeout()), this, SLOT(reserveMeasurement()));
    _reserveTimer->setSingleShot(true);
}

DataLoggerViewModel::~DataLoggerViewModel()
{
    _userListOperationProhibited = false;
}

void DataLoggerViewModel::activate()
{
    if (nullptr == _view) {
        qErrnoWarning("_view is null");
        return;
    }

    // 前画面からの引き継ぎデータ
    connect(this, SIGNAL(requestSetTakeOver(QVariant, QVariant)), _view, SLOT(backup(QVariant, QVariant)));

    connect(this, SIGNAL(notifyConflictPowerSupplySetting()), this, SLOT(popupConflictPowerSupplySetting()),
            Qt::QueuedConnection);

    _backToScreen = SCREEN_ID_COUNT;

    // 動作種別を取得する
    QObject *takeOverData = _view->findChild<QObject *>("takeOverData");

    if (takeOverData) {
        QVariant val;

        if (_takeOver.contains("dataloggerFunction")) {
            val = _takeOver["dataloggerFunction"];
            _mode = static_cast<DataloggerFunction>(val.toInt());
        } else {
            _mode = UNKNOWN;
        }

        val = _takeOver["selectedUserSetting"];
        _editType = static_cast<DataloggerEditType>(val.toInt());

        val = _takeOver["fileselectionListIndex"];
        _fileselectionInedx = val.toInt();

        val = _takeOver["filemixState"];
        _filemixState = static_cast<DataloggerFileMixState>(val.toInt());

        val = _takeOver["selectedMeasurement"];

        if (val.toString() == "SingleMeasurement") {
            _backToScreen = SCREEN_SINGLE_MEASUREMENT;
        } else if (val.toString() == "MultiMeasurement") {
            _backToScreen = SCREEN_MULTI_MEASUREMENT;
        } else {}
    }

    if (_mode != USER) {
        _filemixState = FILEMIX_UNKNOWN;
    }

    setScreenName();

    // 初期化
    _actionButtonActiveButton = _dataLoggerActionButtonData[0][0];
    _userListOperationProhibited = false;
    _duplicateFileName = QString("");

    // ページ数の初期化
    _userListCurrentPage = 1;
    _settingListCurrentPage = 1;

    // ユーザリストボタン操作設定
    if (_filemixState != FILEMIX_BEFORE) {
        _userListButtonOperation.setButtonName(USER_LIST_PART1_COLUMN_NUMBER, USER_LIST_ROW_NUMBER,
                                               _dataLoggerUserListPart1ButtonData);
        _userListButtonOperation.setActiveObject(_dataLoggerUserListPart1ButtonData[0][0]);
        _userListActiveButton = _dataLoggerUserListPart1ButtonData[0][0];
    } else {
        _userListButtonOperation.setButtonName(USER_LIST_PART2_COLUMN_NUMBER, USER_LIST_ROW_NUMBER,
                                               _dataLoggerUserListPart2ButtonData);
        _userListButtonOperation.setActiveObject(_dataLoggerUserListPart2ButtonData[0][0]);
        _userListActiveButton = _dataLoggerUserListPart2ButtonData[0][0];
    }

    setActionButtonDisp();

    changeLayout();

    setUserFileListAndUserSettingList();
}

void DataLoggerViewModel::deactivate()
{
    AbstractViewModel::deactivate();
    disconnect(this, SIGNAL(requestSetTakeOver(QVariant, QVariant)), _view, SLOT(backup(QVariant, QVariant)));

    disconnect(this, SIGNAL(notifyConflictPowerSupplySetting()), this, SLOT(popupConflictPowerSupplySetting()));

}

void DataLoggerViewModel::setScreenName()
{
    QObject *target;
    target = _view->findChild<QObject *>("screenName");

    // 画面名
    if ((_mode == SINGLE) || (_mode == MULTI)) {
        if (target) {
            if (_fileselectionInedx == 0) {
                // トーンダウンしたゴミ箱アイコンを設定する
                _view->setProperty("trashIcon", "trash_disable.png");
                target->setProperty("name", "USER 設定呼び出し");
            } else {
                // 選択可能なゴミ箱アイコンを設定する
                _view->setProperty("trashIcon", "trash_disable.png");
                target->setProperty("name", "設定保存");

                if (_mode == SINGLE) {
                    _backToScreen = SCREEN_SINGLE_MEASUREMENT;
                } else if (_mode == MULTI) {
                    _backToScreen = SCREEN_MULTI_MEASUREMENT;
                } else {}

                _mode = USER;
                _editType = EDIT_AUTO;
            }
        }
    } else if (_mode == LOGGER) {
        // トーンダウンしたゴミ箱アイコンを設定する
        _view->setProperty("trashIcon", "trash_disable.png");

        if (target) {
            target->setProperty("name", "データロガー");
        }
    } else if (_mode == USER) {
        // 選択可能なゴミ箱アイコンを設定する
        _view->setProperty("trashIcon", "trash_able.png");

        if (target) {
            if (EDIT_FILEMIX == _editType) {
                // ファイル合成
                target->setProperty("name", "ファイル合成/複製");
            } else if (EDIT_MANUAL == _editType) {
                // 手動設定
                target->setProperty("name", "手入力/編集");
            } else {
                // 自動スキャン後
                target->setProperty("name", "設定保存");

                // showUserSettingList() で設定 - 自動のスキャン後の結果を表示
            }
        }
    } else if (_mode == USERSETTING_SHOW) {
        // トーンダウンしたゴミ箱アイコンを設定する
        _view->setProperty("trashIcon", "trash_disable.png");

        if (target) {
            // データ管理
            target->setProperty("name", "ユーザ設定表示");
        }
    } else if (_mode == SAVE_MEASURESETTING) {
        if (_fileselectionInedx != 0) {
            // 選択可能なゴミ箱アイコンを表示する
            _view->setProperty("trashIcon", "trash_able.png");
            target->setProperty("name", "設定保存");
            _mode = USER;
            _editType = EDIT_AUTO;
        }
    }
}

void DataLoggerViewModel::setActionButtonDisp()
{
    QObject *target;

    switch (_mode) {
    case SINGLE:
    case MULTI:
    case LOGGER: {
        target = _view->findChild<QObject *>(_dataLoggerActionButtonData[0][0]);

        if (target) {
            target->setProperty("message", "測\n定\n開\n始");
            // 削除は無効なので下の矢印を見えないようにする
            _view->setProperty("noDownArrow", true);
        }

        target = _view->findChild<QObject *>(_dataLoggerActionButtonData[1][0]);

        if (target) {
            target->setProperty("disable", true);
        }

    }
    break;

    case USER: {
        _view->setProperty("noDownArrow", false);
        if (EDIT_FILEMIX == _editType) {
            if (_filemixState == FILEMIX_BEFORE) {
                target = _view->findChild<QObject *>(_dataLoggerActionButtonData[0][0]);

                if (target) {
                    target->setProperty("message", "合\n成");
                    target->setProperty("width", 55);
                    target->setProperty("height", 313);
                    target->setProperty("disable", true);
                    target->setProperty("activebg", "datalogger_action_btn_active_l.png");
                }

                target = _view->findChild<QObject *>(_dataLoggerActionButtonData[1][0]);

                if (target) {
                    target->setProperty("disable", false);
                    target->setProperty("visible", false);
                }
            } else if (_filemixState == FILEMIX_AFTER) {
                target = _view->findChild<QObject *>(_dataLoggerActionButtonData[0][0]);

                if (target) {
                    target->setProperty("message", "保\n存");
                }

                target = _view->findChild<QObject *>(_dataLoggerActionButtonData[1][0]);

                if (target) {
                    target->setProperty("disable", false);
                    target->setProperty("visible", true);
                }
            }
        } else {
            target = _view->findChild<QObject *>(_dataLoggerActionButtonData[0][0]);

            if (target) {
                target->setProperty("message", "保\n存");
            }

            target = _view->findChild<QObject *>(_dataLoggerActionButtonData[1][0]);

            if (target) {
                target->setProperty("disable", false);
            }
        }
    }
    break;

    case USERSETTING_SHOW : {
        target = _view->findChild<QObject *>(_dataLoggerActionButtonData[0][0]);
        _view->setProperty("noDownArrow", false);

        if (target) {
            target->setProperty("message", "保\n存");
            target->setProperty("disable", true);
        }

        target = _view->findChild<QObject *>(_dataLoggerActionButtonData[1][0]);

        if (target) {
            target->setProperty("disable", true);
        }

    }
    break;

    default:
        break;
    }
}

void DataLoggerViewModel::setUserFileListAndUserSettingList()
{
    // ユーザファイルリストの表示
    switch (_editType) {
    case EDIT_MANUAL: {
        // ユーザファイルリストの読み込み

        // ユーザファイルリスト選択
        _selectArea = USERLIST_AREA;
        showUserFileList();
    }
    break;

    case EDIT_AUTO: {

        // データを作成する
        if (_model->allScanResult().count() > 0) {
            // スキャン結果を保存
            displaySettingAutoScanResult();

            QVariant value = _takeOver["selectedMeasurement"];

            if (value.toString() == "SingleMeasurement") {
                _backToScreen = SCREEN_SINGLE_MEASUREMENT;
            } else if (value.toString() == "MultiMeasurement") {
                _backToScreen = SCREEN_MULTI_MEASUREMENT;
            } else {
                // 保存後 USERファイル作成画面に遷移を行う
                _backToScreen = SCREEN_MANUAL_AUTO_SELECTION;
            }
        } else {
            // 測定画面からのユーザー設定保存
            createUserSettingFile();
        }

        const int listDispNum = 10;
        _userListCurrentPage = _fileselectionInedx / listDispNum;
        int surplus = (_fileselectionInedx % listDispNum);

        if (surplus != 0) {
            _userListCurrentPage++;
        }

        int index = surplus - 1;

        if (surplus == 0) {
            index = listDispNum - 1;
        }

        _userListActiveButton = _dataLoggerUserListPart1ButtonData[index][0];

        // ユーザファイルリスト表示
        showUserFileList();

        // チャンネルリスト
        showUserSettingList(true);

        // 選択状態を表示
        QObject *target = _view->findChild<QObject *>(_userListActiveButton);
        target->setProperty("activebg", "datalogger_userlist_btn_edit.png");

        _selectArea = CHANNEL_AREA;
        _channelListActiveButton = dataLoggerChannelListButtonData[0][0];
        _channelListButtonOperation.setActiveObject(dataLoggerChannelListButtonData[0][0]);
        target = _view->findChild<QObject *>(_channelListActiveButton);
        target->setProperty("active", true);

        // 仕様:このケースでは、[ユーザファイルリスト]が操作できない
        _userListOperationProhibited = true;

        // ファイル合成画面 削除ボタンを非活性とする
        target = _view->findChild<QObject *>("execute2");
        if (target) {
            target->setProperty("disable", true);
        }
    }
    break;

    case EDIT_FILEMIX: {
        if (_filemixState == FILEMIX_AFTER) {
            // 動作種別を取得する
            QObject *takeOverData = _view->findChild<QObject *>("takeOverData");
            QString file1;
            QString file2;

            if (takeOverData) {
                QVariant val;

                val = _takeOver["filemixFilename1"];
                file1 = val.toString();

                val = _takeOver["filemixFilename2"];
                file2 = val.toString();
            }

            _model->importDataLoggerUserSettingList(VALUE_USERSETTING_SETTINGLIST, file1);
            QVariant value1;
            _model->getValue(VALUE_USERSETTING_SETTINGLIST, value1);
            QVariantList channelList1 = value1.toList();

            _model->importDataLoggerUserSettingList(VALUE_USERSETTING_SETTINGLIST, file2);
            QVariant value2;
            _model->getValue(VALUE_USERSETTING_SETTINGLIST, value2);
            QVariantList channelList2 = value2.toList();

            bool isConflictMerSetting = checkConflictMerSetting(channelList1, channelList2);
            bool isConflictBerSetting = checkConflictBerSetting(channelList1, channelList2);
            bool isConflictPowerSupplySetting = checkConflictPowerSupplySetting(channelList1, channelList2);
            // 合成
            channelList1 += channelList2;

            // MER/CN設定競合チェック
            if (isConflictMerSetting) {
                updateMerSetting(channelList1);
            }

            // BER設定競合チェック
            if (isConflictBerSetting) {
                updateBerSetting(channelList1);
            }

            // 給電設定競合チェック
            if (isConflictPowerSupplySetting) {
                updatePowerSupplySetting(channelList1);
                emit notifyConflictPowerSupplySetting();
            }

            _model->setValue(VALUE_USERSETTING_SETTINGLIST, channelList1);
            _model->commit(VALUE_USERSETTING_SETTINGLIST);

            const int listDispNum = 10;
            _userListCurrentPage = _fileselectionInedx / listDispNum;
            int surplus = (_fileselectionInedx % listDispNum);

            if (surplus != 0) {
                _userListCurrentPage++;
            }

            int index = surplus - 1;

            if (surplus == 0) {
                index = listDispNum - 1;
            }

            _userListActiveButton = _dataLoggerUserListPart1ButtonData[index][0];

            // ユーザファイルリスト表示
            showUserFileList();

            // チャンネルリスト
            _channellistMaxCheckCount = showUserSettingList();

            // 選択状態を表示
            QObject *target = _view->findChild<QObject *>(_userListActiveButton);
            target->setProperty("activebg", "datalogger_userlist_btn_edit.png");

            _selectArea = CHANNEL_AREA;
            _channelListActiveButton = dataLoggerChannelListButtonData[0][0];
            _channelListButtonOperation.setActiveObject(dataLoggerChannelListButtonData[0][0]);
            target = _view->findChild<QObject *>(_channelListActiveButton);
            target->setProperty("active", true);

            // 仕様:このケースでは、[ユーザファイルリスト]が操作できない
            _userListOperationProhibited = true;

            target = _view->findChild<QObject *>("channelNumDisp");

            if (target) {
                QString title;
                title.sprintf(" CH登録数: %d/max120", _channellistMaxCheckCount);
                target->setProperty("text", title);
            }

            // グレーアウト
            target = _view->findChild<QObject *>("execute2");

            if (target) {
                target->setProperty("disable", true);
            }
        } else {
            // ユーザファイルリスト選択
            _selectArea = USERLIST_AREA;
            showUserFileList();
        }
    }
    break;

    default:
        // ユーザファイルリスト選択
        _selectArea = USERLIST_AREA;
        showUserFileList();
        break;
    }
}

void DataLoggerViewModel::showUserFileList()
{
    QVariant value;

    QObject *target = nullptr;

    if (_model->getValue(VALUE_USERSETTING_FILELIST, value)) {

        // 現在ページの１０件(または７件)を表示する
        QVariantList userlist = value.toList();
        int userlistSize = userlist.size();

        if (_filemixState != FILEMIX_BEFORE) {
            for (int i = 0; i < 10; i++) {//(_userListCurrentPage - 1) * 10; i < _userListCurrentPage * 10; i++) {
                target = _view->findChild<QObject *>(_dataLoggerUserListPart1ButtonData[i][0]);

                int listIndex = i + (_userListCurrentPage - 1) * 10;

                if (target) {
                    if (0 <= listIndex && listIndex < userlistSize) {
                        // [Memo]
                        //  listIndexは0オリジンだが、 表示はnumberは1オリジンとなるため listIndex+1の値を送信
                        target->setProperty("listItemNumber", QString::number(listIndex + 1));
                        target->setProperty("message", userlist[listIndex].toList().at(2).toString());
                    } else {
                        // ファイルが存在しない
                        target->setProperty("disable", true);
                    }
                }
            }
        } else {
            for (int i = 0; i < 7; i++) {
                target = _view->findChild<QObject *>(_dataLoggerUserListPart2ButtonData[i][0]);

                int listIndex = i + (_userListCurrentPage - 1) * 7;

                if (target) {
                    if (listIndex < userlistSize) {
                        // [Memo]
                        //  listIndexは0オリジンだが、 表示はnumberは1オリジンとなるため listIndex+1の値を送信
                        target->setProperty("listItemNumber", QString::number(listIndex + 1));
                        target->setProperty("message", userlist[listIndex].toList().at(2).toString());
                    } else {
                        // ファイルが存在しない
                        target->setProperty("listItemNumber", QString::number(listIndex + 1));
                        target->setProperty("message", CANNOT_SELECTION_MESSAGE);
                        target->setProperty("disable", true);
                    }
                }
            }
        }
    }

    // ページ番号表示
    target = _view->findChild<QObject *>("userfilelistpage");

    if (target) {
        QString page;

        if (_filemixState == FILEMIX_BEFORE) {
            page.sprintf("ページ %2d/20", _userListCurrentPage);
        } else {
            page.sprintf("ページ %2d/14", _userListCurrentPage);
        }

        target->setProperty("text", page);
    }


    // ユーザファイルリストの選択状態設定
    target = _view->findChild<QObject *>(_userListActiveButton);

    if (target) {
        target->setProperty("active", true);

        QString fileName = target->property("message").toString();

        // 選択中のユーザリストのindex
        int index = getSelectedUserListIndex();

        // 選択リストがuserListSizeを超えていた場合 (- 選択不可 - の場合)
        // USERファイルリストの詳細を全て「-」で表示する
        QVariantList userList = value.toList();

        if (index >= userList.size()) {
            showEmptyUserSettingList();
            target = _view->findChild<QObject *>("channelInfoDisp");
            target->setProperty("text", "");
        } else {
            // 選択されているユーザのデータ読み込み
            getUserSettingList();

            // 対応するチャンネル情報の初期表示
            int listNum = showUserSettingList(true);

            // ページ数表示の更新
            target = _view->findChild<QObject *>("channelListPage");
            if (target) {
                int maxPage = _mode == USER ? 20 : (((_userSettingListNum - 1) / 6) + 1);
                QString currentPage;
                currentPage.sprintf("ページ %d/%d", _settingListCurrentPage, maxPage);
                target->setProperty("text", currentPage);
            }

            target = _view->findChild<QObject *>("channelInfoDisp");

            if (target) {
                if ((fileName.size() > 0 ) && (fileName != CANNOT_SELECTION_MESSAGE)) {
                    int maxPage = listNum / 6;

                    if ((listNum % 6) != 0) {
                        maxPage++;
                    }

                    QString title;
                    title.sprintf(" に登録されているCH：1/%d ページ", maxPage);
                    target->setProperty("text", fileName + title);
                } else {
                    target->setProperty("text", "");
                }
            }

            // 手入力/編集の場合ファイル名の有無で削除ボタンの活性/非活性を変更する
            if (_mode == USER && _editType == EDIT_MANUAL) {
                target = _view->findChild<QObject *>("execute2");
                if (target) {
                    if (fileName.isEmpty()) {
                        target->setProperty("disable", true);
                    } else {
                        target->setProperty("disable", false);
                    }
                }
            }
        }
    }
}

void DataLoggerViewModel::setTakeOver()
{
}

void DataLoggerViewModel::onRequest(int condition)
{
    emit request(_screenId, condition); // 0 origin のため
    return;
}

void DataLoggerViewModel::onKeyStatusUserListArea(ButtonId id)
{
    // EnterKey の動作はなし
    // 上下移動でユーザ設定データの表示切替を行う
    // パフォーマンス次第でEnterKeyで読み込みに変更かも

    if (id == BUTTON_ENTER) {
        enterUserListArea();
    } else {
        moveCursorUserListArea(id);
    }
}

void DataLoggerViewModel::moveCursorUserListArea(ButtonId id)
{
    if ((id == BUTTON_UP) || (id == BUTTON_DOWN)) {
        // 選択している USERLIST の切替

        QString nextBtn;
        bool ret = _userListButtonOperation.nextActiveObject(id, nextBtn);

        if (ret) {

            // inactive
            QObject *target = _view->findChild<QObject *>(_userListActiveButton);

            if (target) {
                target->setProperty("active", false);
            }

            // active
            target = _view->findChild<QObject *>(nextBtn);

            if (target) {
                target->setProperty("active", true);
            }

            _userListActiveButton = nextBtn;
            _userListButtonOperation.setActiveObject(_userListActiveButton);

            // ページ切替の確認
            updateUserListCurrentPage(id);

            // 表示更新
            updateImageMoveCursor();

            showUserFileList();
        }
    } else if (id == BUTTON_RIGHT) {
        // カーソルを設定データへ移行

        if (_mode == LOGGER) {
            QVariant value;
            _model->getValue(VALUE_USERSETTING_SETTINGLIST, value);
            QVariantList userSettingList = value.toList();
        }

        // 選択状態を表示
        QObject *target = _view->findChild<QObject *>(_userListActiveButton);
        _reserveUserListActivebg = target->property("activebg").toString();

        if (_filemixState != FILEMIX_BEFORE) {
            target->setProperty("activebg", "datalogger_userlist_btn_edit.png");

            _selectArea = CHANNEL_AREA;
            _channelListActiveButton = dataLoggerChannelListButtonData[0][0];
            _channelListButtonOperation.setActiveObject(dataLoggerChannelListButtonData[0][0]);
            target = _view->findChild<QObject *>(_channelListActiveButton);
            target->setProperty("active", true);
        } else {
            // 合成ボタンが有効であれば（2個選択していれば）移動可能
            if (_filemixFileIndex.size() == 2) {
                target->setProperty("activebg", "");

                if (target->property("check1on") == true) {
                    target->setProperty("activebg", "datalogger_filemix_userlist_btn_edit.png");
                }

                _selectArea = ACTION_AREA;
                target = _view->findChild<QObject *>(_actionButtonActiveButton);

                if (target) {
                    target->setProperty("active", true);
                }
            }
        }
    }
}

void DataLoggerViewModel::updateUserListCurrentPage(ButtonId id)
{
    if (_filemixState != FILEMIX_BEFORE) {
        switch (id) {
        case BUTTON_UP:
            if (_userListActiveButton == _dataLoggerUserListPart1ButtonData[9][0]) {
                // 前ページに遷移
                if (_userListCurrentPage == 1) {
                    _userListCurrentPage = 14;
                } else {
                    _userListCurrentPage--;
                }
            }

            break;

        case BUTTON_DOWN:
            if (_userListActiveButton == _dataLoggerUserListPart1ButtonData[0][0]) {
                // 次ページに遷移
                if (_userListCurrentPage == 14) {
                    _userListCurrentPage = 1;
                } else {
                    _userListCurrentPage++;
                }
            }

            break;

        default:
            break;
        }
    } else {
        switch (id) {
        case BUTTON_UP:
            if (_userListActiveButton == _dataLoggerUserListPart2ButtonData[6][0]) {
                // 前ページに遷移
                if (_userListCurrentPage == 1) {
                    _userListCurrentPage = 20;
                } else {
                    _userListCurrentPage--;
                }
            }

            break;

        case BUTTON_DOWN:
            if (_userListActiveButton == _dataLoggerUserListPart2ButtonData[0][0]) {
                // 次ページに遷移
                if (_userListCurrentPage == 20) {
                    _userListCurrentPage = 1;
                } else {
                    _userListCurrentPage++;
                }
            }

            break;

        default:
            break;
        }
    }
}

void DataLoggerViewModel::updateImageMoveCursor()
{
    if (_filemixState != FILEMIX_BEFORE) {
        return;
    }

    if (_filemixFileIndex.size() == 0) {// カーソル移動の場合、選択がないなら更新処理は不要
        return;
    }

    int selectIndex1 = _filemixFileIndex[0];
    int selectIndex2 = -1;

    if (_filemixFileIndex.size() == 2) {
        selectIndex2 = _filemixFileIndex[1];
    }

    // 表示位置へ補正すると
    selectIndex1 = selectIndex1 - (_userListCurrentPage - 1) * 7;
    selectIndex2 = selectIndex2 - (_userListCurrentPage - 1) * 7;

    for (int i = 0; i < 7; i++) {
        updateUserListItemImage(i, selectIndex1, selectIndex2);
    }
}

void DataLoggerViewModel::updateUserListItemImage(int index, int selectIndex1, int selectIndex2)
{
    // ボタン自身で判断するならば.
    QObject *target = _view->findChild<QObject *>(_dataLoggerUserListPart2ButtonData[index][0]);

    if (target) {
        if ((index == selectIndex1) || (index == selectIndex2)) {
            // checkbox & select image の設定
            target->setProperty("check1on", true);
            target->setProperty("check2visible", true);

            if (index == selectIndex1) {
                target->setProperty("check2bg", "qrc:/resource/png/select_1.png");
            } else if (index == selectIndex2) {
                target->setProperty("check2bg", "qrc:/resource/png/select_2.png");
            }

            // active 状態と,背景画像の設定
            // active 画像の設定
            target->setProperty("active", true);

            if (_dataLoggerUserListPart2ButtonData[index][0] == _userListActiveButton) {
                // 矢印あり
                if (index == 0) {
                    target->setProperty("activebg", "datalogger_filemix_userlist_btn_active_rd.png");
                } else if (index == 6) {
                    target->setProperty("activebg", "datalogger_filemix_userlist_btn_active_ur.png");
                } else {
                    target->setProperty("activebg", "datalogger_filemix_userlist_btn_active_urd.png");
                }
            } else {
                // 選択状態
                target->setProperty("activebg", "datalogger_filemix_userlist_btn_edit.png");
            }
        } else {
            if (_dataLoggerUserListPart2ButtonData[index][0] != _userListActiveButton) {
                target->setProperty("active", false);
            }

            target->setProperty("check1on", false);
            target->setProperty("check2visible", false);
            target->setProperty("check2bg", "");

            // 矢印あり
            if (index == 0) {
                target->setProperty("activebg", "datalogger_filemix_userlist_btn_active_rd.png");
            } else if (index == 6) {
                target->setProperty("activebg", "datalogger_filemix_userlist_btn_active_ur.png");
            } else {
                target->setProperty("activebg", "datalogger_filemix_userlist_btn_active_urd.png");
            }
        }
    }
}

void DataLoggerViewModel::onKeyStatusChannelListArea(ButtonId id)
{
    if (id == BUTTON_ENTER && _mode == USER) {

        if (_filemixState == FILEMIX_BEFORE) {
            // 編集には移行しない
        } else {
            // チャンネル情報の編集はユーザ設定の場合だけ
            QObject *parentTarget = _view->findChild<QObject *>(_channelListActiveButton);

            // チャネル情報編集へ移行
            _selectArea = CHANNEL_EDIT;
            QObject *target = parentTarget->findChild<QObject *>(dataLoggerChannelEditButtonData[0][0]);
            _channelEditActiveButton = dataLoggerChannelEditButtonData[0][0];
            _channelEditButtonOperation.setActiveObject(dataLoggerChannelEditButtonData[0][0]);
            target->setProperty("active", true);

            _modifyCheck = target->property("message").toString();
        }
    } else {
        moveCursorChannelListArea(id);
    }
}

void DataLoggerViewModel::moveCursorChannelListArea(ButtonId id)
{
    if ((id == BUTTON_UP) || (id == BUTTON_DOWN)) {

        QString nextBtn;
        bool ret = _channelListButtonOperation.nextActiveObject(id, nextBtn);

        if (ret) {

            int maxPage = _mode == USER ? 20 : (((_userSettingListNum - 1) / 6) + 1);
            if ((id == BUTTON_UP) && (nextBtn == "list5")) {
                // ページUP
                if (_settingListCurrentPage == 1) {
                    _settingListCurrentPage = maxPage;
                } else {
                    --_settingListCurrentPage;
                }

                showUserSettingList();
            } else if ((id == BUTTON_DOWN) && (nextBtn == "list0")) {
                // ページDown / Page 数 : max 120 行 / 6 行
                if (_settingListCurrentPage == maxPage) {
                    _settingListCurrentPage = 1;
                } else {
                    ++_settingListCurrentPage;
                }

                showUserSettingList();
            } else {
                // 行移動
            }

            // ページ数表示の更新
            QObject *target = _view->findChild<QObject *>("channelListPage");

            if (target) {
                QString currentPage;
                currentPage.sprintf("ページ %d/%d", _settingListCurrentPage, maxPage);
                target->setProperty("text", currentPage);
            }

            // inactive
            target = _view->findChild<QObject *>(_channelListActiveButton);

            if (target) {
                target->setProperty("active", false);
            }

            // active
            target = _view->findChild<QObject *>(nextBtn);

            if (target) {
                target->setProperty("active", true);
            }

            _channelListActiveButton = nextBtn;
            _channelListButtonOperation.setActiveObject(_channelListActiveButton);
        }
    } else if (id == BUTTON_LEFT) {

        if (_userListOperationProhibited == false) {
            // データ編集されていた場合にはダイアログ表示
            if (_model->isUpdate(VALUE_USERSETTING_SETTINGLIST)) {
                // データ破棄の確認POPUP
                emit requestToShowPopup(POPUP_CANCEL_CONFIRMATION);
            } else {
                onAccept(POPUP_CANCEL_CONFIRMATION, true);
            }
        }

    } else if (id == BUTTON_RIGHT) {

        if (_mode == USERSETTING_SHOW) {
            // ユーザー設定表示の場合は、アクションボタンへ遷移はしない
            return;
        }

        // アクションボタンへカーソルを変更する
        QObject *target = _view->findChild<QObject *>(_channelListActiveButton);

        // 現在カーソルが当たっているボタンからカーソルを外す
        if (target) {
            target->setProperty("idlebg", "datalogger_channellist_cur_edit.png");
            target->setProperty("active", false);
        }

        target = _view->findChild<QObject *>(_actionButtonActiveButton);

        // アクションボタンに対してカーソルを移す
        if (target) {
            if (target->property("disable") == false) {
                // [Memo]
                // カーソルを当てる部品が活性状態であれば、
                // その部品に対してカーソルを当てる
                target->setProperty("active", true);
            }

            else {
                // [Memo]
                // カーソルを当てる部品が活性状態でなければ、
                // アクションボタンの先頭ボタンに対してカーソルを当てる
                _actionButtonActiveButton = _dataLoggerActionButtonData[0][0];
                target = _view->findChild<QObject *>(_actionButtonActiveButton);

                if (target) {
                    target->setProperty("active", true);
                }
            }
        }

        _selectArea = ACTION_AREA;
    }
}

void DataLoggerViewModel::onKeyStatusChannelEditArea(ButtonId id)
{
    if (id == BUTTON_ENTER) {
        if (_channelEditActiveButton == "trash") {
            // ゴミ箱でのEnterは行削除動作を行う
            emit requestToShowPopup(POPUP_DATA_LOGGER_DELETE_CONFIRMATION);
        } else {
            QObject *parentTarget = _view->findChild<QObject *>(_channelListActiveButton);

            // チャネル情報変更へ移行
            QObject *target = parentTarget->findChild<QObject *>(_channelEditActiveButton);
            target->setProperty("active", false);

            if (_modifyCheck != target->property("message").toString()) {
                if (_modifyCheck == "-") {
                    _channellistMaxCheckCount++;

                    if (_filemixState == FILEMIX_AFTER) {
                        QString title;
                        title.sprintf(" CH登録数: %d/max120", _channellistMaxCheckCount);
                        QObject *target = _view->findChild<QObject *>("channelNumDisp");

                        if (target) {
                            target->setProperty("text", title);
                        }
                    }
                }

                // 削除はここでは検知できない / 別経路 deleteLine()
            }

            _selectArea = CHANNEL_AREA;

            parentTarget->setProperty("edit", false);
            parentTarget->setProperty("active", true);
        }
    } else {
        moveCursorChannelEditArea(id);
    }
}

void DataLoggerViewModel::moveCursorChannelEditArea(ButtonId id)
{
    // リスト上の位置を求める
    int channelListIndex = getSelectedChannelListIndex();

    if ((id == BUTTON_LEFT) || (id == BUTTON_RIGHT)) {
        {
            QVariant value;
            _model->getValue(VALUE_USERSETTING_SETTINGLIST, value);
            QVariantList channelList = value.toList();

            if (channelList.size() > channelListIndex) {
                QVariantMap channelData = channelList[channelListIndex].toMap();

                if (channelData["enable"].toBool() == false) {
                    // データ未入力行なので項目移動はさせない
                    return;
                }
            } else {
                // データ自体がまだ存在しない
                return;
            }
        }

        QString nextBtn;
        bool ret = _channelEditButtonOperation.nextActiveObject(id, nextBtn);

        if (ret) {
            QObject *parentTarget = _view->findChild<QObject *>(_channelListActiveButton);

            // inactive
            QObject *target = parentTarget->findChild<QObject *>(_channelEditActiveButton);

            if (target) {
                target->setProperty("active", false);
            }

            // active
            target = parentTarget->findChild<QObject *>(nextBtn);

            if (target) {
                target->setProperty("active", true);
            }

            _channelEditActiveButton = nextBtn;
            _channelEditButtonOperation.setActiveObject(_channelEditActiveButton);
        }
    } else if ((id == BUTTON_UP) || (id == BUTTON_DOWN)) {

        _model->addDataLoggerUserSettingList(channelListIndex);

        // 各設定値の変更
        if (_channelEditActiveButton == "band") {
            changeBandData(id, channelListIndex);
        } else if (_channelEditActiveButton == "broadbandSystem") {
            changeBroadbandSystem(id, channelListIndex);
        } else if (_channelEditActiveButton == "channel") {
            changeChannel(id, channelListIndex);
        } else if (_channelEditActiveButton == "modulation") {
            changeModulation(id, channelListIndex);
        } else if (_channelEditActiveButton == "levelOffset") {
            changeLocalFrequency(id, channelListIndex);
        } else if (_channelEditActiveButton == "mercnSwitch") {
            changeMerOnOff(channelListIndex);
        } else if (_channelEditActiveButton == "berSwitch") {
            changeBerOnOff(channelListIndex);
        } else if (_channelEditActiveButton == "powerSupply") {
            changePowerSupply(id, channelListIndex);
        } else {

        }

        showUserSettingList();
    }

}

void DataLoggerViewModel::onKeyStatusActionButtonArea(ButtonId id)
{
    if (id == BUTTON_ENTER) {
        QObject *target = _view->findChild<QObject *>(_actionButtonActiveButton);

        if (target == nullptr) {
            return;
        }

        target->setProperty("press", false);

        switch (_mode) {
        case SINGLE:
            // 選択しているチャンネルリストでシングル測定
            executeSingleMeasurement();
            break;

        case MULTI:
            // チャンネルリストでマルチ測定
            executeMultiMeasurement();
            break;

        case USER:  // 設定(手動/自動/ファイル合成) (SINGLE/MULTI 計測結果)
            // チャンネル情報編集
            executeEditUserSetting();
            break;

        case LOGGER: {
            // チャンネルリストでマルチ測定してファイル出力
            // オートパワーオフがオフでなければポップアップで実行確認
            QVariant value;

            if (_model->getValue(VALUE_AUTOPOWEROFF, value)) {
                if (value.toInt() != LC70_SYS_SET_POWOFF_OFF) {
                    emit requestToShowPopup(POPUP_CONFIRM_EXECUTE_WITH_AUTO_POWER_OFF);
                    return;
                }
            }

            executeDataLogger();
            break;
        }
        default:
            break;
        }
    } else {
        moveCursorActionButtonArea(id);
    }
}

void DataLoggerViewModel::onKeyStatusPopupButtonArea(ButtonId id)
{
    QObject *target = _view->findChild<QObject *>(_popupActiveButton);

    if (target == nullptr) {
        return;
    }

    target->setProperty("press", false);

    if (id == BUTTON_ENTER) {
        QObject *popupItem = nullptr;
        popupItem = _view->findChild<QObject *>("dgPopup");

        switch (_popupType) {
        case COLLECTCONFIRM: {
            if (_popupActiveButton == "m1") {
                // 取得間隔設定POPUPを表示する
                popupItem->setProperty("popupType", CORRECTINTERVALSET);
                _popupType = CORRECTINTERVALSET;
                _popupButtonOperation.setButtonName(2, 1, _dataLoggerPopupType2ButtonData);
                _popupButtonOperation.setActiveObject(_dataLoggerPopupType2ButtonData[0][0]);
                _popupActiveButton = _dataLoggerPopupType2ButtonData[0][0];
                _popupState = SELECT;
            } else if (_popupActiveButton == "m2") {
                // 取得日時期間設定POPUPを表示する
                popupItem->setProperty("popupType", DATETIMESET);
                _popupType = DATETIMESET;
                _popupButtonOperation.setButtonName(3, 5, _dataLoggerPopupType3ButtonData);
                _popupButtonOperation.setActiveObject(_dataLoggerPopupType3ButtonData[0][0]);
                _popupActiveButton = _dataLoggerPopupType3ButtonData[0][0];
                initDatetimeset();
                setSelectModeImage();
                setVisibleSelectEditImage(BUTTON_UNKNOWN);
                // ボタンのアクティブ戻し.
                QObject *target = popupItem->findChild<QObject *>("m2");

                if (target) {
                    target->setProperty("active", false);
                }
            }

            // 間隔の初期値は連続(=0)
            popupItem->setProperty("interval", 0);

            QObject *target = popupItem->findChild<QObject *>(_popupActiveButton);

            if (target) {
                target->setProperty("active", true);
            }

            break;
        }

        case DATETIMESET: {
            onKeyEnterDatetimeset();
            break;
        }

        case CORRECTINTERVALSET: {
            if (_popupActiveButton == "m1") {
                transitionDataLoggerMeasurementList();
            } else if (_popupActiveButton == "intervaldata") {
                // 編集・選択モードの切替
                _popupState = (_popupState == SELECT) ? EDIT : SELECT;

                QObject *target = _view->findChild<QObject *>(_popupActiveButton);

                if (target) {
                    if (_popupState == SELECT) {
                        target->setProperty("activebg", "datalogger_interval_btn_d.png");
                    } else {
                        target->setProperty("activebg", "datalogger_interval_btn_edit.png");
                    }
                }
            } else {
            }

            break;
        }

        case WAITING: {
            if (_popupActiveButton == "m1") {
                // POPUPを消去してロガーの画面に戻る
                _reserveTimer->stop();
                QObject *popupItem = nullptr;
                popupItem = _view->findChild<QObject *>("dgPopup");
                popupItem->setProperty("visible", false);
                _selectArea = ACTION_AREA;
            }

            break;
        }

        case NODATA: {
            if (_popupActiveButton == "m1") {
                // POPUPを消去してロガーの画面に戻る
                QObject *popupItem = nullptr;
                popupItem = _view->findChild<QObject *>("dgPopup");
                popupItem->setProperty("visible", false);
                _selectArea = ACTION_AREA;
            }

            break;
        }

        default:
            break;
        }
    } else {
        moveCursorPopupArea(id);
    }
}

void DataLoggerViewModel::onKeyEnterDatetimeset()
{
    QObject *popupItem = nullptr;
    popupItem = _view->findChild<QObject *>("dgPopup");

    if (_popupActiveButton == "m1") {
        QString errorMessage;
        int errorCode = isStartDataCollection(errorMessage);

        if (errorCode == 0) {
            // 実行待ちPOPUPを表示する
            popupItem->setProperty("popupType", WAITING);
            _popupType = WAITING;

            QString message1("");

            QObject *target = popupItem->findChild<QObject *>("startmonthdata");

            if (target) {
                message1 += target->property("message").toString();
                message1 += " ";
            }

            target = popupItem->findChild<QObject *>("startdaydata");

            if (target) {
                message1 += target->property("message").toString();
                message1 += " ";
            }

            target = popupItem->findChild<QObject *>("starthourdata");

            if (target) {
                message1 += target->property("message").toString();
                message1 += ":";
            }

            target = popupItem->findChild<QObject *>("startminutesdata");

            if (target) {
                message1 += target->property("message").toString();
                message1 += " ";
            }

            popupItem->setProperty("visible", true);
            popupItem->setProperty("message", message1 +
                                   "にデータを取得開始します。\n\n※別画面に遷移するとデータロガーを停止します。");
            popupItem->setProperty("leftButtonMessage", "閉じる");

            // 現在時刻を取得
            QDateTime currentdatetime = QDateTime::currentDateTime();
            QDateTime startdatetime(QDate(_yyyy, _start_mm, _start_dd), QTime(_start_HH, _start_MM, 0));
            qint64 msec = currentdatetime.msecsTo(startdatetime);

            // ロギング開始日時を検知するタイマーを開始
            _reserveTimer->start(msec);

        } else {
            // 測定データの登録なし
            QObject *popupItem = nullptr;
            popupItem = _view->findChild<QObject *>("dgPopup");
            popupItem->setProperty("popupType", NODATA);
            popupItem->setProperty("visible", true);
            popupItem->setProperty("message", errorMessage);
            popupItem->setProperty("leftButtonMessage", "戻る");

            _popupButtonOperation.setButtonName(1, 1, _dataLoggerPopupType4ButtonData);
            _popupButtonOperation.setActiveObject(_dataLoggerPopupType4ButtonData[0][0]);
            _popupActiveButton = _dataLoggerPopupType4ButtonData[0][0];

            QObject *target = popupItem->findChild<QObject *>(_popupActiveButton);

            if (target) {
                target->setProperty("active", true);
            }

            _selectArea = POPUP_AREA;
            _popupType = NODATA;
        }
    } else {
        _popupState = (_popupState  == EDIT) ? SELECT : EDIT;

        if (_popupState == SELECT) {
            setSelectModeImage();

            if ((_popupActiveButton == "startmonthdata") || (_popupActiveButton == "endmonthdata")) {
                // 何もしない
            } else if ((_popupActiveButton == "startdaydata") || (_popupActiveButton == "starthourdata")
                       || (_popupActiveButton == "startminutesdata")) {
                // active change.
                QObject *target = _view->findChild<QObject *>(_popupActiveButton);

                if (target) {
                    target->setProperty("active", false);
                }

                target = _view->findChild<QObject *>("startmonthdata");

                if (target) {
                    target->setProperty("active", true);
                }

                _popupActiveButton = "startmonthdata";
            } else {
                // active change.
                QObject *target = _view->findChild<QObject *>(_popupActiveButton);

                if (target) {
                    target->setProperty("active", false);
                }

                target = _view->findChild<QObject *>("endmonthdata");

                if (target) {
                    target->setProperty("active", true);
                }

                _popupActiveButton = "endmonthdata";
            }
        } else {
            setEditModeImage();
        }
    }
}

void DataLoggerViewModel::reserveMeasurement()
{
    emit requestSetTakeOver("enddatetimeSet", true);
    transitionDataLoggerMeasurementList();

    _loggingStarted = !_loggingStarted;
}

void DataLoggerViewModel::transitionDataLoggerMeasurementList()
{
    //取得開始
    // ダイアログを消去して収集画面に遷移する
    QObject *popupItem = nullptr;
    popupItem = _view->findChild<QObject *>("dgPopup");
    popupItem->setProperty("visible", false);
    _selectArea = ACTION_AREA;

    // 収集間隔を取得
    // データ収集実行結果画面を表示

    // 選択ユーザリストの保存
    int index = getSelectedUserListIndex();
    QVariant value;
    _model->getValue(VALUE_USERSETTING_FILELIST, value);

    QVariantList userList = value.toList();

    if (index < userList.size()) {
        QVariantList userData = userList[index].toList();

        QString filename = userData.at(2).toString();
        // ".csv" なしで保存
        emit requestSetTakeOver("selectedUserListFile", filename);
    }

    QObject *target = _view->findChild<QObject *>("dgPopup");

    value = target->property("interval");
    emit requestSetTakeOver("getInterval", value.toInt());
    emit requestSetTakeOver("enddatetimeyyyy", _end_yyyy);
    emit requestSetTakeOver("enddatetimemm", _end_mm);
    emit requestSetTakeOver("enddatetimedd", _end_dd);
    emit requestSetTakeOver("enddatetimeHH", _end_HH);
    emit requestSetTakeOver("enddatetimeMM", _end_MM);

    onRequest(2);
}

void DataLoggerViewModel::moveCursorActionButtonArea(ButtonId id)
{
    if ((id == BUTTON_UP) || (id == BUTTON_DOWN)) {

        if (_filemixState == FILEMIX_BEFORE) {
            return;
        }

        QString nextBtn;
        bool ret = _actionButtonOperation.nextActiveObject(id, nextBtn);

        if (ret) {
            QObject *nextTarget = _view->findChild<QObject *>(nextBtn);

            if (nextTarget->property("disable") == false) {
                // inactive
                QObject *target = _view->findChild<QObject *>(_actionButtonActiveButton);

                if (target) {
                    target->setProperty("active", false);
                }

                // active
                target = _view->findChild<QObject *>(nextBtn);

                if (target) {
                    target->setProperty("active", true);
                }

                _actionButtonActiveButton = nextBtn;
                _actionButtonOperation.setActiveObject(_actionButtonActiveButton);
            }
        }
    } else if (id == BUTTON_LEFT) {
        QObject *target = _view->findChild<QObject *>(_actionButtonActiveButton);

        if (target) {
            target->setProperty("active", false);
        }

        if (_filemixState != FILEMIX_BEFORE) {
            target = _view->findChild<QObject *>(_channelListActiveButton);

            if (target) {
                // 選択表現を解除
                target->setProperty("idlebg", "");
                // カーソル移動対象とする
                target->setProperty("active", true);
            }

            _selectArea = CHANNEL_AREA;
        } else {
            // FILEMIX_BEFORE
            target = _view->findChild<QObject *>(_userListActiveButton);

            if (target) {
                // カーソル移動対象とする
                target->setProperty("active", true);
                target->setProperty("activebg", _reserveUserListActivebg);
            }

            _selectArea = USERLIST_AREA;
        }
    }
}

void DataLoggerViewModel::moveCursorPopupArea(ButtonId id)
{
    switch (_popupType) {
    case COLLECTCONFIRM: {
        if (id == BUTTON_LEFT || id == BUTTON_RIGHT) {
            QString nextBtn;
            bool ret = _popupButtonOperation.nextActiveObject(id, nextBtn);

            // active 表示の切替
            if (ret) {
                QObject *nextTarget = _view->findChild<QObject *>(nextBtn);

                if (nextTarget->property("disable") == false) {
                    // inactive
                    QObject *target = _view->findChild<QObject *>(_popupActiveButton);

                    if (target) {
                        target->setProperty("active", false);
                    }

                    // active
                    target = _view->findChild<QObject *>(nextBtn);

                    if (target) {
                        target->setProperty("active", true);
                    }

                    _popupActiveButton = nextBtn;
                    _popupButtonOperation.setActiveObject(_popupActiveButton);
                }
            }
        }

        break;
    }

    case DATETIMESET: {
        QObject *popupItem = _view->findChild<QObject *>("dgPopup");

        if (_popupState == EDIT) {
            if ((id == BUTTON_RIGHT) || (id == BUTTON_LEFT)) {

                QString nextBtn;
                _popupButtonOperation.nextActiveObject(id, nextBtn);

                // active 表示の切替
                QObject *nextTarget = _view->findChild<QObject *>(nextBtn);

                if (nextTarget->property("disable") == false) {
                    // inactive
                    QObject *target = _view->findChild<QObject *>(_popupActiveButton);

                    if (target) {
                        target->setProperty("active", false);
                    }

                    // active
                    target = _view->findChild<QObject *>(nextBtn);

                    if (target) {
                        target->setProperty("active", true);
                    }

                    _popupActiveButton = nextBtn;
                    _popupButtonOperation.setActiveObject(_popupActiveButton);
                }
            } else if ((id == BUTTON_UP) || (id == BUTTON_DOWN)) {
                // 日時の更新処理

                if (_popupActiveButton == "startmonthdata") {
                    updateStartMonth(id);
                }

                if (_popupActiveButton == "startdaydata") {
                    updateStartDay(id);
                }

                if (_popupActiveButton == "starthourdata") {
                    updateStartHour(id);
                }

                if (_popupActiveButton == "startminutesdata") {
                    updateStartMinutes(id);
                }

                if (_popupActiveButton == "endmonthdata") {
                    updateEndMonth(id);
                }

                if (_popupActiveButton == "enddaydata") {
                    updateEndDay(id);
                }

                if (_popupActiveButton == "endhourdata") {
                    updateEndHour(id);
                }

                if (_popupActiveButton == "endminutesdata") {
                    updateEndMinutes(id);
                }

                if (_popupActiveButton == "datetimeintervaldata") {
                    _dataloggerExecuteInterval = editInterval(popupItem->property("interval").toInt(), id);

                    popupItem->setProperty("interval", _dataloggerExecuteInterval);
                }
            }
        } else {
            QString nextBtn;

            if ((id == BUTTON_UP) || (id == BUTTON_DOWN)) {
                setVisibleSelectEditImage(id);

                // 上下移動は左端のボタンに移動
                if ((_popupActiveButton == _dataLoggerPopupType3ButtonData[0][0])
                        || _popupActiveButton == _dataLoggerPopupType3ButtonData[0][1]
                        || _popupActiveButton == _dataLoggerPopupType3ButtonData[0][2]
                        || _popupActiveButton == _dataLoggerPopupType3ButtonData[0][3]) {
                    if (id == BUTTON_UP) {
                        nextBtn = _dataLoggerPopupType3ButtonData[2][0];
                    } else {
                        nextBtn = _dataLoggerPopupType3ButtonData[1][0];
                    }
                }

                if (_popupActiveButton == _dataLoggerPopupType3ButtonData[1][0]
                        || _popupActiveButton == _dataLoggerPopupType3ButtonData[1][1]
                        || _popupActiveButton == _dataLoggerPopupType3ButtonData[1][2]
                        || _popupActiveButton == _dataLoggerPopupType3ButtonData[1][3]
                        || _popupActiveButton == _dataLoggerPopupType3ButtonData[1][4]) {
                    if (id == BUTTON_UP) {
                        nextBtn = _dataLoggerPopupType3ButtonData[0][0];
                    } else {
                        nextBtn = _dataLoggerPopupType3ButtonData[2][0];
                    }
                }

                if (_popupActiveButton == _dataLoggerPopupType3ButtonData[2][0]) {
                    // UPボタン仕様:
                    //   取得開始ボタンにカーソルがある状態で操作した場合は
                    //   開始日時（月）にカーソルを移動する
                    nextBtn = _dataLoggerPopupType3ButtonData[0][0];
                }
            } else {

            }

            // active 表示の切替
            QObject *nextTarget = _view->findChild<QObject *>(nextBtn);

            if (nextTarget->property("disable") == false) {
                // inactive
                QObject *target = _view->findChild<QObject *>(_popupActiveButton);

                if (target) {
                    target->setProperty("active", false);
                }

                // active
                target = _view->findChild<QObject *>(nextBtn);

                if (target) {
                    target->setProperty("active", true);
                }

                _popupActiveButton = nextBtn;
                _popupButtonOperation.setActiveObject(_popupActiveButton);
            }
        }

        break;
    }

    case CORRECTINTERVALSET: {

        if (_popupState == EDIT) {
            QObject *popupItem = _view->findChild<QObject *>("dgPopup");

            if (popupItem) {
                // 更新間隔の変更
                if (id == BUTTON_UP || id == BUTTON_DOWN) {
                    _dataloggerExecuteInterval = editInterval(popupItem->property("interval").toInt(), id);

                    popupItem->setProperty("interval", _dataloggerExecuteInterval);
                }
            }
        } else {
            if (id == BUTTON_UP || id == BUTTON_DOWN) {
                QString nextBtn;
                bool ret = _popupButtonOperation.nextActiveObject(id, nextBtn);

                // active 表示の切替
                if (ret) {
                    QObject *nextTarget = _view->findChild<QObject *>(nextBtn);

                    if (nextTarget->property("disable") == false) {
                        // inactive
                        QObject *target = _view->findChild<QObject *>(_popupActiveButton);

                        if (target) {
                            target->setProperty("active", false);
                        }

                        // active
                        target = _view->findChild<QObject *>(nextBtn);

                        if (target) {
                            target->setProperty("active", true);
                        }

                        _popupActiveButton = nextBtn;
                        _popupButtonOperation.setActiveObject(_popupActiveButton);
                    }
                }
            }
        }

        break;
    }

    case WAITING: {
        break;
    }

    default:
        break;
    }
}

int DataLoggerViewModel::editInterval(int interval, ButtonId id)
{
    if (id == BUTTON_UP) {
        interval++;

        // MER/BER が ON の設定がある場合には 5分間隔は選択肢から外す
        if (interval == 1 && isEnableMERorBER()) {
            interval++;
        }
    } else if (id == BUTTON_DOWN) {
        interval--;

        // MER/BER が ON の設定がある場合には 5分間隔は選択肢から外す
        if (interval == 1 && isEnableMERorBER()) {
            interval--;
        }
    }

    // 下限・上限チェック
    if (interval < 0) {
        interval = 4;
    } else if (interval  > 4) {
        interval = 0;
    }

    return interval;
}

void DataLoggerViewModel::getUserSettingList()
{
    // 選択中のユーザリストのindex
    int index = getSelectedUserListIndex();

    if (_filemixState == FILEMIX_AFTER || _editType == EDIT_AUTO) {
        // index 位置での読み込みは行わない
        // activate 処理で合成ファイルを作成済
    } else {
        QVariant value;
        _model->getValue(VALUE_USERSETTING_FILELIST, value);

        QVariantList userList = value.toList();

        if (index < userList.size()) {
            QVariantList userData = userList[index].toList();

            // ファイル取得
            QString filename = userData.at(2).toString();

#if !Q_PROCESSOR_ARM

            if (!filename.contains(".csv")) {
                filename += ".csv";
            }

#endif
            _model->importDataLoggerUserSettingList(VALUE_USERSETTING_FILELIST, filename);
        }
    }
}

int DataLoggerViewModel::showUserSettingList(bool isInitialList)
{
    // チャンネル情報取得
    QVariant value;
    _model->getValue(VALUE_USERSETTING_SETTINGLIST, value);
    QVariantList userSettingList = value.toList();

    _userSettingListNum = userSettingList.size();

    // 1.BAND種別
    // 2.放送規格
    // 3.チャンネル番号
    // 4.中心周波数
    // 5.変調方式
    // 6.局発周波数
    // 7.MER/CN
    // 8.BER
    // 9.給電

    QVariantMap userSettingData;

    bool dataEmpty = false;

    if (isInitialList) {
        // 給電設定の組み合わせを作成し直す
        _powerSupplySettingMap.clear();
        // BER・MER取得設定の組み合わせを作成し直す
        _merSettingMap.clear();
        _berSettingMap.clear();
    }

    for (int i = (_settingListCurrentPage - 1) * 6; i < (_settingListCurrentPage * 6); i++) {
        if (userSettingList.size() <= i) {
            // 当該行のデータが存在しない
            dataEmpty = true;
        } else {
            dataEmpty = false;
            userSettingData = userSettingList[i].toMap();

            if (userSettingData["enable"] == false) {
                //データが存在していない行や削除行
                dataEmpty = true;
            }
        }

        QString listItem = "list" + QString::number(i % 6);
        QObject *target = _view->findChild<QObject *>(listItem);

        if (target) {
            target->setProperty("no", i + 1);   // No.1 から開始

            if (dataEmpty) {
                target->setProperty("band", EMPTY_VALUE);
                target->setProperty("broadbandSystem", EMPTY_VALUE);
                target->setProperty("channel", EMPTY_VALUE);
                target->setProperty("modulation", EMPTY_VALUE);
                target->setProperty("leveloffset", EMPTY_VALUE);
                target->setProperty("mercn", EMPTY_VALUE);
                target->setProperty("ber", EMPTY_VALUE);
                target->setProperty("powerSupply", EMPTY_VALUE);
                target->setProperty("isTrashVisible", false);
            } else {
                int bandId = userSettingData["band"].toInt();
                target->setProperty("band", Correcter::displayBandName(bandId, true));
                QString broadbandSystem = Correcter::displayBroadbandSystem(userSettingData["broadbandSystem"].toUInt());

                if (broadbandSystem.isEmpty()) {
                    broadbandSystem = EMPTY_VALUE;
                }

                target->setProperty("broadbandSystem", broadbandSystem);
                target->setProperty("channel", userSettingData["channel"]);

                QString modulation = Correcter::displayModulation(userSettingData["modulationBit"].toUInt());

                if (userSettingData["modulationBit"].toUInt() == 0) {
                    // 未定義なら空
                    modulation.clear();
                } else if (modulation.isEmpty()) {
                    modulation = EMPTY_VALUE;
                }

                target->setProperty("modulation", modulation);

                // 局発周波数
                if (userSettingData["localFreq"] != QVariant(0)) {
                    // 局発周波数の値あり
                    // kHz => GHz
                    float leveloffset = userSettingData["localFreq"].toUInt() / float(1000000);
                    target->setProperty("leveloffset", QString::number(leveloffset));
                } else {
                    // [Memo]
                    //  対応するデータがない場合は「-」を表示する
                    target->setProperty("leveloffset", EMPTY_VALUE);
                }

                if (_filemixState != FILEMIX_BEFORE) {
                    // MER/CN
                    MerBerSettingType merSettingType = SETTING_INVALID;
                    if (userSettingData["MERCN"] != QVariant(-1)) {
                        // [Memo]
                        //  バンドがPILOT, LTE, FMの場合は「-」を表示する
                        if (bandId == LC70_BAND_PILOT
                                || bandId == LC70_BAND_LTE
                                || bandId == LC70_BAND_FM
                                || bandId == LC70_BAND_CATV_UP_STREAM) {
                            target->setProperty("mercn", EMPTY_VALUE);
                        } else {
                            if (userSettingData["MERCN"].toBool()) {
                                target->setProperty("mercn", "ON");
                                merSettingType = SETTING_ON;
                            } else {
                                target->setProperty("mercn", "OFF");
                                merSettingType = SETTING_OFF;
                            }
                        }
                    } else {
                        // [Memo]
                        //  対応するデータがない場合は「-」を表示する
                        target->setProperty("mercn", EMPTY_VALUE);
                    }

                    // BER
                    MerBerSettingType berSettingType = SETTING_INVALID;
                    if (userSettingData["BER"] != QVariant(-1)) {
                        // [Memo]
                        //  バンドがPILOT, LTE, FMの場合は「-」を表示する
                        if (bandId == LC70_BAND_PILOT
                                || bandId == LC70_BAND_LTE
                                || bandId == LC70_BAND_FM
                                || bandId == LC70_BAND_CATV_UP_STREAM) {
                            target->setProperty("ber", EMPTY_VALUE);
                        } else {
                            if (userSettingData["BER"].toBool()) {
                                target->setProperty("ber", "ON");
                                berSettingType = SETTING_ON;
                            } else {
                                target->setProperty("ber", "OFF");
                                berSettingType = SETTING_OFF;
                            }
                        }
                    } else {
                        // [Memo]
                        //  対応するデータがない場合は「-」を表示する
                        target->setProperty("ber", EMPTY_VALUE);
                    }

                    // POWER SUPPLY
                    // powerSupplyは、0が設定されている場合「OFF」を表示する。
                    target->setProperty("powerSupply", Correcter::displayPowerSupply(userSettingData["PowerSupply"].toUInt()));

                    ChannelDefinitionItem currentChannel;

                    if (_model->getChannelDefinitionItem(bandId, userSettingData["channel"].toString(), currentChannel)) {
                        QPair<LC70_BAND_T, int> key = {static_cast<LC70_BAND_T>(bandId), currentChannel.polarization};

                        if (_merSettingMap.count(key) == 0) {
                            _merSettingMap[key] = merSettingType;
                        }

                        if (_berSettingMap.count(key) == 0) {
                            _berSettingMap[key] = berSettingType;
                        }

                        if (_powerSupplySettingMap.count(key) == 0) {
                            _powerSupplySettingMap[key] = userSettingData["PowerSupply"].toUInt();
                        }
                    }

                    // TRASH
                    // [Memo]
                    // データが空の場合は、Trashは表示しない BAND名がある場合のみ表示する
                    target->setProperty("isTrashVisible", true);
                } else {
                    target->setProperty("isTrashVisible", false);
                }
            }
        }
    }

    return userSettingList.size();
}

void DataLoggerViewModel::showEmptyUserSettingList()
{
    for (int i = 0; i < 6; i++) {
        QString listItem = "list" + QString::number(i % 6);
        QObject *target = _view->findChild<QObject *>(listItem);

        if (target) {
            target->setProperty("no", i + 1);   // No.1 から開始
            target->setProperty("band", EMPTY_VALUE);
            target->setProperty("broadbandSystem", EMPTY_VALUE);
            target->setProperty("channel", EMPTY_VALUE);
            target->setProperty("modulation", EMPTY_VALUE);
            target->setProperty("leveloffset", EMPTY_VALUE);
            target->setProperty("isTrashVisible", false);
        }
    }
}

void DataLoggerViewModel::onKeyStatus(ButtonId id)
{
    // ESC キーは入力破棄して前画面に戻る
    // データ更新ある場合には rollback
    if (id == BUTTON_ESCAPE  || id == BUTTON_HOME || id == BUTTON_USER || id == BUTTON_MENU) {
        if (_model->isUpdate(VALUE_USERSETTING_SETTINGLIST)) {
            emit requestToShowPopup(POPUP_CANCEL_CONFIRMATION);
        } else {
            onAccept(POPUP_CANCEL_CONFIRMATION, true);
        }
    } else {
        switch (_selectArea) {
        case USERLIST_AREA:
            onKeyStatusUserListArea(id);
            break;

        case CHANNEL_AREA:
            onKeyStatusChannelListArea(id);
            break;

        case CHANNEL_EDIT:
            onKeyStatusChannelEditArea(id);
            break;

        case ACTION_AREA:
            onKeyStatusActionButtonArea(id);
            break;

        case POPUP_AREA:
            onKeyStatusPopupButtonArea(id);
            break;

        default:
            break;
        }
    }
}

void DataLoggerViewModel::onButtonPress(ButtonId id)
{
    if (id == BUTTON_ENTER) {
        QObject *target = nullptr;

        switch (_selectArea) {
        case USERLIST_AREA:
            // nothing to do
            break;

        case CHANNEL_AREA:
            target = _view->findChild<QObject *>(_channelListActiveButton);

            if (target && _mode == USER) {

                if (_filemixState == FILEMIX_BEFORE) {
                    // nothing to do
                } else {
                    target->setProperty("edit", true);
                }
            }

            break;

        case CHANNEL_EDIT:
            break;

        case ACTION_AREA:
            target = _view->findChild<QObject *>(_actionButtonActiveButton);

            if (target) {
                target->setProperty("press", true);
            }

            break;

        default:
            break;
        }
    }
}

void DataLoggerViewModel::onAccept(PopupId popupId, bool okOnly)
{
    Q_UNUSED(okOnly);

    AbstractViewModel::onAccept(popupId, okOnly);

    if (popupId == POPUP_SAVE_CONFIRMATION) {
        onAcceptPopupSaveConfirmation();
    } else if (popupId == POPUP_DATA_LOGGER_KEYBOARD) {
        onAcceptPopupDataLoggerKeyboard();
    } else if (popupId == POPUP_CANCEL_CONFIRMATION) {
        onAcceptPopupCancelConfirmation();
    } else if (popupId == POPUP_DATA_LOGGER_DELETE_CONFIRMATION) {
        deleteLine();

        showUserSettingList();

        // ファイル合成モードである場合は以下の処理を行う
        if (_filemixState == FILEMIX_AFTER) {
            QString title;
            title.sprintf(" CH登録数: %d/max120", _channellistMaxCheckCount);
            QObject *target = _view->findChild<QObject *>("channelNumDisp");

            if (target) {
                target->setProperty("text", title);
            }
        }
    } else if (popupId == POPUP_DATA_LOGGER_DELETE_FILELIST_CONFIRMATION) {
        deleteUserFileList();
        backToUserList();
        // 再描画
        // ユーザファイルリスト表示
        showUserFileList();
        // チャンネルリスト
        showUserSettingList();
    } else if (popupId == POPUP_CONFIRM_OVERWRITE_USER_LOGGER_DATA) {
        // 同一ファイル名の場合に再入力を促す
        // キーボード表示
        emit requestToShowPopup(POPUP_DATA_LOGGER_KEYBOARD);

        // ファイル名が取得できるようにシグナル接続をする
        connect(_mainFrame, SIGNAL(inputFileName(PopupId, SaveLocation, QString)),
                this, SLOT(onInputFileName(PopupId, SaveLocation, QString)));
    } else if (popupId == POPUP_CONFIRM_EXECUTE_WITH_AUTO_POWER_OFF) {
        // オートパワーオフありでデータロガー実行
        executeDataLogger();
    } else {}
}

void DataLoggerViewModel::onAcceptPopupSaveConfirmation()
{
    // ソート
    sortUserSettingList();

    // 重複チェック
    bool isDuplicate = isDuplicateUserSettingList();

    if (isDuplicate) {
        // 重複あり

        QObject *popupItem = nullptr;
        popupItem = _view->findChild<QObject *>("dgPopup");
        popupItem->setProperty("popupType", NODATA);
        popupItem->setProperty("visible", true);
        popupItem->setProperty("message", "同一 CH が存在します。");
        popupItem->setProperty("leftButtonMessage", "戻る");

        _popupButtonOperation.setButtonName(1, 1, _dataLoggerPopupType4ButtonData);
        _popupButtonOperation.setActiveObject(_dataLoggerPopupType4ButtonData[0][0]);
        _popupActiveButton = _dataLoggerPopupType4ButtonData[0][0];

        QObject *target = popupItem->findChild<QObject *>(_popupActiveButton);

        if (target) {
            target->setProperty("active", true);
        }

        _selectArea = POPUP_AREA;
        _popupType = NODATA;

        return;
    }

    // 選択中のユーザリストのindex
    int index = getSelectedUserListIndex();

    QVariant value;
    _model->getValue(VALUE_USERSETTING_FILELIST, value);

    // /media/mmcblk0p1/user_logset/user_logger_settig_file_list.csv がファイル仕様に基づいた内容で存在することを前提とする
    QVariantList userList = value.toList();
    QVariantList userData;

    if (userList.count() > 0) {
        userData = userList[index].toList();
    }

    if (userList.count() == 0 || userData.at(2).toString().isEmpty()) {
        // 新規ファイル
        // キーボード表示
        emit requestToShowPopup(POPUP_DATA_LOGGER_KEYBOARD);

        // ファイル名が取得できるようにシグナル接続をする
        connect(_mainFrame, SIGNAL(inputFileName(PopupId, SaveLocation, QString)),
                this, SLOT(onInputFileName(PopupId, SaveLocation, QString)));
    } else {
        // ファイル取得
        QString filename = userData.at(2).toString();

        // キーボード表示
        emit requestToShowPopupWithMessage(POPUP_DATA_LOGGER_KEYBOARD, filename);

        // ファイル名が取得できるようにシグナル接続をする
        connect(_mainFrame, SIGNAL(inputFileName(PopupId, SaveLocation, QString)),
                this, SLOT(onInputFileName(PopupId, SaveLocation, QString)));

//        _model->commit(VALUE_DATALOGGER_USERSETTINGLIST);

//#if !Q_PROCESSOR_ARM

//        if (!filename.contains(".csv")) {
//            filename += ".csv";
//        }

//#endif
//        _model->exportDataLoggerUserSettingList(filename);

//        _userListOperationProhibited = false;

//        // export画面遷移
//        if (_backToScreen != SCREEN_ID_COUNT) {
//            emit requestInHistory(_backToScreen);
//            _backToScreen = SCREEN_ID_COUNT;
//            return;
//        }

//        if (_filemixState == FILEMIX_AFTER) {
//            requestInHistory(SCREEN_MANUAL_AUTO_SELECTION);
//            return;
//        }

//        // カーソル移動
//        backToUserList();

    }
}

void DataLoggerViewModel::onAcceptPopupDataLoggerKeyboard()
{
    disconnect(_mainFrame, SIGNAL(inputFileName(PopupId, SaveLocation, QString)),
               this, SLOT(onInputFileName(PopupId, SaveLocation, QString)));
    // 選択中のユーザリストのindex
    int index = getSelectedUserListIndex();

    QVariant value;
    _model->getValue(VALUE_USERSETTING_FILELIST, value);

    QVariantList userList = value.toList();
    QVariantList userData = userList[index].toList();

    _model->commit(VALUE_USERSETTING_SETTINGLIST);

    // ファイル取得
    QString filename = userData.at(2).toString();

#if !Q_PROCESSOR_ARM

    if (!filename.contains(".csv")) {
        filename += ".csv";
    }

#endif
    _model->exportDataLoggerUserSettingList(VALUE_USERSETTING_FILELIST, filename);

    _userListOperationProhibited = false;

    // export、画面遷移
    if (_backToScreen != SCREEN_ID_COUNT) {
        emit requestInHistory(_backToScreen);
        _backToScreen = SCREEN_ID_COUNT;
        return;
    }

    if (_filemixState == FILEMIX_AFTER) {
        requestInHistory(SCREEN_MANUAL_AUTO_SELECTION);
        return;
    }

    // カーソル移動
    backToUserList();

    // 再描画
    // ユーザファイルリスト表示
    showUserFileList();
    // チャンネルリスト
    showUserSettingList();
}

void DataLoggerViewModel::onAcceptPopupCancelConfirmation()
{
    _model->rollback(VALUE_USERSETTING_SETTINGLIST);

    // 押下されたボタンにより遷移先を変更する
    switch (_lastPressedButtonId) {
    case BUTTON_LEFT: {
        if (_selectArea == CHANNEL_AREA) {
            // 選択リストへ遷移
            QObject *target = _view->findChild<QObject *>(_channelListActiveButton);

            if (target) {
                target->setProperty("active", false);
            }

            target = _view->findChild<QObject *>(_userListActiveButton);

            if (target) {
                target->setProperty("activebg", _reserveUserListActivebg);
                target->setProperty("active", true);
            }

            _selectArea = USERLIST_AREA;

            showUserSettingList();
        }

        break;
    }

    default:
        screenTransitionByKey(_lastPressedButtonId);
        break;
    }
}

void DataLoggerViewModel::screenTransitionByKey(ButtonId id)
{
    ScreenId nextScreen = SCREEN_ID_COUNT;
    bool isBack = false;

    switch (id) {
    case BUTTON_HOME:
        nextScreen = SCREEN_HOME;
        break;

    case BUTTON_MENU:
        isBack = true;
        break;

    case BUTTON_USER:
        nextScreen = SCREEN_USER_DATA_LOGGER_MENU;
        break;

    case BUTTON_ESCAPE:
        isBack = true;
        break;

    default:
        break;
    }

    // 遷移
    if (nextScreen != SCREEN_ID_COUNT) {
        _reserveTimer->stop();
        _filemixFileIndex.clear();
        _filemixState = FILEMIX_UNKNOWN;
        emit requestSetTakeOver("fileselectionListIndex", 0);

        _fileselectionInedx = 0;
        emit requestDirect(nextScreen, true);
    } else if (isBack) {
        _reserveTimer->stop();
        _filemixFileIndex.clear();
        _filemixState = FILEMIX_UNKNOWN;
        emit requestSetTakeOver("fileselectionListIndex", 0);

        _fileselectionInedx = 0;
        emit back();
    }
}

void DataLoggerViewModel::onReject(PopupId popupId)
{
    Q_UNUSED(popupId);

    if (popupId == POPUP_CONFIRM_EXECUTE_WITH_AUTO_POWER_OFF) {
        emit requestPopupClose();
    }
}

void DataLoggerViewModel::onInputFileName(PopupId popupId, SaveLocation saveLocation, QString fileName)
{
    Q_UNUSED(saveLocation);

    // 名前が重複しているファイル名
    _duplicateFileName = QString("");

    // ファイル名が空でデータ保存してしまわないよう、
    // ファイル名が空の場合は、後続処理は実施しない
    if (fileName.isEmpty()) {
        _model->writeLog(QString("USER設定 保存処理"), QString("File名の入力が空"));
        return;
    }

    // 選択中のユーザリストのindex
    int index = getSelectedUserListIndex();

    QVariant value;
    _model->getValue(VALUE_USERSETTING_FILELIST, value);

    QVariantList userList = value.toList();
    QVariantList userData;

    if (userList.count() > 0) {
        userData = userList[index].toList();
        if (checkContainSameNamefile(userList, fileName)) {
            // 同じ名前のファイル名がUSER Dataloggerに存在する場合データ上書き保存確認ダイアログを表示する
            _duplicateFileName = fileName;
            emit requestToShowPopup(POPUP_CONFIRM_OVERWRITE_USER_LOGGER_DATA);
            return;
        }
        // USERリストに保存する
        userData[2] = fileName;
        userList[index] = userData;
    } else {
        userData = QVariantList() <<  1 << 0 << fileName;
        userList.append(QVariant::fromValue(userData));
    }

    _model->setValue(VALUE_USERSETTING_FILELIST, userList);
    _model->commit(VALUE_USERSETTING_FILELIST);

    // 保存処理
    onAccept(popupId, true);
}


void DataLoggerViewModel::changeBandData(ButtonId id, int channelListIndex)
{
    QVariant value;
    _model->getValue(VALUE_USERSETTING_SETTINGLIST, value);
    QVariantList channelList = value.toList();
    QVariantMap channelData = channelList[channelListIndex].toMap();

    int currentBandIndex = getListIndexBand(static_cast<LC70_BAND_T>(channelData["band"].toInt()));

    switch (id) {
    case BUTTON_UP:
        if (currentBandIndex == -1) {
            currentBandIndex = 0;
        } else {
            currentBandIndex++;
        }

        break;

    case BUTTON_DOWN:
        if (currentBandIndex == -1) {
            currentBandIndex = BAND_LIST_INDEX_MAP.size();
        } else {
            currentBandIndex--;
        }

        break;

    default:
        break;
    }

    // 上限下限チェック
    if (currentBandIndex < 0) {
        currentBandIndex = BAND_LIST_INDEX_MAP.size() - 1;
    } else if (currentBandIndex > BAND_LIST_INDEX_MAP.size() - 1) {
        currentBandIndex = 0;
    } else {
        // nothing to do.
    }

    // model 更新
    channelData["enable"] = true;

    // バンド情報 valueが正しく得られなかった時は地デジを返す
    int currentBandId = BAND_LIST_INDEX_MAP.value(currentBandIndex, LC70_BAND_UHF);
    channelData["band"] = currentBandId;

    // BAND 更新により他項目の更新も行う
    QList<ChannelDefinitionItem> channelDefiList;
    bool ret = _model->getChannelDefinitionList(currentBandId, channelDefiList);

    if (ret == false) {
        // エラー処理 TODO
        channelList[channelListIndex] = channelData;
        _model->setValue(VALUE_USERSETTING_SETTINGLIST, channelList);
        return;
    }

    // 放送規格
    // BAND から求める
    QList<int> broadbandSystemList;
    _model->getBroadbandSystem(static_cast<LC70_BAND_T>(currentBandId), broadbandSystemList);

    // 変調方式
    // 放送規格から求める
    unsigned int modulationBit = _model->getModulationBit(static_cast<LC70_BAND_T>(currentBandId), broadbandSystemList[0]);

    // チャンネル名
    channelData["channel"] = channelDefiList[0].channelNumber;

    // 中心周波数
    channelData["centerFreq"] = Correcter::centerFrequency(channelDefiList[0], modulationBit);

    // 放送規格
    channelData["broadbandSystem"] = broadbandSystemList[0];

    // 変調方式
    QList<unsigned int> bitlist;
    Correcter::getModulationBitList(modulationBit, bitlist);

    if (bitlist.empty()) {
        channelData["modulationBit"] = LC70_SETMOD_UNDEF;
    } else {
        channelData["modulationBit"] = bitlist[0];
    }

    // 局発
    {
        QVariant localFrequencyValue;
        _model->getValue(VALUE_LOCAL_FREQUENCY, localFrequencyValue);
        QString polarizationString = Correcter::convertPolarizeNumToString(channelDefiList[0].polarization);
        QList<uint32_t> localFrequencyValueList = {};
        Correcter::getLocalOscillatorList(localFrequencyValue, currentBandId, polarizationString, localFrequencyValueList);

        if (localFrequencyValueList.isEmpty()) {
            // 対応するデータがない場合は、0を設定する
            channelData["localFreq"] = 0;
        } else {
            channelData["localFreq"] = localFrequencyValueList.at(0);
        }
    }

    // MER/CN
    //  選択BANDがPILOT, LTE, FM の場合はMER/CNの取得は行わないため「-」を表示するように「-1」を設定
    //  それ以外のバンドの場合は、ONを表示するように初期値trueを設定する。
    if (currentBandId == LC70_BAND_PILOT || currentBandId == LC70_BAND_LTE || currentBandId == LC70_BAND_FM || currentBandId == LC70_BAND_CATV_UP_STREAM) {
        channelData["MERCN"] = -1;
    } else {
        channelData["MERCN"] = getMerSetting(currentBandId, channelDefiList[0].polarization);
    }

    // BER
    //  選択BANDがPILOT, LTE, FM の場合はBERの取得は行わないため「-」を表示するように「-1」を設定
    //  それ以外のバンドの場合は、ONを表示するように初期値trueを設定する
    if (currentBandIndex == LC70_BAND_PILOT || currentBandIndex == LC70_BAND_LTE || currentBandIndex == LC70_BAND_FM || currentBandIndex == LC70_BAND_CATV_UP_STREAM) {
        channelData["BER"] = -1;
    } else {
        channelData["BER"] = getBerSetting(currentBandId, channelDefiList[0].polarization);
    }

    // 給電
    // バンド・偏波の組み合わせで給電設定を統一する
    channelData["PowerSupply"] = getPowerSupplySetting(currentBandId, channelDefiList[0].polarization);

    channelList[channelListIndex] = channelData;

    _model->setValue(VALUE_USERSETTING_SETTINGLIST, channelList);
}

void DataLoggerViewModel::changeBroadbandSystem(ButtonId id, int channelListIndex)
{
    QVariant value;
    _model->getValue(VALUE_USERSETTING_SETTINGLIST, value);
    QVariantList channelList = value.toList();
    QVariantMap channelData = channelList[channelListIndex].toMap();

    int bandid = channelData["band"].toInt();
    int currentBroadbandSystem = channelData["broadbandSystem"].toInt();

    QList<int> broadbandSystemList;
    _model->getBroadbandSystem(static_cast<LC70_BAND_T>(bandid), broadbandSystemList);

    // １つしかない場合は変更なし
    if (broadbandSystemList.size() == 1) {
        return;
    }

    int selected = 0;

    for (; selected < broadbandSystemList.size(); selected++) {
        if (broadbandSystemList[selected] == currentBroadbandSystem) {
            break;
        }
    }


    switch (id) {
    case BUTTON_UP:
        selected++;
        break;

    case BUTTON_DOWN:
        selected--;
        break;

    default:
        break;
    }

    if (selected < 0) {
        selected = broadbandSystemList.size() - 1;
    } else if (selected >= broadbandSystemList.size()) {
        selected = 0;
    }

    // 変調方式
    // 放送規格から求める
    unsigned int modulationBit = _model->getModulationBit(static_cast<LC70_BAND_T>(bandid), broadbandSystemList[selected]);
    QList<unsigned int> bitlist;
    Correcter::getModulationBitList(modulationBit, bitlist);

    if (bitlist.empty()) {
        channelData["modulationBit"] = LC70_SETMOD_UNDEF;
    } else {
        channelData["modulationBit"] = bitlist[0];
    }

    // model 更新
    channelData["broadbandSystem"] = broadbandSystemList[selected];
    channelList[channelListIndex] = channelData;
    _model->setValue(VALUE_USERSETTING_SETTINGLIST, channelList);
}

void DataLoggerViewModel::changeModulation(ButtonId id, int channelListIndex)
{
    QVariant value;
    _model->getValue(VALUE_USERSETTING_SETTINGLIST, value);
    QVariantList channelList = value.toList();
    QVariantMap channelData = channelList[channelListIndex].toMap();

    // 放送方式から変調方式のリストを取得
    int broadBandSystem = channelData["broadbandSystem"].toInt();
    unsigned int modulationBit = _model->getModulationBit(static_cast<LC70_BAND_T>(channelData["band"].toInt()),
                                 broadBandSystem);
    QList<unsigned int> modulationBitList;
    Correcter::getModulationBitList(modulationBit, modulationBitList);

    // 選択可能な変調方式のリストを取得
    unsigned int currentModulation = channelData["modulationBit"].toUInt();

    int selected = modulationBitList.indexOf(currentModulation);

    switch (id) {
    case BUTTON_UP:
        selected++;
        break;

    case BUTTON_DOWN:
        selected--;
        break;

    default:
        break;
    }

    if (selected < 0) {
        selected = modulationBitList.size() - 1;
    } else if (selected >= modulationBitList.size()) {
        selected = 0;
    }

    // リストに対応するチャンネル定義情報を取得
    ChannelDefinitionItem channelDefinitionItem;
    bool ret = _model->getChannelDefinitionItem(channelData["band"].toInt(), channelData["channel"].toString(),
               channelDefinitionItem);

    if (ret == false) {
        // エラー処理 TODO
        channelList[channelListIndex] = channelData;
        _model->setValue(VALUE_USERSETTING_SETTINGLIST, channelList);
        return;
    }

    // model 更新
    channelData["modulationBit"] = modulationBitList[selected];
    channelData["centerFreq"] = Correcter::centerFrequency(channelDefinitionItem, channelData["modulationBit"].toUInt());
    channelList[channelListIndex] = channelData;
    _model->setValue(VALUE_USERSETTING_SETTINGLIST, channelList);
}

void DataLoggerViewModel::changeMerOnOff(int channelListIndex)
{
    QVariant value;
    _model->getValue(VALUE_USERSETTING_SETTINGLIST, value);
    QVariantList channelList = value.toList();
    QVariantMap channelData = channelList[channelListIndex].toMap();
    int band = channelData["band"].toInt();

    // [Memo]
    //  BANDデータが、PILOT, LTE, FM, CATV上りの場合は、以降の処理は実施しない
    if (band == LC70_BAND_PILOT || band == LC70_BAND_LTE || band == LC70_BAND_FM || band == LC70_BAND_CATV_UP_STREAM) {
        return;
    }

    bool settingValue = channelData["MERCN"].toBool();

    // 押下ボタンに関係なく値を反転させる
    settingValue = !settingValue;

    // model 更新
    channelData["MERCN"] = settingValue;
    MerBerSettingType type = SETTING_INVALID;
    if (settingValue) {
        type = SETTING_ON;
    } else {
        type = SETTING_OFF;
    }
    setMerSetting(channelData, type);
    channelList[channelListIndex] = channelData;
    updateMerSetting(channelList);
    _model->setValue(VALUE_USERSETTING_SETTINGLIST, channelList);
}


void DataLoggerViewModel::changeBerOnOff(int channelListIndex)
{
    QVariant value;
    _model->getValue(VALUE_USERSETTING_SETTINGLIST, value);
    QVariantList channelList = value.toList();
    QVariantMap channelData = channelList[channelListIndex].toMap();
    int band = channelData["band"].toInt();

    // [Memo]
    //  BANDデータが、PILOT, LTE, FMの場合は、以降の処理は実施しない
    if (band == LC70_BAND_PILOT || band == LC70_BAND_LTE || band == LC70_BAND_FM) {
        return;
    }

    bool settingValue = channelData["BER"].toBool();

    // 押下ボタンに関係なく値を反転させる
    settingValue = !settingValue;

    // model 更新
    channelData["BER"] = settingValue;
    MerBerSettingType type = SETTING_INVALID;
    if (settingValue) {
        type = SETTING_ON;
    } else {
        type = SETTING_OFF;
    }
    setBerSetting(channelData, type);
    channelList[channelListIndex] = channelData;
    updateBerSetting(channelList);
    _model->setValue(VALUE_USERSETTING_SETTINGLIST, channelList);
}

void DataLoggerViewModel::changePowerSupply(ButtonId id, int channelListIndex)
{
    QVariant value;
    _model->getValue(VALUE_USERSETTING_SETTINGLIST, value);
    QVariantList channelList = value.toList();
    QVariantMap channelData = channelList[channelListIndex].toMap();

    int settingValue = channelData["PowerSupply"].toInt();

    switch (id) {
    case BUTTON_UP:
        settingValue = nextPowerSupplySetting(channelData, settingValue);
        break;

    case BUTTON_DOWN:
        settingValue = prevPowerSupplySetting(channelData, settingValue);
        break;

    default:
        break;
    }

    // model 更新
    channelData["PowerSupply"] = settingValue;
    setPowerSupplySetting(channelData, settingValue);
    channelList[channelListIndex] = channelData;
    updatePowerSupplySetting(channelList);
    _model->setValue(VALUE_USERSETTING_SETTINGLIST, channelList);
}

void DataLoggerViewModel::changeChannel(ButtonId id, int channelListIndex)
{
    QVariant value;
    _model->getValue(VALUE_USERSETTING_SETTINGLIST, value);
    QVariantList channelList = value.toList();
    QVariantMap channelData = channelList[channelListIndex].toMap();

    // 現在のチャンネル情報を取得 key = band
    int currentBand = channelData["band"].toInt();
    QString currentChannelName = channelData["channel"].toString();
    QList<ChannelDefinitionItem> channelDefList;
    _model->getChannelDefinitionList(currentBand, channelDefList);

    // チャンネル定義リスト上の現在の位置を求める
    int currentChannelndex = 0;

    for (int i = 0; i < channelDefList.size(); i++) {
        if (channelDefList[i].channelNumber == currentChannelName) {
            currentChannelndex = i;
            break;
        }
    }

    switch (id) {
    case BUTTON_UP:
        currentChannelndex++;
        break;

    case BUTTON_DOWN:
        currentChannelndex--;
        break;

    default:
        break;
    }

    if (currentChannelndex < 0) {
        currentChannelndex = channelDefList.size() - 1;
    } else if (currentChannelndex > channelDefList.size() - 1) {
        currentChannelndex = 0;
    } else {
        // nothing to do
    }

    channelData["channel"] = channelDefList[currentChannelndex].channelNumber;

    // 局発周波数を変更する
    {
        QVariant localFrequencyValue;
        _model->getValue(VALUE_LOCAL_FREQUENCY, localFrequencyValue);
        QString polarizationString = Correcter::convertPolarizeNumToString(channelDefList[currentChannelndex].polarization);
        QList<uint32_t> localFrequencyValueList = {};

        Correcter::getLocalOscillatorList(localFrequencyValue, currentBand, polarizationString, localFrequencyValueList);

        if (localFrequencyValueList.isEmpty()) {
            channelData["localFreq"] = 0;
        } else {
            channelData["localFreq"] = localFrequencyValueList.at(0);
        }
    }
    // 中心周波数
    channelData["centerFreq"] = Correcter::centerFrequency(channelDefList[currentChannelndex],
                                channelData["modulationBit"].toUInt());

    // MER/CN
    channelData["MERCN"] = getMerSetting(currentBand, channelDefList[currentChannelndex].polarization);
    // BER
    channelData["BER"] = getBerSetting(currentBand, channelDefList[currentChannelndex].polarization);
    // 給電
    channelData["PowerSupply"] = getPowerSupplySetting(currentBand, channelDefList[currentChannelndex].polarization);

    channelList[channelListIndex] = channelData;
    _model->setValue(VALUE_USERSETTING_SETTINGLIST, channelList);
}

void DataLoggerViewModel::changeLocalFrequency(ButtonId id, int channelListIndex)
{
    QVariant value;
    _model->getValue(VALUE_USERSETTING_SETTINGLIST, value);
    QVariantList channelList = value.toList();
    QVariantMap channelData = channelList[channelListIndex].toMap();

    // 現在の設定を取得し、偏波種別を求める
    int currentBand = channelData["band"].toInt();
    QString currentChannelName = channelData["channel"].toString();
    ChannelDefinitionItem currentChannel;
    _model->getChannelDefinitionItem(currentBand, currentChannelName, currentChannel);

    int polarization = currentChannel.polarization;

    if (polarization == (-1)) {
        // 偏波定義なしの場合には処理なし
        return;
    }

    // 局発
    QVariant localFrequencyValue;
    _model->getValue(VALUE_LOCAL_FREQUENCY, localFrequencyValue);
    QString polarizationString = Correcter::convertPolarizeNumToString(polarization);

    QList<uint32_t> localFrequencyValueList = {};
    Correcter::getLocalOscillatorList(localFrequencyValue, currentBand, polarizationString, localFrequencyValueList);

    if (localFrequencyValueList.isEmpty()) {
        // 局発周波数のリストがうまく取得できていない場合は[-]を表示する
        channelData["localFreq"] = 0;
    } else {
        // 現在の周波数の位置を特定する
        int pos = 0;

        for (pos = 0; pos <= 8; pos++) {
            if (localFrequencyValueList.at(pos) == channelData["localFreq"].toUInt()) {
                break;
            }
        }

        switch (id) {
        case BUTTON_UP:
            pos++;
            break;

        case BUTTON_DOWN:
            pos--;
            break;

        default:
            break;
        }

        if (pos < 0) {
            pos = localFrequencyValueList.size() - 1;
        } else if (pos > localFrequencyValueList.size() - 1) {
            pos = 0;
        } else {

        }

        channelData["localFreq"] = localFrequencyValueList.at(pos);
    }

    channelList[channelListIndex] = channelData;
    _model->setValue(VALUE_USERSETTING_SETTINGLIST, channelList);
}

void DataLoggerViewModel::deleteLine()
{
    int channelListIndex = getSelectedChannelListIndex();
    _model->deleteDataLoggerUserSettingList(channelListIndex);

    _channellistMaxCheckCount--;

    // チャネル情報変更へ移行
    QObject *parentTarget = _view->findChild<QObject *>(_channelListActiveButton);
    QObject *target = parentTarget->findChild<QObject *>(_channelEditActiveButton);
    target->setProperty("active", false);

    _selectArea = CHANNEL_AREA;

    parentTarget->setProperty("edit", false);
    parentTarget->setProperty("active", true);
}

void DataLoggerViewModel::deleteUserFileList()
{
    // 選択中のユーザリストのindex
    int index = getSelectedUserListIndex();

    QVariant value;
    _model->getValue(VALUE_USERSETTING_FILELIST, value);

    QVariantList userLists = value.toList();
    QVariantList deleteItem = userLists[index].toList();

    // チャンネル設定リストを削除
    QString filename = deleteItem[2].toString();
    _model->removeDataLoggerUserSettingList(VALUE_USERSETTING_FILELIST, filename);

    deleteItem[1] = 0;              // 無効状態
    deleteItem[2] = QString("");    // ファイル名消去
    userLists[index] = deleteItem;

    _model->setValue(VALUE_USERSETTING_FILELIST, userLists);
    _model->commit(VALUE_USERSETTING_FILELIST);

    if (_model->isUpdate(VALUE_USERSETTING_SETTINGLIST)) {
        _model->rollback(VALUE_USERSETTING_SETTINGLIST);
    }
}

int DataLoggerViewModel::getSelectedUserListIndex()
{
    int column = 10;

    if (_filemixState == FILEMIX_BEFORE) {
        column = 7;
    }

    return _userListActiveButton.mid(8).toInt() + (_userListCurrentPage - 1) * column;
}

int DataLoggerViewModel::getSelectedChannelListIndex()
{
    int channelListIndex = (_settingListCurrentPage - 1) * 6;
    channelListIndex += _channelListActiveButton.mid(4).toInt();

    return channelListIndex;
}

void DataLoggerViewModel::executeSingleMeasurement()
{
    // 選択行を取得
    int channelListIndex = getSelectedChannelListIndex();

    // チャンネルデータを取得
    QVariant value;
    _model->getValue(VALUE_USERSETTING_SETTINGLIST, value);
    QVariantList channelList = value.toList();

    if (channelList.size() <= channelListIndex) {
        // 範囲外
        QObject *popupItem = nullptr;
        popupItem = _view->findChild<QObject *>("dgPopup");
        popupItem->setProperty("popupType", NODATA);
        popupItem->setProperty("visible", true);
        popupItem->setProperty("message", "選択チャンネルは無効です");
        popupItem->setProperty("leftButtonMessage", "戻る");

        _popupButtonOperation.setButtonName(1, 1, _dataLoggerPopupType4ButtonData);
        _popupButtonOperation.setActiveObject(_dataLoggerPopupType4ButtonData[0][0]);
        _popupActiveButton = _dataLoggerPopupType4ButtonData[0][0];

        QObject *target = popupItem->findChild<QObject *>(_popupActiveButton);

        if (target) {
            target->setProperty("active", true);
        }

        _selectArea = POPUP_AREA;
        _popupType = NODATA;
        return;
    }

    QVariantMap channelData = channelList[channelListIndex].toMap();

    // パラメータ設定
    emit requestSetTakeOver("selectedBand", channelData["band"]);
    emit requestSetTakeOver("selectedModulation", Correcter::displayModulation(channelData["modulationBit"].toUInt()));
    emit requestSetTakeOver("selectedLocalOscillator", channelData["localFreq"]);
    ChannelDefinitionItem item;
    _model->getChannelDefinitionItem(channelData["band"].toInt(), channelData["channel"].toString(), item);
    emit requestSetTakeOver("selectedPolarization", item.polarization);

    emit requestSetTakeOver("fromUserSetting", true);

    // 選択ユーザリストの保存
    int index = getSelectedUserListIndex();
    _model->getValue(VALUE_USERSETTING_FILELIST, value);

    QVariantList userList = value.toList();

    if (index < userList.size()) {
        QVariantList userData = userList[index].toList();

        QString filename = userData.at(2).toString();
        // ".csv" なしで保存
        emit requestSetTakeOver("selectedUserListFile", filename);
    }

    onRequest(0);
}

void DataLoggerViewModel::executeMultiMeasurement()
{
    // チャンネルデータを取得
    QVariant value;
    _model->getValue(VALUE_USERSETTING_SETTINGLIST, value);
    QVariantList channelList = value.toList();

    if (channelList.size() < 1) {
        // 範囲外
        QObject *popupItem = nullptr;
        popupItem = _view->findChild<QObject *>("dgPopup");
        popupItem->setProperty("popupType", NODATA);
        popupItem->setProperty("visible", true);
        popupItem->setProperty("message", "選択チャンネルは無効です");
        popupItem->setProperty("leftButtonMessage", "戻る");

        _popupButtonOperation.setButtonName(1, 1, _dataLoggerPopupType4ButtonData);
        _popupButtonOperation.setActiveObject(_dataLoggerPopupType4ButtonData[0][0]);
        _popupActiveButton = _dataLoggerPopupType4ButtonData[0][0];

        QObject *target = popupItem->findChild<QObject *>(_popupActiveButton);

        if (target) {
            target->setProperty("active", true);
        }

        _selectArea = POPUP_AREA;
        _popupType = NODATA;
        return;
    }

    emit requestSetTakeOver("fromUserSetting", true);

    // 選択ユーザリストの保存
    int index = getSelectedUserListIndex();

    _model->getValue(VALUE_USERSETTING_FILELIST, value);

    QVariantList userList = value.toList();

    if (index < userList.size()) {
        QVariantList userData = userList[index].toList();

        QString filename = userData.at(2).toString();
        // ".csv" なしで保存
        emit requestSetTakeOver("selectedUserListFile", filename);
    }

    onRequest(1);
}

void DataLoggerViewModel::executeEditUserSetting()
{
    if ((_filemixState == FILEMIX_BEFORE) || (_filemixState == FILEMIX_AFTER)) {
        executeEditUserSettingFilemix();
        return;
    }

    if (_actionButtonActiveButton == "execute1") {
        QVariant data;
        _model->getValue(VALUE_USERSETTING_SETTINGLIST, data);

        if (data.toList().size() > 0) {
            if (_model->isUpdate(VALUE_USERSETTING_SETTINGLIST)) {
                //保存処理
                // POPUP_SAVE_USER_SETTING_DATA
                emit requestToShowPopup(POPUP_SAVE_CONFIRMATION);
            }

            // 更新なくても、保存を実行する条件
            if (_backToScreen != SCREEN_ID_COUNT) {
                emit requestToShowPopup(POPUP_SAVE_CONFIRMATION);
            }
        } else {
            // 測定データの登録なし
            QObject *popupItem = nullptr;
            popupItem = _view->findChild<QObject *>("dgPopup");
            popupItem->setProperty("popupType", NODATA);
            popupItem->setProperty("visible", true);
            popupItem->setProperty("message", "測定データが登録されていません");
            popupItem->setProperty("leftButtonMessage", "戻る");

            _popupButtonOperation.setButtonName(1, 1, _dataLoggerPopupType4ButtonData);
            _popupButtonOperation.setActiveObject(_dataLoggerPopupType4ButtonData[0][0]);
            _popupActiveButton = _dataLoggerPopupType4ButtonData[0][0];

            QObject *target = popupItem->findChild<QObject *>(_popupActiveButton);

            if (target) {
                target->setProperty("active", true);
            }

            _selectArea = POPUP_AREA;
            _popupType = NODATA;
        }
    } else if (_actionButtonActiveButton == "execute2") {
        // 削除処理
        emit requestToShowPopup(POPUP_DATA_LOGGER_DELETE_FILELIST_CONFIRMATION);
    }
}

void DataLoggerViewModel::executeEditUserSettingFilemix()
{
    if (_actionButtonActiveButton == "execute1") {

        QObject *target = _view->findChild<QObject *>("execute1");

        if (target) {

            if (_filemixState == FILEMIX_BEFORE) {
                if (target->property("disable") == false) {

                    QVariant value;
                    _model->getValue(VALUE_USERSETTING_FILELIST, value);

                    QString filename1("");
                    QString filename2("");

                    QVariantList userList = value.toList();

                    if (_filemixFileIndex[0] < userList.size()) {
                        QVariantList userData = userList[_filemixFileIndex[0]].toList();

                        // ファイル取得
                        if (userData.at(2).toString().size() > 0) {
                            filename1 = userData.at(2).toString();

#if !Q_PROCESSOR_ARM

                            if (!filename1.contains(".csv")) {
                                filename1 += ".csv";
                            }

#endif
                        }
                    }

                    if (_filemixFileIndex[1] < userList.size()) {
                        QVariantList userData = userList[_filemixFileIndex[1]].toList();

                        // ファイル取得
                        if (userData.at(2).toString().size() > 0) {
                            filename2 = userData.at(2).toString();

#if !Q_PROCESSOR_ARM

                            if (!filename2.contains(".csv")) {
                                filename2 += ".csv";
                            }

#endif
                        }
                    }

                    // ファイル名が空のファイルが選択されている場合は、
                    // ユーザに対して空ファイル合成対象外という旨を伝えるダイアログを表示する。
                    if (filename1.isEmpty() || filename2.isEmpty()) {
                        QObject *popupItem = nullptr;
                        popupItem = _view->findChild<QObject *>("dgPopup");
                        popupItem->setProperty("popupType", NODATA);
                        popupItem->setProperty("visible", true);
                        popupItem->setProperty("message",
                                               "空ファイルはファイル合成対象外となります。\n選択しなおしてください");
                        popupItem->setProperty("leftButtonMessage", "戻る");

                        _popupButtonOperation.setButtonName(1, 1, _dataLoggerPopupType4ButtonData);
                        _popupButtonOperation.setActiveObject(_dataLoggerPopupType4ButtonData[0][0]);
                        _popupActiveButton = _dataLoggerPopupType4ButtonData[0][0];

                        QObject *target = popupItem->findChild<QObject *>(_popupActiveButton);

                        if (target) {
                            target->setProperty("active", true);
                        }

                        _selectArea = POPUP_AREA;
                        _popupType = NODATA;
                    } else {
                        emit requestSetTakeOver("filemixFilename1", filename1);
                        emit requestSetTakeOver("filemixFilename2", filename2);

                        _filemixFileIndex.clear();
                        // "保存先選択"へ遷移
                        onRequest(3);
                    }
                }
            } else if (_filemixState == FILEMIX_AFTER) {
                if (_channellistMaxCheckCount <= USER_SETTING_DATA_DETAIL_NUMBER) {
                    emit requestToShowPopup(POPUP_SAVE_CONFIRMATION);
                } else {
                    QObject *popupItem = nullptr;
                    popupItem = _view->findChild<QObject *>("dgPopup");
                    popupItem->setProperty("popupType", NODATA);
                    popupItem->setProperty("visible", true);
                    popupItem->setProperty("message", "CH登録数が max120 を超えています\n登録数を変更してください");
                    popupItem->setProperty("leftButtonMessage", "戻る");

                    _popupButtonOperation.setButtonName(1, 1, _dataLoggerPopupType4ButtonData);
                    _popupButtonOperation.setActiveObject(_dataLoggerPopupType4ButtonData[0][0]);
                    _popupActiveButton = _dataLoggerPopupType4ButtonData[0][0];

                    QObject *target = popupItem->findChild<QObject *>(_popupActiveButton);

                    if (target) {
                        target->setProperty("active", true);
                    }

                    _selectArea = POPUP_AREA;
                    _popupType = NODATA;
                }
            }
        }
    }
}

void DataLoggerViewModel::executeDataLogger()
{
    if (_actionButtonActiveButton != "execute1") {
        return;
    }

    QObject *popupItem = nullptr;
    popupItem = _view->findChild<QObject *>("dgPopup");

    // チャンネルデータを取得
    QVariant value;
    _model->getValue(VALUE_USERSETTING_SETTINGLIST, value);
    QVariantList channelList = value.toList();

    if (channelList.size() < 1) {
        // 範囲外
        popupItem->setProperty("popupType", NODATA);
        popupItem->setProperty("visible", true);
        popupItem->setProperty("message", "選択チャンネルは無効です");
        popupItem->setProperty("leftButtonMessage", "戻る");

        _popupButtonOperation.setButtonName(1, 1, _dataLoggerPopupType4ButtonData);
        _popupButtonOperation.setActiveObject(_dataLoggerPopupType4ButtonData[0][0]);
        _popupActiveButton = _dataLoggerPopupType4ButtonData[0][0];

        QObject *target = popupItem->findChild<QObject *>(_popupActiveButton);

        if (target) {
            target->setProperty("active", true);
        }

        _selectArea = POPUP_AREA;
        _popupType = NODATA;
        return;
    }

    QString listname;
    listname.sprintf("%d: %s", getSelectedUserListIndex() + 1, getSelectedUserFileListName().toUtf8().constData());

    popupItem->setProperty("popupType", COLLECTCONFIRM);
    popupItem->setProperty("visible", true);
    popupItem->setProperty("message", "データ取得開始\n\n登録番号 " + listname);
    popupItem->setProperty("leftButtonMessage", "取得開始する");
    popupItem->setProperty("rightButtonMessage", "開始、終了日時を\n設定して取得する");

    _popupButtonOperation.setButtonName(1, 2, _dataLoggerPopupType1ButtonData);
    _popupButtonOperation.setActiveObject(_dataLoggerPopupType1ButtonData[0][0]);
    _popupActiveButton = _dataLoggerPopupType1ButtonData[0][0];

    QObject *target = popupItem->findChild<QObject *>(_popupActiveButton);

    if (target) {
        target->setProperty("active", true);
    }

    _selectArea = POPUP_AREA;
    _popupType = COLLECTCONFIRM;
}

void DataLoggerViewModel::backToUserList()
{
    // ACTION_AREA からユーザリストへ戻すための処理
    moveCursorActionButtonArea(BUTTON_LEFT);
    _lastPressedButtonId = BUTTON_LEFT;
    moveCursorChannelListArea(BUTTON_LEFT);

    // 保存ボタンに設定しておく
    _actionButtonActiveButton = _dataLoggerActionButtonData[0][0];
}

QString DataLoggerViewModel::getSelectedUserFileListName()
{
    // 選択中のユーザリストのindex
    int index = getSelectedUserListIndex();


    QVariant value;
    _model->getValue(VALUE_USERSETTING_FILELIST, value);

    QVariantList userList = value.toList();

    // 選択行がUSERファイルリストのサイズ以上の場合は後続処理は実施しない
    if (userList.size() <= index) {
        return QString("");
    }

    QVariantList userData = userList[index].toList();
    // ファイル取得
    QString filename = userData.at(2).toString();
    return filename;
}

bool DataLoggerViewModel::isEnableMERorBER()
{
    QVariant value;
    QVariantList list;
    _model->getValue(VALUE_USERSETTING_SETTINGLIST, value);
    list = value.toList();

    foreach (const QVariant &item, list) {
        QVariantMap data = item.toMap();

        if (data["MERCN"].toBool()) {
            return true;
        }

        if (data["BER"].toBool()) {
            return true;
        }
    }

    return false;
}

void DataLoggerViewModel::updateStartMonth(ButtonId id)
{
    QDate date(_yyyy, _start_mm, _start_dd);

    if (id == BUTTON_UP) {
        date = date.addMonths(1);
    } else if (id == BUTTON_DOWN) {
        date = date.addMonths(-1);
    } else {
        // nothing to do
    }

    _start_mm = date.month();
    // 月末日付の調整
    int day = date.day();

    if (_start_dd != day) {
        _start_dd = day;
    }

    QObject *btn1 = _view->findChild<QObject *>("startmonthdata");

    if (btn1) {
        btn1->setProperty("message", QString().sprintf("%d月", _start_mm));
    }

    QObject *btn2 = _view->findChild<QObject *>("startdaydata");

    if (btn2) {
        btn2->setProperty("message", QString().sprintf("%d日", _start_dd));
    }
}
void DataLoggerViewModel::updateStartDay(ButtonId id)
{
    QDate date(_yyyy, _start_mm, _start_dd);

    if (id == BUTTON_UP) {
        _start_dd++;
    } else if (id == BUTTON_DOWN) {
        _start_dd--;
    } else {
        // nothing to do
    }

    // 月末日付の調整
    int daysInMonth = date.daysInMonth();
    _start_dd = (_start_dd + daysInMonth) % daysInMonth;

    if (_start_dd == 0) {
        _start_dd = daysInMonth;
    }

    QObject *btn = _view->findChild<QObject *>("startdaydata");

    if (btn) {
        btn->setProperty("message", QString().sprintf("%d日", _start_dd));
    }
}
void DataLoggerViewModel::updateStartHour(ButtonId id)
{
    if (id == BUTTON_UP) {
        _start_HH++;
    } else if (id == BUTTON_DOWN) {
        _start_HH--;
    } else {
        // nothing to do.
    }

    _start_HH = (_start_HH + 24) % 24;
    QObject *btn = _view->findChild<QObject *>("starthourdata");

    if (btn) {
        btn->setProperty("message", QString().sprintf("%d", _start_HH));
    }
}
void DataLoggerViewModel::updateStartMinutes(ButtonId id)
{
    if (id == BUTTON_UP) {
        _start_MM++;
    } else if (id == BUTTON_DOWN) {
        _start_MM--;
    } else {
        // nothing to do.
    }

    _start_MM = (_start_MM + 60) % 60;
    QObject *btn = _view->findChild<QObject *>("startminutesdata");

    if (btn) {
        btn->setProperty("message", QString().sprintf("%d", _start_MM));
    }
}
void DataLoggerViewModel::updateEndMonth(ButtonId id)
{
    QDate date(_yyyy, _end_mm, _end_dd);

    if (id == BUTTON_UP) {
        date = date.addMonths(1);
    } else if (id == BUTTON_DOWN) {
        date = date.addMonths(-1);
    } else {
        // nothing to do
    }

    _end_mm = date.month();
    // 月末日付の調整
    int day = date.day();

    if (_end_dd != day) {
        _end_dd = day;
    }

    QObject *btn1 = _view->findChild<QObject *>("endmonthdata");

    if (btn1) {
        btn1->setProperty("message", QString().sprintf("%d月", _end_mm));
    }

    QObject *btn2 = _view->findChild<QObject *>("enddaydata");

    if (btn2) {
        btn2->setProperty("message", QString().sprintf("%d日", _end_dd));
    }
}
void DataLoggerViewModel::updateEndDay(ButtonId id)
{
    QDate date(_yyyy, _end_mm, _end_dd);

    if (id == BUTTON_UP) {
        _end_dd++;
    } else if (id == BUTTON_DOWN) {
        _end_dd--;
    } else {
        // nothing to do
    }

    // 月末日付の調整
    int daysInMonth = date.daysInMonth();
    _end_dd = (_end_dd + daysInMonth) % daysInMonth;

    if (_end_dd == 0) {
        _end_dd = daysInMonth;
    }

    QObject *btn = _view->findChild<QObject *>("enddaydata");

    if (btn) {
        btn->setProperty("message", QString().sprintf("%d日", _end_dd));
    }
}
void DataLoggerViewModel::updateEndHour(ButtonId id)
{
    if (id == BUTTON_UP) {
        _end_HH++;
    } else if (id == BUTTON_DOWN) {
        _end_HH--;
    } else {
        // nothing to do.
    }

    _end_HH = (_end_HH + 24) % 24;
    QObject *btn = _view->findChild<QObject *>("endhourdata");

    if (btn) {
        btn->setProperty("message", QString().sprintf("%d", _end_HH));
    }
}
void DataLoggerViewModel::updateEndMinutes(ButtonId id)
{
    if (id == BUTTON_UP) {
        _end_MM++;
    } else if (id == BUTTON_DOWN) {
        _end_MM--;
    } else {
        // nothing to do.
    }

    _end_MM = (_end_MM + 60) % 60;
    QObject *btn = _view->findChild<QObject *>("endminutesdata");

    if (btn) {
        btn->setProperty("message", QString().sprintf("%d", _end_MM));
    }
}

void DataLoggerViewModel::initDatetimeset()
{
    // 現在時刻を取得
    QDateTime currentdatetime = QDateTime::currentDateTime();

    QString val;
    val = currentdatetime.toString("yyyy");
    _yyyy = val.toInt();

    val = currentdatetime.toString("MM");
    _start_mm = val.toInt();
    _end_mm = val.toInt();

    val = currentdatetime.toString("dd");
    _start_dd = val.toInt();
    _end_dd = val.toInt();

    val = currentdatetime.toString("HH");
    _start_HH = val.toInt();
    _end_HH = val.toInt();

    val = currentdatetime.toString("mm");
    _start_MM = val.toInt();
    _end_MM = val.toInt();

    // 初期表示
    updateStartMonth(BUTTON_UNKNOWN);
    updateStartDay(BUTTON_UNKNOWN);
    updateStartHour(BUTTON_UNKNOWN);
    updateStartMinutes(BUTTON_UNKNOWN);

    updateEndMonth(BUTTON_UNKNOWN);
    updateEndDay(BUTTON_UNKNOWN);
    updateEndHour(BUTTON_UNKNOWN);
    updateEndMinutes(BUTTON_UNKNOWN);

//todo: 算出と動的に変化
    // 測定可能時間を表示する
    QObject *target = _view->findChild<QObject *>("measurableTime");

    if (target) {
        target->setProperty("text", "測定可能時間は約 24 時間");
    }
}

int DataLoggerViewModel::isStartDataCollection(QString &errorMessage)
{
    // 1．開始日時の未来日時チェック
    //   開始日時＜＝現在日時＋1分の場合、エラーとする
    //
    // 3．測定可能時間チェック
    //   終了日時－開始日時＞測定可能時間の場合、エラーとする

    // 注意:
    //   開始日時＞終了日時の場合、年を扱っていないため、終了日時は翌年の指定として処理する

    // errorcode
    // 0x01:開始日過去扱い
    // 0x02:

    int errorStart = 1;
    int errorSize  = 2;

    // 現在時刻を取得
    QDateTime currentdatetime = QDateTime::currentDateTime();

    QString val;
    val = currentdatetime.toString("yyyy");
    int current_yyyy = val.toInt();

    val = currentdatetime.toString("MM");
    int current_mm = val.toInt();

    val = currentdatetime.toString("dd");
    int current_dd = val.toInt();

    val = currentdatetime.toString("HH");
    int current_HH = val.toInt();

    val = currentdatetime.toString("mm");
    int current_MM = val.toInt();

    // 年は同じ
    QDate currentDay(current_yyyy, current_mm, current_dd);
    QDate startDay(current_yyyy, _start_mm, _start_dd);

    qint64 diffDay = currentDay.daysTo(startDay);

    if (diffDay > 0) {
        // 未来が設定されている
    } else if (diffDay < 0) {
        // 過去が設定されている
        errorMessage = "開始月日の指定が過去になっています";
        return errorStart;
    } else {
        // 現在時刻プラス１分より前の場合、エラーとする
        if ((_start_HH * 60 + _start_MM) <= (current_HH * 60 + current_MM + 1)) {
            errorMessage = "開始の分設定は現在より2分以上\n未来を設定してください";
            return errorStart;
        }
    }

    // 翌年か確認する _end_yyyy を設定する
    // サイズチェックまで処理を動かして、収まらないNGとする
    //
    QDate endDay(current_yyyy, _end_mm, _end_dd);

    diffDay = startDay.daysTo(endDay);

    if (diffDay < 0) {
        _end_yyyy = current_yyyy + 1;
    }

    // 測定可能時間のチェック
    if (isMeasurable()) {
        return 0;
    } else {
        errorMessage = QString("USBの保存領域が不足しています。\n不要なデータを消去してください。");
        return errorSize;
    }
}

bool DataLoggerViewModel::isMeasurable()
{
    quint64 availableSize = getAvailableSize();

    if (availableSize == 0) {
        return false;
    }

    quint64 estimatedUseSize = getEstimatedUseSize();

    if (estimatedUseSize == 0) {
        return false;
    }

    if (estimatedUseSize < availableSize) {
        return true;
    } else {
        return false;
    }
}

quint64 DataLoggerViewModel::getAvailableSize()
{
    // 1. 空きがあるか
    //bool isNoSpace = UsbOperation::freeSpace();

    bool isNoSpace = false;

    if (isNoSpace) {
        return 0;
    }

    // 2. 空きサイズはどれくらいか
    quint64 udbFreeSpace = UsbOperation::getFreeSpaceSize();
    return udbFreeSpace;
}

quint64 DataLoggerViewModel::getEstimatedUseSize()
{
    // 測定可能時間＝USBの空き容量－（※1×リストのCH数×※2）
    // ※1：設定ファイルに定義された、1CHのデータ量
    // ※2：時間内に計測できる回数＝（終了日時－開始日時）／間隔

    QDateTime enddatetime(QDate(_end_yyyy, _end_mm, _end_dd), QTime(_end_HH, _end_MM, 0));
    QDateTime startdatetime(QDate(_yyyy, _start_mm, _start_dd), QTime(_start_HH, _start_MM, 0));
    qint64 msec = startdatetime.msecsTo(enddatetime);

    quint64 sec = msec / 1000;
    quint64 numberOfMeasurements = -1;

    // マルチ測定取得間隔(ms)
    quint64 interval = _model->applicationSetting()->pollingIntervalMultiMeasurement();
    // 1 秒間の測定取得回数
    int expectedCount = 1000 / interval;
    if (1000 % interval) {
        ++expectedCount;
    }

    switch (_dataloggerExecuteInterval) {
    case 0:// 0 : 連続
        numberOfMeasurements = sec / 1 * expectedCount;
        break;

    case 1:// 1 :  5min
        numberOfMeasurements = sec / (5 * 60) * expectedCount;
        break;

    case 2:// 2 : 15min
        numberOfMeasurements = sec / (15 * 60) * expectedCount;
        break;

    case 3:// 3 : 30min
        numberOfMeasurements = sec / (30 * 60) * expectedCount;
        break;

    case 4:// 4 : 60min
        numberOfMeasurements = sec / (60 * 60) * expectedCount;
        break;

    default:
        break;
    }

    if (numberOfMeasurements < 1) {
        return 0;
    }

    quint64 needSize = MEASUREMENT_1CH_DATA_SIZE * _userSettingListNum * numberOfMeasurements;
    return needSize;
}

void DataLoggerViewModel::setVisibleSelectEditImage(ButtonId id)
{
    // 画像表示非表示切り替え
    // startmonthdata
    // endmonthdata
    // m1

    bool visibleStart = false;
    bool visibleEnd = false;

    if (id == BUTTON_UNKNOWN) {
        // 初期表示時で
        visibleStart = true;
    }

    if ((_popupActiveButton == "startmonthdata") || (_popupActiveButton == "startdaydata")
            || (_popupActiveButton == "starthourdata") || (_popupActiveButton == "startminutesdata")) {
        if (id == BUTTON_UP) {
            visibleStart = false;
        }

        if (id == BUTTON_DOWN) {
            visibleEnd = true;
        }
    }

    if ((_popupActiveButton == "endmonthdata") || (_popupActiveButton == "enddaydata")
            || (_popupActiveButton == "endhourdata") || (_popupActiveButton == "endminutesdata")
            || (_popupActiveButton == "datetimeintervaldata")) {
        if (id == BUTTON_UP) {
            visibleStart = true;
        }

        if (id == BUTTON_DOWN) {
            visibleEnd = false;
        }
    }

    if (_popupActiveButton == "m1") {
        // UP/DOWN
        visibleStart = true;
    }

    QString object1("startDatetimeBackground");
    QObject *startTimeImage = _view->findChild<QObject *>(object1);

    if (startTimeImage) {
        startTimeImage->setProperty("visible", visibleStart);
    }

    QString object2("endDatetimeBackground");
    QObject *endTimeImage = _view->findChild<QObject *>(object2);

    if (endTimeImage) {
        endTimeImage->setProperty("visible", visibleEnd);
    }
}

void DataLoggerViewModel::setSelectModeImage()
{
    // startDatetimeBackground
    // endDatetimeBackground
    // startmonthdata
    // endmonthdata
    QString object1("startDatetimeBackground");
    QObject *startTimeImage = _view->findChild<QObject *>(object1);

    if (startTimeImage) {
        startTimeImage->setProperty("startDatetimeBackgroundImage",
                                    "qrc:/resource/png/datalogger_datetimeset_starttime_cur.png");
    }

    QString object2("endDatetimeBackground");
    QObject *endTimeImage = _view->findChild<QObject *>(object2);

    if (endTimeImage) {
        endTimeImage->setProperty("endDatetimeBackgroundImage", "qrc:/resource/png/datalogger_datetimeset_endtime_cur.png");
    }

    QString object3("startmonthdata");
    QObject *startmonthdataImage = _view->findChild<QObject *>(object3);

    if (startmonthdataImage) {
        startmonthdataImage->setProperty("activebgImage", "");
    }

    QString object4("endmonthdata");
    QObject *endmonthdataImage = _view->findChild<QObject *>(object4);

    if (endmonthdataImage) {
        endmonthdataImage->setProperty("activebgImage", "");
    }
}

void DataLoggerViewModel::setEditModeImage()
{
    // startDatetimeBackground
    // endDatetimeBackground
    // startmonthdata
    // endmonthdata
    QString object1("startDatetimeBackground");
    QObject *startTimeImage = _view->findChild<QObject *>(object1);

    if (startTimeImage) {
        startTimeImage->setProperty("startDatetimeBackgroundImage",
                                    "qrc:/resource/png/datalogger_datetimeset_starttime_cur_edit.png");
    }

    QString object2("endDatetimeBackground");
    QObject *endTimeImage = _view->findChild<QObject *>(object2);

    if (endTimeImage) {
        endTimeImage->setProperty("endDatetimeBackgroundImage",
                                  "qrc:/resource/png/datalogger_datetimeset_endtime_cur_edit.png");
    }

    QString object3("startmonthdata");
    QObject *startmonthdataImage = _view->findChild<QObject *>(object3);

    if (startmonthdataImage) {
        startmonthdataImage->setProperty("activebgImage", "datetime_btn_r.png");
    }

    QString object4("endmonthdata");
    QObject *endmonthdataImage = _view->findChild<QObject *>(object4);

    if (endmonthdataImage) {
        endmonthdataImage->setProperty("activebgImage", "datetime_btn_r.png");
    }
}

void DataLoggerViewModel::enterUserListArea()
{
    if (_filemixState != FILEMIX_BEFORE) {
        return;
    }

    // リスト名を取得し、空であれば後続処理は実施しない
    // ファイル名が空のデータは合成対象ファイルとしない。
    if (getSelectedUserFileListName().isEmpty()) {
        return;
    }

    // 管理情報の更新
    int userListIndex = getSelectedUserListIndex();

    int targetIndex = _filemixFileIndex.indexOf(userListIndex);

    if (targetIndex != -1) {
        // 含んでいる
        _filemixFileIndex.removeAt(targetIndex);
    } else {
        // 含んでいない
        if (_filemixFileIndex.size() < 2) {
            _filemixFileIndex.push_back(userListIndex);
        }
    }

    QObject *target = _view->findChild<QObject *>("execute1");

    if (target) {
        if (_filemixFileIndex.size() == 2) {
            target->setProperty("disable", false);
        } else {
            target->setProperty("disable", true);
        }
    }

    // 見た目更新
    int index = _userListActiveButton.mid(8).toInt();

    int selectIndex1 = -1;
    int selectIndex2 = -1;

    if (_filemixFileIndex.size() == 1) {
        selectIndex1 = _filemixFileIndex[0];
    }

    if (_filemixFileIndex.size() == 2) {
        selectIndex2 = _filemixFileIndex[1];
    }

    // 表示位置へ補正すると
    selectIndex1 = selectIndex1 - (_userListCurrentPage - 1) * 7;
    selectIndex2 = selectIndex2 - (_userListCurrentPage - 1) * 7;

    updateUserListItemImage(index, selectIndex1, selectIndex2);
}

void DataLoggerViewModel::changeLayout()
{
    if (_filemixState == FILEMIX_BEFORE) {
        changeLayoutForFilemixOperation();
    } else {
        // AFTER で戻らない場合もある想定で
        changeLayoutForDefault();
    }
}

void DataLoggerViewModel::changeLayoutForFilemixOperation()
{
    QObject *target;

    target = _view->findChild<QObject *>("channelNumDisp");

    if (target) {
        target->setProperty("visible", false);
    }

    target = _view->findChild<QObject *>("channelListPage");

    if (target) {
        target->setProperty("visible", false);
    }

    target = _view->findChild<QObject *>("channelInfoDisp");

    if (target) {
        target->setProperty("visible", true);
    }

    target = _view->findChild<QObject *>("userSelectList");

    if (target) {
        // 左端に隙間を設定
        target->setProperty("x", 25);
        target->setProperty("width", 250);
    }

    target = _view->findChild<QObject *>("userfilelistpage");

    if (target) {
        target->setProperty("width", 250);
    }

    target = _view->findChild<QObject *>("background");

    if (target) {
        target->setProperty("visible", true);
    }

    target = _view->findChild<QObject *>("channelListBg");

    if (target) {
        target->setProperty("source", "qrc:/resource/png/datalogger_filemix_channellist_bg.png");
        target->setProperty("y", 35);
    }

    target = _view->findChild<QObject *>("userSelectListBg");

    if (target) {
        target->setProperty("source", "qrc:/resource/png/datalogger_filemix_userlist_bg.png");
        target->setProperty("y", 34);
        target->setProperty("width", 235);
        target->setProperty("height", 281);
    }

    // userdata0 - userdata9
    for (int i = 0; i < 10; i++) {
        QString userListItem = "userdata" + QString::number(i % 10);
        target = _view->findChild<QObject *>(userListItem);

        if (target) {
            target->setProperty("width", 235);
            target->setProperty("height", 40);
            target->setProperty("type", 1);
        }
    }

    for (int i = 0; i < 6; i++) {
        QString listItem = "list" + QString::number(i % 6);
        target = _view->findChild<QObject *>(listItem);

        if (target) {
            target->setProperty("width", 442);

            target->setProperty("bandWidth", 78);
            target->setProperty("broadbandSystemWidth", 78);
            target->setProperty("channelWidth", 78);
            target->setProperty("modulationWidth", 78);
            target->setProperty("leveloffsetWidth", 78);
            target->setProperty("mercnSwitchWidth", 0);
            target->setProperty("berSwitchWidth", 0);
            target->setProperty("powerSupplyWidth", 0);
            target->setProperty("trashWidth", 0);
        }
    }

    QList<QString> rowList = {"row2", "row3", "row4", "row5", "row6"};

    for (int i = 0; i < rowList.size(); i++) {
        target = _view->findChild<QObject *>(rowList[i]);

        if (target) {
            target->setProperty("width", 78);
        }
    }

    QList<QString> invisibleList = {"row7", "row8", "row9", "row10", "userdata7", "userdata8", "userdata9"};

    for (int i = 0; i < invisibleList.size(); i++) {
        target = _view->findChild<QObject *>(invisibleList[i]);

        if (target) {
            target->setProperty("visible", false);
        }
    }

    // ユーザリストの画像更新
    for (int i = 0; i < 7; i++) {
        updateUserListItemImage(i, -1, -1);
    }

    target = _view->findChild<QObject *>("operationKey");

    if (target) {
        target->setProperty("visibleDownUP", true);
    }

    target = _view->findChild<QObject *>("execute1");

    if (target) {
        target->setProperty("activebg", "datalogger_action_filemix_btn_active_l.png");
        target->setProperty("idlebg", "datalogger_action_filemix_btn.png");
        target->setProperty("pressbg", "datalogger_action_filemix_btn_p.png");
    }
}

void DataLoggerViewModel::changeLayoutForDefault()
{
    QObject *target;

    target = _view->findChild<QObject *>("channelNumDisp");

    if (target) {
        target->setProperty("visible", true);
        target->setProperty("text", "");

        if (_filemixState == FILEMIX_AFTER) {
            QString title;
            title.sprintf(" CH登録数: %d/max120", _channellistMaxCheckCount);
            QObject *target = _view->findChild<QObject *>("channelNumDisp");

            if (target) {
                target->setProperty("text", title);
            }
        }
    }

    target = _view->findChild<QObject *>("channelListPage");

    if (target) {
        target->setProperty("visible", true);
    }

    target = _view->findChild<QObject *>("channelInfoDisp");

    if (target) {
        target->setProperty("visible", false);
    }

    target = _view->findChild<QObject *>("userSelectList");

    if (target) {
        target->setProperty("x", 0);
        target->setProperty("width", 185);
    }

    target = _view->findChild<QObject *>("background");

    if (target) {
        target->setProperty("visible", false);
    }

    target = _view->findChild<QObject *>("channelListBg");

    if (target) {
        target->setProperty("source", "qrc:/resource/png/datalogger_channellist_bg.png");
        target->setProperty("y", 33);
    }

    target = _view->findChild<QObject *>("userSelectListBg");

    if (target) {
        target->setProperty("source", "qrc:/resource/png/datalogger_userlist_base.png");
        target->setProperty("width", 175);
        target->setProperty("height", 340);
    }

    // userdata0 - userdata9
    for (int i = 0; i < 10; i++) {
        QString userListItem = "userdata" + QString::number(i % 10);
        target = _view->findChild<QObject *>(userListItem);

        if (target) {
            target->setProperty("width", 175);
            target->setProperty("height", 34);
            target->setProperty("type", 0);
        }
    }

    for (int i = 0; i < 6; i++) {
        QString listItem = "list" + QString::number(i % 6);
        target = _view->findChild<QObject *>(listItem);

        if (target) {
            target->setProperty("width", 550);

            target->setProperty("bandWidth", 63);
            target->setProperty("broadbandSystemWidth", 63);
            target->setProperty("channelWidth", 63);
            target->setProperty("modulationWidth", 63);
            target->setProperty("leveloffsetWidth", 63);
            target->setProperty("mercnSwitchWidth", 38);
            target->setProperty("berSwitchWidth", 38);
            target->setProperty("powerSupplyWidth", 63);
            target->setProperty("trashWidth", 39);
        }
    }

    QList<QString> rowList = {"row2", "row3", "row4", "row5", "row6"};

    for (int i = 0; i < rowList.size(); i++) {
        target = _view->findChild<QObject *>(rowList[i]);

        if (target) {
            target->setProperty("width", 63);
        }
    }

    QList<QString> invisibleList = {"row7", "row8", "row9", "row10", "userdata7", "userdata8", "userdata9"};

    for (int i = 0; i < invisibleList.size(); i++) {
        target = _view->findChild<QObject *>(invisibleList[i]);

        if (target) {
            target->setProperty("visible", true);
        }
    }

    for (int i = 0; i < 10; i++) {
        target = _view->findChild<QObject *>(_dataLoggerUserListPart1ButtonData[i][0]);

        if (target) {
            if (i == 0) {
                target->setProperty("activebg", "datalogger_userlist_btn_active_rd.png");
            } else if (i == 9) {
                target->setProperty("activebg", "datalogger_userlist_btn_active_ur.png");
            } else {
                target->setProperty("activebg", "datalogger_userlist_btn_active_urd.png");
            }
        }
    }

    target = _view->findChild<QObject *>("operationKey");

    if (target) {
        target->setProperty("visibleDownUP", false);
    }

    target = _view->findChild<QObject *>("execute1");

    if (target) {
        switch (_mode) {
        case SINGLE:
        case MULTI:
        case LOGGER:
            target->setProperty("activebg", "datalogger_action_btn_active_ld2.png");
            break;
        default:
            target->setProperty("activebg", "datalogger_action_btn_active_ld.png");
            break;
        }
        target->setProperty("idlebg", "datalogger_action_btn.png");
        target->setProperty("pressbg", "datalogger_action_btn_p.png");
    }
}

void DataLoggerViewModel::sortUserSettingList()
{
    sortBand();
    sortChannel();

    // 保存押下前の表示を一旦クリア
    for (int i = 0; i < 6; i++) {
        QString listItem = "list" + QString::number(i % 6);
        QObject *target = _view->findChild<QObject *>(listItem);

        if (target) {
            target->setProperty("no", i + 1);
            target->setProperty("band", EMPTY_VALUE);
            target->setProperty("broadbandSystem", EMPTY_VALUE);
            target->setProperty("channel", EMPTY_VALUE);
            target->setProperty("modulation", EMPTY_VALUE);
            target->setProperty("leveloffset", EMPTY_VALUE);
            target->setProperty("mercn", EMPTY_VALUE);
            target->setProperty("ber", EMPTY_VALUE);
            target->setProperty("powerSupply", EMPTY_VALUE);
        }
    }

    // 再表示
    _settingListCurrentPage = 1;
    showUserSettingList();
}

void DataLoggerViewModel::sortBand()
{
    QVariant value;
    _model->getValue(VALUE_USERSETTING_SETTINGLIST, value);
    QVariantList channelList = value.toList();
    QVariantMap channelData;
    QList<int> sortIndex;

    for (int bandno = static_cast<int>(LC70_BAND_UNDEF); bandno <= static_cast<int>(LC70_BAND_END); bandno++) {
        for (int index = 0; index < channelList.size(); index++) {
            channelData = channelList[index].toMap();

            if (channelData["enable"] == false) {
                // nothing to do
            } else {
                if (bandno == channelData["band"].toInt()) {
                    sortIndex.push_back(index);
                }
            }
        }
    }

    QVariantList sortChannelList;

    for (int i = 0; i < sortIndex.size(); i++) {
        channelData = channelList[sortIndex[i]].toMap();
        sortChannelList.push_back(channelData);
    }

    // 書き換え
    _model->setValue(VALUE_USERSETTING_SETTINGLIST, sortChannelList);
}

void DataLoggerViewModel::sortChannel()
{
    // 前提
    // band ソートされた後
    // リストの途中に空白無し
    QVariant value;
    _model->getValue(VALUE_USERSETTING_SETTINGLIST, value);
    QVariantList channelList = value.toList();

    if (channelList.size() < 2) {
        // ソート不要
        return;
    }

    QVariantMap channelData;

    int hikakuBand = channelData["band"].toInt();

    int beginIndex = 0;
    int endIndex = 0;

    for (int index = 0; index < channelList.size(); index++) {
        channelData = channelList[index].toMap();

        if (hikakuBand == channelData["band"].toInt()) {
            endIndex = index;
        } else {
            // 2個以上あればソート
            if (beginIndex == endIndex) {
                // ソート不要
            } else {
                // ソート実施
                int min;
                QVariantMap channelData1;
                QVariantMap channelData2;

                int minBorder = beginIndex;

                for (int pos = endIndex; pos > minBorder; minBorder++) {
                    min = pos;

                    for (int loop = pos; loop > minBorder; loop--) {
                        channelData1 = channelList[loop - 1].toMap();
                        channelData2 = channelList[min].toMap();

                        if (channelData1["channel"].toString() < channelData2["channel"].toString()) {
                            min = loop - 1;
                        }
                    }

                    channelList.move(min, minBorder);
                }
            }

            hikakuBand = channelData["band"].toInt();
            beginIndex = index;
            endIndex = index;
        }

        // 末端まで検索したら
        if (index == (channelList.size() - 1)) {
            if (beginIndex == endIndex) {
                // ソート不要
            } else {
                // ソート実施
                int min;
                QVariantMap channelData1;
                QVariantMap channelData2;

                int minBorder = beginIndex;

                for (int pos = endIndex; pos > minBorder; minBorder++) {
                    min = pos;

                    for (int loop = pos; loop > minBorder; loop--) {
                        channelData1 = channelList[loop - 1].toMap();
                        channelData2 = channelList[min].toMap();

                        if (channelData1["channel"].toString() < channelData2["channel"].toString()) {
                            min = loop - 1;
                        }
                    }

                    channelList.move(min, minBorder);
                }
            }
        }
    }

    // 書き換え
    _model->setValue(VALUE_USERSETTING_SETTINGLIST, channelList);
}

bool DataLoggerViewModel::isDuplicateUserSettingList()
{
    QVariant value;
    _model->getValue(VALUE_USERSETTING_SETTINGLIST, value);
    QVariantList channelList = value.toList();

    if (channelList.size() < 2) {
        return false;
    }

    QVariantMap channelData1;
    QVariantMap channelData2;

    for (int index = 0; index < channelList.size() - 1; index++) {
        channelData1 = channelList[index].toMap();
        channelData2 = channelList[index + 1].toMap();

        if (channelData1["band"].toInt() == channelData2["band"].toInt()) {
            if (channelData1["channel"].toString() == channelData2["channel"].toString()) {
                return  true;
            }
        }
    }

    return false;
}

void DataLoggerViewModel::createUserSettingFile()
{
    QVariant data = _takeOver["selectedBand"];

    int bandID = data.toInt();

    // 定義チャンネル数がUSER設定ファイルの最大データ数を超えている場合
    // USER設定ファイルの最大データ数分データを作成する。

    // 画面共有情報からユーザ設定ファイルを作成する
    // リストに対応するチャンネル定義情報を取得
    QList<ChannelDefinitionItem> channelDefinitionList;

    QString polarization = "";

    if (_takeOver.contains("selectedPolarization")) {
        polarization = _takeOver["selectedPolarization"].toString();
    }

    // チャンネル定義リストを取得する。
    _model->selectChannelDefinitionList(bandID, polarization, channelDefinitionList);

    int iterationNum = channelDefinitionList.size();

    if (iterationNum > USER_SETTING_DATA_DETAIL_NUMBER) {
        iterationNum = USER_SETTING_DATA_DETAIL_NUMBER;
    }

    // BANDデータから決まるデータを先に取得する
    // 放送方式、変調方式の取得
    unsigned int modulationBit;
    int broadbandSystem;

    if (_takeOver.contains("selectedModulation")) {
        if (bandID == LC70_BAND_CATV_ALL || bandID == LC70_BAND_CATV_90_470MHZ || bandID == LC70_BAND_CATV_470_1002MHZ) {
            // BAND : CATV_ALL、CATV_90-470MHz、 CATV_470-1002MHz
            if (_takeOver["selectedModulation"].toString() == OFDM) {
                // ISDBT 選択時
                modulationBit   = LC70_SETMOD_OFDM;
                broadbandSystem = LC70_BD_SYS_ISDBT;
            } else if (_takeOver["selectedModulation"].toString() == SIXTY_FOUR_QAM) {
                // ANNEXC 選択時
                modulationBit   = LC70_SETMOD_UNDEF;
                broadbandSystem = LC70_BD_SYS_ANNEXC;
            } else {
                // ANNEX 選択時
                modulationBit   = LC70_SETMOD_UNDEF;
                broadbandSystem = LC70_BD_SYS_ANNEXB;
            }
        } else if (bandID == LC70_BAND_SKYP) {
            // BAND : スカパー光
            if (_takeOver["selectedModulation"].toString() == OFDM) {
                // ISDBT 選択時
                modulationBit = LC70_SETMOD_OFDM;
                broadbandSystem = LC70_BD_SYS_ISDBT;
            } else {
                // OPTICAST 選択時
                modulationBit = LC70_SETMOD_256QAM;
                broadbandSystem = LC70_BD_SYS_OPTICAST;
            }
        }
    } else {
        // BAND : CATV_ALL、CATV_90-470MHz、 CATV_470-1002MHz、 スカパー光以外
        QList<int> broadbandSystemList;
        _model->getBroadbandSystem(static_cast<LC70_BAND_T>(bandID), broadbandSystemList);
        broadbandSystem = broadbandSystemList.at(0);
        modulationBit = _model->getModulationBit(static_cast<LC70_BAND_T>(bandID), broadbandSystemList.at(0));
        QList <unsigned int> bitList;
        Correcter::getModulationBitList(modulationBit, bitList);

        if (bitList.empty()) {
            modulationBit = LC70_SETMOD_UNDEF;
        } else {
            modulationBit = bitList[0];
        }

        modulationBit = bitList.at(0);
    }

    QVariantList channelList;

    for (int i = 0; i < iterationNum; ++i) {
        QVariantMap channeldata;
        channeldata["enable"] = true;

        // バンド
        channeldata["band"] = getDisplayBandId(bandID);

        // チャンネル
        channeldata["channel"] = channelDefinitionList.at(i).channelNumber;

        // 変調方式
        channeldata["modulationBit"] = modulationBit;

        // 放送規格
        channeldata["broadbandSystem"] = broadbandSystem;

        // 中心周波数
        channeldata["centerFreq"] = Correcter::centerFrequency(channelDefinitionList.at(i), modulationBit);

        // 局発周波数
        if (_takeOver.contains("selectedLocalOscillator")) {
            channeldata["localFreq"] = _takeOver["selectedLocalOscillator"].toUInt();
        } else {
            channeldata["localFreq"] = 0;
        }

        // MERCN
        // bandがPILOT, LTE, FM, CATV上りの場合は、「-」を表示するため-1を設定
        if (bandID == LC70_BAND_PILOT || bandID == LC70_BAND_LTE || bandID == LC70_BAND_FM || bandID == LC70_BAND_CATV_UP_STREAM) {
            channeldata["MERCN"] = -1;
        } else {
            channeldata["MERCN"] = true;
        }

        // BER
        // bandがPILOT, LTE, FMの場合は、「-」を表示するため-1を設定
        if (bandID == LC70_BAND_PILOT || bandID == LC70_BAND_LTE || bandID == LC70_BAND_FM || bandID == LC70_BAND_CATV_UP_STREAM) {
            channeldata["BER"] = -1;
        } else {
            channeldata["BER"] = true;
        }

        // 給電
        int powerSupply = LC70_POWER_SUPPLY_OFF;

        if (_takeOver.contains("powerSupply")) {
            powerSupply = _takeOver["powerSupply"].toInt();

            if (powerSupply > LC70_MEAS_SET_DC_OUT_VAL_15V_P) {
                powerSupply = LC70_MEAS_SET_DC_OUT_VAL_NONE;
            }
        }

        channeldata["PowerSupply"] = powerSupply;

        channelList.append(channeldata);
    }

    _model->setValue(VALUE_USERSETTING_SETTINGLIST, channelList);
    _model->commit(VALUE_USERSETTING_SETTINGLIST);
}

void DataLoggerViewModel::displaySettingAutoScanResult()
{
    // チャンネル情報取得
    QList<MeasureResult> result = _model->allScanResult();

    int bandId = _takeOver["selectedBand"].toInt();

    // 保存数
    int count = result.count();

    if (count > USER_SETTING_DATA_DETAIL_NUMBER) {
        count = USER_SETTING_DATA_DETAIL_NUMBER;
    }

    // 偏波
    QString polarization;

    if (_takeOver.contains("selectedPolarization")) {
        polarization = _takeOver["selectedPolarization"].toString();
    }

    // BANDデータから決まるデータを先に取得する
    // 放送方式、変調方式の取得
    unsigned int modulationBit;
    int broadcastSystem;

    QList<int> broadbandSystemList;
    _model->getBroadbandSystem(static_cast<LC70_BAND_T>(bandId), broadbandSystemList);

    QVariantList channelList;

    // CATV_90-470、 CATV_470_1002はCATV_ALLとする。
    for (int i = 0; i < count; ++i) {
        QVariantMap channelData;
        channelData["enable"] = true;

        // バンド
        channelData["band"] = getDisplayBandId(bandId);

        // チャンネル
        channelData["channel"] = result[i].Channel;

        // 放送規格
        if (!broadbandSystemList.contains(result[i].BroadcastSystem)) {
            broadcastSystem = broadbandSystemList[0];
        } else {
            broadcastSystem = result[i].BroadcastSystem;
        }
        channelData["broadbandSystem"] = broadcastSystem;

        // 変調方式
        modulationBit = _model->getModulationBit(static_cast<LC70_BAND_T>(bandId), broadcastSystem);
        QList <unsigned int> bitList;
        Correcter::getModulationBitList(modulationBit, bitList);

        if (!bitList.contains(result[i].Modulation)) {
            if (result[i].Modulation == LC70_SETMOD_UNDEF) {
                modulationBit = LC70_SETMOD_UNDEF;
            } else {
                // 変調方式bitリストの先頭を保持
                modulationBit = bitList[0];
            }
        } else {
            // スキャンした結果から変調方式を保持
            modulationBit = result[i].Modulation;
        }
        channelData["modulationBit"] = modulationBit;

        // 中心周波数
        ChannelDefinitionItem item;
        _model->getChannelDefinitionItem(bandId, result[i].Channel, item);
        channelData["centerFreq"] = Correcter::centerFrequency(item, modulationBit);

        // 局発周波数
        if (_takeOver.contains("selectedLocalOscillator")) {
            channelData["localFreq"] = _takeOver["selectedLocalOscillator"].toUInt();
        } else {
            channelData["localFreq"] = 0;
        }

        // MERCN
        if (bandId == LC70_BAND_PILOT || bandId == LC70_BAND_LTE || bandId == LC70_BAND_FM || bandId == LC70_BAND_CATV_UP_STREAM) {
            channelData["MERCN"] = -1;
        } else {
            channelData["MERCN"] = true;
        }

        // BER
        if (bandId == LC70_BAND_PILOT || bandId == LC70_BAND_LTE || bandId == LC70_BAND_FM || bandId == LC70_BAND_CATV_UP_STREAM) {
            channelData["BER"] = -1;
        } else {
            channelData["BER"] = true;
        }

        // 給電
        channelData["PowerSupply"] = LC70_MEAS_SET_DC_OUT_VAL_NONE;

        channelList.append(channelData);
    }

    // 保存するデータを設定
    _model->setValue(VALUE_USERSETTING_SETTINGLIST, channelList);

    // 保持したスキャン結果をクリアー
    _model->clearScanResult();
}

int DataLoggerViewModel::getListIndexBand(LC70_BAND_T bandId)
{
    // 取得できなければ -1(不定値)を返す
    return BAND_LIST_INDEX_MAP.key(bandId, -1);
}

LC70_BAND_T DataLoggerViewModel::getDisplayBandId(int bandId)
{
    LC70_BAND_T band = static_cast<LC70_BAND_T>(bandId);

    // bandの情報がCATV_90_470MHz、 CATV_470_1002MHzの場合 CATV_ALLに設定する
    if (band == LC70_BAND_CATV_90_470MHZ || band == LC70_BAND_CATV_470_1002MHZ) {
        band = LC70_BAND_CATV_ALL;
    }

    return band;
}

// 給電設定リスト
static const QList<uint8_t> POWER_15VONLY = {
    LC70_MEAS_SET_DC_OUT_VAL_NONE,
    LC70_MEAS_SET_DC_OUT_VAL_15V,
};
static const QList<uint8_t> POWER_11V_15V = {
    LC70_MEAS_SET_DC_OUT_VAL_NONE,
    LC70_MEAS_SET_DC_OUT_VAL_11V,
    LC70_MEAS_SET_DC_OUT_VAL_15V,
};
static const QList<uint8_t> POWER_15VP_15V = {
    LC70_MEAS_SET_DC_OUT_VAL_NONE,
    LC70_MEAS_SET_DC_OUT_VAL_15V_P,
    LC70_MEAS_SET_DC_OUT_VAL_15V
};
static const QList<uint8_t> POWER_11VP_15V = {
    LC70_MEAS_SET_DC_OUT_VAL_NONE,
    LC70_MEAS_SET_DC_OUT_VAL_11V_P,
    LC70_MEAS_SET_DC_OUT_VAL_15V
};
static const QMap<QPair<LC70_BAND_T, int>, QList<uint8_t>> POWER_SUPPLY_SETTING_MAP = {
    {{LC70_BAND_JCSAT3, LC70_MEAS_SET_WAVE_H}, POWER_15VONLY},
    {{LC70_BAND_JCSAT3, LC70_MEAS_SET_WAVE_V}, POWER_11V_15V},
    {{LC70_BAND_JCSAT4, LC70_MEAS_SET_WAVE_H}, POWER_15VP_15V},
    {{LC70_BAND_JCSAT4, LC70_MEAS_SET_WAVE_V}, POWER_11VP_15V},
    {{LC70_BAND_SCCB,   LC70_MEAS_SET_WAVE_H}, POWER_15VONLY},
    {{LC70_BAND_SCCB,   LC70_MEAS_SET_WAVE_V}, POWER_11V_15V},
    {{LC70_BAND_SCCC,   LC70_MEAS_SET_WAVE_H}, POWER_15VONLY},
    {{LC70_BAND_SCCC,   LC70_MEAS_SET_WAVE_V}, POWER_11V_15V},
};

int DataLoggerViewModel::getCurrentPowerSupplyIndex(const QVariantMap &channelData, const int currentValue,
        QList<uint8_t> &settingList)
{
    int currentBand = channelData["band"].toInt();
    QString currentChannelName = channelData["channel"].toString();
    ChannelDefinitionItem currentChannel;
    _model->getChannelDefinitionItem(currentBand, currentChannelName, currentChannel);

    settingList = POWER_SUPPLY_SETTING_MAP.value({static_cast<LC70_BAND_T>(currentBand), currentChannel.polarization},
                  POWER_15VONLY);

    for (int i = 0; i < settingList.size(); ++i) {
        if (settingList[i] == currentValue) {
            return i;
        }
    }

    return 0;
}

uint8_t DataLoggerViewModel::nextPowerSupplySetting(QVariantMap channelData, int currentValue)
{
    QList<uint8_t> settingList;
    int settingIndex = getCurrentPowerSupplyIndex(channelData, currentValue, settingList);

    ++settingIndex;

    if (settingList.isEmpty()) {
        // fail safe
        return LC70_MEAS_SET_DC_OUT_VAL_NONE;
    }

    if (settingIndex >= settingList.size()) {
        settingIndex = 0;
    }

    return settingList.at(settingIndex);
}

uint8_t DataLoggerViewModel::prevPowerSupplySetting(QVariantMap channelData, int currentValue)
{
    QList<uint8_t> settingList;
    int settingIndex = getCurrentPowerSupplyIndex(channelData, currentValue, settingList);

    --settingIndex;

    if (settingList.isEmpty()) {
        // fail safe
        return LC70_MEAS_SET_DC_OUT_VAL_NONE;
    }

    if (settingIndex < 0) {
        settingIndex = settingList.size() - 1;
    }

    return settingList.at(settingIndex);
}

void DataLoggerViewModel::setPowerSupplySetting(QVariantMap channelData, int value)
{
    int currentBand = channelData["band"].toInt();
    QString currentChannelName = channelData["channel"].toString();
    ChannelDefinitionItem currentChannel;
    _model->getChannelDefinitionItem(currentBand, currentChannelName, currentChannel);

    QPair<LC70_BAND_T, int> key = {static_cast<LC70_BAND_T>(currentBand), currentChannel.polarization};
    _powerSupplySettingMap[key] = static_cast<uint8_t>(value);
}

uint8_t DataLoggerViewModel::getPowerSupplySetting(int bandId, int polarization)
{
    return _powerSupplySettingMap.value({static_cast<LC70_BAND_T>(bandId), polarization}, LC70_MEAS_SET_DC_OUT_VAL_NONE);
}

void DataLoggerViewModel::updatePowerSupplySetting(QVariantList &list)
{
    // 同一のBand、偏波の設定であれば、給電設定を合わせる
    for (int i = 0; i < list.size(); ++i) {
        QVariantMap channelData = list[i].toMap();

        int bandId = channelData["band"].toInt();
        QString currentChannelName = channelData["channel"].toString();
        ChannelDefinitionItem currentChannel;
        _model->getChannelDefinitionItem(bandId, currentChannelName, currentChannel);

        channelData["PowerSupply"] = _powerSupplySettingMap.value({static_cast<LC70_BAND_T>(bandId), currentChannel.polarization},
                                     LC70_MEAS_SET_DC_OUT_VAL_NONE);
        list[i] = channelData;
    }
}

void DataLoggerViewModel::setMerSetting(QVariantMap channelData, MerBerSettingType value)
{
    int currentBand = channelData["band"].toInt();
    QString currentChannelName = channelData["channel"].toString();
    ChannelDefinitionItem currentChannel;
    _model->getChannelDefinitionItem(currentBand, currentChannelName, currentChannel);

    QPair<LC70_BAND_T, int> key = {static_cast<LC70_BAND_T>(currentBand), currentChannel.polarization};
    _merSettingMap[key] = value;
}

DataLoggerViewModel::MerBerSettingType DataLoggerViewModel::getMerSetting(int bandId, int polarization)
{
    return _merSettingMap.value({static_cast<LC70_BAND_T>(bandId), polarization}, SETTING_ON);
}

void DataLoggerViewModel::updateMerSetting(QVariantList &list)
{
    // 同一のBand、偏波の設定であれば、設定を合わせる
    for (int i = 0; i < list.size(); ++i) {
        QVariantMap channelData = list[i].toMap();

        int bandId = channelData["band"].toInt();
        QString currentChannelName = channelData["channel"].toString();
        ChannelDefinitionItem currentChannel;
        _model->getChannelDefinitionItem(bandId, currentChannelName, currentChannel);

        MerBerSettingType type = _merSettingMap.value({static_cast<LC70_BAND_T>(bandId), currentChannel.polarization}, SETTING_INVALID);
        if (type == SETTING_OFF) {
            channelData["MERCN"] = false;
        } else if (type == SETTING_ON) {
            channelData["MERCN"] = true;
        } else {
            channelData["MERCN"] = -1;
        }
        list[i] = channelData;
    }
}

void DataLoggerViewModel::setBerSetting(QVariantMap channelData, MerBerSettingType value)
{
    int currentBand = channelData["band"].toInt();
    QString currentChannelName = channelData["channel"].toString();
    ChannelDefinitionItem currentChannel;
    _model->getChannelDefinitionItem(currentBand, currentChannelName, currentChannel);

    QPair<LC70_BAND_T, int> key = {static_cast<LC70_BAND_T>(currentBand), currentChannel.polarization};
    _berSettingMap[key] = value;
}

DataLoggerViewModel::MerBerSettingType DataLoggerViewModel::getBerSetting(int bandId, int polarization)
{
    return _berSettingMap.value({static_cast<LC70_BAND_T>(bandId), polarization}, SETTING_ON);
}

void DataLoggerViewModel::updateBerSetting(QVariantList &list)
{
    // 同一のBand、偏波の設定であれば、設定を合わせる
    for (int i = 0; i < list.size(); ++i) {
        QVariantMap channelData = list[i].toMap();

        int bandId = channelData["band"].toInt();
        QString currentChannelName = channelData["channel"].toString();
        ChannelDefinitionItem currentChannel;
        _model->getChannelDefinitionItem(bandId, currentChannelName, currentChannel);

        MerBerSettingType type = _berSettingMap.value({static_cast<LC70_BAND_T>(bandId), currentChannel.polarization}, SETTING_INVALID);
        if (type == SETTING_OFF) {
            channelData["BER"] = false;
        } else if (type == SETTING_ON) {
            channelData["BER"] = true;
        } else {
            channelData["BER"] = -1;
        }
        list[i] = channelData;
    }
}

bool DataLoggerViewModel::checkConflictPowerSupplySetting(const QVariantList &list1, const QVariantList &list2)
{
    _powerSupplySettingMap.clear();

    // 合成リスト1から、給電設定の組み合わせを抽出
    for (int i = 0; i < list1.size(); ++i) {
        QVariantMap channelData = list1[i].toMap();
        LC70_BAND_T bandId = static_cast<LC70_BAND_T>(channelData["band"].toInt());
        ChannelDefinitionItem channelDef;

        if (_model->getChannelDefinitionItem(bandId, channelData["channel"].toString(), channelDef)) {
            QPair<LC70_BAND_T, int> key = {bandId, channelDef.polarization};

            if (_powerSupplySettingMap.count(key) == 0) {
                _powerSupplySettingMap[key] = channelData["PowerSupply"].toUInt();
            }
        }
    }

    // 合成リスト2の給電組み合わせと照らし合わせ、競合していないかチェック
    bool isConflict = false;

    for (int i = 0; i < list2.size(); ++i) {
        QVariantMap channelData = list2[i].toMap();
        LC70_BAND_T bandId = static_cast<LC70_BAND_T>(channelData["band"].toInt());
        ChannelDefinitionItem channelDef;

        if (_model->getChannelDefinitionItem(bandId, channelData["channel"].toString(), channelDef)) {
            QPair<LC70_BAND_T, int> key = {bandId, channelDef.polarization};

            if (_powerSupplySettingMap.count(key) != 0) {
                if (_powerSupplySettingMap.value(key) != channelData["PowerSupply"].toUInt()) {
                    // 競合しているので、給電なしに切り替える
                    isConflict = true;
                    // ここではMapの値を更新しておき、後ほどupdatePowerSupplySetting()で反映する
                    _powerSupplySettingMap[key] = LC70_MEAS_SET_DC_OUT_VAL_NONE;
                }
            } else {
                // 競合していない場合は設定を共存させる
                _powerSupplySettingMap[key] = channelData["PowerSupply"].toUInt();
            }
        }
    }

    return isConflict;
}

bool DataLoggerViewModel::checkConflictMerSetting(const QVariantList &list1, const QVariantList &list2)
{
    _merSettingMap.clear();

    // 合成リスト1から、設定の組み合わせを抽出
    for (int i = 0; i < list1.size(); ++i) {
        QVariantMap channelData = list1[i].toMap();
        LC70_BAND_T bandId = static_cast<LC70_BAND_T>(channelData["band"].toInt());
        ChannelDefinitionItem channelDef;

        if (_model->getChannelDefinitionItem(bandId, channelData["channel"].toString(), channelDef)) {
            QPair<LC70_BAND_T, int> key = {bandId, channelDef.polarization};

            if (_merSettingMap.count(key) == 0) {
                _merSettingMap[key] = static_cast<MerBerSettingType>(channelData["MERCN"].toInt());
            }
        }
    }

    // 合成リスト2の設定の組み合わせと照らし合わせ、競合していないかチェック
    bool isConflict = false;

    for (int i = 0; i < list2.size(); ++i) {
        QVariantMap channelData = list2[i].toMap();
        LC70_BAND_T bandId = static_cast<LC70_BAND_T>(channelData["band"].toInt());
        ChannelDefinitionItem channelDef;

        if (_model->getChannelDefinitionItem(bandId, channelData["channel"].toString(), channelDef)) {
            QPair<LC70_BAND_T, int> key = {bandId, channelDef.polarization};

            if (_merSettingMap.count(key) != 0) {
                if (_merSettingMap.value(key) != channelData["MERCN"].toInt()) {
                    // 競合しているので、取得ありに切り替える
                    isConflict = true;
                    // ここではMapの値を更新しておき、後ほどupdateMerSetting()で反映する
                    _merSettingMap[key] = SETTING_ON;
                }
            } else {
                // 競合していない場合は設定を共存させる
                _merSettingMap[key] = static_cast<MerBerSettingType>(channelData["MERCN"].toInt());
            }
        }
    }

    return isConflict;
}

bool DataLoggerViewModel::checkConflictBerSetting(const QVariantList &list1, const QVariantList &list2)
{
    _berSettingMap.clear();

    // 合成リスト1から、設定の組み合わせを抽出
    for (int i = 0; i < list1.size(); ++i) {
        QVariantMap channelData = list1[i].toMap();
        LC70_BAND_T bandId = static_cast<LC70_BAND_T>(channelData["band"].toInt());
        ChannelDefinitionItem channelDef;
        MerBerSettingType type = static_cast<MerBerSettingType>(channelData["BER"].toInt());

        if (_model->getChannelDefinitionItem(bandId, channelData["channel"].toString(), channelDef)) {
            QPair<LC70_BAND_T, int> key = {bandId, channelDef.polarization};

            if (_berSettingMap.count(key) == 0) {
                _berSettingMap[key] = type;
            }
        }
    }

    // 合成リスト2の設定の組み合わせと照らし合わせ、競合していないかチェック
    bool isConflict = false;

    for (int i = 0; i < list2.size(); ++i) {
        QVariantMap channelData = list2[i].toMap();
        LC70_BAND_T bandId = static_cast<LC70_BAND_T>(channelData["band"].toInt());
        ChannelDefinitionItem channelDef;
        MerBerSettingType type = static_cast<MerBerSettingType>(channelData["BER"].toInt());

        if (_model->getChannelDefinitionItem(bandId, channelData["channel"].toString(), channelDef)) {
            QPair<LC70_BAND_T, int> key = {bandId, channelDef.polarization};

            if (_berSettingMap.count(key) != 0) {
                if (_berSettingMap.value(key) != type) {
                    // 競合しているので、取得ありに切り替える
                    isConflict = true;
                    // ここではMapの値を更新しておき、後ほどupdateBerSetting()で反映する
                    _berSettingMap[key] = SETTING_ON;
                }
            } else {
                // 競合していない場合は設定を共存させる
                _berSettingMap[key] = type;
            }
        }
    }

    return isConflict;
}

void DataLoggerViewModel::popupConflictPowerSupplySetting()
{
    emit requestToShowPopup(POPUP_CONFLICT_POWER_SUPPLY_SETTING);
}

bool DataLoggerViewModel::checkContainSameNamefile(QVariantList userDataLoggerList ,QString fileName)
{
    bool isContainSameNameFile = false;
    for (int index = 0; index < userDataLoggerList.count(); ++index) {
        if(userDataLoggerList[index].toList().at(2).toString() == fileName){
            isContainSameNameFile = true;
            break;
        }
    }

    return isContainSameNameFile;
}

void DataLoggerViewModel::saveDuplicateFile()
{
    QVariant value;
    QVariantList dataLoggerItem;

    _model->getValue(VALUE_USERSETTING_FILELIST, value);
    QVariantList userList = value.toList();

    for (int index = 0; index < userList.count(); ++index) {
        if (userList[index].toList().at(2).toString() == _duplicateFileName) {
            // 既に保存されているファイルを削除する
            dataLoggerItem = userList[index].toList();
            dataLoggerItem[1] = 0;  // 無効状態
            dataLoggerItem[2] = QString("");
            userList[index] = dataLoggerItem;
        }
    }

    // 上書きファイルを設定する
    dataLoggerItem = userList[getSelectedUserListIndex()].toList();
    dataLoggerItem[1] = 0; // 無効状態
    dataLoggerItem[2] = _duplicateFileName;

    userList[getSelectedUserListIndex()] = dataLoggerItem;

    // チャンネルリストの更新を行う
    _model->commit(VALUE_USERSETTING_SETTINGLIST);

    // 保存処理
    _model->setValue(VALUE_USERSETTING_FILELIST, userList);
    _model->commit(VALUE_USERSETTING_FILELIST);

    // CSVファイルに書き出す
    _model->exportDataLoggerUserSettingList(VALUE_USERSETTING_FILELIST, _duplicateFileName);
    _userListOperationProhibited = false;

    // export、画面遷移
    if (_backToScreen != SCREEN_ID_COUNT) {
        emit requestInHistory(_backToScreen);
        _backToScreen = SCREEN_ID_COUNT;
        return;
    }

    if (_filemixState == FILEMIX_AFTER) {
        requestInHistory(SCREEN_MANUAL_AUTO_SELECTION);
        return;
    }

    // カーソル移動
    backToUserList();

    // 再描画
    // ユーザファイルリスト表示
    showUserFileList();

    // チャンネルリスト
    showUserSettingList();
}

void DataLoggerViewModel::filterFileList(QVariant &value)
{
    QVariantList userlist = value.toList();

}
