//
//      (c) 2020 DX ANTENNA CO.,LTD.
//

#ifndef DATALOGGERVIEWMODEL_H
#define DATALOGGERVIEWMODEL_H

#include "abstractviewmodel.h"
#include "buttonoperation.h"

/**
 * @brief データロガー ViewModel
 * @note USER データロガー設定に置き換えるため不使用
 */
class DataLoggerViewModel : public AbstractViewModel
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクター
     * @param screenId 画面 ID
     * @param model Model クラスのポインター
     * @param parent 親オブジェクト
     */
    explicit DataLoggerViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent = nullptr);

    /**
     * @brief デストラクタ
     */
    virtual ~DataLoggerViewModel();
    /**
     * @brief 画面Active 時の処理
     *
     * ユーザリストデータを取得して画面に表示する
     */
    void activate() override;

    /**
     * @brief 画面deactivate 時の処理
     */
    void deactivate() override;

    /**
     * @brief 遷移先画面で参照する遷移前画面のデータ設定
     */
    virtual void setTakeOver() override;

signals:
    void requestSetTakeOver(QVariant, QVariant);
    void requestGetTakeOver();

    /**
     * @brief 給電設定競合通知
     */
    void notifyConflictPowerSupplySetting(void);
protected:
    /**
     * @brief onKeyStatus
     * @param id
     */
    virtual void onKeyStatus(ButtonId id) override;

    /**
     * @brief onButtonPress
     * @param id
     */
    void onButtonPress(ButtonId id) override;

protected slots:
    void onAccept(PopupId popupId, bool okOnly) override;
    void onReject(PopupId popupId) override;

    /**
     * @brief 入力されたファイル名を受信
     * @param popupId ポップアップの種類
     * @param saveLocation 保存先
     * @param fileName 入力されたファイル名
     */
    void onInputFileName(PopupId popupId, SaveLocation saveLocation, QString fileName);

private slots:
    /**
     * @brief QML からの画面遷移要求を受信
     * @param condition 遷移先を特定する情報(ボタンのインデックスなど)
     */
    virtual void onRequest(int condition) override;

    /**
     * @brief 測定予約
     */
    void reserveMeasurement();

    /**
     * @brief 給電設定競合通知を受信
     */
    void popupConflictPowerSupplySetting(void);

private:
    static const char *EMPTY_VALUE;

    // ユーザリストの操作用
    static const int USER_LIST_PART1_COLUMN_NUMBER;
    static const int USER_LIST_PART2_COLUMN_NUMBER;
    static const int USER_LIST_ROW_NUMBER;

    // 局発周波数 未定義値
    static const unsigned int LOCAL_FREQ_UNDEFINED_DATA;

    QVector< QVector<QString> > _dataLoggerUserListPart1ButtonData;
    QVector< QVector<QString> > _dataLoggerUserListPart2ButtonData;
    ButtonOperation _userListButtonOperation;   //<
    QString _userListActiveButton;
    QString _reserveUserListActivebg;

    // チャンネル設定リストの操作用
    static const int CHANNEL_LIST_COLUMN_NUMBER;
    static const int CHANNEL_LIST_ROW_NUMBER;

    QVector<QVector<QString>> dataLoggerChannelListButtonData;
    ButtonOperation _channelListButtonOperation;   //<
    QString _channelListActiveButton;

    // 設定値編集の操作用
    static const int CHANNEL_EDIT_COLUMN_NUMBER;
    static const int CHANNEL_EDIT_ROW_NUMBER;

    QVector<QVector<QString> > dataLoggerChannelEditButtonData;
    ButtonOperation _channelEditButtonOperation;   //<
    QString _channelEditActiveButton;

    // 動作ボタンの操作用
    static const int ACTION_COLUMN_NUMBER;
    static const int ACTION_ROW_NUMBER;

    // 選択不可 データに対してのメッセージ
    static const QString CANNOT_SELECTION_MESSAGE;

    // User設定詳細のデータ数
    static const int USER_SETTING_DATA_DETAIL_NUMBER;

    // リストのインデックスと表示するバンドデータの関係マップ
    static const QMap<int, LC70_BAND_T> BAND_LIST_INDEX_MAP;

    QVector<QVector<QString> > _dataLoggerActionButtonData;
    ButtonOperation _actionButtonOperation;   //<
    QString _actionButtonActiveButton;

    // 独自POPUPの操作用
    QVector<QVector<QString>> _dataLoggerPopupType1ButtonData;
    QVector<QVector<QString>> _dataLoggerPopupType2ButtonData;
    QVector<QVector<QString>> _dataLoggerPopupType3ButtonData;
    QVector<QVector<QString>> _dataLoggerPopupType4ButtonData;
    ButtonOperation _popupButtonOperation;
    QString _popupActiveButton;

    int _userListCurrentPage;       //< ユーザリストの現在ページ
    int _settingListCurrentPage;    //< 設定リストの現在ページ

    int _dataloggerExecuteInterval; //< 実行間隔
    int _userSettingListNum;        //< チャンネル数

    // データ取得開始（日時設定）関連のメンバ
    int _yyyy;
    int _start_mm;
    int _start_dd;
    int _start_HH;
    int _start_MM;
    int _end_mm;
    int _end_dd;
    int _end_HH;
    int _end_MM;
    int _end_yyyy;

    QString _duplicateFileName;                     //!< 保存対象のファイル名

    QTimer *_reserveTimer;                  //!< データ取得開始（日時設定）実行タイマー

    int _fileselectionInedx;                //!< 保存先選択のファイル位置
    bool _userListOperationProhibited;      //!< ユーザファイルリスト操作禁止

    int _channellistMaxCheckCount;          //!< チャンネルリストのmaxチェック用カウンター
    QString _modifyCheck;                   //!<
    QList<int> _filemixFileIndex;           //!< ファイル合成に選択したファイルのindex
    ScreenId _backToScreen;                 //!< 画面戻り先(シングル測定 or マルチ測定)
    bool _loggingStarted;                   //!< ロギングを開始したか否か

    /**
     * @brief MER・BER設定タイプ
     */
    enum MerBerSettingType {
        SETTING_INVALID = -1,               //!< 設定なし（-）
        SETTING_OFF,                        //!< 無効   （OFF）
        SETTING_ON,                         //!< 有効   （ON）
    };

    QMap<QPair<LC70_BAND_T, int>, uint8_t> _powerSupplySettingMap;      //!< 給電設定マップ
    QMap<QPair<LC70_BAND_T, int>, MerBerSettingType> _merSettingMap;    //!< MER取得設定マップ
    QMap<QPair<LC70_BAND_T, int>, MerBerSettingType> _berSettingMap;    //!< BER取得設定マップ

    // 操作対象のエリア定義
    enum SelectArea {
        USERLIST_AREA = 1,  // ユーザリスト
        CHANNEL_AREA  = 2,  // チャンネルリスト
        CHANNEL_EDIT  = 3,  // 設定値編集
        ACTION_AREA   = 4,  // 動作ボタン部
        POPUP_AREA    = 5,  // 独自POPUP部
    };

    SelectArea _selectArea; //< 選択している操作対象エリア

    // データロガー画面の動作種別
    enum DataloggerFunction {
        UNKNOWN  = 0,
        SINGLE   = 1,            // シングル測定実行
        MULTI    = 2,            // マルチ測定実行
        USER     = 3,            // ユーザ設定
        LOGGER   = 4,            // データロガー実行
        USERSETTING_SHOW = 5,    // ユーザ測定設定表示
        SAVE_MEASURESETTING = 6, // 測定設定保存
    };

    DataloggerFunction _mode;

    // ユーザ設定の詳細種別
    enum DataloggerEditType {
        EDIT_UNKNOWN = 0,
        EDIT_MANUAL = 1,
        EDIT_AUTO = 2,
        EDIT_FILEMIX = 3
    };

    DataloggerEditType _editType;

    // ファイル合成状態
    enum DataloggerFileMixState {
        FILEMIX_UNKNOWN = 0,
        FILEMIX_BEFORE = 1,
        FILEMIX_AFTER = 2,
    };

    DataloggerFileMixState _filemixState;

    // ダイアログ種別
    enum DataloggerPopupType {
        TYPEUNKNOWN = (-1),
        COLLECTCONFIRM = 0,     //収集確認
        DATETIMESET  = 1,       //取得日時期間設定
        CORRECTINTERVALSET = 2, //取得間隔設定・
        WAITING = 3,             //収集待機
        NODATA = 4
    };

    DataloggerPopupType _popupType;

    enum PopupEditState {
        SELECT = 0,
        EDIT = 1
    };

    PopupEditState _popupState;

    /**
     * @brief onKeyStatusUserListArea
     * @param id
     */
    void onKeyStatusUserListArea(ButtonId id);

    /**
     * @brief moveCursor
     * @param id
     */
    void moveCursorUserListArea(ButtonId id);

    /**
     * @brief onKeyStatusChannelListArea
     * @param id
     */
    void onKeyStatusChannelListArea(ButtonId id);

    /**
     * @brief moveCursorChannelListArea
     * @param id
     */
    void moveCursorChannelListArea(ButtonId id);

    /**
     * @brief onKeyStatusChannelEditArea
     * @param id
     */
    void onKeyStatusChannelEditArea(ButtonId id);

    /**
     * @brief moveCursorChannelEditArea
     * @param id
     */
    void moveCursorChannelEditArea(ButtonId id);


    /**
     * @brief onKeyStatusChannelEditArea
     * @param id
     */
    void onKeyStatusActionButtonArea(ButtonId id);

    /**
     * @brief onKeyStatusPopupButtonArea
     * @param id
     */
    void onKeyStatusPopupButtonArea(ButtonId id);

    /**
     * @brief onKeyEnterDatetimeset
     */
    void onKeyEnterDatetimeset();

    /**
     * @brief moveCursorChannelEditArea
     * @param id
     */
    void moveCursorActionButtonArea(ButtonId id);

    /**
     * @brief moveCursorPopupArea
     * @param id
     */
    void moveCursorPopupArea(ButtonId id);

    /**
     * @brief ユーザ設定リストの取り込み
     * @param activeButton 選択されているユーザリストのボタン名称 (userlistxx.csv が前提)
     */
    void getUserSettingList();

    /**
     * @brief ユーザ設定リストの表示
     * @param isInitialList true: リスト初期化、false: 初期化しない
     *
     */
    int showUserSettingList(bool isInitialList = false);

    /**
     * @brief 空のユーザ設定リストを表示
     * @note  「- 設定不可 -」 を選択時のユーザ設定リスト
     */
    void showEmptyUserSettingList();

    /**
     * @brief カーソル上下でバンドデータを変更する
     * @param id
     * @param channelListIndex 変更対象のデータの index
     */
    void changeBandData(ButtonId id, int channelListIndex);

    /**
     * @brief カーソル上下で放送方式を変更する
     * @param id
     * @param channelListIndex
     */
    void changeBroadbandSystem(ButtonId id, int channelListIndex);

    /**
     * @brief カーソル上下で変調方式を変更する
     * @param id
     * @param channelListIndex
     */
    void changeModulation(ButtonId id, int channelListIndex);

    /**
     * @brief MER/CN設定変更
     * @param channelListIndex リストインデックス
     */
    void changeMerOnOff(int channelListIndex);

    /**
     * @brief BER設定変更
     * @param channelListIndex リストインデックス
     */
    void changeBerOnOff(int channelListIndex);

    /**
     * @brief カーソル上下で給電設定を切り替える
     * @param item 変更対象の項目名
     * @param channelListIndex 変更対象のデータの index
     */
    void changePowerSupply(ButtonId id, int channelListIndex);

    /**
     * @brief カーソル上下でチャンネル名を切り替える
     * @param id
     * @param channelListIndex
     */
    void changeChannel(ButtonId id, int channelListIndex);

    /**
     * @brief カーソル上下で局発周波数を切り替える
     * @param idｗ
     * @param channelListIndex
     */
    void changeLocalFrequency(ButtonId id, int channelListIndex);

    /**
     * @brief 選択されている行を削除する
     * 内部動作はリスト削除ではなく初期化
     *
     * @param channelListIndex
     */
    void deleteLine();

    /**
     * @brief 選択されているユーザファイルリストから削除する
     */
    void deleteUserFileList();

    /**
     * @brief Activeなユーザリスト部品からデータ上のインデックスを返す
     * @return
     */
    int getSelectedUserListIndex();

    /**
     * @brief 現在の選択行の先頭からのインデックスを返す
     * @return
     */
    int getSelectedChannelListIndex();


    /**
     * @brief シングル測定を実行する
     */
    void executeSingleMeasurement();

    /**
     * @brief マルチ測定を実行する
     */
    void executeMultiMeasurement();

    /**
     * @brief 設定情報の保存・削除を実行する
     */
    void executeEditUserSetting();
    void executeEditUserSettingFilemix();

    /**
     * @brief データ収集を実行する
     */
    void executeDataLogger();

    /**
     * @brief ユーザリストへカーソルを移動する
     */
    void backToUserList();

    /**
     * @brief ユーザファルリストを表示する
     */
    void showUserFileList();

    /**
     * @brief 選択中のユーザファイルリストの名称を取得する
     * @return
     */
    QString getSelectedUserFileListName();

    /**
     * @brief 設定リスト中のMER/BER の測定がONになっているかを返す
     * @return On の場合には true
     */
    bool isEnableMERorBER();

    /**
     * @brief 測定間隔を変更する
     * @param interval 測定間隔
     * @param id ボタンID
     * @return 更新後の測定間隔
     */
    int editInterval(int interval, ButtonId id);

    /**
     * @brief 開始日時（月）を更新する
     * @param id
     */
    void updateStartMonth(ButtonId id);

    /**
     * @brief 開始日時（日）を更新する
     * @param id
     */
    void updateStartDay(ButtonId id);

    /**
     * @brief 開始日時（時）を更新する
     * @param id
     */
    void updateStartHour(ButtonId id);

    /**
     * @brief 開始日時（分）を更新する
     * @param id
     */
    void updateStartMinutes(ButtonId id);

    /**
     * @brief 終了日時（月）を更新する
     * @param id
     */
    void updateEndMonth(ButtonId id);

    /**
     * @brief 終了日時（日）を更新する
     * @param id
     */
    void updateEndDay(ButtonId id);

    /**
     * @brief 終了日時（時）を更新する
     * @param id
     */
    void updateEndHour(ButtonId id);

    /**
     * @brief 終了日時（分）を更新する
     * @param id
     */
    void updateEndMinutes(ButtonId id);

    /**
     * @brief 初期表示設定
     */
    void initDatetimeset();

    /**
     * @brief 開始可能判定
     * @param errorMessage
     */
    int isStartDataCollection(QString &errorMessage);

    /**
     * @brief 測定可能時間のチェック
     */
    bool isMeasurable();

    /**
     * @brief 測定可能サイズの取得
     */
    quint64 getAvailableSize();

    /**
     * @brief 推定使用サイズの取得
     */
    quint64 getEstimatedUseSize();

    /**
     * @brief Select/Edit操作中の画像表示非表示制御
     * @param id
     */
    void setVisibleSelectEditImage(ButtonId id);

    /**
     * @brief Selectモードの画像設定
     */
    void setSelectModeImage();

    /**
     * @brief Editモードの画像設定
     */
    void setEditModeImage();

    /**
     * @brief レイアウト変更
     */
    void changeLayout();

    /**
     * @brief レイアウト変更
     */
    void changeLayoutForFilemixOperation();

    /**
     * @brief レイアウト変更
     */
    void changeLayoutForDefault();

    /**
     * @brief ユーザーリストEnter操作
     */
    void enterUserListArea();

    /**
     * @brief POPUP_SAVE_CONFIRMATION の onAccept 処理
     */
    void onAcceptPopupSaveConfirmation();

    /**
     * @brief POPUP_DATA_LOGGER_KEYBOARD の onAccept 処理
     */
    void onAcceptPopupDataLoggerKeyboard();

    /**
     * @brief POPUP_CANCEL_CONFIRMATION の onAccept 処理
     */
    void onAcceptPopupCancelConfirmation();

    /**
     * @brief 画面遷移キー処理
     */
    void screenTransitionByKey(ButtonId id);

    /**
     * @brief 画面名設定
     */
    void setScreenName();

    /**
     * @brief ActionButton 表示設定
     */
    void setActionButtonDisp();

    /**
     * @brief ユーザファイル&ユーザ設定リスト設定
     */
    void setUserFileListAndUserSettingList();

    /**
     * @brief カーソル移動での画像更新
     */
    void updateImageMoveCursor();

    /**
     * @brief ユーザリストアイテムの画像更新
     */
    void updateUserListItemImage(int index, int selectIndex1, int selectIndex2);

    /**
     * @brief ユーザリストカレントページ更新
     */
    void updateUserListCurrentPage(ButtonId id);

    /**
     * @brief データロガー測定リスト遷移
     */
    void transitionDataLoggerMeasurementList();

    /**
     * @brief ユーザ設定リストのソート
     */
    void sortUserSettingList();

    /**
     * @brief Bandでソート
     */
    void sortBand();

    /**
     * @brief Channelでソート
     */
    void sortChannel();

    /**
     * @brief ユーザ設定リストの重複確認
     *   true:重複あり
     */
    bool isDuplicateUserSettingList();

    /**
     * @brief 画面共有情報からユーザ設定ファイルを作成する
     */
    void createUserSettingFile();

    /**
     * @brief 設定自動でのスキャン結果を表示する
     */
    void displaySettingAutoScanResult(void);

    /**
     * @brief バンドに対応したリストのインデックスを取得する
     * @param bandId バンドのID
     * @return リストのインデックス
     */
    int getListIndexBand(LC70_BAND_T bandId);

    /**
     * @brief リストエリアに表示するBANDIDを取得する
     * @param bandId バンドID
     * @return リストエリアに表示するBANDID
     */
    LC70_BAND_T getDisplayBandId(int bandId);

    /**
     * @brief 給電設定を設定
     * @param channelData チャンネルデータ
     * @param value 給電設定
     */
    void setPowerSupplySetting(QVariantMap channelData, int value);

    /**
     * @brief 給電設定を取得
     * @param bandId Band の ID
     * @param polarization 偏波
     * @return 給電設定
     */
    uint8_t getPowerSupplySetting(int bandId, int polarization);

    /**
     * @brief 現在の給電設定インデックスを取得
     * @param channelData チャンネルデータ
     * @param currentValue 現在の給電設定
     * @param settingList 給電設定リスト
     * @return 給電設定インデックス
     */
    int getCurrentPowerSupplyIndex(const QVariantMap &channelData, const int currentValue, QList<uint8_t> &settingList);

    /**
     * @brief 設定可能な候補について、1つ次の給電設定を取得
     * @param channelData チャンネルデータ
     * @param currentValue 現在の給電設定
     * @return 給電設定
     */
    uint8_t nextPowerSupplySetting(QVariantMap channelData, int currentValue);

    /**
     * @brief 設定可能な候補について、1つ前の給電設定を取得
     * @param channelData チャンネルデータ
     * @param currentValue 現在の給電設定
     * @return 給電設定
     */
    uint8_t prevPowerSupplySetting(QVariantMap channelData, int currentValue);

    /**
     * @brief 給電設定を更新
     * @param list 設定データ
     */
    void updatePowerSupplySetting(QVariantList &list);

    /**
     * @brief 給電設定競合チェック
     * @param list1 リスト1
     * @param list2 リスト2
     * @return true: 競合あり、false: 競合なし
     */
    bool checkConflictPowerSupplySetting(const QVariantList &list1, const QVariantList &list2);

    /**
     * @brief MER/CN設定を設定
     * @param channelData チャンネルデータ
     * @param value MER/CN設定
     */
    void setMerSetting(QVariantMap channelData, MerBerSettingType value);

    /**
     * @brief MER/CN設定を取得
     * @param bandId Band の ID
     * @param polarization 偏波
     * @return MER/CN設定
     */
    MerBerSettingType getMerSetting(int bandId, int polarization);

    /**
     * @brief MER/CN設定を更新
     * @param list 設定データ
     */
    void updateMerSetting(QVariantList &list);

    /**
     * @brief BER設定を設定
     * @param channelData チャンネルデータ
     * @param value BER設定
     */
    void setBerSetting(QVariantMap channelData, MerBerSettingType value);

    /**
     * @brief BER設定を取得
     * @param bandId Band の ID
     * @param polarization 偏波
     * @return BER設定
     */
    MerBerSettingType getBerSetting(int bandId, int polarization);

    /**
     * @brief BER設定を更新
     * @param list 設定データ
     */
    void updateBerSetting(QVariantList &list);

    /**
     * @brief MER/CN設定競合チェク
     * @param list1 リスト1
     * @param list2 リスト2
     * @return true：競合あり、false：競合なし
     */
    bool checkConflictMerSetting(const QVariantList &list1, const QVariantList &list2);

    /**
     * @brief BER設定競合チェク
     * @param list1 リスト1
     * @param list2 リスト2
     * @return true：競合あり、false：競合なし
     */
    bool checkConflictBerSetting(const QVariantList &list1, const QVariantList &list2);

    /**
     * @brief 引数の名前と同じファイル名が保持されているかを調べる
     * @param userDataLoggerList ユーザデータロガーリスト
     * @param fileName データロガーのファイル名
     * @return 引数の名前と同じ名前のファイル名がデータロガーに含まれているか (True: 含まれている場合 False: 含まれていない場合)
     */
    bool checkContainSameNamefile(QVariantList userDataLoggerList,QString fileName);

    /**
     * @brief 名前が重複したファイルを保存する。
     * @note 名前が重複したファイル保存時は、もともと保存されているファイルを削除する
     */
    void saveDuplicateFile(void);

    /**
     * @brief 有効な行のみに絞り込む
     * @param value
     */
    void filterFileList(QVariant &value);
};

#endif // DATALOGGERVIEWMODEL_H
