/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef DATALOGGERDATALISTVIEWMODEL_H
#define DATALOGGERDATALISTVIEWMODEL_H

#include "abstractviewmodel.h"
#include "measurementresultfilecomponentlist.h"
#include "buttonoperation.h"

/**
 * @brief データロガー取得データ一覧表示 ViewModel
 */
class DataloggerDataListViewModel : public AbstractViewModel
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクター
     * @param screenId 画面 ID
     * @param model Model クラスのポインター
     * @param parent 親オブジェクト
     */
    explicit DataloggerDataListViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent = nullptr);

    /**
     * @brief デストラクタ
     */
    virtual ~DataloggerDataListViewModel();

    /**
     * @brief 画面Active 時の処理
     */
    virtual void activate(void) override;

    /**
     * @brief 画面を閉じるときに呼び出すスレッド停止処理
     */
    virtual void suspend(void) override;

    /**
     * @brief 遷移先画面で参照する遷移前画面のデータ設定
     */
    virtual void setTakeOver() override;

signals:
    void requestSetTakeOver(QVariant, QVariant);

    /**
     * @brief リストのページを移動
     */
    void scrollPage(QVariant);
protected:
    /**
     * @brief ボタン押下時イベント受信時の処理
     * @param id ボタンID
     */
    virtual void onKeyStatus(ButtonId id) override;

private slots:
    /**
     * @brief 画面遷移要求の受信時処理
     * @param condition 画面IDリストのインデックス
     */
    virtual void onRequest(int condition) override;

private:
    /**
     * @brief カーソル移動
     * @param buttonId 押下ボタンのID
     */
    void moveCursor(ButtonId buttonId);

    /**
     * @brief ファイル生成日でソートを行う
     * @param dataList ソート対象のファイル情報のデータリスト
     * @return ソート後のファイル情報のリスト
     */
    QList<QFileInfo> sortCreateDate(QList<QFileInfo> dataList);

    /**
     * @brief 選択しているページを求める
     */
    void calcCurrentPage(void);

    QSharedPointer<MeasurementResultFileComponentList> _listData;   //!< リストデータ
    int _listIndex;                                                 //!< リストのインデックス
    int _totalPage;                                                 //!< リストの全ページ数
    int _currentPage;                                               //!< 選択中のページ数
};

#endif // DATALOGGERDATALISTVIEWMODEL_H
