/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "dataloggermenuviewmodel.h"
#include "usboperation.h"

// メニューマップ(データロガー取得情報の表示、データロガー情報の削除)
QVector<QVector<QString>> dataLoggerMenuButtonData = {
    {{"m0"}, {"m1"}},
};

const int DataLoggerMenuViewModel::BUTTON_COLUMN_NUMBER = 1;
const int DataLoggerMenuViewModel::BUTTON_ROW_NUMBER = 2;

DataLoggerMenuViewModel::DataLoggerMenuViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent)
    : AbstractViewModel(screenId, model, parent)
{
    setObjectName("dataLoggerMenuViewModel");
    _buttonOperation.setButtonName(BUTTON_COLUMN_NUMBER, BUTTON_ROW_NUMBER, dataLoggerMenuButtonData);
    _buttonOperation.setActiveObject(dataLoggerMenuButtonData[0][0]);
    _activeButton = dataLoggerMenuButtonData[0][0];
}

DataLoggerMenuViewModel::~DataLoggerMenuViewModel()
{

}

void DataLoggerMenuViewModel::activate()
{
    if (_view == nullptr) {
        qErrnoWarning("_view is null");
        return;
    }

    // 画面表示時の初期選択アイコンを設定
    QObject *target = nullptr;
    if (_view) {
        target = _view->findChild<QObject *>(_activeButton);
    }
    if (target) {
        target->setProperty("active", true);
    }
}

void DataLoggerMenuViewModel::onKeyStatus(ButtonId id)
{
    AbstractViewModel::onKeyStatus(id);

    if (id == BUTTON_ENTER) {
        if (_activeButton == "m1") {
            emit requestToShowPopup(POPUP_DELETE_ALL_DATA_LOGGER_CONFIRMATION); // データロガー情報の削除
            moveCursor(id);
        } else {
            int button_index = _activeButton.mid(1).toInt();
            onRequest(button_index);
        }
    } else if (id == BUTTON_USER) {
#ifdef NEW_USER_SETTING
        emit requestDirect(SCREEN_USER_SETTING, true);
#else
        emit requestDirect(SCREEN_USER_DATA_LOGGER_MENU, true);
#endif
    } else {
        moveCursor(id);
    }
}

void DataLoggerMenuViewModel::onAccept(PopupId popupId, bool okOnly)
{
    AbstractViewModel::onAccept(popupId, okOnly);

    // データロガーデータ取得結果の一括削除
    if (popupId == POPUP_DELETE_ALL_DATA_LOGGER_CONFIRMATION) {
        UsbErrorType error = UsbOperation::deleteUsbData(UsbDataType::DATA_LOGGER_RESULT);

        if (error == UsbErrorType::DELETE_ERROR) {
            // 削除失敗ポップアップを表示する
            emit requestToShowPopup(POPUP_FAILURE_DELETE_EXECUTE);
        }
    }
}

void DataLoggerMenuViewModel::onReject(PopupId popupId)
{
    Q_UNUSED(popupId)
}

void DataLoggerMenuViewModel::onRequest(int condition)
{
    emit request(_screenId, condition);
}

void DataLoggerMenuViewModel::moveCursor(ButtonId buttonId)
{
    if ((buttonId == BUTTON_RIGHT) || (buttonId == BUTTON_LEFT)) {

        QString nextButton;
        bool ret = _buttonOperation.nextActiveObject(buttonId, nextButton);

        if (ret) {

            // inactive
            QObject *target = nullptr;
            if (_view) {
                target = _view->findChild<QObject *>(_activeButton);
            }
            if (target) {
                target->setProperty("active", false);
            }

            // active
            target = nullptr;
            if (_view) {
                target = _view->findChild<QObject *>(nextButton);
            }
            if (target) {
                target->setProperty("active", true);
            }

            _activeButton = nextButton;
            _buttonOperation.setActiveObject(_activeButton);
        }
    }
}
