/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef DATALOGGERMENUVIEWMODEL_H
#define DATALOGGERMENUVIEWMODEL_H

#include "abstractviewmodel.h"
#include "buttonoperation.h"

/**
 * @brief データロガー取得データメニュー ViewModel
 */
class DataLoggerMenuViewModel : public AbstractViewModel
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクター
     * @param screenId 画面 ID
     * @param model Model クラスのポインター
     * @param parent 親オブジェクト
     */
    explicit DataLoggerMenuViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent = nullptr);

    /**
     * @brief デストラクタ
     */
    virtual ~DataLoggerMenuViewModel();

    /**
     * @brief 画面Active 時の処理
     */
    void activate() override;

protected:
    /**
     * @brief ボタン押下時イベント受信時の処理
     * @param id ボタンID
     */
    virtual void onKeyStatus(ButtonId id) override;

    /**
     * @brief ダイアログからのAccept受信処理
     * @param popupId ダイアログID
     * @param okOnly 結果
     */
    void onAccept(PopupId popupId, bool okOnly) override;

    /**
     * @brief ダイアログからのReject受信処理
     * @param popupId ダイアログID
     */
    void onReject(PopupId popupId) override;

private slots:
    /**
     * @brief 画面遷移要求の受信時処理
     * @param condition 画面IDリストのインデックス
     */
    virtual void onRequest(int condition) override;

private:
    /**
     * @brief カーソル移動
     * @param buttonId 押下ボタンのID
     */
    void moveCursor(ButtonId buttonId);

    static const int BUTTON_COLUMN_NUMBER;
    static const int BUTTON_ROW_NUMBER;

    ButtonOperation _buttonOperation;
    QString _activeButton;

};

#endif // DATALOGGERMENUVIEWMODEL_H
