/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "measurementresultcopyviewmodel.h"

static const int MINIMUM_LIST_SIZE = 6;

static const int OPERATION_BUTTON_COLUMN = 2;
static const int OPERATION_BUTTON_ROW = 1;

MeasurementResultCopyViewModel::MeasurementResultCopyViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent)
    : MeasurementResultOperationViewModelBase(screenId, model, "measurementResultCopyViewModel", parent)
{
}

MeasurementResultCopyViewModel::~MeasurementResultCopyViewModel()
{
}

void MeasurementResultCopyViewModel::activate() {
    // viewとのコネクションの生成
    connect(this, SIGNAL(scrollPage(QVariant)), _view, SLOT(onScrollPage(QVariant)));

    MeasurementResultOperationViewModelBase::activate();
}

void MeasurementResultCopyViewModel::suspend()
{
    // コネクションの破棄
    disconnect(this, SIGNAL(scrollPage(QVariant)), _view, SLOT(onScrollPage(QVariant)));

    MeasurementResultOperationViewModelBase::suspend();
}

void MeasurementResultCopyViewModel::pressExecuteButton()
{
    // コピー確認ダイアログを表示
    if(MeasurementResultOperationViewModelBase::getTargetPathList().isEmpty()) {
        // 処理対象のパスが空の場合 ダイアログは表示しない
        return;
    }

    emit requestToShowPopup(POPUP_CONFIRM_COPY_SELECTED_FILE);
}

void MeasurementResultCopyViewModel::onSelect(PopupId popupId, int index)
{
    Q_UNUSED(popupId);
    executeOperation(index);
}

void MeasurementResultCopyViewModel::onReject(PopupId popupId)
{
    Q_UNUSED(popupId);
}

void MeasurementResultCopyViewModel::executeOperation(int selectedButtonIndex)
{
    // 処理を行う対象のパスのリストを取得
    QStringList pathList = getTargetPathList();
    if (pathList.isEmpty()) {
        // 対象パスのリストが空の場合後続処理は実施しない
        return;
    }

//    if (selectedButtonIndex == ConfirmDataSaveDialogSelection::Copy) {
//        // コピーのみを実施
//        copyMeasurementResultData(pathList);
//    }else if (selectedButtonIndex == ConfirmDataSaveDialogSelection::CopyAndDelete) {
//        // コピー後、コピー元のファイルを削除する
//        copyMeasurementResultData(pathList);
//        removeMeasurementResultData(pathList);

//        // リストの再読込を行う
//        MeasurementResultOperationViewModelBase::updateListData();
//    }
}

void MeasurementResultCopyViewModel::copyMeasurementResultData(QStringList targetPathList)
{
    UsbErrorType error = UsbErrorType::NON_ERROR;

    // コピー処理を行うパスを決める
    QStringList copyTargetPath = {};
    for (int index = 0; index < targetPathList.size(); ++index) {
        error = UsbOperation::checkExistsFile(targetPathList.at(index));

        if (error == UsbErrorType::NON_ERROR) {
            copyTargetPath.append(targetPathList.at(index));
        }
    }

    if (copyTargetPath.isEmpty()) {
        // コピー対象ファイルが無い場合は、以降の処理は実施しない
        return;
    }

    error = UsbErrorType::NON_ERROR;

    // コピー可能な状態化のチェックを行う
    error = UsbOperation::checkCopyable(copyTargetPath, true);

    if (error == UsbErrorType::COPY_FILE_ERROR) {
        // コピー元ファイルなし
        emit requestToShowPopup(POPUP_NOTHING_COPY_FILE);
        return;
    } else if (error == UsbErrorType::SPACE_ERROR) {
        // USBの空き容量が足りない
        emit requestToShowPopup(POPUP_USB_NO_SPACE);
        return;
    }

    // コピー処理を実施
    for (int i = 0; i < copyTargetPath.size(); ++i) {

        UsbDataType fileType;
        if (copyTargetPath.at(i).contains("/single/", Qt::CaseInsensitive)){
            fileType = UsbDataType::MEASUREMENT_RESULT_SINGLE;
        } else {
            fileType = UsbDataType::MEASUREMENT_RESULT_MULTI;
        }

        error = UsbOperation::copyToUsb(fileType, targetPathList[i], false, _model->applicationSetting()->password());

        if (error == UsbErrorType::COPY_EXEC_ERROR) {
            // コピー実施エラー
            emit requestToShowPopup(POPUP_FAILURE_COPY_EXECUTE);
            return;
        }
    }
}

void MeasurementResultCopyViewModel::removeMeasurementResultData(QStringList targetPathList)
{
    for (int index = 0; index < targetPathList.size(); ++index) {
        _model->removePreservedData(targetPathList.at(index), false);
    }
}
