/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef MEASUREMENTRESULTCOPYVIEWMODEL_H
#define MEASUREMENTRESULTCOPYVIEWMODEL_H

#include "measurementresultoperationviewmodelbase.h"

//enum ConfirmDataSaveDialogSelection {
//    Copy = 0,
//    CopyAndDelete,
//};

/**
 * @brief 保存データのコピー ViewModel
 */
class MeasurementResultCopyViewModel : public MeasurementResultOperationViewModelBase
{
    Q_OBJECT

public:
    /**
     * @brief コンストラクター
     * @param screenId 画面 ID
     * @param model Model クラスのポインター
     * @param parent 親オブジェクト
     */
    explicit MeasurementResultCopyViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent = nullptr);

    /**
     * @brief デストラクタ
     */
    virtual ~MeasurementResultCopyViewModel(void);

    /**
     * @brief 画面Activate時の処理
     */
    virtual void activate(void) override;

    /**
     * @brief 画面Suspend時の処理
     */
    virtual void suspend(void) override;

protected slots:
    /**
     * @brief ポップアップから選択の通知を受信
     * @param popupId ポップアップID
     * @param index 選択されたインデックス
     */
    virtual void onSelect(PopupId popupId, int index) override;

    /**
     * @brief ポップアップから拒否通知を受信
     * @param popupId ポップアップID
     */
    virtual void onReject(PopupId popupId) override;

private:
    /**
     * @brief 処理ボタン押下時処理
     */
    virtual void pressExecuteButton(void) override;

    /**
     * @brief 処理の実施を行う
     * @param selectedButtonIndex 選択したボタンindex
     */
    void executeOperation(int selectedButtonIndex);

    /**
     * @brief 測定データのコピーを実施
     * @param targetPathList 処理対象リスト
     */
    void copyMeasurementResultData(const QStringList targetPathList);

    /**
     * @brief 測定データの削除を実施
     * @param targetPathList 処理対象リスト
     */
    void removeMeasurementResultData(const QStringList targetPathList);
};

#endif // MEASUREMENTRESULTCOPYVIEWMODEL_H
