/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "measurementresultcsvcomponentlist.h"
#include <QMetaEnum>

MeasurementResultCsvComponentList::MeasurementResultCsvComponentList(QObject *parent)
    : QAbstractListModel(parent), _roles(), _data()
{
    if (_roles.isEmpty()) {
        int metaIndex      = metaObject()->indexOfEnumerator("MeasurementResultCsvRoles");
        QMetaEnum metaEnum = metaObject()->enumerator(metaIndex);
        _roles.insert(MeasurementResultCsvRoles::BandRole,
                      metaEnum.valueToKey(MeasurementResultCsvRoles::BandRole));
        _roles.insert(MeasurementResultCsvRoles::ChannelRole, metaEnum.valueToKey(MeasurementResultCsvRoles::ChannelRole));
        _roles.insert(MeasurementResultCsvRoles::FrequencyRole, metaEnum.valueToKey(MeasurementResultCsvRoles::FrequencyRole));
        _roles.insert(MeasurementResultCsvRoles::LocalOscillatorRole,
                      metaEnum.valueToKey(MeasurementResultCsvRoles::LocalOscillatorRole));
        _roles.insert(MeasurementResultCsvRoles::BroadcastSystemRole,
                      metaEnum.valueToKey(MeasurementResultCsvRoles::BroadcastSystemRole));
        _roles.insert(MeasurementResultCsvRoles::ModulationRole,
                      metaEnum.valueToKey(MeasurementResultCsvRoles::ModulationRole));
        _roles.insert(MeasurementResultCsvRoles::LayerRole, metaEnum.valueToKey(MeasurementResultCsvRoles::LayerRole));
        _roles.insert(MeasurementResultCsvRoles::LevelRole, metaEnum.valueToKey(MeasurementResultCsvRoles::LevelRole));
        _roles.insert(MeasurementResultCsvRoles::MerRole, metaEnum.valueToKey(MeasurementResultCsvRoles::MerRole));
        _roles.insert(MeasurementResultCsvRoles::BerRole, metaEnum.valueToKey(MeasurementResultCsvRoles::BerRole));
    }
}

MeasurementResultCsvComponentList::~MeasurementResultCsvComponentList()
{
    _data.clear();
}

int MeasurementResultCsvComponentList::rowCount(const QModelIndex &/*parent*/) const
{
    if (_data.isEmpty()) {
        return 0;
    } else {
        return _data.size();
    }
}

QHash<int, QByteArray> MeasurementResultCsvComponentList::roleNames() const
{
    return _roles;
}

QVariant MeasurementResultCsvComponentList::data(const QModelIndex &index, int role) const
{
    if (_data.isEmpty()) {
        return QVariant();
    }

    switch (role) {
    case MeasurementResultCsvRoles::BandRole:
        return QVariant(_data.at(index.row()).band);

    case MeasurementResultCsvRoles::ChannelRole:
        return QVariant(_data.at(index.row()).channel);

    case MeasurementResultCsvRoles::FrequencyRole:
        return QVariant(_data.at(index.row()).frequency);

    case MeasurementResultCsvRoles::LocalOscillatorRole:
        return QVariant(_data.at(index.row()).localOscillator);

    case MeasurementResultCsvRoles::BroadcastSystemRole:
        return QVariant(_data.at(index.row()).broadcastSystem);

    case MeasurementResultCsvRoles::ModulationRole:
        return QVariant(_data.at(index.row()).modulation);

    case MeasurementResultCsvRoles::LayerRole:
        return QVariant(_data.at(index.row()).layer);

    case MeasurementResultCsvRoles::LevelRole:
        return QVariant(_data.at(index.row()).level);

    case MeasurementResultCsvRoles::MerRole:
        return QVariant(_data.at(index.row()).mer);

    case MeasurementResultCsvRoles::BerRole:
        return QVariant(_data.at(index.row()).ber);

    default:
        return QVariant();
    }
}

void MeasurementResultCsvComponentList::setListData(QList<MeasureResultCsvItems> items)
{
    beginResetModel();
    _data.clear();
    _data = items;
    endResetModel();
}

void MeasurementResultCsvComponentList::setBand(int listIndex, const QString &band)
{
    if (_data[listIndex].band == band) {
        return;
    }

    _data[listIndex].band = band;
    emit dataChanged(index(listIndex), index(listIndex), QVector<int>() = {MeasurementResultCsvRoles::BandRole});
}

QString MeasurementResultCsvComponentList::getBand(int listIndex)
{
    if (rowCount() - 1 < listIndex || listIndex < 0) {
        return "";
    }

    return _data[listIndex].band;
}

void MeasurementResultCsvComponentList::setChannel(int listIndex, const QString &channel)
{
    if (_data[listIndex].channel == channel) {
        return;
    }

    _data[listIndex].channel = channel;
    emit dataChanged(index(listIndex), index(listIndex), QVector<int>() = {MeasurementResultCsvRoles::ChannelRole});
}

QString MeasurementResultCsvComponentList::getChannel(int listIndex)
{
    if (rowCount() - 1 < listIndex || listIndex < 0) {
        return "";
    }

    return _data[listIndex].channel;
}

void MeasurementResultCsvComponentList::setFrequency(int listIndex, const QString &frequency)
{
    if (_data[listIndex].frequency == frequency) {
        return;
    }

    _data[listIndex].frequency = frequency;
    emit dataChanged(index(listIndex), index(listIndex), QVector<int>() = {MeasurementResultCsvRoles::FrequencyRole});
}

QString MeasurementResultCsvComponentList::getFrequency(int listIndex)
{
    if (rowCount() - 1 < listIndex || listIndex < 0) {
        return "";
    }

    return _data[listIndex].frequency;
}

void MeasurementResultCsvComponentList::setLocalOscillator(int listIndex, const QString &localOscillator)
{
    if (_data[listIndex].localOscillator == localOscillator) {
        return;
    }

    _data[listIndex].localOscillator = localOscillator;
    emit dataChanged(index(listIndex), index(listIndex), QVector<int>() = {MeasurementResultCsvRoles::LocalOscillatorRole});
}

QString MeasurementResultCsvComponentList::getLocalOscillator(int listIndex)
{
    if (rowCount() - 1 < listIndex || listIndex < 0) {
        return "";
    }

    return _data[listIndex].localOscillator;
}

void MeasurementResultCsvComponentList::setBroadcastSystem(int listIndex, const QString &broadcastSystem)
{
    if (_data[listIndex].broadcastSystem == broadcastSystem) {
        return;
    }

    _data[listIndex].broadcastSystem = broadcastSystem;
    emit dataChanged(index(listIndex), index(listIndex), QVector<int>() = {MeasurementResultCsvRoles::BroadcastSystemRole});
}

QString MeasurementResultCsvComponentList::getBroadcastSystem(int listIndex)
{
    if (rowCount() - 1 < listIndex || listIndex < 0) {
        return "";
    }

    return _data[listIndex].broadcastSystem;
}

void MeasurementResultCsvComponentList::setModulation(int listIndex, const QString &modulation)
{
    if (_data[listIndex].modulation == modulation) {
        return;
    }

    _data[listIndex].modulation = modulation;
    emit dataChanged(index(listIndex), index(listIndex), QVector<int>() = {MeasurementResultCsvRoles::ModulationRole});
}

QString MeasurementResultCsvComponentList::getModulation(int listIndex)
{
    if (rowCount() - 1 < listIndex || listIndex < 0) {
        return "";
    }

    return _data[listIndex].modulation;
}

void MeasurementResultCsvComponentList::setLayer(int listIndex, const QString &layer)
{
    if (_data[listIndex].layer == layer) {
        return;
    }

    _data[listIndex].layer = layer;
    emit dataChanged(index(listIndex), index(listIndex), QVector<int>() = {MeasurementResultCsvRoles::LayerRole});
}

QString MeasurementResultCsvComponentList::getLayer(int listIndex)
{
    if (rowCount() - 1 < listIndex || listIndex < 0) {
        return "";
    }

    return _data[listIndex].layer;
}

void MeasurementResultCsvComponentList::setLevel(int listIndex, const QString &level)
{
    if (_data[listIndex].level == level) {
        return;
    }

    _data[listIndex].level = level;
    emit dataChanged(index(listIndex), index(listIndex), QVector<int>() = {MeasurementResultCsvRoles::LevelRole});
}

QString MeasurementResultCsvComponentList::getLevel(int listIndex)
{
    if (rowCount() - 1 < listIndex || listIndex < 0) {
        return "";
    }

    return _data[listIndex].level;
}

void MeasurementResultCsvComponentList::setMer(int listIndex, const QString &mer)
{
    if (_data[listIndex].mer == mer) {
        return;
    }

    _data[listIndex].mer = mer;
    emit dataChanged(index(listIndex), index(listIndex), QVector<int>() = {MeasurementResultCsvRoles::MerRole});
}

QString MeasurementResultCsvComponentList::getMer(int listIndex)
{
    if (rowCount() - 1 < listIndex || listIndex < 0) {
        return "";
    }

    return _data[listIndex].mer;
}

void MeasurementResultCsvComponentList::setBer(int listIndex, const QString &ber)
{
    if (_data[listIndex].ber == ber) {
        return;
    }

    _data[listIndex].ber = ber;
    emit dataChanged(index(listIndex), index(listIndex), QVector<int>() = {MeasurementResultCsvRoles::BerRole});
}

QString MeasurementResultCsvComponentList::getBer(int listIndex)
{
    if (rowCount() - 1 < listIndex || listIndex < 0) {
        return "";
    }

    return _data[listIndex].ber;
}
