/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef MEASUREMENTRESULTCSVDATAVIEWMODEL_H
#define MEASUREMENTRESULTCSVDATAVIEWMODEL_H

#include "abstractviewmodel.h"
#include "measurementresultcsvcomponentlist.h"
#include "buttonoperation.h"

/**
 * @brief 測定結果データ表示(CSV) ViewModel
 */
class MeasurementResultCsvDataViewModel : public AbstractViewModel
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクター
     * @param screenId 画面 ID
     * @param model Model クラスのポインター
     * @param parent 親オブジェクト
     */
    explicit MeasurementResultCsvDataViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent = nullptr);

    /**
     * @brief デストラクタ
     */
    virtual ~MeasurementResultCsvDataViewModel();

    /**
     * @brief 画面を開くときに呼び出す表示内容の復元処理
     */
    virtual void activate(void) override;

    /**
     * @brief 画面を閉じるときに呼び出す処理
     */
    virtual void deactivate(void) override;
signals:
    /**
     * @brief リストのページを移動
     */
    void scrollPage(QVariant);

protected slots:
    /**
     * @brief ボタン押下の状態を受信
     * @param id ボタン ID
     */
    virtual void onKeyStatus(ButtonId id) override;

private:
    static const int BUTTON_COLUMN_NUMBER;
    static const int BUTTON_ROW_NUMBER;

    ButtonOperation _buttonOperation;
    QSharedPointer<MeasurementResultCsvComponentList> _listData;
    int _listIndex;
    QObject *_list;
    int _totalPage;                                                 //!< リストの全ページ数
    int _currentPage;                                               //!< 選択中のページ数

    /**
     * @brief カーソル移動
     * @param buttonId 押下ボタンのID
     */
    void moveCursor(ButtonId buttonId);

    /**
     * @brief 画面情報の更新
     */
    void updateDisplayInfo(void);

    /**
    * @brief 選択しているページを求める
    */
   void calcCurrentPage(void);
};

#endif // MEASUREMENTRESULTCSVDATAVIEWMODEL_H
