/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "measurementresultdeletionviewmodel.h"

static const int MINIMUM_LIST_SIZE = 6;

static const int OPERATION_BUTTON_COLUMN = 2;
static const int OPERATION_BUTTON_ROW = 1;

MeasurementResultDeletionViewModel::MeasurementResultDeletionViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent)
    : MeasurementResultOperationViewModelBase(screenId, model, "measurementResultDeletion", parent)
{
}

MeasurementResultDeletionViewModel::~MeasurementResultDeletionViewModel()
{
}

void MeasurementResultDeletionViewModel::activate() {
    // viewとのコネクションの生成
    connect(this, SIGNAL(scrollPage(QVariant)), _view, SLOT(onScrollPage(QVariant)));

    MeasurementResultOperationViewModelBase::activate();
}

void MeasurementResultDeletionViewModel::suspend()
{
    // コネクションの破棄
    disconnect(this, SIGNAL(scrollPage(QVariant)), _view, SLOT(onScrollPage(QVariant)));

    MeasurementResultOperationViewModelBase::suspend();
}

void MeasurementResultDeletionViewModel::pressExecuteButton()
{
    if (MeasurementResultOperationViewModelBase::getTargetPathList().isEmpty()) {
        // 処理対象のパスが空の場合 ダイアログは表示しない
        return;
    }

    // 削除確認ダイアログを表示
    emit requestToShowPopup(POPUP_CONFIRM_DELETE_SELECTED_FILE);
}

void MeasurementResultDeletionViewModel::onAccept(PopupId popupId, bool okOnly)
{
    AbstractViewModel::onAccept(popupId, okOnly);

    Q_UNUSED(okOnly);
    if (popupId == POPUP_CONFIRM_DELETE_SELECTED_FILE) {
        removeMeasurementResultData();
    }
}

void MeasurementResultDeletionViewModel::onReject(PopupId popupId)
{
    Q_UNUSED(popupId);
}

void MeasurementResultDeletionViewModel::removeMeasurementResultData()
{

    QStringList targetPathList = MeasurementResultOperationViewModelBase::getTargetPathList();

    if (targetPathList.isEmpty()){
        // 選択リストが空の場合後続処理は実施しない
        return;
    }

    for (int index = 0; index < targetPathList.size(); ++index) {
        _model->removePreservedData(targetPathList.at(index), false);
    }

    MeasurementResultOperationViewModelBase::updateListData();
}
