﻿/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef MEASUREMENTRESULTDELETIONVIEWMODEL_H
#define MEASUREMENTRESULTDELETIONVIEWMODEL_H

#include "measurementresultoperationviewmodelbase.h"

/**
 * @brief 測定結果データ一削除画面 ViewModel
 */
class MeasurementResultDeletionViewModel : public MeasurementResultOperationViewModelBase
{
    Q_OBJECT

public:
    /**
     * @brief コンストラクター
     * @param screenId 画面 ID
     * @param model Model クラスのポインター
     * @param parent 親オブジェクト
     */
    explicit MeasurementResultDeletionViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent = nullptr);

    /**
     * @brief デストラクタ
     */
    virtual ~MeasurementResultDeletionViewModel(void);

    /**
     * @brief 画面Activate時の処理
     */
    virtual void activate(void) override;

    /**
     * @brief 画面Suspend時の処理
     */
    virtual void suspend(void) override;

protected slots:
    /**
     * @brief ポプアップからの受諾の通知を受信
     * @param PopupId ポップアップのID
     * @param okonly okOnly OKのみの場合 true
     */
    virtual void onAccept(PopupId PopupId, bool okonly) override;

    /**
     * @brief ポップアップから拒否通知を受信
     * @param popupId ポップアップのID
     */
    virtual void onReject(PopupId popupId) override;
private:
    /**
     * @brief 処理ボタン押下時の処理
     */
     virtual void pressExecuteButton(void) override;

    /**
     * @brief 測定結果ファイルの削除を実施する
     */
    void removeMeasurementResultData(void);
};

#endif // MEASUREMENTRESULTDELETIONVIEWMODEL_H
