/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "measurementresultfilecomponentlist.h"
#include <QMetaEnum>

MeasurementResultFileComponentList::MeasurementResultFileComponentList(QObject *parent) :
    QAbstractListModel(parent), _roles(), _data()
{
    if (_roles.isEmpty()) {
        int metaIndex      = metaObject()->indexOfEnumerator("MeasurementResultFileListRoles");
        QMetaEnum metaEnum = metaObject()->enumerator(metaIndex);
        _roles.insert(MeasurementResultFileListRoles::NumberRole,
                      metaEnum.valueToKey(MeasurementResultFileListRoles::NumberRole));
        _roles.insert(MeasurementResultFileListRoles::DataRole,
                      metaEnum.valueToKey(MeasurementResultFileListRoles::DataRole));
        _roles.insert(MeasurementResultFileListRoles::PathRole,
                      metaEnum.valueToKey(MeasurementResultFileListRoles::PathRole));
        _roles.insert(MeasurementResultFileListRoles::ExtensionRole,
                      metaEnum.valueToKey(MeasurementResultFileListRoles::ExtensionRole));
        _roles.insert(MeasurementResultFileListRoles::UserDataRole,
                      metaEnum.valueToKey(MeasurementResultFileListRoles::UserDataRole));
        _roles.insert(MeasurementResultFileListRoles::DateRole,
                      metaEnum.valueToKey(MeasurementResultFileListRoles::DateRole));
    }
}

MeasurementResultFileComponentList::~MeasurementResultFileComponentList()
{
    _data.clear();
}

int MeasurementResultFileComponentList::rowCount(const QModelIndex &/*parent*/) const
{
    if (_data.isEmpty()) {
        return 0;
    } else {
        return _data.size();
    }
}

QHash<int, QByteArray> MeasurementResultFileComponentList::roleNames() const
{
    return _roles;
}

QVariant MeasurementResultFileComponentList::data(const QModelIndex &index, int role) const
{
    if (_data.isEmpty()) {
        return QVariant();
    }

    switch (role) {
    case MeasurementResultFileListRoles::NumberRole:
        return QVariant(_data.at(index.row()).number);

    case MeasurementResultFileListRoles::DataRole:
        return QVariant(_data.at(index.row()).fileName);

    case MeasurementResultFileListRoles::PathRole:
        return QVariant(_data.at(index.row()).filePath);

    case MeasurementResultFileListRoles::ExtensionRole:
        return QVariant(_data.at(index.row()).extension);

    case MeasurementResultFileListRoles::UserDataRole:
            return QVariant(_data.at(index.row()).userDataName);

    case MeasurementResultFileListRoles::DateRole:
        return QVariant(_data.at(index.row()).date);

    default:
        return QVariant();
    }
}

void MeasurementResultFileComponentList::setListData(QList<MeasurementResultFileListItems> items)
{
    beginResetModel();
    _data.clear();
    _data = items;
    endResetModel();
}

void MeasurementResultFileComponentList::setFileName(const int listIndex, const QString &fileName)
{
    if (_data[listIndex].fileName == fileName) {
        return;
    }

    _data[listIndex].fileName = fileName;
    emit dataChanged(index(listIndex), index(listIndex), QVector<int>() = {MeasurementResultFileListRoles::DataRole});
}

QString MeasurementResultFileComponentList::getFileName(const int listIndex)
{
    if (rowCount() - 1 < listIndex || listIndex < 0) {
        return "";
    }

    return _data[listIndex].fileName;
}

void MeasurementResultFileComponentList::setFilePath(const int listIndex, const QString &filePath)
{
    if (_data[listIndex].filePath == filePath) {
        return;
    }

    _data[listIndex].filePath = filePath;
    emit dataChanged(index(listIndex), index(listIndex), QVector<int>() = {MeasurementResultFileListRoles::PathRole});
}

QString MeasurementResultFileComponentList::getFilePath(const int listIndex)
{
    if (rowCount() - 1 < listIndex || listIndex < 0) {
        return "";
    }

    return _data[listIndex].filePath;
}

void MeasurementResultFileComponentList::setExtension(const int listIndex, const QString &extension)
{
    if (_data[listIndex].extension == extension) {
        return;
    }

    _data[listIndex].extension = extension;
    emit dataChanged(index(listIndex), index(listIndex), QVector<int>() = {MeasurementResultFileListRoles::ExtensionRole});
}

QString MeasurementResultFileComponentList::getExtension(const int listIndex)
{
    if (rowCount() - 1 < listIndex || listIndex < 0) {
        return "";
    }

    return _data[listIndex].extension;
}
