/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef MEASUREMENTRESULTFILECOMPONENTLIST_H
#define MEASUREMENTRESULTFILECOMPONENTLIST_H

#include <QAbstractListModel>

/**
 * @brief リストアイテム
 */
struct MeasurementResultFileListItems {
    unsigned int number;              //!< No.
    QString fileName;                 //!< ファイル名
    QString filePath;                 //!< ファイルパス
    QString extension;                //!< 拡張子
    QString userDataName;             //!< ファイル名のユーザーがつけた部分のみ[日付_プリフィックス_[dataName.csv]]
    QString date;                     //!< 日付
    MeasurementResultFileListItems(unsigned int paramNumber = 0,
                                   QString paramFileName    = "",
                                   QString paramFilePath    = "",
                                   QString paramExtension   = "",
                                   QString paramUserDataName= "",
                                   QString paramDate        = "")
    {
        number      = paramNumber;
        fileName    = paramFileName;
        filePath    = paramFilePath;
        extension   = paramExtension;
        userDataName= paramUserDataName;
        date        = paramDate;
    }
};

/**
 * @brief 測定結果データ一覧用のリストクラス
 */
class MeasurementResultFileComponentList : public QAbstractListModel
{
    Q_OBJECT
    Q_ENUMS(MeasurementResultFileListRoles)
public:
    /**
     * @brief 測定結果データ一覧用ロール定義
     */
    enum MeasurementResultFileListRoles {
        NumberRole = Qt::UserRole + 80,   //!< No.
        DataRole,                         //!< データ
        PathRole,                         //!< パス
        ExtensionRole,                    //!< 拡張子
        UserDataRole,                     //!< ファイル名のユーザーがつけた部分のみ[日付_プリフィックス_[dataName.csv]]
        DateRole,                         //!< 日付
    };

    /**
     * @brief コンストラクタ
     * @param parent 親オブジェクト
     */
    MeasurementResultFileComponentList(QObject *parent = nullptr);

    /**
     * @brief デストラクター
     */
    ~MeasurementResultFileComponentList();
    /**
     * @brief 測定結果数を返す
     * @return 測定結果数
     */
    int rowCount(const QModelIndex &parent = QModelIndex()) const override;

    /**
     * @brief Role情報取得
     * @return ロール名
     */
    QHash<int, QByteArray> roleNames() const override;

    /**
     * @brief 測定データ取得
     * @param index データの位置
     * @param role ロール
     * @return 測定データ
     */
    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;

    /**
     * @brief リストデータを設定する
     * @param items リストデータ
     */
    void setListData(QList<MeasurementResultFileListItems> items);

    /**
     * @brief ファイル名の設定
     * @param listIndex リストインデックス
     * @param fileName ファイル名
     */
    void setFileName(const int listIndex, const QString &fileName);

    /**
     * @brief ファイル名の取得
     * @param listIndex リストインデックス
     * @return ファイル名
     */
    QString getFileName(const int listIndex);

    /**
     * @brief ファイルパスの設定
     * @param listIndex リストインデックス
     * @param filePath ファイルパス
     */
    void setFilePath(const int listIndex, const QString &filePath);

    /**
     * @brief ファイルパスの取得
     * @param listIndex リストインデックス
     * @return ファイルパス
     */
    QString getFilePath(const int listIndex);

    /**
     * @brief 拡張子の設定
     * @param listIndex リストインデックス
     * @param extension 拡張子
     */
    void setExtension(const int listIndex, const QString &extension);

    /**
     * @brief 拡張子の取得
     * @param listIndex リストインデックス
     * @return 拡張子
     */
    QString getExtension(const int listIndex);

private:
    QHash<int, QByteArray> _roles;                  //!< ロールデータ
    QList<MeasurementResultFileListItems> _data;    //!< リストデータ
};

#endif // MEASUREMENTRESULTFILECOMPONENTLIST_H
