/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "measurementresultoperationlist.h"
#include <QMetaEnum>

MeasurementResultOperationList::MeasurementResultOperationList(QObject *parent) :
    QAbstractListModel(parent), _roles(), _data()
{
    if (_roles.isEmpty()) {
        int metaIndex = metaObject()->indexOfEnumerator("MeasurementResultFileOperationListRoles");
        QMetaEnum metaEnum = metaObject()->enumerator(metaIndex);
        _roles.insert(MeasurementResultFileOperationListRoles::NumberRole,
                      metaEnum.valueToKey(MeasurementResultFileOperationListRoles::NumberRole));
        _roles.insert(MeasurementResultFileOperationListRoles::FileNameRole,
                      metaEnum.valueToKey(MeasurementResultFileOperationListRoles::FileNameRole));
        _roles.insert(MeasurementResultFileOperationListRoles::PathRole,
                      metaEnum.valueToKey(MeasurementResultFileOperationListRoles::PathRole));
        _roles.insert(MeasurementResultFileOperationListRoles::IsSelectedRole,
                      metaEnum.valueToKey(MeasurementResultFileOperationListRoles::IsSelectedRole));
        _roles.insert(MeasurementResultFileOperationListRoles::UserDataRole,
                      metaEnum.valueToKey(MeasurementResultFileOperationListRoles::UserDataRole));
        _roles.insert(MeasurementResultFileOperationListRoles::DateRole,
                      metaEnum.valueToKey(MeasurementResultFileOperationListRoles::DateRole));
    }
}

MeasurementResultOperationList::~MeasurementResultOperationList()
{
    _data.clear();
}

int MeasurementResultOperationList::rowCount(const QModelIndex &parent) const
{
    Q_UNUSED(parent);
    if (_data.isEmpty()) {
        return 0;
    } else {
        return _data.size();
    }
}

QHash<int, QByteArray> MeasurementResultOperationList::roleNames() const
{
    return _roles;
}

QVariant MeasurementResultOperationList::data(const QModelIndex &index, int role) const
{
    if (_data.empty()) {
        return QVariant();
    }

    switch (role) {
    case MeasurementResultFileOperationListRoles::NumberRole:
        return QVariant(_data.at(index.row()).number);

    case MeasurementResultFileOperationListRoles::FileNameRole:
        return QVariant(_data.at(index.row()).fileName);

    case MeasurementResultFileOperationListRoles::PathRole:
        return QVariant(_data.at(index.row()).filePath);

    case MeasurementResultFileOperationListRoles::IsSelectedRole:
        return QVariant(_data.at(index.row()).isSelected);

    case MeasurementResultFileOperationListRoles::UserDataRole:
        return QVariant(_data.at(index.row()).userDataName);

    case MeasurementResultFileOperationListRoles::DateRole:
        return QVariant(_data.at(index.row()).date);

    default:
        return QVariant();
    }
}

void MeasurementResultOperationList::setListData(QList<MeasurementResultOperationListItems> items)
{
    beginResetModel();
    _data.clear();
    _data = items;
    endResetModel();
}

QString MeasurementResultOperationList::getFileName(const int listIndex)
{
    if (rowCount() - 1 < listIndex || listIndex < 0) {
        return "";
    }

    return _data[listIndex].fileName;
}

QString MeasurementResultOperationList::getFilePath(const int listIndex)
{
    if (rowCount() -1 < listIndex || listIndex < 0) {
        return "";
    }

    return _data[listIndex].filePath;
}

bool MeasurementResultOperationList::getIsSelected(const int listIndex)
{
    if (rowCount() -1 < listIndex || listIndex < 0) {
        return false;
    }

    return _data[listIndex].isSelected;
}

void MeasurementResultOperationList::setIsSelected(const int listIndex, const bool isSelected)
{
    if (rowCount() - 1 < listIndex || listIndex < 0) {
        return;
    }

    if (_data[listIndex].isSelected == isSelected) {
        return;
    }

    _data[listIndex].isSelected = isSelected;
    emit dataChanged(index(listIndex), index(listIndex), QVector<int>() = { MeasurementResultFileOperationListRoles::IsSelectedRole });;
}
