/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef MEASUREMENTRESULTFILEOPERATIONLIST_H
#define MEASUREMENTRESULTFILEOPERATIONLIST_H

#include <QAbstractListModel>

/**
 * @brief リストアイテム
 */
struct MeasurementResultOperationListItems {
    unsigned int number;   //!< No.
    QString fileName;      //!< ファイル名
    QString filePath;      //!< ファイルパス
    bool    isSelected;    //!< 選択の有無 (true: 選択済み, false: 未選択)
    QString userDataName;  //!< ファイル名のユーザーがつけた部分のみ[日付_プリフィックス_[dataName.csv]]
    QString date;          //!< 日付
    MeasurementResultOperationListItems(unsigned int paramNumber = 0,
                                            QString paramFileName = "",
                                            QString paramFilePath = "",
                                            bool paramSelected = false,
                                            QString paramUserDataName= "",
                                            QString paramDate        = "")
    {
        number      = paramNumber;
        fileName    = paramFileName;
        filePath    = paramFilePath;
        isSelected  = paramSelected;
        userDataName= paramUserDataName;
        date        = paramDate;
    }
};

/**
 * @brief 測定結果データ操作用のリストクラス
 */
class MeasurementResultOperationList : public QAbstractListModel
{
    Q_OBJECT
    Q_ENUMS(MeasurementResultFileOperationListRoles)

public:

    /**
     * @brief 測定結果データ操作用ロール定義
     */
    enum MeasurementResultFileOperationListRoles {
        NumberRole = Qt::UserRole + 90,     //!< No.
        FileNameRole,                       //!< データ (ファイル名)
        PathRole,                           //!< パス
        IsSelectedRole,                     //!< 選択有無
        UserDataRole,                       //!< ファイル名のユーザーがつけた部分のみ[日付_プリフィックス_[dataName.csv]]
        DateRole,                           //!< 日付
    };

    /**
     * @brief コンストラクタ
     * @param parent 親オブジェクト
     */
    MeasurementResultOperationList(QObject *parent = nullptr);

    /**
     * @brief デストラクター
     */
    ~MeasurementResultOperationList();

    /**
     * @brief 測定結果数を返す
     * @return 測定結果数
     */
    int rowCount(const QModelIndex &parent = QModelIndex()) const override;

    /**
     * @brief ロール情報取得
     * @return ロール情報
     */
    QHash<int, QByteArray> roleNames() const override;

    /**
     * @brief 測定データ取得
     * @param index データの位置
     * @param role ロール
     * @return 測定データ
     */
    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayPropertyRole) const override;

    /**
     * @brief リストデータを設定する
     * @param items リストデータ
     */
    void setListData(QList<MeasurementResultOperationListItems> items);

    /**
     * @brief ファイル名の取得
     * @param listIndex リストインデックス
     * @return ファイル名
     */
    QString getFileName(const int listIndex);

    /**
     * @brief ファイルパスの取得
     * @param listIndex リストインデックス
     * @return ファイルパス
     */
    QString getFilePath(const int listIndex);

    /**
     * @brief 選択の有無を取得
     * @param listIndex リストインデックス
     * @return 選択の有無
     */
    bool getIsSelected(const int listIndex);

    /**
     * @brief 選択の有無を設定
     * @param listIndex リストインデックス
     */
    void setIsSelected(const int listIndex, const bool isSelected);

private:
    QHash<int, QByteArray> _roles;                        //!< ロールデータ
    QList<MeasurementResultOperationListItems> _data; //!< リストデータ
};

#endif // MEASUREMENTRESULTFILEOPERATIONLIST_H

