/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef MEASUREMENTRESULTOPERATIONVIEWMODELBASE_H
#define MEASUREMENTRESULTOPERATIONVIEWMODELBASE_H

#include "abstractviewmodel.h"
#include "measurementresultoperationlist.h"
#include "buttonoperation.h"

/**
 * @brief 測定データ操作画面のベースクラス
 */
class MeasurementResultOperationViewModelBase : public AbstractViewModel
{
    Q_OBJECT
signals:
    /**
     * @brief リストのページを移動
     */
    void scrollPage(QVariant);
public:
    /**
     * @brief コンストラクタ
     * @param ScreenId 画面 ID
     * @param model Model クラスのポインター
     * @param objectName 紐付けを行うQMLのObject名
     * @param parent 親オブジェクト
     */
    explicit MeasurementResultOperationViewModelBase(ScreenId ScreenId, LevelCheckerModel *&model,QString objectName, QObject *parent = nullptr);

    /**
     * @brief デストラクタ
     */
    virtual ~MeasurementResultOperationViewModelBase();

    /**
     * @brief 画面Active時の処理
     */
    virtual void activate(void) override;

    /**
     * @brief 画面Deactive時の処理
     */
    virtual void deactivate(void) override;

    /**
     * @brief 画面を閉じるときに呼び出すスレッド停止処理
     */
    virtual void suspend(void) override;
protected:
    /**
     * @brief ボタン押下時イベント受信時の処理
     * @param id ボタンid
     */
    virtual void onKeyStatus(ButtonId id) override;

    /**
     * @brief カーソル移動
     * @param buttonId 押下したボタンID
     */
    void moveCursor(ButtonId buttonId);

    /**
     * @brief ENTERボタン押下時の処理
     */
    void pressEnterButton(void);

    /**
     * @brief 処理ボタン押下時の処理
     */
    virtual void pressExecuteButton(void);

    /**
     * @brief 全選択/解除ボタン押下時の処理
     */
    void pressAllSelectCancelButton(void);

    /**
     * @brief リスト表示の更新を行う
     */
    void updateListData(void);

    /**
     * @brief 処理対象のパスのリストを取得
     * @return 処理対象のパスリスト
     */
    QStringList getTargetPathList(void);

    QSharedPointer<MeasurementResultOperationList> _listData; //!< 測定データリスト
    int _listIndex;                                           //!< 選択中のインデックス
    bool _cursoredButtonArea;                                 //!< カーソルがボタンエリアに入っているかどうか
    ButtonOperation _buttonOperation;                         //!< ボタン操作情報
    QString _activeButton;                                    //!< 活性ボタンID
    int _totalPage;                                           //!< リスト全ページ数
    int _currentPage;                                         //!< 選択中のページ数
private:
    void onButtonPress(ButtonId id) override;

    /**
     * @brief リスト表示用のデータリストを取得
     * @param dirList リスト表示用の対象のファイルのディレクトリ名のリスト
     * @return リスト表示用のデータリスト
     * @note データリストは作成日でソートした状態となっている
     */
    QList<QFileInfo> displayDataList(QStringList dirList);

    /**
     * @brief 選択しているページを求める
     */
    void calcCurrentPage(void);
};

#endif // MEASUREMENTRESULTOPERATIONVIEWMODELBASE_H
