/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef MEASUREMENTRESULTPNGDATAVIEWMODEL_H
#define MEASUREMENTRESULTPNGDATAVIEWMODEL_H

#include "abstractviewmodel.h"
#include "buttonoperation.h"

/**
 * @brief 測定結果データ表示(PNG) ViewModel
 */
class MeasurementResultPngDataViewModel : public AbstractViewModel
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクター
     * @param screenId 画面 ID
     * @param model Model クラスのポインター
     * @param parent 親オブジェクト
     */
    explicit MeasurementResultPngDataViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent = nullptr);

    /**
     * @brief デストラクタ
     */
    virtual ~MeasurementResultPngDataViewModel();

    /**
     * @brief 画面Active 時の処理
     */
    void activate() override;

protected slots:
    /**
     * @brief ボタン押下の状態を受信
     * @param id ボタン ID
     */
    virtual void onKeyStatus(ButtonId id) override;
signals:
    /**
     * @brief 共有情報のロード要求
     */
    void requestLoadTakeOver(void);
};

#endif // MEASUREMENTRESULTPNGDATAVIEWMODEL_H
