/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef USERMEASUREMENTSETTINGMENUVIEWMODEL_H
#define USERMEASUREMENTSETTINGMENUVIEWMODEL_H

#include "abstractviewmodel.h"
#include "buttonoperation.h"

/**
 * @brief ユーザ測定設定メニュー ViewModel
 */
class UserMeasurementSettingMenuViewModel : public AbstractViewModel
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクター
     * @param screenId 画面 ID
     * @param model Model クラスのポインター
     * @param parent 親オブジェクト
     */
    explicit UserMeasurementSettingMenuViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent = nullptr);

    /**
     * @brief デストラクタ
     */
    virtual ~UserMeasurementSettingMenuViewModel();

    /**
     * @brief 画面Active 時の処理
     */
    void activate() override;

    /**
     * @brief 遷移先画面で参照する遷移前画面のデータ設定
     */
    virtual void setTakeOver() override;

signals:
    void requestSetTakeOver(QVariant, QVariant);

protected:
    /**
     * @brief ボタン押下時イベント受信時の処理
     * @param id ボタンID
     */
    virtual void onKeyStatus(ButtonId id) override;

    /**
     * @brief ダイアログからのAccept受信処理
     * @param popupId ダイアログID
     * @param okOnly 結果
     */
    void onAccept(PopupId popupId, bool okOnly) override;

    /**
     * @brief ダイアログからのReject受信処理
     * @param popupId ダイアログID
     */
    void onReject(PopupId popupId) override;


private slots:
    /**
     * @brief 画面遷移要求の受信時処理
     * @param condition 画面IDリストのインデックス
     */
    virtual void onRequest(int condition) override;

private:
    void onButtonPress(ButtonId id) override;

    /**
     * @brief カーソル移動
     * @param buttonId 押下ボタンのID
     */
    void moveCursor(ButtonId buttonId);

    /**
     * @brief ユーザ測定設定データを一括削除する
     */
    void removeAllUserMeasurementSettingData(void);

    /**
     * @brief ユーザ測定設定データを本体からUSBにコピーする
     */
    void copyUserMeasurementSettingDataToUsb(void);

    /**
     * @brief ユーザ測定設定データをUSBから本体にコピーする
     */
    void copyUserMeasurementSettingDataToBody(void);

    /**
     * @brief データロガー設定データを本体からUSBにコピーする
     */
    void copyDataLoggerMeasurementSettingDataToUsb(void);

    /**
     * @brief USB状態エラー発生チェック
     * @return true: USB状態エラーが発生している、false: 発生していない
     */
    bool isErrorUsbStatus(void);

    /**
     * @brief プロパティに Bool 値を設定
     * @param objectName オブジェクト名
     * @param propertyName プロパティ名
     * @param value 設定する Bool 値
     */
    void setBoolProperty(QString objectName, QString propertyName, bool value);

    static const int BUTTON_COLUMN_NUMBER;
    static const int BUTTON_ROW_NUMBER;

    ButtonOperation _buttonOperation;  //!< ボタン操作情報
    QString _activeButton;             //!< 活性ボタンID
};

#endif // USERMEASUREMENTSETTINGMENUVIEWMODEL_H
