/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef ATTRIBUTES_H
#define ATTRIBUTES_H

#include <QObject>
#include "abstractviewmodel.h"

/**
 * @brief ViewModel - View 間で連携するデータ
 */
class Attributes : public QObject
{
    Q_OBJECT
    Q_PROPERTY(QString qmlPath READ qmlPath WRITE setQmlPath)
    Q_PROPERTY(QVariant viewModel READ viewModel WRITE setViewModel)
    Q_PROPERTY(QVariantMap takeOver READ takeOver WRITE setTakeOver)
public:
    /**
     * @brief コンストラクター
     * @param parent 親オブジェクト
     */
    explicit Attributes(QObject *parent = nullptr);

    /**
     * @brief デストラクター
     */
    ~Attributes();

    /**
     * @brief QML ファイルのパスを返す
     * @return QML ファイルのパス
     */
    QString qmlPath(void) const
    {
        return _qmlPath;
    }

    /**
     * @brief QML ファイルのパスを設定する
     * @param qmlPath QML ファイルのパス
     */
    void setQmlPath(const QString &qmlPath)
    {
        _qmlPath = qmlPath;
    }

    /**
     * @brief QML ファイルに対応する ViewModel を返す
     * @return　ViewModel
     */
    QVariant viewModel(void) const
    {
        return QVariant::fromValue(_viewModel);
    }

    /**
     * @brief QML ファイルに対応する ViewModel を設定する
     * @param viewModel ViewModel
     */
    void setViewModel(QVariant viewModel)
    {
        _viewModel = viewModel;
    }

    /**
     * @brief 引き継ぎデータの設定
     * @param takeOver 引き継ぎデータ
     */
    void setTakeOver(const QVariantMap &takeOver)
    {
        _takeOver = takeOver;
    }

    /**
     * @brief 引き継ぎデータを返す
     * @return 引き継ぎデータ
     */
    QVariantMap takeOver(void) const
    {
        return _takeOver;
    }

    /**
     * @brief 引き継ぎデータを設定する
     */
    void setTakeOverData();

    /**
     * @brief 引き継ぎデータのクリアー
     */
    void clearTakeOver(void);

    /**
     * @brief 引き継ぎデータの項目の値を変更する
     * @param key キー
     * @param value 値
     */
    void change(const QString &key, QVariant value);

    /**
     * @brief 引き継ぎデータの項目の値を削除する
     * @param key キー
     */
    void remove(const QString &key);

signals:

private:
    QString _qmlPath;                   //!< qml ファイルのパス
    QVariant _viewModel;                //!< QML に対応する ViewModel
    QVariantMap _takeOver;              //!< 引き継ぎデータ
};

#endif // ATTRIBUTES_H
