/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "buttonoperation.h"


ButtonOperation::ButtonOperation(QObject *parent)
    : QObject(parent)
    , _columnNumber(0)
    , _rowNumber(0)
{

}

ButtonOperation::~ButtonOperation()
{
}

void ButtonOperation::setButtonName(int columnNumber, int rowNumber, QVector<QVector<QString>> &buttonNameData)
{
    _columnNumber = columnNumber;
    _rowNumber    = rowNumber;

    _buttonObject.clear();

    for (int colunmIndex = 0; colunmIndex < columnNumber; colunmIndex++) {
        _buttonObject.append(QVector<QString>());

        for (int rowIndex = 0; rowIndex < rowNumber; rowIndex++) {
            _buttonObject[colunmIndex].append(buttonNameData[colunmIndex][rowIndex]);
        }
    }
}

bool ButtonOperation::nextActiveObject(ButtonId buttonId, QString &nextObjectName)
{
    int nowColumn = 0;
    int nowRow = 0;

    for (int colunmIndex = 0; colunmIndex < _columnNumber; colunmIndex++) {
        for (int rowIndex = 0; rowIndex < _rowNumber; rowIndex++) {
            if (_buttonObject[colunmIndex][rowIndex] == _activeObject) {
                nowColumn = colunmIndex;
                nowRow = rowIndex;
                break;
            }
        }
    }

    QString nextActive;
    nextActive.clear();

    if (BUTTON_UP == buttonId) {
        for (int colunmIndex = nowColumn; colunmIndex > 0; colunmIndex--) {
            if (_buttonObject[colunmIndex - 1][nowRow] != "") {
                nextActive = _buttonObject[colunmIndex - 1][nowRow];
                break;
            }
        }

        if (nextActive.isEmpty()) {
            for (int colunmIndex = _columnNumber - 1; colunmIndex >= nowColumn; colunmIndex--) {
                if (_buttonObject[colunmIndex][nowRow] != "") {
                    nextActive = _buttonObject[colunmIndex][nowRow];
                    break;
                }
            }
        }
    } else if (BUTTON_DOWN == buttonId) {
        for (int colunmIndex = nowColumn; colunmIndex < _columnNumber - 1; colunmIndex++) {
            if (_buttonObject[colunmIndex + 1][nowRow] != "") {
                nextActive = _buttonObject[colunmIndex + 1][nowRow];
                break;
            }
        }

        if (nextActive.isEmpty()) {
            for (int colunmIndex = 0; colunmIndex < nowColumn; colunmIndex++) {
                if (_buttonObject[colunmIndex][nowRow] != "") {
                    nextActive = _buttonObject[colunmIndex][nowRow];
                    break;
                }
            }
        }
    } else if (BUTTON_LEFT == buttonId) {
        for (int rowIndex = nowRow; rowIndex > 0; rowIndex--) {
            if (_buttonObject[nowColumn][rowIndex - 1] != "") {
                nextActive = _buttonObject[nowColumn][rowIndex - 1];
                break;
            }
        }

        if (nextActive.isEmpty()) {
            for (int rowIndex = _rowNumber - 1; rowIndex >= nowRow; rowIndex--) {
                if (_buttonObject[nowColumn][rowIndex] != "") {
                    nextActive = _buttonObject[nowColumn][rowIndex];
                    break;
                }
            }
        }
    } else if (BUTTON_RIGHT == buttonId) {
        for (int rowIndex = nowRow; rowIndex < _rowNumber - 1; rowIndex++) {
            if (_buttonObject[nowColumn][rowIndex + 1] != "") {
                nextActive = _buttonObject[nowColumn][rowIndex + 1];
                break;
            }
        }

        if (nextActive.isEmpty()) {
            for (int rowIndex = 0; rowIndex < nowRow; rowIndex++) {
                if (_buttonObject[nowColumn][rowIndex] != "") {
                    nextActive = _buttonObject[nowColumn][rowIndex];
                    break;
                }
            }
        }
    } else {}

    nextObjectName = nextActive;

    if (nextObjectName.isEmpty()) {
        return false;
    } else {
        // 呼び元で setProperty を実施する事を通常使用と考え、設定漏れを考慮し更新する
        // 呼び元で setProperty を実施しない場合は、戻す必要がある
        setActiveObject(nextObjectName);
        return true;
    }
}

void ButtonOperation::setActiveObject(QString activeObjectName)
{
    _activeObject = activeObjectName;
}
