/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef BUTTONOPERATION_H
#define BUTTONOPERATION_H

#include <QObject>
#include <QString>
#include <QVector>
#include "buttonid.h"


/**
 * @brief ボタン操作クラス
 */
class ButtonOperation : public QObject
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクタ
     * @param parent 親オブジェクト
     */
    explicit ButtonOperation(QObject *parent = nullptr);

    /**
     * @brief デストラクタ
     */
    ~ButtonOperation();

    /**
     * @brief データセット
     * @param columnNumber   行数
     * @param rowNumber      列数
     * @param buttonNameData 全ボタンのオブジェクト名
     */
    void setButtonName(int columnNumber, int rowNumber, QVector<QVector<QString>> &buttonNameData);

    /**
     * @brief ボタン操作後アクティブにするオブジェクト名を取得
     * @param buttonId       操作ボタンID
     * @param nextObjectName 次にアクティブにするオブジェクト名
     */
    bool nextActiveObject(ButtonId buttonId, QString &nextObjectName);

    /**
     * @brief 現アクティブオブジェクト名の設定
     * @param activeObjectName 現在アクティブの（基準とする）オブジェクト名
     */
    void setActiveObject(QString activeObjectName);

private:
    QVector<QVector<QString>> _buttonObject;

    QString _activeObject;
    int _columnNumber;
    int _rowNumber;
};

#endif // BUTTONOPERATION_H
