/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef BUTTONPROHIBITIONDATA_H
#define BUTTONPROHIBITIONDATA_H

#include <QObject>
#include "buttonid.h"

/**
 * @brief ボタン禁則ID
 */
enum ButtonProhibitionId {
    BUTTON_PROHIBITION_001,     //!< 全て無効
    BUTTON_PROHIBITION_002,     //!< 無効：チャンネル Up、チャンネル Down、上、下、左、右、決定、画面 Save、データ Save、給電、Band、Scan
    BUTTON_PROHIBITION_003,     //!< 全て有効
    BUTTON_PROHIBITION_004,     //!< 無効：Band
    BUTTON_PROHIBITION_005,     //!< 無効：上、下
    BUTTON_PROHIBITION_006,     //!< 無効：上、下、画面 Save
    BUTTON_PROHIBITION_007,     //!< 無効：チャンネル Up、チャンネル Down、上、下、左、右、決定、画面 Save、データ Save、給電、Menu、Band、Scan
    BUTTON_PROHIBITION_008,     //!< 無効：チャンネル Up、チャンネル Down、画面 Save、データ Save、Scan
    BUTTON_PROHIBITION_009,     //!< 無効：チャンネル Up、チャンネル Down、画面 Save、データ Save、給電、Scan
    BUTTON_PROHIBITION_010,     //!< 無効：チャンネル Up、チャンネル Down、画面 Save、データ Save、給電、Band、Scan
    BUTTON_PROHIBITION_011,     //!< 無効：チャンネル Up、チャンネル Down、画面 Save、データ Save、給電、Menu、Band、Escape、Scan
    BUTTON_PROHIBITION_012,     //!< 無効：チャンネル Up、チャンネル Down、上、下、画面 Save、データ Save、Scan
    BUTTON_PROHIBITION_013,     //!< 無効：チャンネル Up、チャンネル Down、上、下、画面 Save、データ Save、給電、Scan
    BUTTON_PROHIBITION_014,     //!< 無効：チャンネル Up、チャンネル Down、上、下、画面 Save、データ Save、給電、Band、Scan
    BUTTON_PROHIBITION_015,     //!< 無効：チャンネル Up、チャンネル Down、上、下、画面 Save、データ Save、給電、Menu、Band、Scan
    BUTTON_PROHIBITION_016,     //!< 無効：チャンネル Up、チャンネル Down、上、下、左、右、画面 Save、データ Save、給電、Band、Scan
    BUTTON_PROHIBITION_017,     //!< 無効：チャンネル Up、チャンネル Down、上、下、画面 Save、データ Save、給電、Menu、Band、Home、User、Scan
    BUTTON_PROHIBITION_018,     //!< 無効：上、下、左、右、決定、画面 Save、データ Save、給電、Menu、Band、User、Scan
    BUTTON_PROHIBITION_019,     //!< 無効：チャンネル Up、チャンネル Down、画面 Save、データ Save、給電、Menu、Scan
    BUTTON_PROHIBITION_020,     //!< 無効：チャンネル Up、チャンネル Down、画面 Save、データ Save、給電、Scan
};

/**
 * @brief ボタン禁則情報構造体
 * @note 機器のボタンの数を配列の要素数とし、インデックスでどのボタンか識別する(ButtonId 列挙体で定義)
 */
struct ButtonProhibitionData {
    bool prohibition[BUTTON_ID_COUNT];   //!< 禁則有無
};

/**
 * @brief ボタン禁則情報クラス
 */
class ButtonProhibition : public QObject
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクタ
     * @param parent 親オブジェクト
     */
    explicit ButtonProhibition(QObject *parent = nullptr);

    /**
     * @brief デストラクタ
     */
    ~ButtonProhibition();

    /**
     * @brief ボタン禁則IDに対応したボタン禁則情報を取得する
     * @param id ボタン禁則ID
     * @return ボタン禁則情報
     */
    ButtonProhibitionData buttonProhibition(const ButtonProhibitionId &id) const;

private:
    QList<ButtonProhibitionData> _buttonProhibitions;   //!< ボタン禁則定義

    /**
     * @brief 初期化
     */
    void initialize(void);

};

#endif // BUTTONPROHIBITIONDATA_H
