/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "popupmanager.h"
#include "scanresultmodel.h"
#include "scanlockmodel.h"
#include "correcter.h"

static constexpr int BUTTON_COLUMN_NUMBER = 1;
static constexpr int BUTTON_COLUMN_NUMBER5 = 5;
static constexpr int BUTTON_ROW_NUMBER1 = 1;
static constexpr int BUTTON_ROW_NUMBER2 = 2;
static constexpr int BUTTON_ROW_NUMBER3 = 3;
static constexpr int BUTTON_ROW_NUMBER14 = 14;

static constexpr int KEYBOARD_INPUT_MAXNUM = 10;

static constexpr const char *PROPERTY_FILE_NAME =
    "fileName";               //!< キーボードのファイル名のプロパティ(BasicPopup.qml 参照)
static constexpr const char *PROPERTY_CURSOR_POSITION =
    "cursorPosition";   //!< キーボードのカーソル位置のプロパティ(BasicPopup.qml 参照)
static constexpr const char *FILE_NAME_INPUT =
    "FileNameInput";             //!< キーボードの入力用エレメントのオブジェクト名(BasicPopup.qml 参照)

static constexpr int SCAN_RESULT_ELEMENT_MAX = 7;   //!< スキャン結果リストの1行の要素数

static const QMap<PopupId, QString> POPUP_MESSAGE_MAP = {
    {POPUP_SCAN_CONFIRMATION,                               "SCAN しますか？"},                                                                                     //SCAN 実行確認
    {POPUP_SCANNING,                                        "SCAN"},                                                                                       // SCAN実行中
    {POPUP_SCAN_CANCEL,                                     "SCAN 中止しますか？"},                                                                                  // SCAN実行キャンセル
    {POPUP_SAVE_USER_SETTING_DATA,                          "USER_SETTING_DATA"},                                                                                  // ユーザ設定データ保存
    {POPUP_SAVE_CONFIRMATION,                               "設定を保存しますか？"},                                                                                  // 保存確認
    {POPUP_SELECT_SAVE_CONFIRMATION,                        "設定を上書きしますか？"},                                                                                  // 保存確認
    {POPUP_CANCEL_CONFIRMATION,                             "変更を破棄しますか？"},                                                                                  // 変更破棄確認
    {POPUP_SELECT_SAVE_DATA,                                "保存先を選択"},                                                                                         // 保存データ選択
    {POPUP_SAVE_MEASUREMENT_DATA,                           "MEASUREMENT_DATA"},                                                                                   // 測定データ保存
    {POPUP_INITIALIZE_CONFIRMATION,                         "初期化処理を実行します。よろしいですか？"},                                                                 // 初期化処理確認
    {POPUP_WRONG_INPUT_DATA,                                "入力データが正しくありません。"},                                                                          // 入力データ誤り
    {POPUP_DATA_LOGGER_KEYBOARD,                            ""/* メッセージなし */},                                                                                 // キーボード表示
    {POPUP_DATA_LOGGER_DELETE_CONFIRMATION,                 "測定項目を削除しますか？"},                                                                               // 削除操作確認
    {POPUP_DATA_LOGGER_DELETE_FILELIST_CONFIRMATION,        "ファイルを削除しますか？"},                                                                               // ファイルリスト削除操作確認
    {POPUP_DELETE_ALL_MEASUREMENT_CONFIRMATION,             "測定データを一括消去しますか？"},                                                                          // 測定データ一括削除確認
    {POPUP_DELETE_ALL_DATA_LOGGER_CONFIRMATION,             "保存データを全消去しますか？"},                                                                            // データロガー情報一括削除確認
    {POPUP_COPY_ALL_TO_USB_USER_SETTING_DATA_CONFIRMATION,  "全ユーザ設定(本体)⇒USBへコピーしますか？"},                                                                 // ユーザ設定データ書き込み確認(本体->USB)
    {POPUP_COPY_ALL_TO_BODY_USER_SETTING_DATA_CONFIRMATION, "全ユーザ設定(USB)⇒本体へコピーしますか？\n※本体のユーザ設定は書き換わります。"},                                 // ユーザ設定データ書き込み確認(USB->本体)
    {POPUP_COPY_ALL_TO_BODY_SELECT_USER_SETTING_DATA_CONFIRMATION, "どちらにコピーしますか？"},                                                                         // ユーザ設定データ書き込み場所選択(取り込みデータ1 or 取り込みデータ2)
    {POPUP_DELETE_ALL_USER_SETTING_DATA_CONFIRMATION,       "保存データを全消去しますか？"},                                                                            // ユーザ設定データ書き込み一括削除確認
    {POPUP_USB_FORMAT_CONFIRMATION,                         "USBをフォーマットしますか？"},                                                                            // USBフォーマット実行確認
    {POPUP_INPUT_FILENAME,                                  "CAPTURE_DATA"},                                                                                       // ファイル名入力用キーボード表示
    {POPUP_USB_FORMAT_RUNNING,                              "USBをフォーマット中"},                                                                                  // USBフォーマット実行中
    {POPUP_FAILURE_COPY_EXECUTE,                            "コピーに失敗しました。"},                                                                                // コピー失敗
    {POPUP_NOTHING_COPY_FILE,                               "コピー対象のファイルが存在しません。"},                                                                     // コピー元ファイル無し
    {POPUP_FAILURE_DELETE_EXECUTE,                          "削除に失敗しました。"},                                                                                  // 削除失敗
    {POPUP_FAILURE_FORMAT_EXECUTE,                          "USBのフォーマットに失敗しました。\nUSBを差し直してください。"},                                               // USBフォーマット失敗
    {POPUP_USB_NO_SPACE,                                    "USBの空き容量が足りません。"},                                                                            // USB容量なし
    {POPUP_POWER_SUPPLY_SELECT3,                            "給電しますか？"},                                                                                       // 給電選択(JCSAT, SCC)
    {POPUP_POWER_SUPPLY_SELECT2,                            "給電しますか？"},                                                                                       // 給電選択(その他)
    {POPUP_MEASUREMENT_CANCEL,                              "測定を中止しますか？"},                                                                                  // 測定キャンセル
    {POPUP_WRONG_LOCAL_OSCILLATOION_DATA,                   "入力データが正しくありません。\n10〜12GHzの範囲で入力してください。\nまた、未使用の場合は0GHzを入力してください。"},  // 局部発振周波数データ誤り
    {POPUP_FAILURE_NO_USB_CONFIRMATION,                     "処理の実行に失敗しました。\nUSBを接続しなおしてください。"},                                                      // USB接続依頼ダイアログ
    {POPUP_CONFIRM_UPDATE,                                  "アップデートしますか？\n※アップデート開始前にACアダプターを接続してください。"},                                 // アップデート確認
    {POPUP_UPDATING,                                        "ソフトウェアアップデート中\n電源を落とさないでください\n再起動後、USBを抜いてください"},                           // アップデート中
    {POPUP_CONFLICT_POWER_SUPPLY_SETTING,                   "給電設定が競合したため、給電なしに変更しました。"},                                                           // 給電設定競合
    {POPUP_POWER_SUPPLY_ERROR_MANUAL_MEASURING,             ""/* 使用しない */},                                                                                     // 給電異常(マニュアル測定中)
    {POPUP_POWER_SUPPLY_ERROR_USER_MEASURING,               ""/* 使用しない */},                                                                                     // 給電異常(USER測定中)
    {POPUP_SCAN_RESULT,                                     ""/* 使用しない */},                                                                                     // スキャン結果
    {POPUP_CONFIRM_DELETE_SELECTED_FILE,                    "選択したファイルを消去しますか？"},                                                                        // 選択ファイル削除確認ダイアログ
    {POPUP_CONFIRM_DELETE,                                  "保存データを削除中です。\nしばらくお待ちください。"},                                                                                          // コピー中ダイアログ
    {POPUP_CONFIRM_COPY_SELECTED_FILE,                      "選択したファイルをUSBメモリーにコピーしますか？"},                                                           // 選択ファイルコピー確認ダイアログ
    {POPUP_CONFIRM_COPY,                                    "USBにコピー中です。\nしばらくお待ちください。"},                                                                                          // コピー中ダイアログ
    {POPUP_CONFIRM_ALL_DELETE_FILE,                         "ファイルを一括消去しますか？"},                                                                           // ファイル一括削除確認ダイアログ
    {POPUP_CONFIRM_OVERWRITE_USER_LOGGER_DATA,              "同じファイル名が存在します。\n保存するファイル名を変更してください。"},                                                                           // ユーザデータロガー上書き確認ダイアログ
    {POPUP_CONFIRM_REGIST_SCAN_RESULT,                      "スキャン結果を保存しますか？"},                                                                           // スキャン結果保存確認ダイアログ
    {POPUP_DATA_LOGGER_USB_REMOVE_ERROR,                    "途中でUSBメモリが抜かれました。\n測定を停止します。"},                                                       // データロガー測定中にUSBが抜かれたことを示すダイアログ
    {POPUP_FAILURE_SETTING_RANGE_WRONG,                     "設定範囲が異なります。"},                                                                                // 設定範囲が異なることを示すダイアログ
    {POPUP_CONFIRM_EXECUTE_WITH_AUTO_POWER_OFF,             "オートパワーオフ設定が有効になっています。\n測定を開始しますか？"},                                             // オートパワーオフありでデータロガーを実行するか確認
    {POPUP_CONFIRM_ACQUIRE_MEASURE_DATA,                    "測定データを収集しますか？"},                                                                                  // 測定データ取得確認(マニュアル マルチ測定)
    {POPUP_MEASURING,                                       "測定データを収集中"},                                                                                          // 測定データ取得中
    {POPUP_MEASURE_CANCEL,                                  "測定データ収集を中止しますか？"},                                                                               // 測定データ取得キャンセル
    {POPUP_SCAN_NOT_APPLICABLE,                             ""/* 使用しない */},                                                                                    // スキャン対象外
    {POPUP_FAILURE_DATE_SETTING,                            "時刻が設定できませんでした。"},                                                                           // 時刻設定失敗
    {POPUP_MEASURE_COMPLETE,                                ""/* 使用しない */},                                                                                    // 測定データ取得完了
    {POPUP_CONFIRM_CHANGE_BAND,                             "既存データを破棄し、バンドを変更しますか？"},                                                                // 強制 Band 変更
    {POPUP_WRITE_ERROR,                                     "ファイル出力に失敗しました。"},                                                                            // ファイル出力失敗
    {POPUP_USER_SETTING_EXCEED_UPPER_LIMIT,                 "測定チャンネルが150件を超えています。"},                                                               // ユーザ設定のチャンネル数の上限超過
    {POPUP_DATA_LOGGER_SETTING_EXCEED_UPPER_LIMIT,           "測定チャンネルが50件を超えています。"},                                                               // データロガーのチャンネル数の上限超過
    {POPUP_SAME_FREQUENCY_CHANNEL,                          "同一CHが存在します。"},                                                                             // 同一周波数を入力したチャンネルの検知
    {POPUP_UNEXPECTED_ERROR,                                "予期しないエラーが発生しました。\n前の画面に戻ります。"},                                                // 予期しないエラーの発生(ex. 静電試験で qml ファイルを指すポインターが nullptr になった場合など)
    {POPUP_DISABLE_POWER_SUPPLY,                            "給電できません。バッテリーを充電してください"},
    {POPUP_MEASURE_CATV_UPSTREAM_NOT_APPLICABLE,            ""/* 使用しない */},                                                                               // 光入力設定のとき CATV 上りは測定不可
    {POPUP_DATA_LOGGER_MESUREMENT_COMLETE,                  "測定を完了しました。"},                                                                             // データロガー取得完了
    {POPUP_DATA_LOGGER_MAX_SAVE_FILE,                       "データロガー測定データの保存上限に達しました。\n不要な測定データを削除してください。"},                       // データロガー測定データ保存上限
    {POPUP_FAILURE_READ_USER_SETTING_FILE,                  "測定設定の読み込みに失敗しました。"},
    {POPUP_DATA_SINGLE_MAX_SAVE_FILE,                       "シングル測定データの保存上限に達しました。\n不要な測定データを削除してください。"},                    // シングル測定データ保存上限
    {POPUP_DATA_MULTI_MAX_SAVE_FILE,                        "マルチ測定データの保存上限に達しました。\n不要な測定データを削除してください。"},                    // マルチ測定データ保存上限
};

PopupManager::PopupManager(LevelCheckerModel *&model, QObject *parent)
    : QObject(parent)
    , _model(model)
    , _basicPopup(nullptr)
    , _strongPopup(nullptr)
    , _popupAlereadyOpened(false)
    , _strongPopupAlreadyOpened(false)
    , _isOpened(false)
    , _buttonOperation(new ButtonOperation(this))
    , _activeButton()
    , _threeButtonData({{{"m1"}, {"m3"}, {"m2"}},})
    , _twoButtonData({{{"m1"}, {"m2"}},})
    , _oneButtonData({{{"m1"}},})
    , _openPopupId(POPUP_ID_COUNT)
#include "popup.inc"    // beautifier の悪影響で保存時に誤変換されてコンパイルエラーになるため別定義する
    , _fileNameInput(nullptr)
    , _fileName()
    , _saveLocation(SAVE_MEASUREMENT_DATA)
    , _pressedButtonId(BUTTON_UNKNOWN)
    , _pressAndHoldTimer(new QTimer())
    , _pressAndHoldTimerInterval(0)
    , _pressCount(0)
    , _scanLockModel(nullptr)
    , _scanResultModel(nullptr)
    , _catvChannelDefMap()
    , _noValidScanResult(false)
    , _lowBatteryPopup(nullptr)
    , _isRejectScanResult(false)
    , _keyboardPattern(KEYBORAD_ALPHANUMERIC_UPPER_LOWER)
{
    connect(_model, SIGNAL(keyStatus(LC70_KEY_STAT_T)), this, SLOT(onKeyStatus(LC70_KEY_STAT_T)));
    connect(_pressAndHoldTimer, SIGNAL(timeout()), this, SLOT(detectPressAndHold()));
    connect(_model, SIGNAL(lowBatteryStatusChanged(bool)), this, SLOT(onLowBatteryStatusChanged(bool)));
}

PopupManager::~PopupManager()
{

}
bool PopupManager::open(PopupId popupId, bool focedDisplay)
{

    if (_popupAlereadyOpened) {
        if (focedDisplay) {
            close();
        } else {
            return false;
        }
    }

    if (_scanLockModel != nullptr) {
         _scanLockModel->clear();
         _scanLockModel = nullptr;
     }

    // [Memo]
    //  BasicPopup.qml の layoutType との関係
    //  requestToOpenPopup() の第1引数で表示するポップアップのレイアウトの指定を行う
    //  NORMAL_LAYOUT                    :  メッセージ, ボタン2つのレイアウト
    //  ONE_BUTTON_LAYOUT                :  メッセージ, ボタン1つのレイアウト
    //  PROGRESSBAR_LAYOUT               :  メッセージ, プログレスバー, ボタン1つのレイアウト
    //  KEYBORAD_LAYOUT                  :  キーボードのレイアウト
    //  MESSAGE_LAYOUT                   :  メッセージのみ、ボタンなしのレイアウト
    //  POWER_SUPPLY_SELECT_LAYOUT       :  給電選択用のレイアウト
    //  SCAN_RESULT_LAYOUT               :  スキャン結果レイアウト
    //  THREE_BUTTON_LAYOUT              :  メッセージ, ボタン3つのレイアウト
    //  PROGRESSBAR_LABELBUTTON_LAYOUT   :  メッセージ, プログレスバー, ボタン1つのレイアウト

    switch (popupId) {
    case POPUP_DELETE_ALL_MEASUREMENT_CONFIRMATION:             // 測定データ一括削除確認
    case POPUP_DELETE_ALL_DATA_LOGGER_CONFIRMATION:             // データロガー情報一括削除確認
    case POPUP_COPY_ALL_TO_USB_USER_SETTING_DATA_CONFIRMATION:  // ユーザ設定データ書き込み確認(本体->USB)
    case POPUP_COPY_ALL_TO_BODY_USER_SETTING_DATA_CONFIRMATION: // ユーザ設定データ書き込み確認(USB->本体)
    case POPUP_DELETE_ALL_USER_SETTING_DATA_CONFIRMATION:       // ユーザ設定データ書き込み一括削除確認
    case POPUP_USB_FORMAT_CONFIRMATION:                         // USBフォーマット実行確認
    case POPUP_CONFIRM_DELETE_SELECTED_FILE:                    // 選択ファイル削除確認ダイアログ
    case POPUP_CONFIRM_ALL_DELETE_FILE:                         // ファイル一括削除確認ダイアログ
#ifdef NEW_USER_SETTING
    case POPUP_CONFIRM_CHANGE_BAND:                             // 既存データのバンド変更確認ダイアログ
#endif
        // はい/いいえボタンのポップアップ表示（デフォルトがいいえ）
        setupYesNoButtonPopup(POPUP_MESSAGE_MAP[popupId], true);
        break;
    case POPUP_CONFIRM_ACQUIRE_MEASURE_DATA:                    // 測定データ取得確認(マニュアル マルチ測定)
    case POPUP_SCAN_CONFIRMATION:                               // SCAN 実行確認
    case POPUP_SAVE_CONFIRMATION:                               // 保存確認
    case POPUP_SELECT_SAVE_CONFIRMATION:                        // 保存確認
    case POPUP_CANCEL_CONFIRMATION:                             // 変更破棄確認
    case POPUP_INITIALIZE_CONFIRMATION:                         // 初期化処理確認
    case POPUP_DATA_LOGGER_DELETE_CONFIRMATION:                 // 削除操作確認
    case POPUP_DATA_LOGGER_DELETE_FILELIST_CONFIRMATION:        // ファイルリスト削除操作確認
    case POPUP_POWER_SUPPLY_SELECT3:                            // 給電選択(JCSAT, SCC)  // two button
    case POPUP_POWER_SUPPLY_SELECT2:                            // 給電選択(その他)
    case POPUP_MEASUREMENT_CANCEL:                              // 測定キャンセル
    case POPUP_CONFIRM_EXECUTE_WITH_AUTO_POWER_OFF:             // オートパワーオフありでデータロガーを実行するか確認
        // はい/いいえボタンのポップアップ表示（デフォルトがはい）
        setupYesNoButtonPopup(POPUP_MESSAGE_MAP[popupId]);
        break;
    case POPUP_MEASURE_CANCEL:                                  // 測定データ取得キャンセル
    case POPUP_SCAN_CANCEL:                                     // SCAN実行キャンセル
        // strongPopup
        emitRequestToOpenStrongPopup(POPUP_MESSAGE_MAP[popupId], "はい", "いいえ");
        createStrongPopupConnection();
        setTwoButton();
        break;
    case POPUP_SELECT_SAVE_DATA: {                              // 保存データ選択
        emitRequestToOpenPopup(NORMAL_LAYOUT, POPUP_MESSAGE_MAP[popupId], "測定データに保存", "ユーザ設定に保存");
        createPopupConnection();
        setTwoButton();
        break;
    }
    case POPUP_CONFIRM_UPDATE: {                                // アップデート確認
        QString updateVersion;
        // バージョン表示
        _model->getUpdateVersion(updateVersion);
        updateVersion = "バージョン " + updateVersion + " へ" + POPUP_MESSAGE_MAP[popupId];
#if 1	//20210625_dx5
        emitRequestToOpenPopup(CONFIRM_UPDATE_LAYOUT, updateVersion, "はい", "いいえ");
        createPopupConnection();
        setTwoButton();
#else
        // はい/いいえボタンのポップアップ表示（デフォルトがはい）
        setupYesNoButtonPopup(updateVersion);
#endif
        break;
    }
    case POPUP_UPDATING: {                                      // アップデート中
        emitRequestToOpenPopup(UPDATE_LAYOUT, POPUP_MESSAGE_MAP[popupId]);
        createPopupConnection();
        setTwoButton(false, false); // ボタンを非表示にする
        break;
    }
    case POPUP_COPY_ALL_TO_BODY_SELECT_USER_SETTING_DATA_CONFIRMATION: {
#if 1	//20210625_dx5
        emitRequestToOpenPopup(NORMAL_LAYOUT, POPUP_MESSAGE_MAP[popupId], "取込みデータ1", "取込みデータ2");
#else		
        emitRequestToOpenPopup(NORMAL_LAYOUT, POPUP_MESSAGE_MAP[popupId], "取り込みデータ1", "取り込みデータ2");
#endif
        createPopupConnection();
        setTwoButton();
        break;
    }
    case POPUP_WRONG_INPUT_DATA:                                // 入力データ誤り
    case POPUP_FAILURE_COPY_EXECUTE:                            // コピー失敗
    case POPUP_FAILURE_DELETE_EXECUTE:                          // 削除失敗
    case POPUP_NOTHING_COPY_FILE:                               // コピー元ファイル無し
    case POPUP_FAILURE_FORMAT_EXECUTE:                          // USBフォーマット失敗
    case POPUP_USB_NO_SPACE:                                    // USB容量なし
    case POPUP_WRONG_LOCAL_OSCILLATOION_DATA:                   // 局部発振周波数データ誤り
    case POPUP_FAILURE_NO_USB_CONFIRMATION:                     // USB接続依頼ダイアログ
    case POPUP_CONFLICT_POWER_SUPPLY_SETTING:                   // 給電設定競合
    case POPUP_WRITE_ERROR:                                     // ファイル出力失敗
    case POPUP_USER_SETTING_EXCEED_UPPER_LIMIT:                 // チャンネル数上限超過
    case POPUP_DATA_LOGGER_SETTING_EXCEED_UPPER_LIMIT:          // チャンネル数上限超過
    case POPUP_SAME_FREQUENCY_CHANNEL:                          // 同一周波数を入力したチャンネル検知
    case POPUP_UNEXPECTED_ERROR:                                // 予期しないエラーの発生
        // 戻るボタンのポップアップ表示
        setupOneButtonPopup(POPUP_MESSAGE_MAP[popupId], "戻る");
        break;
    case POPUP_DATA_LOGGER_USB_REMOVE_ERROR:                    // データロガー測定中にUSBが抜かれたことを示すダイアログ
    case POPUP_FAILURE_SETTING_RANGE_WRONG:                     // 設定範囲が異なることを示すダイアログ
    case POPUP_DATA_LOGGER_MESUREMENT_COMLETE:                  // データロガー取得完了
    case POPUP_DATA_LOGGER_MAX_SAVE_FILE:                       // データロガー測定データ保存上限
    case POPUP_DATA_SINGLE_MAX_SAVE_FILE:                       // シングル測定データ保存上限
    case POPUP_DATA_MULTI_MAX_SAVE_FILE:                        // マルチ測定データ保存上限
#ifdef NEW_USER_SETTING
    case POPUP_CONFIRM_OVERWRITE_USER_LOGGER_DATA:              // ユーザデータロガー上書き確認ダイアログ
#endif
        // はいボタンのポップアップ表示
        setupOneButtonPopup(POPUP_MESSAGE_MAP[popupId], "はい");
        break;
    case POPUP_FAILURE_DATE_SETTING:                            // 時刻設定失敗
    case POPUP_DISABLE_POWER_SUPPLY:                            // バッテリーレベルが 10% 以下のため給電不可
    case POPUP_FAILURE_READ_USER_SETTING_FILE:                  // ユーザ設定ファイル読み込みエラー
        // OKボタンのポップアップ表示
        setupOneButtonPopup(POPUP_MESSAGE_MAP[popupId], "OK");
        break;
    case POPUP_MEASURING: {                                     // 測定データ取得中
        emitRequestToOpenPopup(PROGRESSBAR_LABELBUTTON_LAYOUT, POPUP_MESSAGE_MAP[popupId], "中止");
        createPopupConnection();
        setOneButton();
        break;
    }
    case POPUP_SCANNING: {                                      // SCAN実行中
        emitRequestToOpenPopup(PROGRESSBAR_LAYOUT, POPUP_MESSAGE_MAP[popupId], "中止");
        disconnectBasicPopup();
        connectBasicPopup();
        setOneButton();
        break;
    }
    case POPUP_USB_FORMAT_RUNNING: {                            // USBフォーマット実行中
        emitRequestToOpenPopup(MESSAGE_LAYOUT, POPUP_MESSAGE_MAP[popupId]);
        createPopupConnection();
        break;
    }
    case POPUP_INPUT_FILENAME:                                  // ファイル名入力用キーボード表示
    case POPUP_SAVE_MEASUREMENT_DATA:                           // 測定データ保存
        emitRequestToOpenPopup(KEYBORAD_LAYOUT, POPUP_MESSAGE_MAP[popupId]);
        createPopupConnection(true);
        _fileNameInput = _basicPopup->findChild<QObject *>(FILE_NAME_INPUT);
        _fileName.clear();
        _saveLocation = SAVE_MEASUREMENT_DATA;
        if (_basicPopup) {
            _basicPopup->setProperty(PROPERTY_FILE_NAME, _fileName);
            _basicPopup->setProperty(PROPERTY_CURSOR_POSITION, 0);
        }
        connect(this, SIGNAL(notifyActiveFocus()), _basicPopup, SLOT(setTextInputFocus()));
        setKeyboardInit();
        break;
    case POPUP_SAVE_USER_SETTING_DATA: {                        // ユーザ設定データ保存
        emitRequestToOpenPopup(KEYBORAD_LAYOUT, POPUP_MESSAGE_MAP[popupId]);
        // 保存先の選択のポップアップを閉じるだけでシグナルの接続は流用する
        _fileNameInput = _basicPopup->findChild<QObject *>(FILE_NAME_INPUT);
        _fileName.clear();
        _saveLocation = SAVE_USER_SETTING;
        if (_basicPopup) {
            _basicPopup->setProperty(PROPERTY_FILE_NAME, _fileName);
            _basicPopup->setProperty(PROPERTY_CURSOR_POSITION, 0);
        }
        setKeyboardInit();
        break;
    }
    case POPUP_DATA_LOGGER_KEYBOARD: {                          // キーボード表示
        emitRequestToOpenPopup(KEYBORAD_LAYOUT, POPUP_MESSAGE_MAP[popupId]);
        createPopupConnection();
        _fileNameInput = _basicPopup->findChild<QObject *>(FILE_NAME_INPUT);
        _fileName.clear();
        if (_basicPopup) {
            _basicPopup->setProperty(PROPERTY_FILE_NAME, _fileName);
            _basicPopup->setProperty(PROPERTY_CURSOR_POSITION, 0);
        }
        setKeyboardInit();
        break;
    }
    // three button
//    case POPUP_POWER_SUPPLY_SELECT3: {                          // 給電設定(JCSAT, SCC)
//        emitRequestToOpenPopup(POWER_SUPPLY_SELECT_LAYOUT, POPUP_MESSAGE_MAP[popupId], "15v固定 給電\n※パルス出力なし", "いいえ", "水平15v/垂直11v 給電\n※JCSAT4にはパルス出力");
//        createPopupConnection(true);
//        setThreeButton();
//        break;
//    }
    case POPUP_CONFIRM_COPY_SELECTED_FILE: {                    // 選択ファイルコピー確認ダイアログ
#if 1   // 20210712 "コピーして消去"が不調のため
        // はい/いいえボタンのポップアップ表示（デフォルトがはい）
        setupYesNoButtonPopup(POPUP_MESSAGE_MAP[popupId]);
#else
        emitRequestToOpenPopup(THREE_BUTTON_LAYOUT, POPUP_MESSAGE_MAP[popupId], "コピー", "コピーして消去", "いいえ");
        createPopupConnection(true);
        setThreeButton();
#endif
        break;
    }
    case POPUP_CONFIRM_COPY:                                     // コピー中ダイアログ
    case POPUP_CONFIRM_DELETE:                                   // 削除中ダイアログ
    {
        emitRequestToOpenPopup(MESSAGE_LAYOUT, POPUP_MESSAGE_MAP[popupId]);
        createPopupConnection();
        break;
    }
    case POPUP_SCAN_RESULT:                                     // スキャン結果
        createScanResultModel();
        break;
    default:
        return true;
    }

    _isOpened = true;
    _openPopupId = popupId;
    checkValidKeyboardSaveButton();

    return true;
}

bool PopupManager::openScan(PopupId popupId, int detailId, bool focedDisplay)
{
    bool ret = false;
    ret = open(popupId, focedDisplay);
    _scanBandId = static_cast<LC70_BAND_T>(detailId);

    return ret;
}

bool PopupManager::openWithMessage(PopupId popupId, QString message, bool focedDisplay)
{
    if (_popupAlereadyOpened) {
        if (focedDisplay) {
            close();
        } else {
            return false;
        }
    }

    // 以下はテーブル定義可能なはず

    switch(popupId) {
    case POPUP_POWER_SUPPLY_ERROR_MANUAL_MEASURING: {
        setupOneButtonPopup(message, "戻る");
        break;
    }
    case POPUP_POWER_SUPPLY_ERROR_USER_MEASURING: {
        setupOneButtonPopup(message, "はい");
        break;
    }
    case POPUP_DATA_LOGGER_KEYBOARD: {
        emitRequestToOpenPopup(KEYBORAD_LAYOUT, "");
        createPopupConnection();
        _fileNameInput = _basicPopup->findChild<QObject *>(FILE_NAME_INPUT);
        _fileName = message;
        if (_basicPopup) {
            _basicPopup->setProperty(PROPERTY_FILE_NAME, _fileName);
            _basicPopup->setProperty(PROPERTY_CURSOR_POSITION, _fileName.length());
        }
        setKeyboardInit();
        break;
    }
    case POPUP_SCAN_NOT_APPLICABLE: {
        setupOneButtonPopup("SCAN対象外です", "OK");
        break;
    }
    case POPUP_MEASURE_COMPLETE: {
        setupYesNoButtonPopup(message, false);
        break;
    }
    case POPUP_MEASURE_CATV_UPSTREAM_NOT_APPLICABLE: {
        setupOneButtonPopup(message, "OK");
        break;
    }
    default:
        return true;
    }

    _isOpened = true;
    _openPopupId = popupId;
    checkValidKeyboardSaveButton();
    return true;
}

bool PopupManager::openLowBattery()
{
    createLowBatteryPopupConnection();
    emitRequestToOpenLowBatteryPopup();
    // ポップアップを閉じた後、元のポップアップを復元するため、_openPopupIdは更新しない
    _isOpened = true;
    return true;
}

void PopupManager::close()
{
    if (_lowBatteryPopup) {
        // バッテリ低下状態中のポップアップを閉じる
        emit requestToCloseLowBattery();
        disconnect(this, SIGNAL(requestToCloseLowBattery()), _lowBatteryPopup, SLOT(closePopup()));
        _lowBatteryPopup = nullptr;
    }

    if (_strongPopup) {
        // ポップアップの上に表示しているポップアップを閉じる
        emit requestToCloseStrong();
        disconnect(this, SIGNAL(requestToCloseStrong()), _strongPopup, SLOT(closePopup()));

        _strongPopup = nullptr;
    }

    _fileNameInput = nullptr;
    _fileName.clear();

    // ポップアップを閉じるよう QML に通知
    emit requestToClose();
    disconnectBasicPopup();

    emit closed();
    _isOpened = false;
}

bool PopupManager::isOpend() const
{
    return _isOpened;
}

void PopupManager::pressButton(ButtonId buttonId)
{
    if (buttonId != BUTTON_ENTER) {
        return;
    }

    propertyChange(_activeButton, "keyPressed", true);
    propertyChange(_activeButton, "press", true);
}

void PopupManager::inputButton(ButtonId buttonId)
{
    propertyChange(_activeButton, "keyPressed", false);
    propertyChange(_activeButton, "press", false);

    switch (buttonId) {
    case BUTTON_UP:
    case BUTTON_DOWN: {
        if (_openPopupId == POPUP_SCAN_RESULT) {
            if (buttonId == BUTTON_UP) {
                emit requestScrollUp();
            } else {    // BUTTON_DOWN
                emit requestScrollDown();
            }
            return;
        }
        QString nextButton;
        bool ret = _buttonOperation->nextActiveObject(buttonId, nextButton);

        if (ret) {
            // inactive
            propertyChange(_activeButton, "active", false);

            // active
            propertyChange(nextButton, "active", true);

            _activeButton = nextButton;
            _buttonOperation->setActiveObject(_activeButton);
        }

        break;
    }
    case BUTTON_LEFT:
    case BUTTON_RIGHT: {

        // スキャン結果表示時に有効なスキャン結果がなければ決定を選択できないようにする
        if (_openPopupId == POPUP_SCAN_RESULT && _noValidScanResult) {
            return;
        }

        QString nextButton;
        bool ret = _buttonOperation->nextActiveObject(buttonId, nextButton);

        if (ret) {
            // inactive
            propertyChange(_activeButton, "active", false);

            // active
            propertyChange(nextButton, "active", true);

            _activeButton = nextButton;
            _buttonOperation->setActiveObject(_activeButton);
        }

        break;
    }

    case BUTTON_ENTER: {
        enterKey();
        break;
    }

    case BUTTON_ESCAPE:
        escapeKey();
        break;

    default:
        break;
    }

    // キーの移動後にフォーカスを入力用エレメントに移動
    emit notifyActiveFocus();
}

void PopupManager::enterKey()
{
    if (_lowBatteryPopup) {
//        emit requestToCloseLowBattery();
//        disconnect(this, SIGNAL(requestToCloseLowBattery()), _lowBatteryPopup, SLOT(closePopup()));
//        _lowBatteryPopup = nullptr;
//        if (_openPopupId == POPUP_ID_COUNT) {
//            emit closed();
//            _isOpened = false;
//        }
        return;
    }
    if (_openPopupId == POPUP_SCAN_CONFIRMATION) {
        if (_activeButton == "m2") {
            onReject();
        } else {
            // 閉じるだけ
            emit requestToClose();

            // 次の Popup 表示
            open(POPUP_SCANNING, false);

            // スキャン開始を依頼
            emit requestToScan();
        }
    } else if (_openPopupId == POPUP_SCANNING) {

        // 中止確認の Popup 表示
        open(POPUP_SCAN_CANCEL, false);

    } else if (_openPopupId == POPUP_SCAN_CANCEL) {

        if (_activeButton == "m2") {
            // 中止確認を閉じる
            emit requestToCloseStrong();
            disconnect(this, SIGNAL(requestToCloseStrong()), _strongPopup, SLOT(closePopup()));

            _strongPopup = nullptr;

            _openPopupId = POPUP_SCANNING;

            // buttonOperationの設定
            setOneButton();

        } else {
            // SCAN 処理を中止する
            emit requestToStopScanning();

            // 中止確認を閉じる
            emit requestToCloseStrong();
            disconnect(this, SIGNAL(requestToCloseStrong()), _strongPopup, SLOT(closePopup()));

            _strongPopup = nullptr;

            if (_scanLockModel) {
                _scanLockModel->clear();
                _scanLockModel = nullptr;
            }

            close();
        }
    } else if (_openPopupId == POPUP_MEASURING) {

        // 中止確認の Popup 表示
        open(POPUP_MEASURE_CANCEL, false);

    } else if (_openPopupId == POPUP_MEASURE_CANCEL) {

        if (_activeButton == "m2") {
            // 中止確認を閉じる
            emit requestToCloseStrong();
            disconnect(this, SIGNAL(requestToCloseStrong()), _strongPopup, SLOT(closePopup()));

            _strongPopup = nullptr;

            _openPopupId = POPUP_MEASURING;

            // buttonOperationの設定
            setOneButton();

        } else {
            // 測定データ取得処理を中止する
            emit requestToStopAcquring();

            // 中止確認を閉じる
            emit requestToCloseStrong();
            disconnect(this, SIGNAL(requestToCloseStrong()), _strongPopup, SLOT(closePopup()));

            _strongPopup = nullptr;

            close();
        }
    } else if (_openPopupId == POPUP_SELECT_SAVE_DATA) {

        if (_activeButton == "m1") {
            // 閉じるだけ
            emit requestToClose();
            disconnectBasicPopup();

            // 次の Popup 表示 / 測定データ保存
            open(POPUP_SAVE_MEASUREMENT_DATA, false);
        } else {
            // 閉じるだけ
            emit requestToClose();

            onAccept(true);
        }
    } else if (_openPopupId == POPUP_COPY_ALL_TO_BODY_SELECT_USER_SETTING_DATA_CONFIRMATION) {
        if (_activeButton == "m1") {
            onSelect(0);        // 取り込みデータ1
        } else if (_activeButton == "m2"){
            onSelect(1);        // 取り込みデータ2
        } else {
            onReject();
        }
    } else if (_openPopupId == POPUP_SAVE_MEASUREMENT_DATA || _openPopupId == POPUP_INPUT_FILENAME) {
        // キーの入力
        setFileName();
    } else if (_openPopupId == POPUP_SAVE_USER_SETTING_DATA) {
        // キーの入力
        setFileName();
    } else if (_openPopupId == POPUP_DATA_LOGGER_KEYBOARD) {
        // キーの入力
        setFileName();
    } else if (_openPopupId == POPUP_USB_FORMAT_RUNNING) {
        // USBフォーマット中は何もしない
        return;
    } else if (_openPopupId == POPUP_POWER_SUPPLY_SELECT3) {
        // three button
//        if (_activeButton == "m1") {        // Fixed 15v
//            onSelect(0);
//        } else if (_activeButton == "m3") { // H15V11v
//            onSelect(1);
//        } else {
//            onReject();
//        }
        // two button
        if (_activeButton == "m1") {        // H15V11v
            onSelect(1);
        } else {
            onReject();
        }
    } else if (_openPopupId == POPUP_SCAN_RESULT) {
        if (_scanLockModel != nullptr) {
            _scanLockModel->clear();
            _scanLockModel = nullptr;
        }
        if (_scanResultModel != nullptr) {
            _scanResultModel->clear();
            _scanResultModel = nullptr;
            if (_activeButton == "m1") {        // 保存する
                onAccept(false);
            } else {                            // 保存しない
                if (_noValidScanResult) {
                    _isRejectScanResult = true;
                }
                else {
                    _isRejectScanResult = false;
                }
                onReject();
            }
        }
    } else if (_openPopupId == POPUP_CONFIRM_COPY_SELECTED_FILE) {
#if 1   // 20210712 "コピーして消去"が不調のため
        // ボタンが 2 つの場合
        if (_activeButton == "m1") {
            onAccept(false);
        } else {
            onReject();
        }
#else
        if (_activeButton == "m1") {            // コピー
            onSelect(0);
        } else if (_activeButton == "m2") {     // コピーして消去
            onSelect(1);
        } else {
            onReject();
        }
#endif
    } else if (_openPopupId == POPUP_DATA_LOGGER_USB_REMOVE_ERROR) {
        if (_activeButton == "m1") {
            onAccept(false);
            close();
        } else {}
    } else {
        // ボタンが 2 つの場合
        if (_activeButton == "m1") {
            onAccept(false);
        } else {
            onReject();
        }    }
}

void PopupManager::escapeKey()
{
    if (_lowBatteryPopup) {
//        emit requestToCloseLowBattery();
//        disconnect(this, SIGNAL(requestToCloseLowBattery()), _lowBatteryPopup, SIGNAL(closePopup));
//        _lowBatteryPopup = nullptr;
//        if (_openPopupId == POPUP_ID_COUNT) {
//            emit closed();
//            _isOpened = false;
//        }
        return;
    }
    if (_openPopupId == POPUP_USB_FORMAT_RUNNING) {
        // USBフォーマット中は何もしない
        return;
    } else if (_openPopupId == POPUP_SCANNING) {
        // 中止確認の Popup 表示
        open(POPUP_SCAN_CANCEL, false);
        return;
    } else if (_openPopupId == POPUP_MEASURING) {
        // 中止確認の Popup 表示
        open(POPUP_MEASURE_CANCEL, false);
        return;
    } else if (_openPopupId == POPUP_MEASURE_CANCEL) {
        // 中止確認を閉じる
        emit requestToCloseStrong();
        disconnect(this, SIGNAL(requestToCloseStrong()), _strongPopup, SLOT(closePopup()));

        _strongPopup = nullptr;

        _openPopupId = POPUP_MEASURING;

        // buttonOperationの設定
        setOneButton();
    } else {
        if (_openPopupId == POPUP_SCAN_RESULT) {
            if (_scanLockModel != nullptr) {
                _scanLockModel->clear();
                _scanLockModel = nullptr;
            }
            if (_scanResultModel != nullptr) {
                _scanResultModel->clear();
                _scanResultModel = nullptr;
            }
            _isRejectScanResult = true;
        }
        else {
            _isRejectScanResult = false;
        }

        // ポップアップを閉じる
        onReject();
    }
}

void PopupManager::onKeyStatus(LC70_KEY_STAT_T keyStatus)
{
    // ポップアップが開いていない場合のボタンの受信は無視する
    if (!_isOpened) {
        return;
    }

    // ボタン状態
    static LC70_KEY_T buttonStatus[LC70_KEY_ID_MAX] = {
        LC70_KEY_OFF, LC70_KEY_OFF, LC70_KEY_OFF, LC70_KEY_OFF,
        LC70_KEY_OFF, LC70_KEY_OFF, LC70_KEY_OFF, LC70_KEY_OFF,
        LC70_KEY_OFF, LC70_KEY_OFF, LC70_KEY_OFF, LC70_KEY_OFF,
        LC70_KEY_OFF, LC70_KEY_OFF, LC70_KEY_OFF, LC70_KEY_OFF,
        LC70_KEY_OFF
    };

    // 前回取得したボタン状態と異なるボタンのリスト
    QList<int> buttons;

    for (int i = 0; i < LC70_KEY_ID_MAX; ++i) {
        // 前回取得したボタン状態と異なるボタンを検知
        if (keyStatus.stat[i] != buttonStatus[i]) {
            buttons.append(i);
        }
    }

    // 電源、給電ボタンを優先
    if (buttons.contains(LC70_KEY_ID_POWER)) {
        manipulateButton(LC70_KEY_ID_POWER, keyStatus);
    } else if (buttons.contains(LC70_KEY_ID_POWER_SUPPLY)) {
        manipulateButton(LC70_KEY_ID_POWER_SUPPLY, keyStatus);
    } else {
        // 電源、給電以外では ID がいちばん大きい前回と状態が異なるボタンを対象とする
        for (int i = buttons.count() - 1; i >= 0; --i) {
            if (buttons[i] == LC70_KEY_ID_POWER ||
                    buttons[i] == LC70_KEY_ID_POWER_SUPPLY) {
                continue;
            }

            manipulateButton(static_cast<LC70_KEYID_T>(buttons[i]), keyStatus);
            break;
        }
    }

    // 取得したボタン状態を保持
    for (int i = 0; i < LC70_KEY_ID_MAX; ++i) {
        buttonStatus[i] = keyStatus.stat[i];
    }

#if 0

    // ボタンIDの変換
    if (BUTTON_UNKNOWN == id) {
        // 複数同時ONの場合には index の若いものが対象になる
        for (int i = 0; i < LC70_KEY_ID_MAX; i++) {
            if (LC70_KEY_ON == keyStatus->stat[i]) {
                id = static_cast<ButtonId>(i);
                pressButton(id);
                break;
            }
        }
    } else {
        // Release された時に呼び出しを行う
        if (LC70_KEY_OFF == keyStatus->stat[id]) {
            inputButton(id);

            id = BUTTON_UNKNOWN;
        }
    }

#endif
}

void PopupManager::onAccept(bool okOnly)
{
    // QML の Popup を閉じる
    emit requestToClose();
    disconnectBasicPopup();

    // ポップアップを呼び出した画面のボタン入力を有効にする
    emit closed();
    _isOpened = false;
    PopupId bkup = _openPopupId;
    _openPopupId = POPUP_ID_COUNT;

    _fileNameInput = nullptr;
    _fileName.clear();

    // 受諾の通知
    emit accept(bkup, okOnly);
}

void PopupManager::onReject()
{
    if (_strongPopup) {
        // 中止確認を閉じる
        emit requestToCloseStrong();
        disconnect(this, SIGNAL(requestToCloseStrong()), _strongPopup, SLOT(closePopup()));

        _strongPopup = nullptr;

        _openPopupId = POPUP_SCANNING;

        // buttonOperationの設定
        setOneButton();
    } else {
        // QML の Popup を閉じる
        emit requestToClose();
        disconnectBasicPopup();

        // ポップアップを呼び出した画面のボタン入力を有効にする
        emit closed();
        _isOpened = false;

        // 拒絶の通知
        if (_isRejectScanResult) {
            emit rejectScanResult();
            _isRejectScanResult = false;
        } else {
            emit reject(_openPopupId);
        }

        _openPopupId = POPUP_ID_COUNT;
        _fileNameInput = nullptr;
        _fileName.clear();
    }
}

void PopupManager::onSelect(int index)
{
    // QML の Popup を閉じる
    emit requestToClose();
    disconnectBasicPopup();

    // ポップアップを呼び出した画面のボタン入力を有効にする
    emit closed();
    _isOpened = false;

    emit select(_openPopupId, index);
    _openPopupId = POPUP_ID_COUNT;
}

void PopupManager::onProgress(double value)
{
    if (!_basicPopup) {
        return;
    }

    if (_openPopupId == POPUP_SCANNING || _openPopupId == POPUP_MEASURING || _openPopupId == POPUP_MEASURE_CANCEL || _openPopupId == POPUP_SCAN_CANCEL) {
        _basicPopup->setProperty("progressingValue", value);
    }
}

void PopupManager::onProgressText(QString current, bool flag)
{
    if (!_basicPopup) {
        return;
    }

    if (flag)  {
        // スキャン結果用のモデル(ScanLockModel の実体(objectName:scanLockModel)を QML から参照)
        _scanLockModel = dynamic_cast<ScanLockModel *>(_basicPopup->findChild<QObject *>(QString("scanLockModel")));
        ScanLockData data;
        data.channel = current;
       if (_scanLockModel->rowCount() < 150) {
            _scanLockModel->append(data);
       }
    }
}

void PopupManager::onScanningFinished(bool)
{
    // SCAN 中止確認を開いている間にスキャンが終了した場合に備える
    if (_strongPopup) {
        emit requestToCloseStrong();
        disconnect(this, SIGNAL(requestToCloseStrong()), _strongPopup, SLOT(closePopup()));

        _strongPopup = nullptr;
    }

    // この時点で給電エラーのポップアップが表示されているので以下の処理は行わず続行する
#if 0

    close();

    _openPopupId = POPUP_ID_COUNT;
    _isOpened = false;
#endif
}

void PopupManager::propertyChange(QString buttonName, QString propertyName, QVariant value)
{
    QObject *target = nullptr;

    if (_strongPopup) {
        target = _strongPopup->findChild<QObject *>(buttonName);
    } else {
        target = _basicPopup->findChild<QObject *>(buttonName);
    }

    if (target) {
        target->setProperty(propertyName.toUtf8().constData(), value);
    }
}

void PopupManager::connectBasicPopup()
{
    connect(_basicPopup, SIGNAL(accept(bool)), this, SLOT(onAccept(bool)));
    connect(_basicPopup, SIGNAL(reject()), this, SLOT(onReject()));
    connect(this, SIGNAL(requestToClose()), _basicPopup, SLOT(closePopup()));
}
void PopupManager::disconnectBasicPopup()
{
    disconnect(_basicPopup, SIGNAL(accept(bool)), this, SLOT(onAccept(bool)));
    disconnect(_basicPopup, SIGNAL(reject()), this, SLOT(onReject()));
    disconnect(this, SIGNAL(requestToClose()), _basicPopup, SLOT(closePopup()));
    disconnect(this, SIGNAL(notifyActiveFocus()), _basicPopup, SLOT(setTextInputFocus()));
    if (_openPopupId == POPUP_SCAN_RESULT) {
        disconnect(this, SIGNAL(requestScrollUp()), _basicPopup, SLOT(scrollUp()));
        disconnect(this, SIGNAL(requestScrollDown()), _basicPopup, SLOT(scrollDown()));
        disconnect(this, SIGNAL(setScanResultRowCount(QVariant)), _basicPopup, SLOT(settingRowCount(QVariant)));
    }
}

void PopupManager::setThreeButton(bool isRightButtonActive)
{
    _buttonOperation->setButtonName(BUTTON_COLUMN_NUMBER, BUTTON_ROW_NUMBER3, _threeButtonData);

    if (isRightButtonActive) {
        _buttonOperation->setActiveObject(_threeButtonData[0][2]);
        _activeButton = _threeButtonData[0][2];
        propertyChange(_threeButtonData[0][0], "active", false);
        propertyChange(_threeButtonData[0][1], "active", false);
        propertyChange(_threeButtonData[0][2], "active", true);
    } else {
        _buttonOperation->setActiveObject(_threeButtonData[0][0]);
        _activeButton = _threeButtonData[0][0];
        propertyChange(_threeButtonData[0][0], "active", true);
        propertyChange(_threeButtonData[0][1], "active", false);
        propertyChange(_threeButtonData[0][2], "active", false);
    }
}

void PopupManager::setTwoButton(bool isRightButtonActive, bool visible)
{
    _buttonOperation->setButtonName(BUTTON_COLUMN_NUMBER, BUTTON_ROW_NUMBER2, _twoButtonData);

    if (isRightButtonActive) {
        _buttonOperation->setActiveObject(_twoButtonData[0][1]);
        _activeButton = _twoButtonData[0][1];
        // inactive
        propertyChange(_twoButtonData[0][0], "active", false);
        propertyChange(_twoButtonData[0][0], "visible", visible);

        // active
        propertyChange(_twoButtonData[0][1], "active", true);
        propertyChange(_twoButtonData[0][1], "visible", visible);
    } else {
        _buttonOperation->setActiveObject(_twoButtonData[0][0]);
        _activeButton = _twoButtonData[0][0];
        // active
        propertyChange(_twoButtonData[0][0], "active", true);
        propertyChange(_twoButtonData[0][0], "visible", visible);

        // inactive
        propertyChange(_twoButtonData[0][1], "active", false);
        propertyChange(_twoButtonData[0][1], "visible", visible);
    }
}

void PopupManager::setOneButton()
{
    _buttonOperation->setButtonName(BUTTON_COLUMN_NUMBER, BUTTON_ROW_NUMBER1, _oneButtonData);
    _buttonOperation->setActiveObject(_oneButtonData[0][0]);
    _activeButton = _oneButtonData[0][0];

    // active
    propertyChange(_oneButtonData[0][0], "visible", true);
    propertyChange(_oneButtonData[0][0], "active", true);
}

void PopupManager::setKeyboardInit()
{
    // koko dehanaiga.
    _buttonOperation->setButtonName(BUTTON_COLUMN_NUMBER5, BUTTON_ROW_NUMBER14, _keyboardButtonData);
    _buttonOperation->setActiveObject(_keyboardButtonData[0][0]);
    _activeButton = _keyboardButtonData[0][0];

    for (int i = 0; i < BUTTON_COLUMN_NUMBER5; i++) {
        for (int j = 0; j < BUTTON_ROW_NUMBER14; j++) {
            propertyChange(_keyboardButtonData[i][j], "active", false);
        }
    }

    // active
    propertyChange(_keyboardButtonData[0][0], "active", true);

    for (int i = 0; i < BUTTON_COLUMN_NUMBER5; i++) {
        for (int j = 0; j < BUTTON_ROW_NUMBER14; j++) {
            propertyChange(_keyboardButtonData[i][j], "message", _keyboardPattrnAlphanumericUpperLower[i][j]);
        }
    }
}

void PopupManager::checkValidKeyboardSaveButton()
{
    QMap<PopupId, bool> targetPouupIdMap = {
        {POPUP_INPUT_FILENAME, true},
        {POPUP_SAVE_MEASUREMENT_DATA, true},
        {POPUP_SAVE_USER_SETTING_DATA, true},
        {POPUP_DATA_LOGGER_KEYBOARD, true},
    };
    if (!targetPouupIdMap.value(_openPopupId, false)) {
        // キーボードダイアログでなければ何もしない
        return;
    }

    if (_keyboardButtonData.size() < BUTTON_COLUMN_NUMBER5) {
        return;
    }
    if (_keyboardButtonData.at(0).size() < BUTTON_ROW_NUMBER14) {
        return;
    }

    // ファイル名の入力がない場合、保存ボタンを押下不能にする
    bool saveButtonEnabled = !_fileName.trimmed().isEmpty();

    // 保存ボタン無効時は、カーソル移動できないようにする
    static const QString SAVE_BUTTON_NAME = "right5";
    static const QString NEXT_CHAR_BUTTON_NAME = "right4";
    _keyboardButtonData[BUTTON_COLUMN_NUMBER5 - 1][BUTTON_ROW_NUMBER14 - 1] = saveButtonEnabled ? SAVE_BUTTON_NAME : "";
    _buttonOperation->setButtonName(BUTTON_COLUMN_NUMBER5, BUTTON_ROW_NUMBER14, _keyboardButtonData);
    propertyChange(SAVE_BUTTON_NAME, "disable", !saveButtonEnabled);
    propertyChange(NEXT_CHAR_BUTTON_NAME, "activeBackgroundImage", saveButtonEnabled ? "qrc:/resource/png/128x56_btn_cur_active.png" : "qrc:/resource/png/128x56_btn_cur_active.png");
}

void PopupManager::setFileName(void)
{
    QString letter;

    if (_activeButton == "right1") {
        // BS は right2 に移動
//        // BS
//        QVariant value = _basicPopup->property(PROPERTY_CURSOR_POSITION);
//        bool ok = false;
//        int position = value.toUInt(&ok);

//        if (!ok) {
//            return;
//        }

//        if (position == 0) {
//            return;
//        }

//        if (position == _fileName.length()) {
//            _fileName = _fileName.left(_fileName.length() - 1);
//        } else {
//            QString left = _fileName.left(position - 1);
//            QString right = _fileName.mid(position);
//            _fileName = left + right;
//        }

//        if (_fileNameInput && _basicPopup) {
//            _basicPopup->setProperty(PROPERTY_FILE_NAME, _fileName);
//        }
//        checkValidKeyboardSaveButton();

//        return;
    } else if (_activeButton == "right2") {
        // スペースキーを無効にして BS としてふるまわせる
        // BS
        QVariant value = _basicPopup->property(PROPERTY_CURSOR_POSITION);
        bool ok = false;
        int position = value.toUInt(&ok);

        if (!ok) {
            return;
        }

        if (position == 0) {
            return;
        }

        if (position == _fileName.length()) {
            _fileName = _fileName.left(_fileName.length() - 1);
        } else {
            QString left = _fileName.left(position - 1);
            QString right = _fileName.mid(position);
            _fileName = left + right;
        }

        if (_fileNameInput && _basicPopup) {
            _basicPopup->setProperty(PROPERTY_FILE_NAME, _fileName);
        }
        checkValidKeyboardSaveButton();

        return;
//        if (_fileName.length() < KEYBOARD_INPUT_MAXNUM) {
//            // スペース
//            letter = " ";
//            QVariant value = _basicPopup->property(PROPERTY_CURSOR_POSITION);
//            bool ok = false;
//            int position = value.toUInt(&ok);

//            if (!ok) {
//                return;
//            }

//            if (position == _fileName.length()) {
//                _fileName += letter;
//            } else {
//                QString left = _fileName.left(position);
//                QString right = _fileName.mid(position);
//                _fileName = left + letter + right;
//            }

//            _basicPopup->setProperty(PROPERTY_FILE_NAME, _fileName);
//            _basicPopup->setProperty(PROPERTY_CURSOR_POSITION, position + 1);
//            checkValidKeyboardSaveButton();
//            return;
//        }
    } else if (_activeButton == "right3") {
        // 前の文字
        if (_fileNameInput && _basicPopup) {
            QVariant value;
            if (_basicPopup) {
                value = _basicPopup->property(PROPERTY_CURSOR_POSITION);
            }
            bool ok = false;
            uint32_t position = value.toUInt(&ok);

            if (!ok) {
                return;
            }

            if (position > 0) {
                --position;
            }

            if (_basicPopup) {
                _basicPopup->setProperty(PROPERTY_CURSOR_POSITION, position);
            }
        }

        return;
    } else if (_activeButton == "right4") {
        // 次の文字
        if (_fileNameInput && _basicPopup) {
            QVariant value;
            if (_basicPopup) {
                value = _basicPopup->property(PROPERTY_CURSOR_POSITION);
            }
            bool ok = false;
            int position = value.toUInt(&ok);

            if (!ok) {
                return;
            }

            if (position < 30) {
                ++position;
            }

            _basicPopup->setProperty(PROPERTY_CURSOR_POSITION, position);
        }

        return;
    } else if (_activeButton == "right5") {
        // 保存ボタン
        QString fileName = _fileName;

        if (_openPopupId == POPUP_DATA_LOGGER_KEYBOARD) {
            // キーボードを単独でOpenしている場合にはPOPUPをCloseした状態に戻す
            _isOpened = false;
        }

        // 画面キャプチャーに写らないようポップアップを閉じる
        close();

        // 保存
        emit inputFileName(_openPopupId, _saveLocation, fileName.trimmed());
    }

    // 他ボタンが押下された場合
    //  キーボードの入力最大文字数(10文字) 以上は入力を受け付けないようにする
    if (_fileName.length() < KEYBOARD_INPUT_MAXNUM) {
        if (_keyboardPattern == KEYBORAD_ALPHANUMERIC_UPPER_LOWER) {
            for (int i = 0; i < BUTTON_COLUMN_NUMBER5; ++i) {
                for (int j = 0; j < BUTTON_ROW_NUMBER14; ++j) {
                    if (_activeButton == _keyboardButtonData[i][j]) {
                        letter = _keyboardPattrnAlphanumericUpperLower[i][j];
                        break;
                    }
                }
            }
        }
    }

    if (_fileNameInput && _basicPopup) {
        QVariant value;
        if (_basicPopup) {
            value = _basicPopup->property(PROPERTY_CURSOR_POSITION);
        }
        bool ok = false;
        int position = value.toUInt(&ok);

        if (!ok) {
            return;
        }

        if (position == _fileName.length()) {
            _fileName += letter;
        } else {
            QString left = _fileName.left(position);
            QString right = _fileName.mid(position);
            _fileName = left + letter + right;
        }

        if (_basicPopup) {
            _basicPopup->setProperty(PROPERTY_FILE_NAME, _fileName);
            _basicPopup->setProperty(PROPERTY_CURSOR_POSITION, position + 1);
            checkValidKeyboardSaveButton();
        }
    }
}

void PopupManager::manipulateButton(const LC70_KEYID_T &button, const LC70_KEY_STAT_T status)
{
    static ButtonId id = BUTTON_UNKNOWN;

    // ボタンIDの変換
    if (BUTTON_UNKNOWN == id) {
        if (LC70_KEY_ON == status.stat[button]) {
            id = static_cast<ButtonId>(button);
            QString message = QString("Button %1 pressed").arg(static_cast<int>(button));
            _model->writeLog(QString(typeid(*this).name()), message);
            pressButton(id);
            // 長押し検出タイマー開始
            _pressedButtonId = id;
            startPressAndHoldTimer();
        }
    } else {
        // Release された時に呼び出しを行う
        if (LC70_KEY_OFF == status.stat[id]) {
            // 長押し検出タイマー停止
            stopPressAndHoldTimer();
            QString message = QString("Button %1 released").arg(static_cast<int>(button));
            _model->writeLog(QString(typeid(*this).name()), message);
            inputButton(id);
            id = BUTTON_UNKNOWN;
        } else {
            // 押下状態が継続
            QString message = QString("Button %1 pressed...").arg(static_cast<int>(button));
            _model->writeLog(QString(typeid(*this).name()), message);
        }
    }
}

void PopupManager::startPressAndHoldTimer()
{
    // 長押し対象キーのリスト
    static const QList<ButtonId> normalTargetList = {BUTTON_RIGHT, BUTTON_LEFT};
    static const QList<ButtonId> keyboardTargetList = {BUTTON_UP, BUTTON_DOWN, BUTTON_RIGHT, BUTTON_LEFT, BUTTON_ENTER};
    static const QList<ButtonId> scanResultTargetList = {BUTTON_UP, BUTTON_DOWN, BUTTON_RIGHT, BUTTON_LEFT};
    static const QMap<PopupId, QList<ButtonId>> targetButtonMap = {
        // キーボードポップアップの場合、上下左右と、ENTERを長押しの対象にする
        {POPUP_DATA_LOGGER_KEYBOARD, keyboardTargetList},
        // スキャン結果の場合、上下左右を長押しの対象にする
        {POPUP_SCAN_RESULT, scanResultTargetList},
    };

    // 押下しているボタンが長押し対象であるかチェック
    foreach (ButtonId id, targetButtonMap.value(_openPopupId, normalTargetList)) {
        if (_pressedButtonId == id) {
            stopPressAndHoldTimer();

            _pressAndHoldTimerInterval = _model->applicationSetting()->firstRepeatTime();
            _pressCount = 0;

            // 長押し検出タイマー開始
            if (_pressAndHoldTimerInterval != 0) {
                _pressAndHoldTimer->start(_pressAndHoldTimerInterval);
            }

            return;
        }
    }
}

void PopupManager::stopPressAndHoldTimer()
{
    if (!_pressAndHoldTimer->isActive()) {
        // タイマーが稼働していなかったら何もしない
        return;
    }

    _pressAndHoldTimer->stop();
    _pressAndHoldTimerInterval = 0;
    _pressCount = 0;
}

void PopupManager::detectPressAndHold()
{
    if (_pressCount < _model->applicationSetting()->lowRepeatCount()) {
        // 長押し検知〜指定回数まで
        ++_pressCount;
        // 長押し間隔(低速)
        _pressAndHoldTimerInterval = _model->applicationSetting()->repeatIntervalLow();
    } else {
        // 指定回数以降
        // 長押し間隔(高速)
        _pressAndHoldTimerInterval = _model->applicationSetting()->repeatIntervalHigh();
    }

    // ボタンを押下する
    QString message = QString("Button %1 released").arg(static_cast<int>(_pressedButtonId));
    _model->writeLog(QString(typeid(*this).name()), message);
    inputButton(_pressedButtonId);

    // 次回の押下タイミングまでのタイマーを再設定
    _pressAndHoldTimer->start(_pressAndHoldTimerInterval);
}

void PopupManager::createScanResultModel() {
    QList<MeasureResult> scanResult = _model->allScanResult();

    // スキャン結果用のモデル(ScanResultModel の実体(objectName:scanResultModel)を QML から参照)
    _scanResultModel = dynamic_cast<ScanResultModel *>(_basicPopup->findChild<QObject *>(QString("scanResultModel")));

    // チャンネル定義を取得する
    QList<ChannelDefinitionItem> catvChannelList;
    _model->getChannelDefinitionList(LC70_BAND_CATV_90_470MHZ, catvChannelList);
    _catvChannelDefMap.insert(LC70_BAND_CATV_90_470MHZ, catvChannelList);
    _model->getChannelDefinitionList(LC70_BAND_CATV_470_1002MHZ, catvChannelList);
    _catvChannelDefMap.insert(LC70_BAND_CATV_470_1002MHZ, catvChannelList);

    // 最初のグループ名を取得
    QVariant message;
    QString groupName;
    message.setValue(QString("SCAN結果"));
    if (!scanResult.isEmpty()) {
        _noValidScanResult = false;
//        groupName = getScanGroupName(scanResult.at(0).Band.toInt(), scanResult.at(0).Channel);
//        message.setValue(QString("取得チャンネル：%1〜%2 / %3").arg(scanResult.first().Channel)
//                         .arg(scanResult.last().Channel).arg(scanResult.size()));
    } else {
        _noValidScanResult = true;
//        message.setValue(QString("有効なチャンネルが見つかりません。"));
    }
    ScanResultData scanResultData;
    ScanResultGroupData scanGroupData;

    int elementCount = 0;
    int rowCount = 0;
    setScanResultGroupTitle(scanResultData, groupName, rowCount, elementCount);
    rowCount = getScanResultRowCount(elementCount);

    for (int index = 0; index < scanResult.size(); ++index) {
        QString bandName = getScanGroupName(scanResult.at(index).Band.toInt(), scanResult.at(index).Channel);
        if (groupName != bandName) {
            elementCount += padingScanResultData(scanResultData, scanGroupData, elementCount, rowCount);
            // グループが変化したので、ここまでのデータを登録する
            _scanResultModel->append(scanResultData);

            // 次のグループを開始する
            scanResultData = ScanResultData();
            rowCount = getScanResultRowCount(elementCount);
            groupName = bandName;
            setScanResultGroupTitle(scanResultData, groupName, rowCount, elementCount);
        }
        rowCount = getScanResultRowCount(elementCount);
        ++elementCount;
        scanGroupData.channel = scanResult.at(index).Channel;
        scanGroupData.colorType = getRowColorType(rowCount);
        scanResultData.groupModel->append(scanGroupData);
    }

    elementCount += padingScanResultData(scanResultData, scanGroupData, elementCount, rowCount);
    _scanResultModel->append(scanResultData);

    QVariant leftCaption;
    QVariant rightCaption;
    leftCaption.setValue(QString("保存する"));
    rightCaption.setValue(QString("しない"));
    emit requestToOpenPopup(SCAN_RESULT_LAYOUT, message, leftCaption, rightCaption, QVariant(QString("")));

    _basicPopup = _model->search(QString("BasicPopup"));
    if (_basicPopup == nullptr) {
        return;
    }
    connect(_basicPopup, SIGNAL(accept(bool)), this, SLOT(onAccept(bool)));
    connect(_basicPopup, SIGNAL(reject()), this, SLOT(onReject()));
    connect(_basicPopup, SIGNAL(select(int)), this, SLOT(onSelect(int)));
    connect(this, SIGNAL(requestToClose()), _basicPopup, SLOT(closePopup()));
    connect(this, SIGNAL(requestScrollUp()), _basicPopup, SLOT(scrollUp()));
    connect(this, SIGNAL(requestScrollDown()), _basicPopup, SLOT(scrollDown()));
    connect(this, SIGNAL(setScanResultRowCount(QVariant)), _basicPopup, SLOT(settingRowCount(QVariant)));

    // スキャン結果が空なら決定ボタンは選択できないようにする
    if (!scanResult.isEmpty()) {
        _basicPopup->setProperty("noValidScanResult", false);
        setTwoButton();
    } else {
        _basicPopup->setProperty("noValidScanResult", true);
        setTwoButton(true, true);
    }
    emit setScanResultRowCount(rowCount);

    _isOpened = true;
    _openPopupId = POPUP_SCAN_RESULT;
}

int PopupManager::padingScanResultData(ScanResultData &resultData, ScanResultGroupData &groupData, const int elementCount, const int rowCount) {
    int addCount = elementCount % SCAN_RESULT_ELEMENT_MAX;
    if (addCount != 0) {
        addCount = SCAN_RESULT_ELEMENT_MAX - addCount;
    }
    for (int j = 0; j < addCount; ++j) {
        groupData.channel = "";
        groupData.colorType = getRowColorType(rowCount);
        resultData.groupModel->append(groupData);
    }
    return addCount;
}

RowColorType PopupManager::getRowColorType(const int rowCount) {
    // 奇数、偶数行で色を分ける
    if ((rowCount % 2) == 0) {
        return BrightColor;
    } else {
        return DarkColor;
    }
}

int PopupManager::getScanResultRowCount(const int elementCount) {
    return floor(elementCount / SCAN_RESULT_ELEMENT_MAX);
}

void PopupManager::setScanResultGroupTitle(ScanResultData &resultData, const QString &title, const int rowCount, int &elementCount) {
    resultData.groupName = title;
    resultData.colorType = getRowColorType(rowCount);
    // グループタイトルの行もグリッドの行の一部として計算するため、グリッドの要素数分増やしておく
    elementCount += SCAN_RESULT_ELEMENT_MAX;
}

QString PopupManager::getScanGroupName(int band, QString channel) {
    LC70_BAND_T bandId = static_cast<LC70_BAND_T>(band);
    if (bandId == LC70_BAND_CATV_ALL) {
        // CATV のどの Band であるか特定する
        QMap<LC70_BAND_T, QList<ChannelDefinitionItem>>::iterator iterator;
        for (iterator = _catvChannelDefMap.begin(); iterator != _catvChannelDefMap.end(); ++iterator) {
            for (int j = 0; j < iterator.value().size(); ++j) {
                if (iterator.value().at(j).channelNumber == channel) {
                    return Correcter::displayBandGroupName(iterator.key());
                }
            }
        }
    }
    return Correcter::displayBandGroupName(bandId);
}

void PopupManager::onAcquiringFinished(bool complete)
{
    Q_UNUSED(complete);
    // データ取得中止確認を開いている間にデータ取得が終了した場合に備える
    if (_strongPopup) {
        emit requestToCloseStrong();
        disconnect(this, SIGNAL(requestToCloseStrong()), _strongPopup, SLOT(closePopup()));

        _strongPopup = nullptr;
    }

    close();

    _openPopupId = POPUP_ID_COUNT;
    _isOpened = false;
}

void PopupManager::onLowBatteryStatusChanged(bool isLowBattery)
{
    if (!_isOpened) {
        // ポップアップ表示中でなければ無視
        return;
    }
    if (!isLowBattery) {
        // バッテリ低下状態になったのでなければ無視
        return;
    }
    if (_openPopupId == POPUP_POWER_SUPPLY_SELECT2 || _openPopupId == POPUP_POWER_SUPPLY_SELECT3) {
        // 給電確認のポップアップを表示中にバッテリ低下状態になった場合は、給電確認を閉じて警告メッセージを表示
        onReject();
        openLowBattery();
    }
    // 給電中にバッテリ低下状態になった場合は、それぞれの画面で処理するためここでは処理しない
}

void PopupManager::emitRequestToOpenPopup(PopupLayoutType layout, const QString message, const QString leftCaption, const QString rightCaption, const QString centerCaption)
{
    emit requestToOpenPopup(layout, message, leftCaption, rightCaption, centerCaption);
}

void PopupManager::createPopupConnection(const bool isSelect)
{
    _basicPopup = _model->search(QString("BasicPopup"));
    if (_basicPopup == nullptr) {
        return;
    }
    connect(this, SIGNAL(requestToClose()), _basicPopup, SLOT(closePopup()));
    connect(_basicPopup, SIGNAL(reject()), this, SLOT(onReject()));
    connect(_basicPopup, isSelect ? SIGNAL(select(int)) : SIGNAL(accept(bool)), this, isSelect ? SLOT(onSelect(int)) : SLOT(onAccept(bool)));
}

void PopupManager::emitRequestToOpenStrongPopup(const QString message, const QString leftCaption, const QString rightCaption)
{
    emit requestToOpenStrongPopup(message, leftCaption, rightCaption);
}

void PopupManager::createStrongPopupConnection()
{
    _strongPopup = _model->search(QString("StrongPopup"));
    connect(this, SIGNAL(requestToCloseStrong()), _strongPopup, SLOT(closePopup()));
}

void PopupManager::emitRequestToOpenLowBatteryPopup()
{
    emit requestToOpenLowBatteryPopup();
}

void PopupManager::createLowBatteryPopupConnection()
{
    _lowBatteryPopup = _model->search(QString("LowBatteryPopup"));
    connect(this, SIGNAL(requestToCloseLowBattery()), _lowBatteryPopup, SLOT(closePopup()));
}

void PopupManager::setupOneButtonPopup(const QString message, const QString buttonCaption)
{
    emitRequestToOpenPopup(ONE_BUTTON_LAYOUT, message, buttonCaption);
    createPopupConnection();
    setOneButton();
}

void PopupManager::setupYesNoButtonPopup(const QString message, const bool isDefaultNo)
{
    emitRequestToOpenPopup(NORMAL_LAYOUT, message, "はい", "いいえ");
    createPopupConnection();
    setTwoButton(isDefaultNo);
}
