/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "screeninformations.h"

ScreenInformations::ScreenInformations(QObject *parent)
    : QObject(parent)
    , _screens()
{
    prepare();
}

ScreenInformations::~ScreenInformations()
{
}

void ScreenInformations::prepare(void)
{
    // 画面定義
    // パス名が不正確なものは適宜修正すること
    _screens.append({SCREEN_MAINFRAME, "", "MainFrame", "MainFrame.qml", BUTTON_PROHIBITION_003, QList<ScreenId>() << SCREEN_HOME});
#ifdef NEW_USER_SETTING
    _screens.append({SCREEN_HOME, "HOME", "Home", "home/Home.qml", BUTTON_PROHIBITION_011, QList<ScreenId>() << SCREEN_BAND << SCREEN_USER_SETTING << SCREEN_OTHER << SCREEN_SPECTRUM_ANALYZER_MENU << SCREEN_DATALOGGER_SETTING << SCREEN_BAND  << SCREEN_MEASUREMENT_DATA_MENU << SCREEN_MEASUREMENT_SETTING_MENU << SCREEN_SYSTEM_SETTING_MENU});
#else
    _screens.append({SCREEN_HOME, "HOME", "Home", "home/Home.qml", BUTTON_PROHIBITION_011, QList<ScreenId>() << SCREEN_BAND << SCREEN_USER_DATA_LOGGER_MENU << SCREEN_OTHER << SCREEN_SPECTRUM_ANALYZER_MENU << SCREEN_OPTICAL_MEASUREMENT << SCREEN_BAND  << SCREEN_DATA_MANAGEMENT_MENU << SCREEN_MEASUREMENT_SETTING_MENU << SCREEN_SYSTEM_SETTING_MENU});
#endif
    _screens.append({SCREEN_BAND, "Band", "Band", "measurement/Band.qml", BUTTON_PROHIBITION_009, QList<ScreenId>() << SCREEN_POLARIZATION << SCREEN_CATV_MENU << SCREEN_SINGLE_MEASUREMENT << SCREEN_MULTI_MEASUREMENT});
    _screens.append({SCREEN_LOCAL_OSCILLATOR_SETTING, "局部発振周波数", "LocalOscillatorSetting", "measurement/LocalOscillatorSetting.qml", BUTTON_PROHIBITION_009, QList<ScreenId>() << SCREEN_SINGLE_MEASUREMENT << SCREEN_MULTI_MEASUREMENT << SCREEN_ANTENNA_ADJUSTMENT << SCREEN_FILE_SELECTION});
    _screens.append({SCREEN_MODULATION, "変調方式", "Modulation", "measurement/Modulation.qml", BUTTON_PROHIBITION_009, QList<ScreenId>() << SCREEN_SINGLE_MEASUREMENT << SCREEN_MULTI_MEASUREMENT << SCREEN_THRESHOLD_SETTING});
    _screens.append({SCREEN_SCAN_SELECTION, "スキャン選択", "ScanSelection", "ScanSelection.qml", BUTTON_PROHIBITION_014, QList<ScreenId>() << SCREEN_SINGLE_MEASUREMENT << SCREEN_MULTI_MEASUREMENT});
    _screens.append({SCREEN_USER_DATA_LOGGER_MENU, "USER/データロガー", "UserDataLoggerMenu", "user/UserDataLoggerMenu.qml", BUTTON_PROHIBITION_010, QList<ScreenId>() << SCREEN_DATA_LOGGER << SCREEN_DATA_LOGGER << SCREEN_MANUAL_AUTO_SELECTION << SCREEN_DATA_LOGGER});
    _screens.append({SCREEN_USER, "ユーザ（SINGLE/MULTI）", "User", "User.qml", BUTTON_PROHIBITION_010, QList<ScreenId>() << SCREEN_USER_SETTING_SELECTION});
    _screens.append({SCREEN_USER_SETTING_SELECTION, "ユーザ設定呼び出し（SINGLE/MULTI）", "UserSettingSelection", "UserSettingSelection.qml", BUTTON_PROHIBITION_010, QList<ScreenId>() << SCREEN_LOCAL_OSCILLATOR_SETTING << SCREEN_MODULATION << SCREEN_SCAN_SELECTION << SCREEN_MANUAL_SETTING});
#ifdef NEW_USER_SETTING
    _screens.append({SCREEN_USER_SETTING, "USER設定", "UserSetting", "user/UserSetting.qml", BUTTON_PROHIBITION_019, QList<ScreenId>() << SCREEN_USER_DATALOGGER_SETTING});
#else
    _screens.append({SCREEN_USER_SETTING, "ユーザ設定", "UserSetting", "UserSetting.qml", BUTTON_PROHIBITION_014, QList<ScreenId>() << SCREEN_MANUAL_AUTO_SELECTION});
#endif
    _screens.append({SCREEN_MANUAL_AUTO_SELECTION, "手動／自動選択", "ManualAutoSelection", "user/ManualAutoSelection.qml", BUTTON_PROHIBITION_010, QList<ScreenId>() << SCREEN_DATA_LOGGER << SCREEN_AUTO_SETTING << SCREEN_DATA_LOGGER});
    _screens.append({SCREEN_MANUAL_SETTING, "手動設定", "ManualSetting", "ManualSetting.qml", BUTTON_PROHIBITION_002, QList<ScreenId>() << SCREEN_FILE_SELECTION});
    _screens.append({SCREEN_AUTO_SETTING, "自動設定", "Band", "measurement/Band.qml", BUTTON_PROHIBITION_010, QList<ScreenId>() << SCREEN_DATA_LOGGER << SCREEN_FILE_SELECTION << SCREEN_POLARIZATION << SCREEN_CATV_MENU});
    _screens.append({SCREEN_SCAN_RESULT, "SCAN結果", "ScanResult", "ScanResult.qml", BUTTON_PROHIBITION_010, QList<ScreenId>() << SCREEN_FILE_SELECTION});
    _screens.append({SCREEN_FILE_SELECTION, "登録ファイル選択", "FileSelection", "user/FileSelection.qml", BUTTON_PROHIBITION_010, QList<ScreenId>() << SCREEN_DATA_LOGGER});
    _screens.append({SCREEN_SINGLE_MEASUREMENT, "シングルチャンネル測定", "SingleMeasurement", "measurement/single/SingleMeasurement.qml", BUTTON_PROHIBITION_003, QList<ScreenId>()});
    _screens.append({SCREEN_CONSTELLATION, "", "", "Constellation.qml", BUTTON_PROHIBITION_003, QList<ScreenId>()});
    _screens.append({SCREEN_DELAY_PROFILE, "", "", "DelayProfile.qml", BUTTON_PROHIBITION_003, QList<ScreenId>()});
    _screens.append({SCREEN_MULTI_MEASUREMENT, "マルチチャンネル測定", "MultiMeasurement", "measurement/multi/MultiMeasurement.qml", BUTTON_PROHIBITION_003, QList<ScreenId>()});
    _screens.append({SCREEN_MEASUREMENT_LIST, "", "", "", BUTTON_PROHIBITION_001, QList<ScreenId>()});
    _screens.append({SCREEN_SPECTRUM_ANALYZER_MENU, "スペアナメニュー", "SpectrumAnalyzerMenu", "SpectrumAnalyzerMenu.qml", BUTTON_PROHIBITION_014, QList<ScreenId>() << SCREEN_FIXED_SPAN << SCREEN_CHANNEL_SELECTION});
    _screens.append({SCREEN_FIXED_SPAN, "固定SPAN", "FixedSpan", "FixedSpan.qml", BUTTON_PROHIBITION_010, QList<ScreenId>() << SCREEN_FIXED_SPAN_SPECTRUM_ANALYZER});
    _screens.append({SCREEN_CHANNEL_SELECTION, "CH指定", "ChannelSelection", "ChannelSelection.qml", BUTTON_PROHIBITION_014, QList<ScreenId>() << SCREEN_CHANNEL_SELECTION_SPECTRUM_ANALYZER});
    _screens.append({SCREEN_FIXED_SPAN_SPECTRUM_ANALYZER, "スペアナ（固定SPAN）", "FixedSpanSpectrumAnalyzer", "FixedSpanSpectrumAnalyzer.qml", BUTTON_PROHIBITION_004, QList<ScreenId>()});
    _screens.append({SCREEN_CHANNEL_SELECTION_SPECTRUM_ANALYZER, "スペアナ（CH指定）", "ChannelSelectionSおpectrumAnalyzer", "ChannelSelectionSpectrumAnalyzer.qml", BUTTON_PROHIBITION_004, QList<ScreenId>()});
    _screens.append({SCREEN_DC_MEASUREMENT, "DC測定", "DCMeasurement", "other/DCMeasurement.qml", BUTTON_PROHIBITION_007, QList<ScreenId>()});
    _screens.append({SCREEN_WAVELENGTH_SELECT, "波長測定", "WaveLengthSelect", "optical_setting/WaveLengthSelect.qml", BUTTON_PROHIBITION_015, QList<ScreenId>() << SCREEN_OPTICAL_MEASUREMENT});
    _screens.append({SCREEN_OPTICAL_MEASUREMENT, "光測定", "OpticalMeasurement", "optical_setting/OpticalMeasurement.qml", BUTTON_PROHIBITION_015, QList<ScreenId>()});
    _screens.append({SCREEN_SYSTEM_SETTING_MENU, "システム設定メニュー", "SystemSettingMenu", "system_setting/SystemSettingMenu.qml", BUTTON_PROHIBITION_010, QList<ScreenId>() << SCREEN_AUTO_POWER_OFF_SETTING << SCREEN_DATE_TIME_SETTING << SCREEN_INITIALIZATION << SCREEN_VOLUME_SETTING << SCREEN_BRIGHTNESS_SETTING << SCREEN_MODEL_INFORMATION << SCREEN_BATTERY_INFO << SCREEN_MANUAL});
    _screens.append({SCREEN_AUTO_POWER_OFF_SETTING, "オートパワーオフ設定", "AutoPowerOffSetting", "system_setting/AutoPowerOffSetting.qml", BUTTON_PROHIBITION_010, QList<ScreenId>()});
    _screens.append({SCREEN_DATE_TIME_SETTING, "日付設定", "DateTimeSetting", "system_setting/DateTimeSetting.qml", BUTTON_PROHIBITION_010, QList<ScreenId>()});
    _screens.append({SCREEN_VOLUME_SETTING, "音量設定", "VolumeSetting", "system_setting/VolumeSetting.qml", BUTTON_PROHIBITION_010, QList<ScreenId>()});
    _screens.append({SCREEN_INITIALIZATION, "初期化（工場出荷状態）", "Initialization", "system_setting/Initialization.qml", BUTTON_PROHIBITION_014, QList<ScreenId>()});
    _screens.append({SCREEN_MEASUREMENT_SETTING_MENU, "測定設定メニュー", "MeasurementSettingMenu", "measurement_setting/MeasurementSettingMenu.qml", BUTTON_PROHIBITION_010, QList<ScreenId>() << SCREEN_SWITCH_OPTICAL_COAXIAL_CABLE << SCREEN_SWITCH_MER_CN << SCREEN_LOCAL_OSCILLATOR << SCREEN_CABLE_OFFSET << SCREEN_CATV_CHANNEL_FREQUENCY << SCREEN_CONSTELLATION_SETTING << SCREEN_THRESHOLD << SCREEN_COMPASS });
    _screens.append({SCREEN_CABLE_OFFSET, "ケーブルオフセット", "LevelOffset", "measurement_setting/LevelOffset.qml", BUTTON_PROHIBITION_010, QList<ScreenId>()});
    _screens.append({SCREEN_LOCAL_OSCILLATOR, "局部発振周波数", "LocalOscillator", "measurement_setting/LocalOscillator.qml", BUTTON_PROHIBITION_010, QList<ScreenId>()});
    _screens.append({SCREEN_THRESHOLD, "インジケータ（BAND選択）", "Band", "measurement/Band.qml", BUTTON_PROHIBITION_010, QList<ScreenId>() << SCREEN_THRESHOLD_SETTING  << SCREEN_BROADCAST_SETTING << SCREEN_CATV_MENU});
    _screens.append({SCREEN_THRESHOLD_SETTING, "インジケータ", "ThresholdSetting", "measurement_setting/ThresholdSetting.qml", BUTTON_PROHIBITION_010, QList<ScreenId>()});
    _screens.append({SCREEN_SWITCH_MER_CN, "MER/CN切り替え", "SwitchMERCN", "measurement_setting/SwitchMERCN.qml", BUTTON_PROHIBITION_014, QList<ScreenId>()});
    _screens.append({SCREEN_CATV_CHANNEL_FREQUENCY, "CATVチャンネル周波数", "CATVChannelFrequency", "measurement_setting/CATVChannelFrequency.qml", BUTTON_PROHIBITION_014, QList<ScreenId>()});
    _screens.append({SCREEN_CONSTELLATION_SETTING, "コンスタレーション表示設定", "ConstellationSetting", "measurement_setting/ConstellationSetting.qml", BUTTON_PROHIBITION_014, QList<ScreenId>()});
    _screens.append({SCREEN_SWITCH_OPTICAL_COAXIAL_CABLE, "光同軸切替え設定", "SwitchOpticalCoaxialCable", "measurement_setting/SwitchOpticalCoaxialCable.qml", BUTTON_PROHIBITION_014, QList<ScreenId>()});
    _screens.append({SCREEN_DATA_LOGGER, "データロガー", "DataLogger", "data_logger/DataLogger.qml", BUTTON_PROHIBITION_010, QList<ScreenId>() << SCREEN_SINGLE_MEASUREMENT << SCREEN_MULTI_MEASUREMENT << SCREEN_DATALOGGER_MEASUREMENT_LIST << SCREEN_FILE_SELECTION});
    _screens.append({SCREEN_LOGGING_SETTING, "取得設定", "LoggingSetting", "LoggingSetting.qml", BUTTON_PROHIBITION_010, QList<ScreenId>()});
    _screens.append({SCREEN_START_SELECTION, "取得開始", "StartSelection", "StartSelection.qml", BUTTON_PROHIBITION_014, QList<ScreenId>() << SCREEN_DATALOGGER_MEASUREMENT_LIST});
    _screens.append({SCREEN_DATALOGGER_MEASUREMENT_LIST, "データロガー測定リスト", "MeasurementList", "data_logger/MeasurementList.qml", BUTTON_PROHIBITION_010, QList<ScreenId>()});
    _screens.append({SCREEN_DATA_MANAGEMENT_MENU, "データ管理メニュー", "DataManagementMenu", "data_management/DataManagementMenu.qml", BUTTON_PROHIBITION_010, QList<ScreenId>() << SCREEN_MEASUREMENT_DATA_MENU << SCREEN_DATA_LOGGER_MENU << SCREEN_USER_MEASUREMENT_SETTING_MENU});
    _screens.append({SCREEN_MEASUREMENT_DATA_MENU, "測定データメニュー", "MeasurementDataMenu", "data_management/MeasurementDataMenu.qml", BUTTON_PROHIBITION_010, QList<ScreenId>() << SCREEN_MEASUREMENT_RESURT_DATA_LIST << SCREEN_MEASUREMENT_RESULT_DATA_COPY_DELETION});
    _screens.append({SCREEN_MEDIA_SELECTION, "メディア選択", "MediaSelection", "MediaSelection.qml", BUTTON_PROHIBITION_014, QList<ScreenId>() << SCREEN_SAVED_DATA_LIST << SCREEN_ALL_DELETION << SCREEN_ALL_COPY});
    _screens.append({SCREEN_SAVED_DATA_LIST, "保存データの呼び出し", "SavedDataList", "SavedDataList.qml", BUTTON_PROHIBITION_010, QList<ScreenId>()});
    _screens.append({SCREEN_ALL_DELETION, "保存データの全消去", "AllDeletion", "AllDeletion.qml", BUTTON_PROHIBITION_014, QList<ScreenId>()});
    _screens.append({SCREEN_ALL_COPY, "保存データの全コピー", "AllCopy.qml", "AllCopy", BUTTON_PROHIBITION_010, QList<ScreenId>()});
    _screens.append({SCREEN_DATA_LOGGER_MENU, "データロガー取得データメニュー", "DataLoggerMenu", "data_management/DataLoggerMenu.qml", BUTTON_PROHIBITION_010, QList<ScreenId>() << SCREEN_DATA_LOGGER_LIST});
    _screens.append({SCREEN_POPUP_FRAME, "", "PopupFrame", "popup/PopupFrame.qml", BUTTON_PROHIBITION_017, QList<ScreenId>()});
    _screens.append({SCREEN_POLARIZATION, "偏波面選択", "Polarization", "measurement/Polarization.qml", BUTTON_PROHIBITION_017, QList<ScreenId>() << SCREEN_LOCAL_OSCILLATOR_SETTING << SCREEN_FILE_SELECTION << SCREEN_SINGLE_MEASUREMENT << SCREEN_MULTI_MEASUREMENT});
    _screens.append({SCREEN_MENULIST, "メニューリスト", "", "", BUTTON_PROHIBITION_001, QList<ScreenId>()});
    _screens.append({SCREEN_BRIGHTNESS_SETTING, "明るさ設定", "BrightnessSetting", "system_setting/BrightnessSetting.qml", BUTTON_PROHIBITION_010, QList<ScreenId>()});
    _screens.append({SCREEN_BROADCAST_SETTING, "放送方式設定", "BroadcastSetting", "measurement_setting/BroadcastSetting.qml", BUTTON_PROHIBITION_017, QList<ScreenId>{} << SCREEN_THRESHOLD_SETTING});
    _screens.append({SCREEN_USER_MEASUREMENT_SETTING_MENU, "ユーザ測定設定メニュー", "UserMeasurementSettingMenu", "data_management/UserMeasurementSettingMenu.qml", BUTTON_PROHIBITION_010, QList<ScreenId>() << SCREEN_DATA_LOGGER});
    _screens.append({SCREEN_MEASUREMENT_RESURT_DATA_LIST, "測定結果データ一覧表示", "MeasurementResultDataList", "data_management/MeasurementResultDataList.qml", BUTTON_PROHIBITION_010, QList<ScreenId>() << SCREEN_MEASUREMENT_RESURT_DATA_PNG << SCREEN_MEASUREMENT_RESURT_DATA_CSV << SCREEN_DATA_LOGGER_DETAILS_DATA});
    _screens.append({SCREEN_DATA_LOGGER_LIST, "データロガー取得データ一覧表示", "DataLoggerDataList", "data_management/DataLoggerDataList.qml", BUTTON_PROHIBITION_010, QList<ScreenId>() << SCREEN_DATA_LOGGER_DETAILS_DATA});
    _screens.append({SCREEN_MEASUREMENT_RESURT_DATA_PNG, "測定結果データ表示(PNG)", "MeasurementResultPngData", "data_management/MeasurementResultPngData.qml", BUTTON_PROHIBITION_010, QList<ScreenId>()});
    _screens.append({SCREEN_MEASUREMENT_RESURT_DATA_CSV, "測定結果データ表示(CSV)", "MeasurementResultCsvData", "data_management/MeasurementResultCsvData.qml", BUTTON_PROHIBITION_010, QList<ScreenId>()});
    _screens.append({SCREEN_DATA_LOGGER_DETAILS_DATA, "データロガー取得データ表示(詳細)", "DataLoggerDetailsData", "data_management/DataLoggerDetailsData.qml", BUTTON_PROHIBITION_010, QList<ScreenId>()});
    _screens.append({SCREEN_ANTENNA_ADJUSTMENT, "アンテナ調整", "AntennaAdjustment", "measurement/AntennaAdjustment.qml", BUTTON_PROHIBITION_018, QList<ScreenId>()});
    _screens.append({SCREEN_CATV_MENU, "CATV", "CATV", "measurement/CATV.qml", BUTTON_PROHIBITION_010, QList<ScreenId>() << SCREEN_MODULATION << SCREEN_SINGLE_MEASUREMENT << SCREEN_MULTI_MEASUREMENT << SCREEN_THRESHOLD_SETTING << SCREEN_FILE_SELECTION});
    _screens.append({SCREEN_MODEL_INFORMATION, "バージョン情報", "ModelInformation", "system_setting/ModelInformation.qml", BUTTON_PROHIBITION_001, QList<ScreenId>() });
    _screens.append({SCREEN_MEASUREMENT_RESULT_DATA_COPY, "測定データコピー", "MeasurementResultCopy", "data_management/MeasurementResultCopy.qml", BUTTON_PROHIBITION_010, QList<ScreenId>()});
    _screens.append({SCREEN_MEASUREMENT_RESULT_DATA_DELETION, "測定データ消去", "MeasurementResultDeletion", "data_management/MeasurementResultDeletion.qml", BUTTON_PROHIBITION_010, QList<ScreenId>()});
    _screens.append({SCREEN_MEASUREMENT_RESULT_DATA_COPY_DELETION, "測定データコピー削除", "MeasurementResultCopyDelete", "data_management/MeasurementResultCopyDelete.qml", BUTTON_PROHIBITION_010, QList<ScreenId>()});
    _screens.append({SCREEN_COMPASS, "コンパス", "MeasurementAdLevel", "other/Compass.qml", BUTTON_PROHIBITION_010, QList<ScreenId>()});

#ifdef NEW_USER_SETTING
    _screens.append({SCREEN_USER_DATALOGGER_SETTING, "USER設定呼び出し", "UserDataLoggerSetting", "user/UserDataLoggerSetting.qml", BUTTON_PROHIBITION_020, QList<ScreenId>() << SCREEN_USER_MEASUREMENT_SELECTION << SCREEN_DATALOGGER_MEASUREMENT_LIST});
    _screens.append({SCREEN_USER_MEASUREMENT_SELECTION, "測定メニュー選択", "UserMeasurementSelection", "user/UserMeasurementSelection.qml", BUTTON_PROHIBITION_019, QList<ScreenId>() << SCREEN_SINGLE_MEASUREMENT << SCREEN_MULTI_MEASUREMENT});
    _screens.append({SCREEN_DATALOGGER_SETTING, "データロガー", "DataLoggerSetting", "data_logger/DataLoggerSetting.qml", BUTTON_PROHIBITION_019, QList<ScreenId>() << SCREEN_USER_DATALOGGER_SETTING});
#endif

    _screens.append({SCREEN_OTHER, "その他", "otherMenu", "other/Other.qml", BUTTON_PROHIBITION_010, QList<ScreenId>() << SCREEN_DC_MEASUREMENT << SCREEN_OPTICAL_MEASUREMENT << SCREEN_COMPASS});
    _screens.append({SCREEN_BATTERY_INFO, "バッテリー情報", "BatteryInfo", "system_setting/BatteryInformation.qml", BUTTON_PROHIBITION_010, QList<ScreenId>()});
    _screens.append({SCREEN_MANUAL, "取扱説明書", "manual", "system_setting/Manual.qml", BUTTON_PROHIBITION_010, QList<ScreenId>()});
}
ScreenInformation ScreenInformations::screen(const ScreenId &id) const
{
    if (SCREEN_MAINFRAME <= id && id < SCREEN_ID_COUNT) {
        return _screens[id];
    } else {
        return _screens[SCREEN_HOME];
    }
}
