/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SCREENINFORMATIONS_H
#define SCREENINFORMATIONS_H

#include <QObject>
#include "screenid.h"
#include "buttonprohibition.h"

/**
 * @brief 画面情報構造体
 */
struct ScreenInformation {
    ScreenId id;                            //!< 画面ID
    QString screenName;                     //!< 画面名
    QString objectName;                     //!< オブジェクト名(QML の objectName プロパティと同一であること)
    QString qml;                            //!< QML ファイルのパス
    ButtonProhibitionId prohibitionId;      //!< ボタン禁則ID
    QList<ScreenId> next;                   //!< 次の画面ID
};

/**
 * @brief 画面データクラス
 */
class ScreenInformations : public QObject
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクタ
     * @param parent 親オブジェクト
     */
    explicit ScreenInformations(QObject *parent = nullptr);

    /**
     * @brief デストラクタ
     */
    ~ScreenInformations();

    /**
     * @brief 画面IDに対応した画面情報を取得する
     * @param id 画面ID
     * @return 画面情報
     */
    ScreenInformation screen(const ScreenId &id) const;

private:
    QList<ScreenInformation> _screens;  //!< 画面定義

    /**
     * @brief 画面情報設定
     */
    void prepare(void);

};

#endif // SCREENINFORMATIONS_H
