/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef VIEWMODELFACTORY_H
#define VIEWMODELFACTORY_H

#include <QObject>
#include "abstractviewmodel.h"
#include "levelcheckermodel.h"

/**
 * @brief 個々の画面に対する ViewModel を生成するクラス
 */
class ViewModelFactory : public QObject
{
    Q_OBJECT
public:
    static ViewModelFactory &instance(QObject *parent = nullptr);

    ViewModelFactory(const ViewModelFactory &) = delete;
    void operator = (const ViewModelFactory &) = delete;

    ~ViewModelFactory();

    /**
     * @brief 画面 ID に対応する ViewModel を特定して返す
     * @param screenId 画面 ID
     * @return 画面 ID に対応する ViewModel
     */
    AbstractViewModel *specify(const ScreenId &screenId);

    /**
     * @brief Model と紐付いた ViewModel を内部に生成する
     * @param parent 親オブジェクト
     * @param model Model のインスタンス
     */
    void prepare(QObject *parent, LevelCheckerModel *model = nullptr);

signals:

private:
    /**
     * @brief コンストラクター
     * @param parent 親オブジェクト
     */
    ViewModelFactory(QObject *parent = nullptr);
    QList<AbstractViewModel *> _viewModels;     //!< ViewModel のインスタンスのリスト
    LevelCheckerModel *_model;                  //!< Model のインスタンス
};

#endif // VIEWMODELFACTORY_H
