/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef HOMEVIEWMODEL_H
#define HOMEVIEWMODEL_H

#include "abstractviewmodel.h"
#include "buttonoperation.h"

/**
 * @brief HOME ViewModel
 */
class HomeViewModel : public AbstractViewModel
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクター
     * @param screenId 画面 ID
     * @param model Model クラスのポインター
     * @param parent 親オブジェクト
     */
    explicit HomeViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent = nullptr);

    /**
     * @brief デストラクタ
     */
    virtual ~HomeViewModel();

    /**
     * @brief 画面Active 時の処理
     *
     * 波長データを取得して画面に表示する
     */
    void activate() override;

    /**
     * @brief 画面deactivate 時の処理
     */
    void deactivate() override;

    /**
     * @brief サブ CPU のスタンバイ
     */
    virtual void standBy(void) override;

    /**
     * @brief 遷移先画面で参照する遷移前画面のデータ設定
     */
    virtual void setTakeOver() override;

signals:
    void requestSetTakeOver(QVariant, QVariant);

    /**
     * @brief スタンバイ要求
     */
    void requestStandBy();

protected:
    virtual void onKeyStatus(ButtonId id) override;

    void onButtonPress(ButtonId id) override;

private slots:
    virtual void onRequest(int condition) override;

    /**
     * @brief スタンバイ要求受信時の処理
     */
    void onRequestStandBy();

private:
    static const int BUTTON_COLUMN_NUMBER;
    static const int BUTTON_ROW_NUMBER;

    ButtonOperation _buttonOperation;

    QString _activeButton;

    bool _isDeveloperMode;
    int _developerOnOff;
    int _developerSequence;

    /**
     * @brief moveCursor
     * @param id
     */
    void moveCursor(ButtonId id);

    /**
     * @brief デベロッパーモード表示の切替
     * @param isDeveloperMode デベロッパーモード表示のOn/Off
     */
    void changeDeveloperMode(bool isDeveloperMode);
};

#endif // HOMEVIEWMODEL_H
