/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef LEVELCHECKERVIEWMODEL_H
#define LEVELCHECKERVIEWMODEL_H

#include <QObject>
#include <QQmlApplicationEngine>
#include <QQuickWindow>
#include <QElapsedTimer>
#include "levelcheckermodel.h"
#include "viewmodelfactory.h"
#include "mainframeviewmodel.h"
#include "screentransitioncontroller.h"
#include "popupmanager.h"
#include "errormanager.h"

class LevelCheckerViewModel : public QObject
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクター
     * @param engine QML のインスタンスを作成するクラスのポインター
     * @param model Model のインスタンスのポインター
     * @param window アプリケーションを表示するウィンドウ
     * @param timer 処理時間計測用のタイマー
     * @param parent 親オブジェクト
     */
    explicit LevelCheckerViewModel(QQmlApplicationEngine *engine, LevelCheckerModel *model, QQuickWindow *window,
                                   QElapsedTimer *timer, QObject *parent = nullptr);

    /**
     *  @brief デストラクター
     */
    ~LevelCheckerViewModel();

signals:

private:
    QQmlApplicationEngine *_engine;             //!< QML のインスタンスを作成するクラスのポインター
    LevelCheckerModel *_model;                  //!< Model のインスタンスのポインター
    ViewModelFactory &_factory;                 //!< ViewModel のファクトリー
    ScreenTransitionController *_controller;    //!< 画面遷移コントローラー
    MainFrameViewModel *_mainFrame;             //!< MainFrameViewModel のポインター
    PopupManager *_popupManager;                //!< ポップアップ表示管理クラスのポインター
    ErrorManager *_errorManager;                //!< エラー管理クラスのポインター
    QQuickWindow *_window;                      //!< アプリケーションを表示するするウィンドウ

    /**
     * @brief MainFrame の作成
     * @param timer 処理時間計測用のタイマー
     */
    void create(QElapsedTimer *timer);

private slots:
    /**
     * @brief Model から通知されたエラー情報を受信
     * @param errorInformation エラー情報
     */
    void onNotifyErrorOccured(LC70_FAIL_INFO_T errorInformation);
};

#endif // LEVELCHECKERVIEWMODEL_H
