/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "localoscillatorsettingviewmodel.h"
#include "mainframeviewmodel.h"
#include "correcter.h"

QVector<QVector<QString>> localOscillatorSettingButtonData1 = {
    { {"m1"} }
};

QVector<QVector<QString>> localOscillatorSettingButtonData2 = {
    { {"m1"}, {"m2"}, {""}}
};

QVector<QVector<QString>> localOscillatorSettingButtonData3 = {
    { {"m1"}, {"m2"}, {"m3"} }
};

QVector<QVector<QString>> localOscillatorSettingButtonData4 = {
    { {"m1"}, {"m2"}, {"m3"} },
    { {"m4"}, {""}, {""}}
};

QVector<QVector<QString>> localOscillatorSettingButtonData5 = {
    { {"m1"}, {"m2"}, {"m3"} },
    { {"m4"}, {"m5"}, {""}}
};

QVector<QVector<QString>> localOscillatorSettingButtonData6 = {
    { {"m1"}, {"m2"}, {"m3"} },
    { {"m4"}, {"m5"}, {"m6"} }
};

const int LocalOscillatorSettingViewModel::BUTTON_COLUMN_NUMBER1 = 1;
const int LocalOscillatorSettingViewModel::BUTTON_ROW_NUMBER1    = 1;

const int LocalOscillatorSettingViewModel::BUTTON_COLUMN_NUMBER2 = 2;
const int LocalOscillatorSettingViewModel::BUTTON_ROW_NUMBER3    = 3;

const int LocalOscillatorSettingViewModel::EDIT_LOCAL_FREQUENCY_INDEX = 5;

LocalOscillatorSettingViewModel::LocalOscillatorSettingViewModel(ScreenId screenId, LevelCheckerModel *&model,
        QObject *parent)
    : AbstractViewModel(screenId, model, parent)
    , _selectedBand(LC70_BAND_UNDEF)
    , _selectedPolarization("")
    , _localOscillatorList()
    , _channelList()
    , _fromAutoSetting(false)
    , _broadBandModulationSetting()
    , _failureCode(0)
    , _actionInFailure(LC70_FAIL_CTL_NONE)
{
    _buttonOperation.setButtonName(BUTTON_COLUMN_NUMBER2, BUTTON_ROW_NUMBER3, localOscillatorSettingButtonData6);

    _activeButton = localOscillatorSettingButtonData6[0][0];
    _buttonOperation.setActiveObject(_activeButton);
}

LocalOscillatorSettingViewModel::~LocalOscillatorSettingViewModel()
{

}

void LocalOscillatorSettingViewModel::setTakeOver()
{
    // 選択したボタンに対応する局発周波数を画面共有データに設定する。
    uint value = _valueMap.value(_activeButton);
    emit requestSetTakeOver("selectedLocalOscillator", value);
}

void LocalOscillatorSettingViewModel::activate(void)
{
    connect(this, SIGNAL(requestSetTakeOver(QVariant, QVariant)), _view, SLOT(backup(QVariant, QVariant)));
    connect(this, SIGNAL(requestGetTakeOver()), _view, SLOT(getTakeOver()));
    connect(_mainFrame, SIGNAL(requestToScan()), this, SLOT(onRequestToScan()));
    connect(_mainFrame, SIGNAL(requestToStopScanning()), this, SLOT(onRequestToStopScanning()));
    connect(_mainFrame, SIGNAL(notifyPowerSupplyError(uint16_t, uint8_t, QString)), this, SLOT(detectPowerSupplyError(uint16_t, uint8_t, QString)));
    connect(_model, SIGNAL(scanningFinished(bool)), this, SLOT(onScanningFinished(bool)));
    connect(_model, SIGNAL(scanningChannelResult(int,LC70_MEAS_MULTI_RESULT_T)), this, SLOT(onScanningChannelResult(int,LC70_MEAS_MULTI_RESULT_T)));
    connect(this, SIGNAL(progress(double)), _mainFrame, SIGNAL(progress(double)));
    connect(this, SIGNAL(requestToReScan()), this, SLOT(onRequestToReScan()), Qt::QueuedConnection);
    connect(this, SIGNAL(requestToShowRegistScanResultPopup()), this, SLOT(onRequestToShowRegistScanResultPopup()), Qt::QueuedConnection);
    emit requestGetTakeOver();

    // マニュアル測定 放送方式、変調方式の取得
    _broadBandModulationSetting.clear();
    _model->getValue(VALUE_BROADBANDSYSTEM_MODULATION, _broadBandModulationSetting);

    QObject *target = nullptr;
    if (_view) {
        target = _view->findChild<QObject *>("takeOverData");
    }

    if (target) {
        QVariant value = target->property("selectedBand");
        bool ok = false;
        int band = value.toInt(&ok);

        if (!ok) {
            return;
        }

        _selectedBand = static_cast<LC70_BAND_T>(band);

        value = target->property("selectedPolarization");
        _selectedPolarization = value.toString();

        // 局発周波数情報を取得する
        QList<uint32_t> localOscillatorList;
        getLocalOscillatorList(localOscillatorList);
        _localOscillatorList = localOscillatorList;
    }

    _fromAutoSetting = _takeOver["autoSettingPolarization"].toBool();

    // 先頭のボタンをアクティブにする
    resetToInitialButtonState(localOscillatorSettingButtonData6[0][0], _activeButton, _buttonOperation);

    // ボタン名と値を紐付けたMapを初期化する。
    _valueMap.clear();

    setButtonMessage();
}

void LocalOscillatorSettingViewModel::deactivate()
{
    AbstractViewModel::deactivate();
    disconnect(this, SIGNAL(requestSetTakeOver(QVariant, QVariant)), _view, SLOT(backup(QVariant, QVariant)));
    disconnect(this, SIGNAL(requestGetTakeOver()), _view, SLOT(getTakeOver()));
    disconnect(_mainFrame, SIGNAL(requestToScan()), this, SLOT(onRequestToScan()));
    disconnect(_mainFrame, SIGNAL(requestToStopScanning()), this, SLOT(onRequestToStopScanning()));
    disconnect(_mainFrame, SIGNAL(notifyPowerSupplyError(uint16_t, uint8_t, QString)), this, SLOT(detectPowerSupplyError(uint16_t, uint8_t, QString)));
    disconnect(_model, SIGNAL(scanningFinished(bool)), this, SLOT(onScanningFinished(bool)));
    disconnect(_model, SIGNAL(scanningChannelResult(int,LC70_MEAS_MULTI_RESULT_T)), this, SLOT(onScanningChannelResult(int,LC70_MEAS_MULTI_RESULT_T)));
    disconnect(this, SIGNAL(progress(double)), _mainFrame, SIGNAL(progress(double)));
    disconnect(this, SIGNAL(requestToReScan()), this, SLOT(onRequestToReScan()));
    disconnect(this, SIGNAL(requestToShowRegistScanResultPopup()), this, SLOT(onRequestToShowRegistScanResultPopup()));

    QObject *target = nullptr;
    if (_view) {
        target = _view->findChild<QObject *>(_activeButton);
    }
    if (target) {
        target->setProperty("activebg", "local_oscillator_select.png");
    }
}

void LocalOscillatorSettingViewModel::suspend()
{
    // 給電を停止
    _powerSupply = LC70_POWER_SUPPLY_OFF;
    _model->setPowerSupply(_powerSupply);
    _model->removeMenuList(MenuListIconIndex::POWER_SUPPLY_ICON);

    _failureCode = 0;

    AbstractViewModel::suspend();
}

void LocalOscillatorSettingViewModel::moveCursor(ButtonId buttonId)
{
    if ((buttonId == BUTTON_UP) || (buttonId == BUTTON_DOWN) || (buttonId == BUTTON_RIGHT) || (buttonId == BUTTON_LEFT)) {

        QString nextButton;
        bool ret = _buttonOperation.nextActiveObject(buttonId, nextButton);

        if (ret) {

            // inactive
            propertyChange(_activeButton, "active", "false");

            // active
            propertyChange(nextButton, "active", "true");

            _activeButton = nextButton;
            _buttonOperation.setActiveObject(_activeButton);
        }
    }
}

void LocalOscillatorSettingViewModel::onKeyStatus(ButtonId id)
{
    // Home, Escape ボタンはベースクラスで対応
    AbstractViewModel::onKeyStatus(id);

    if (id == BUTTON_ENTER) {
        enterKey();
    } else if (id == BUTTON_USER) {
#ifdef NEW_USER_SETTING
        emit requestDirect(SCREEN_USER_SETTING, true);
#else
        emit requestDirect(SCREEN_USER_DATA_LOGGER_MENU, true);
#endif
    } else {
        moveCursor(id);
    }
}

void LocalOscillatorSettingViewModel::onButtonPress(ButtonId id)
{
    if (id == BUTTON_ENTER) {
        QObject *target = nullptr;
        if (_view) {
            target = _view->findChild<QObject *>(_activeButton);
        }
        if (target) {
            target->setProperty("activebg", "combtn_p.png");
        }
    }
}

void LocalOscillatorSettingViewModel::onSelect(PopupId popupId, int index)
{
    if (popupId == POPUP_SCAN_RESULT) {
        // スキャン結果を採用する
        selectReactionScanResult(index);
    } else if (popupId == POPUP_POWER_SUPPLY_SELECT3) {
        if (index == FIXED_15V) {
            // 15v固定 給電
            _powerSupply = LC70_POWER_SUPPLY_15V;
            _model->setPowerSupply(_powerSupply);
            _model->replaceMenuList(MenuListIconIndex::POWER_SUPPLY_ICON, Correcter::powerSupplyIcon(_powerSupply));
        } else if (index == H15V11) {
            // 水平15v/垂直11v 給電
            if (_selectedBand == LC70_BAND_JCSAT4) {
                // 偏波による分岐
                if (_takeOver["selectedPolarization"].toString() == HORIZONTALLY_POLARIZE) {
                    _powerSupply = LC70_POWER_SUPPLY_15V_P;
                    _model->setPowerSupply(_powerSupply);
                    _model->replaceMenuList(MenuListIconIndex::POWER_SUPPLY_ICON, Correcter::powerSupplyIcon(_powerSupply));
                } else if (_takeOver["selectedPolarization"].toString() == VERTICALLY_POLARIZE) {
                    _powerSupply = LC70_POWER_SUPPLY_11V_P;
                    _model->setPowerSupply(_powerSupply);
                    _model->replaceMenuList(MenuListIconIndex::POWER_SUPPLY_ICON, Correcter::powerSupplyIcon(_powerSupply));
                }
            } else if (_selectedBand == LC70_BAND_JCSAT3 || _selectedBand == LC70_BAND_SCCB || _selectedBand == LC70_BAND_SCCC) {
                // 偏波による分岐
                if (_takeOver["selectedPolarization"].toString() == HORIZONTALLY_POLARIZE) {
                    _powerSupply = LC70_POWER_SUPPLY_15V;
                    _model->setPowerSupply(_powerSupply);
                    _model->replaceMenuList(MenuListIconIndex::POWER_SUPPLY_ICON, Correcter::powerSupplyIcon(_powerSupply));
                } else if (_takeOver["selectedPolarization"].toString() == VERTICALLY_POLARIZE) {
                    _powerSupply = LC70_POWER_SUPPLY_11V;
                    _model->setPowerSupply(_powerSupply);
                    _model->replaceMenuList(MenuListIconIndex::POWER_SUPPLY_ICON, Correcter::powerSupplyIcon(_powerSupply));
                } else {
                    _powerSupply = LC70_POWER_SUPPLY_15V;
                    _model->setPowerSupply(_powerSupply);
                    _model->replaceMenuList(MenuListIconIndex::POWER_SUPPLY_ICON, Correcter::powerSupplyIcon(_powerSupply));
                }
            }
        }
        QTimer::singleShot(100, this, SLOT(onRequestScanConfirm()));
    } else {
        // nothing to do
    }
}

void LocalOscillatorSettingViewModel::onAccept(PopupId popupId, bool okOnly)
{
    Q_UNUSED(okOnly);

    AbstractViewModel::onAccept(popupId, okOnly);

    if (popupId == POPUP_POWER_SUPPLY_ERROR_MANUAL_MEASURING) {
        // nothing to do.
    } else if (popupId == POPUP_CONFIRM_REGIST_SCAN_RESULT) {
        // 保存先選択画面へ遷移
        // 遷移先画面はScreenTransitioncontrollerにて決まる
#ifdef NEW_USER_SETTING
        // 保存先選択で USER データロガー設定を呼び出す
        emit requestSetTakeOver("userDataloggerFunction", CHANNEL_EDIT_SELECT_DESTINATION);
        emit requestDirect(SCREEN_USER_DATALOGGER_SETTING, false);
#else
        onRequest(0);
#endif
    } else {
        // nothing to do
    }
}

void LocalOscillatorSettingViewModel::enterKey()
{
    if (_fromAutoSetting) {
        if (isLowBattery()) {
            // バッテリ低下状態中は給電開始させない
            onRequestScanConfirm();
            return;
        }
        // 給電確認ダイアログを表示する
        emit requestToShowPopup(POPUP_POWER_SUPPLY_SELECT3);
    } else {
        // 遷移先固定
        onRequest(0);
    }
}

void LocalOscillatorSettingViewModel::onReject(PopupId popupId)
{
    if (popupId == POPUP_POWER_SUPPLY_SELECT3) {
        // スキャン開始
        QTimer::singleShot(100, this, SLOT(onRequestScanConfirm()));
    }

    // ボタン押下の状態を元に戻す
    QObject *target = nullptr;
    if (_view) {
        target = _view->findChild<QObject *>(_activeButton);
    }

    if (target) {
        if (_activeButton == "m1") {
            target->setProperty("activebg", "localoscillatorbtn_r.png");
        } else if (_activeButton == "m2") {
            target->setProperty("activebg", "localoscillatorbtn_lr.png");
        } else if (_activeButton == "m3") {
            target->setProperty("activebg", "localoscillatorbtn_l.png");
        } else if (_activeButton == "m4") {
            target->setProperty("activebg", "localoscillatorbtn_r.png");
        } else if (_activeButton == "m5") {
            target->setProperty("activebg", "localoscillatorbtn_lr.png");
        } else if (_activeButton == "m6") {
            target->setProperty("activebg", "localoscillatorbtn_l.png");
        }
    }

    // 給電中だった場合は給電OFFにする
    if (_powerSupply != LC70_POWER_SUPPLY_OFF) {
        _powerSupply = LC70_POWER_SUPPLY_OFF;
        _model->setPowerSupply(_powerSupply);
        _model->replaceMenuList(MenuListIconIndex::POWER_SUPPLY_ICON, Correcter::powerSupplyIcon(_powerSupply));
    }

    // スキャン結果のアイコンを消去
    _model->removeMenuList(MenuListIconIndex::SCAN_ICON);
}

void LocalOscillatorSettingViewModel::onRequestToScan()
{
    // 指定BANDのチャンネルデータを取得
    _model->getChannelDefinitionList(_selectedBand, _channelList);

    // 保持したスキャン結果をクリアー
    _model->clearScanResult();

    // 局発周波数
    uint32_t localFrequency = _valueMap.value(_activeButton);

    // 変調方式
    // 本画面からスキャンを行うBANDの放送方式はすべて定義無しであるため固定値を設定
    unsigned int modulationValue = LC70_SETMOD_UNDEF;

    // 放送方式
    // 本画面からスキャンを行うBANDの放送方式はすべてDVBS2であるため固定値を設定
    uint16_t bdSys = LC70_BD_SYS_DVBS2;

    // 放送方式、変調方式の設定(定義ファイル 1.0.1 対応)
    QString polarization = _takeOver["selectedPolarization"].toString();
    uint16_t mod = Correcter::getModulationCondition(_selectedBand, bdSys, Correcter::convertPolarizationToWave(polarization), modulationValue, _broadBandModulationSetting);

    // スキャン実行を通知
    _model->writeLog(QString("USER・データロガー設定  自動  偏波面選択画面"),
                     QString("スキャン開始"));
    _model->scan(_channelList, AcquisitionTarget::NOT_ACQUISITION, localFrequency, bdSys, mod, false, _powerSupply);
}

void LocalOscillatorSettingViewModel::onScanningChannelResult(int index, LC70_MEAS_MULTI_RESULT_T result)
{
    if (result.ucLock == UNLOCKED) {
        // 無効判定
        _channelList[index].valid = false;
    }

    // スキャン結果の保持
    if(result.ucLock == LOCKED) {
        MeasureResult scanResult;
        scanResult.Received = true;

        scanResult.Band = QString::number(_channelList[index].band);
        scanResult.Channel = _channelList[index].channelNumber;
        scanResult.Status = result.usStat;
        scanResult.Level = result.ulLevel;
        scanResult.Mer = 0;
        scanResult.Ber = 0;
        scanResult.BroadcastSystem = result.usBdSys;
        scanResult.Modulation = result.ulModBitPtrn;
        scanResult.Layer = result.ucLayer;
        scanResult.Frequency = -1;
        scanResult.LocalOscillator = 0;
        _model->appendScanResult(scanResult);

        // スキャン結果で有効チャンネルが見つかった場合 ブザーを1度鳴動させる
        _model->buzzer(LC70_BUZZ_VOL_CHG, LC70_BUZZ_MODE_ONESHOT);
    }

    // プログレスバーの進捗を設定
    double value = static_cast<double>(index + 1) / static_cast<double>(_channelList.count()) * 100;
    emit progress(value);
}

void LocalOscillatorSettingViewModel::onRequestScanConfirm(void)
{
    emit requestToShowPopup(POPUP_SCAN_CONFIRMATION);
    return;
}

void LocalOscillatorSettingViewModel::onRequestToReScan()
{
    // 指定BANDのチャンネルデータを取得
    // スキャン中ポップアップを表示
    emit requestToShowPopup(POPUP_SCANNING);

    // スキャン開始時に給電が選択されていた場合は、再スキャン中も給電する
    if (_powerSupply != LC70_POWER_SUPPLY_OFF) {
        _model->setPowerSupply(_powerSupply);
        _model->replaceMenuList(MenuListIconIndex::POWER_SUPPLY_ICON, Correcter::powerSupplyIcon(_powerSupply));
    }

    // 再スキャン
    onRequestToScan();
}

void LocalOscillatorSettingViewModel::onRequestToStopScanning()
{
    // スキャン中止
    _model->writeLog(QString("USER・データロガー設定  自動  局部発信周波数選択画面"),
                     QString("スキャン中止"));
    _model->stopChannelScan();
}

void LocalOscillatorSettingViewModel::onScanningFinished(bool complete)
{
    _model->writeLog(QString("USER・データロガー設定  自動  局部発信周波数選択画面ｋ"),
                     QString("スキャン終了"));

    // 給電中だった場合は、一旦給電OFFにする
    if (_powerSupply != LC70_POWER_SUPPLY_OFF) {
        // 再スキャン時の給電有無を判断するため、_powerSupplyは更新しない
        _model->setPowerSupply(LC70_POWER_SUPPLY_OFF);
        _model->replaceMenuList(MenuListIconIndex::POWER_SUPPLY_ICON, Correcter::powerSupplyIcon(LC70_POWER_SUPPLY_OFF));
    }

    if (complete) {
        // スキャン完了時 ブザーを1度鳴動させる
        _model->buzzer(LC70_BUZZ_ALL_CH_SCAN, LC70_BUZZ_MODE_ONESHOT);

        emit requestToShowPopup(POPUP_SCAN_RESULT);
    } else {
        _model->removeMenuList(MenuListIconIndex::SCAN_ICON);
#ifdef NEW_USER_SETTING
        emit requestDirect(SCREEN_USER_SETTING, true);
#else
        emit requestDirect(SCREEN_USER_DATA_LOGGER_MENU, true);
#endif
    }
}

void LocalOscillatorSettingViewModel::selectReactionScanResult(const int index)
{
    if (index == 0) {
        // スキャンアイコン表示
        _model->replaceMenuList(MenuListIconIndex::SCAN_ICON, "icon_scan_n.png");
        emit requestToShowRegistScanResultPopup();
    } else {
        // 再スキャン
        emit requestToReScan();
    }
}

void LocalOscillatorSettingViewModel::onRequest(int condition)
{
    emit request(_screenId, condition);
    return;
}

void LocalOscillatorSettingViewModel::onLowBatteryStatusChanged(bool isLowBattery)
{
    if (isLowBattery && _powerSupply != LC70_POWER_SUPPLY_OFF) {
        // 給電を停止する
        _powerSupply = LC70_POWER_SUPPLY_OFF;
        _model->setPowerSupply(_powerSupply);
        _model->removeMenuList(MenuListIconIndex::POWER_SUPPLY_ICON);
        emit requestToShowLowBatteryPopup();
    }
}

void LocalOscillatorSettingViewModel::recover()
{
    AbstractViewModel::recover();

    if (_view) {
        connect(this, SIGNAL(requestSetTakeOver(QVariant, QVariant)), _view, SLOT(backup(QVariant, QVariant)));
        connect(this, SIGNAL(requestGetTakeOver()), _view, SLOT(getTakeOver()));
    }
}

static const QMap<int, QString> buttonNameMap = {
    {0, "m1"},
    {1, "m2"},
    {2, "m3"},
    {3, "m4"},
    {4, "m5"},
    {5, "m6"},
};

void LocalOscillatorSettingViewModel::setButtonMessage()
{
    for (int index = 0; index < _localOscillatorList.size(); ++index) {
        propertyChange(buttonNameMap.value(index), "message",
                       QString::number(_localOscillatorList.at(index) / float(1000000), 'f',
                                       getDecimalDigits(_localOscillatorList.at(index))));


        propertyChange(buttonNameMap.value(index), "visible", "true");

        // ボタン名をキーとして実値データを格納する
        _valueMap.insert(buttonNameMap.value(index), _localOscillatorList.at(index));
    }

    layoutSetting(_localOscillatorList.size());
}

void LocalOscillatorSettingViewModel::propertyChange(QString buttonName, QString propertyName, QString value)
{
    QObject *target = nullptr;
    if (_view) {
        target = _view->findChild<QObject *>(buttonName);
    }
    if (target) {
        if (propertyName == "message") {
            target->setProperty(propertyName.toUtf8().constData(), value);
        } else if (propertyName == "visible") {
            target->setProperty(propertyName.toUtf8().constData(), value);
        } else if (propertyName == "active") {
            target->setProperty(propertyName.toUtf8().constData(), value);
        } else if (propertyName == "activebg") {
            target->setProperty(propertyName.toUtf8().constData(), value);
        } else if (propertyName == "disable") {
            target->setProperty(propertyName.toUtf8().constData(), value);
        }
    }
}

void LocalOscillatorSettingViewModel::layoutSetting(int buttonCount)
{
    for (int index = 0; index < 6; ++index) {
        propertyChange(buttonNameMap.value(index), "visible",
                       index < buttonCount ? "true" : "false");
    }

    propertyChange(buttonNameMap.value(buttonCount - 1), "activebg", "localoscillatorbtn_one.png");

    // 選択できないボタンが active である場合、初期表示の際に先頭候補に変更する
    int currentActiveIndex = buttonNameMap.key(_activeButton, buttonNameMap.key(0));

    if (currentActiveIndex > (buttonCount - 1)) {
        currentActiveIndex = 0;
    }

    _activeButton = buttonNameMap.value(currentActiveIndex, 0);

    QObject *target = nullptr;
    if (_view) {
        target = _view->findChild<QObject *>(_activeButton);
    }
    if (target) {
        target->setProperty("active", true);
    }

    _buttonOperation.setActiveObject(_activeButton);

    switch (buttonCount) {
    case 1: {
        _buttonOperation.setButtonName(BUTTON_COLUMN_NUMBER1, BUTTON_ROW_NUMBER1, localOscillatorSettingButtonData1 );
        propertyChange("m1", "activebg", "localoscillatorbtn_one.png");
        break;
    }

    case 2: {
        _buttonOperation.setButtonName(BUTTON_COLUMN_NUMBER1, BUTTON_ROW_NUMBER3, localOscillatorSettingButtonData2 );
        if (_view) {
            _view->setProperty("position",171);
        }
        propertyChange("m1", "activebg", "combtn_sel.png");
        propertyChange("m2", "activebg", "combtn_sel.png");
        break;
    }

    case 3: {
        _buttonOperation.setButtonName(BUTTON_COLUMN_NUMBER1, BUTTON_ROW_NUMBER3, localOscillatorSettingButtonData3);

        propertyChange("m1", "activebg", "combtn_sel.png");
        propertyChange("m2", "activebg", "combtn_sel.png");
        propertyChange("m3", "activebg", "combtn_sel.png");
        break;
    }

    case 4: {
        _buttonOperation.setButtonName(BUTTON_COLUMN_NUMBER2, BUTTON_ROW_NUMBER3, localOscillatorSettingButtonData4);

        propertyChange("m1", "activebg", "combtn_sel.png");
        propertyChange("m2", "activebg", "combtn_sel.png");
        propertyChange("m3", "activebg", "combtn_sel.png");
        propertyChange("m4", "activebg", "combtn_sel.png");
        break;
    }

    case 5: {
        _buttonOperation.setButtonName(BUTTON_COLUMN_NUMBER2, BUTTON_ROW_NUMBER3, localOscillatorSettingButtonData5);

        propertyChange("m1", "activebg", "combtn_sel.png");
        propertyChange("m2", "activebg", "combtn_sel.png");
        propertyChange("m3", "activebg", "combtn_sel.png");
        propertyChange("m4", "activebg", "combtn_sel.png");
        propertyChange("m5", "activebg", "combtn_sel.png");
        break;
    }

    case 6: {
        _buttonOperation.setButtonName(BUTTON_COLUMN_NUMBER2, BUTTON_ROW_NUMBER3, localOscillatorSettingButtonData6);

        propertyChange("m1", "activebg", "combtn_sel.png");
        propertyChange("m2", "activebg", "combtn_sel.png");
        propertyChange("m3", "activebg", "combtn_sel.png");
        propertyChange("m4", "activebg", "combtn_sel.png");
        propertyChange("m5", "activebg", "combtn_sel.png");
        propertyChange("m6", "activebg", "combtn_sel.png");
        break;
    }

    default:
        break;
    }
}

bool LocalOscillatorSettingViewModel::getLocalOscillatorList(QList<uint32_t> &localOscillatorList)
{
    QVariant data;

    if (!_model->getValue(VALUE_LOCAL_FREQUENCY, data)) {
        qDebug() << "get LocalOscillator List Error";
        return false;
    }

    return Correcter::getLocalOscillatorList(data, _selectedBand, _selectedPolarization, localOscillatorList);
}

int LocalOscillatorSettingViewModel::getDecimalDigits(const uint value)
{
    if (value % 10000 != 0) {
        // 小数点以下、3桁
        return 3;
    } else if (value % 100000 != 0) {
        // 小数点以下、2桁
        return 2;
    } else  {
        // 小数点以下、1桁(整数でも10.0といった表示にするため、最低でも1を返す)
        return 1;
    }
}

void LocalOscillatorSettingViewModel::detectPowerSupplyError(uint16_t code, uint8_t action, QString message)
{
    _failureCode = code;
    _actionInFailure = action;
    // 給電を停止する
    _powerSupply = LC70_POWER_SUPPLY_OFF;
    _model->setPowerSupply(_powerSupply);
    _model->removeMenuList(MenuListIconIndex::POWER_SUPPLY_ICON);

    if (_actionInFailure == LC70_FAIL_CTL_MSGDISP_CLR) {
        uint8_t addInfo[LC70_FAIL_ADD_INFO_NUM];
        memset(addInfo, 0x00, LC70_FAIL_ADD_INFO_NUM);
        // _model->setFaultInformation(_failureCode, LC70_FAIL_STAT_NORMAL, addInfo);    故障復旧処理不要
        _failureCode = 0;
        _actionInFailure = LC70_FAIL_CTL_NONE;
    }

    _model->buzzer(LC70_BUZZ_ERR, LC70_BUZZ_MODE_ONESHOT, true);

    emit requestToShowPopupWithMessage(POPUP_POWER_SUPPLY_ERROR_MANUAL_MEASURING, message);
}

void LocalOscillatorSettingViewModel::onRequestToShowRegistScanResultPopup(){
    emit requestToShowPopup(POPUP_CONFIRM_REGIST_SCAN_RESULT);
}
