/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef MODULATIONVIEWMODEL_H
#define MODULATIONVIEWMODEL_H

#include "abstractviewmodel.h"
#include "buttonid.h"
#include "buttonoperation.h"

/**
 * @brief 変調方式選択 ViewModel
 */
class ModulationViewModel : public AbstractViewModel
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクター
     * @param screenId 画面 ID
     * @param model Model クラスのポインター
     * @param parent 親オブジェクト
     */
    explicit ModulationViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent = nullptr);

    /**
     * @brief デストラクタ
     */
    virtual ~ModulationViewModel();

    /**
     * @brief 画面を開くときに呼び出す表示内容の復元処理
     */
    virtual void activate(void) override;

    /**
     * @brief 画面を開くときに呼び出す表示内容の復元処理
     */
    virtual void deactivate(void) override;

    /**
     * @brief 遷移先画面で参照する遷移前画面のデータ設定
     */
    virtual void setTakeOver() override;

signals:
    void requestSetTakeOver(QVariant, QVariant);
    void requestGetTakeOver();

private slots:
    virtual void onRequest(int condition) override;

protected:
    /**
     * @brief 押下ボタンを受信
     * @param id ...押下ボタンのID
     */
    virtual void onKeyStatus(ButtonId id) override;

    virtual void onButtonPress(ButtonId id) override;
private:
    /**
     * @brief カーソル移動
     * @param buttonId 押下ボタンのID
     */
    void moveCursor(ButtonId buttonId);
    /**
     * @brief エンターキー処理
     */
    void enterKey();

public:

protected:

private:
    QString _transitionSourceScreen;
    ButtonOperation _buttonOperation;                         //!< ボタン操作情報
    QString         _activeButton;                            //!< 活性ボタン名
    bool _isSkyp;                                             //!< 選択BANDがスカパー光かどうか     (true: スカパー光, false: スカパー光以外)
    bool _isThresholdSetting;                                 //!< インジケータ画面からの遷移かどうか (true: インジケータ画面からの遷移, false: 測定画面からの遷移)
    static const int BUTTON_COLUMN_NUMBER;                    //!< BAND スカパー光以外ボタン列数 (測定画面から遷移した場合)
    static const int BUTTON_ROW_NUMBER;                       //!< BAND スカパー光以外ボタン行数 (測定画面から遷移した場合)
    static const int SKYP_BUTTON_COLUMN_NUMBER;               //!< BAND スカパー光ボタン列数 (測定画面から遷移した場合)
    static const int SKYP_BUTTON_ROW_NUMBER;                  //!< BAND スカパー光ボタン行数 (測定画面から遷移した場合)
    static const int SETTING_THRESHOLD_BUTTON_COLUMN_NUMBER;  //!< ボタン列数 (測定設定 > インジケータ画面から遷移した場合)
    static const int SETTING_THRESHOLD_BUTTON_ROW_NUMBER;     //!< ボタン行数 (測定設定 > インジケータ画面から遷移した場合)
};

#endif // MODULATIONVIEWMODEL_H
