/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "broadcastsettingviewmodel.h"

QVector<QVector<QString>> broadcastSettingButtonData = {
    { {"m1"}, {"m2"} }
};
const int BroadcastSettingViewModel::BUTTON_COLUMN_NUMBER = 1;
const int BroadcastSettingViewModel::BUTTON_ROW_NUMBER    = 2;


BroadcastSettingViewModel::BroadcastSettingViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent)
    : AbstractViewModel(screenId, model, parent)
    , _selectedBand()
{
    _buttonOperation.setButtonName(BUTTON_COLUMN_NUMBER, BUTTON_ROW_NUMBER, broadcastSettingButtonData);

    _activeButton = broadcastSettingButtonData[0][0];
    _buttonOperation.setActiveObject(_activeButton);
}

BroadcastSettingViewModel::~BroadcastSettingViewModel()
{

}

void BroadcastSettingViewModel::setTakeOver()
{
    if ((_selectedBand == LC70_BAND_BS) || (_selectedBand == LC70_BAND_CS)) {
        if (_activeButton == "m1") {
            emit requestSetTakeOver("selectedBroadcast", ISDBS);
        } else if (_activeButton == "m2") {
            emit requestSetTakeOver("selectedBroadcast", ISDBS3);
        } else {}
    } else {
        if (_activeButton == "m1") {
            emit requestSetTakeOver("selectedBroadcast", DVBS);
        } else if (_activeButton == "m2") {
            emit requestSetTakeOver("selectedBroadcast", DVBS2);
        } else {}
    }
}

void BroadcastSettingViewModel::activate(void)
{
    connect(this, SIGNAL(requestSetTakeOver(QVariant, QVariant)), _view, SLOT(backup(QVariant, QVariant)));
    connect(this, SIGNAL(requestGetTakeOver()), _view, SLOT(getTakeOver()));
    emit requestGetTakeOver();

    QObject *target = nullptr;
    if (_view) {
        target = _view->findChild<QObject *>("takeOverData");
    }
    if (target) {
        QVariant get = target->property("selectedBand");
        _selectedBand = get.toInt();
    }

    // 先頭のボタンをアクティブにする
    resetToInitialButtonState(broadcastSettingButtonData[0][0], _activeButton, _buttonOperation);

    setButtonMessage();
}

void BroadcastSettingViewModel::deactivate()
{
    AbstractViewModel::deactivate();
    disconnect(this, SIGNAL(requestSetTakeOver(QVariant, QVariant)), _view, SLOT(backup(QVariant, QVariant)));
    disconnect(this, SIGNAL(requestGetTakeOver()), _view, SLOT(getTakeOver()));
}

void BroadcastSettingViewModel::moveCursor(ButtonId buttonId)
{
    if ((buttonId == BUTTON_RIGHT) || (buttonId == BUTTON_LEFT)) {

        QString nextButton;
        bool ret = _buttonOperation.nextActiveObject(buttonId, nextButton);

        if (ret) {

            // inactive
            QObject *target = nullptr;
            if (_view) {
                target = _view->findChild<QObject *>(_activeButton);
            }
            if (target) {
                target->setProperty("active", false);
            }

            // active
            target = nullptr;
            if (_view) {
                target = _view->findChild<QObject *>(nextButton);
            }
            if (target) {
                target->setProperty("active", true);
            }

            _activeButton = nextButton;
            _buttonOperation.setActiveObject(_activeButton);
        }
    }
}

void BroadcastSettingViewModel::onKeyStatus(ButtonId id)
{
    // Home, Escape ボタンはベースクラスで対応
    AbstractViewModel::onKeyStatus(id);

    if (id == BUTTON_ENTER) {
        enterKey();
    } else if (id == BUTTON_USER) {
#ifdef NEW_USER_SETTING
        emit requestDirect(SCREEN_USER_SETTING, true);
#else
        emit requestDirect(SCREEN_USER_DATA_LOGGER_MENU, true);
#endif
    } else {
        moveCursor(id);
    }
}

void BroadcastSettingViewModel::onButtonPress(ButtonId id)
{
    if (id == BUTTON_ENTER) {
        QObject *target = nullptr;
        if (_view) {
            target = _view->findChild<QObject *>(_activeButton);
        }
        if (target) {
            target->setProperty("activebg", "combtn_p.png");
        }
    }
}

void BroadcastSettingViewModel::enterKey()
{
    // 遷移先固定
    qDebug() << "onEnterKey";
    onRequest(0);
}

void BroadcastSettingViewModel::onRequest(int condition)
{
    emit request(_screenId, condition);
    return;
}

void BroadcastSettingViewModel::setButtonMessage()
{
    if ((_selectedBand == LC70_BAND_BS) || (_selectedBand == LC70_BAND_CS)) {
        // 右旋、左旋
        QObject *target = nullptr;
        if (_view) {
            target = _view->findChild<QObject *>("m1");
        }
        if (target) {
            target->setProperty("message", ISDBS);
        }

        target = nullptr;
        if (_view) {
            target = _view->findChild<QObject *>("m2");
        }
        if (target) {
            target->setProperty("message", ISDBS3);
        }
    } else {
        // 水平、垂直
        QObject *target = nullptr;
        if (_view) {
            target = _view->findChild<QObject *>("m1");
        }
        if (target) {
            target->setProperty("message", DVBS);
        }

        target = nullptr;
        if (_view) {
            target = _view->findChild<QObject *>("m2");
        }
        if (target) {
            target->setProperty("message", DVBS2);
        }
    }
}
