/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef BROADCASTSETTINGVIEWMODEL_H
#define BROADCASTSETTINGVIEWMODEL_H

#include "abstractviewmodel.h"
#include "buttonid.h"
#include "buttonoperation.h"


/**
 * @brief 放送方式選択 ViewModel
 */
class BroadcastSettingViewModel : public AbstractViewModel
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクター
     * @param screenId 画面 ID
     * @param model Model クラスのポインター
     * @param parent 親オブジェクト
     */
    explicit BroadcastSettingViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent = nullptr);

    /**
     * @brief デストラクタ
     */
    virtual ~BroadcastSettingViewModel();

    /**
     * @brief 画面を開くときに呼び出す表示内容の復元処理
     */
    virtual void activate(void) override;

    /**
     * @brief 画面を開くときに呼び出す表示内容の復元処理
     */
    virtual void deactivate(void) override;

    /**
     * @brief 遷移先画面で参照する遷移前画面のデータ設定
     */
    virtual void setTakeOver() override;

signals:
    void requestSetTakeOver(QVariant, QVariant);
    void requestGetTakeOver();

private slots:
    virtual void onRequest(int condition) override;

protected:
    /**
     * @brief 押下ボタンを受信
     * @param id ...押下ボタンのID
     */
    virtual void onKeyStatus(ButtonId id) override;

    virtual void onButtonPress(ButtonId id) override;

private:
    /**
     * @brief カーソル移動
     * @param buttonId 押下ボタンのID
     */
    void moveCursor(ButtonId buttonId);
    /**
     * @brief エンターキー処理
     */
    void enterKey(void);
    /**
     * @brief ボタンメッセージ設定
     */
    void setButtonMessage(void);

public:

protected:

private:
    ButtonOperation _buttonOperation;
    QString         _activeButton;
    static const int BUTTON_COLUMN_NUMBER;
    static const int BUTTON_ROW_NUMBER;
    int             _selectedBand;
};

#endif // BROADCASTSETTINGVIEWMODEL_H

