/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "catvchannelfrequencyviewmodel.h"

QVector<QVector<QString>> CATVChannelFreqencyButtonData = {
    {{"setting1"}, {"setting2"}}
};

const int CATVChannelFrequencyViewModel::BUTTON_COLUMN_NUMBER = 1;
const int CATVChannelFrequencyViewModel::BUTTON_ROW_NUMBER = 2;

const int CATVChannelFrequencyViewModel::CATV_FREQUENCY_SETTING_1 = 1;
const int CATVChannelFrequencyViewModel::CATV_FREQUENCY_SETTING_2 = 2;

const int CATVChannelFrequencyViewModel::C24_QAM_FREQUENCY_SETTING_1 = 231000;
const int CATVChannelFrequencyViewModel::C24_QAM_FREQUENCY_SETTING_2 = 233000;
const int CATVChannelFrequencyViewModel::C25_QAM_FREQUENCY_SETTING_1 = 237000;
const int CATVChannelFrequencyViewModel::C25_QAM_FREQUENCY_SETTING_2 = 239000;
const int CATVChannelFrequencyViewModel::C26_QAM_FREQUENCY_SETTING_1 = 243000;
const int CATVChannelFrequencyViewModel::C26_QAM_FREQUENCY_SETTING_2 = 245000;
const int CATVChannelFrequencyViewModel::C27_QAM_FREQUENCY_SETTING_1 = 249000;
const int CATVChannelFrequencyViewModel::C27_QAM_FREQUENCY_SETTING_2 = 251000;

CATVChannelFrequencyViewModel::CATVChannelFrequencyViewModel(ScreenId screenId, LevelCheckerModel *&model,
        QObject *parent)
    : AbstractViewModel(screenId, model, parent)
{
    _buttonOperation.setButtonName(BUTTON_COLUMN_NUMBER, BUTTON_ROW_NUMBER, CATVChannelFreqencyButtonData);

    _activeButton = CATVChannelFreqencyButtonData[0][0];
    _buttonOperation.setActiveObject(_activeButton);
}

CATVChannelFrequencyViewModel::~CATVChannelFrequencyViewModel()
{

}

void CATVChannelFrequencyViewModel::activate()
{
    if (nullptr == _view) {
        qErrnoWarning("_view is null");
        return;
    }

    // ボタンActive設定
    QVariant value;

    // CATVの設定値
    int buttonIndex = 0;

    if (_model->getValue(VALUE_CATVCHANNEL_FREQ, value)) {
        int settingCatvFrequenecy = value.toInt();
        qDebug() << "CATVCHANNEL_FREQ : " << settingCatvFrequenecy;

        if (settingCatvFrequenecy < 0 || settingCatvFrequenecy > 2) {
            // [Memo]
            //  得られる値が想定している範囲(1~2)以外である場合
            //  設定1を選択しているように表示する。
            settingCatvFrequenecy = 1;
        }

        buttonIndex = settingCatvFrequenecy;
    }

    // Active にするボタンを設定
    QString itemname("setting");
    itemname += QString().sprintf("%d", buttonIndex);

    QObject *item = nullptr;
    if (_view) {
        item = _view->findChild<QObject *>(itemname);
    }
    if (item) {
        item->setProperty("active", true);
    }
    _activeButton = itemname;
    _buttonOperation.setActiveObject(_activeButton);
}

void CATVChannelFrequencyViewModel::deactivate()
{
    AbstractViewModel::deactivate();
    // 保存していなければ編集内容を破棄
    if (_model->isUpdate(VALUE_CATVCHANNEL_FREQ)) {
        _model->rollback(VALUE_CATVCHANNEL_FREQ);
    }
}

void CATVChannelFrequencyViewModel::moveCursor(ButtonId buttonId)
{
    if ((buttonId == BUTTON_RIGHT) || (buttonId == BUTTON_LEFT)) {
        // UP, DOWN なし

        QString nextBtn;
        bool ret = _buttonOperation.nextActiveObject(buttonId, nextBtn);

        if (ret) {

            // inactive
            QObject *target = nullptr;
            if (_view) {
                target = _view->findChild<QObject *>(_activeButton);
            }
            if (target) {
                target->setProperty("active", false);
            }

            // active
            target = nullptr;
            if (_view) {
                target = _view->findChild<QObject *>(nextBtn);
            }
            if (target) {
                target->setProperty("active", true);
            }

            _activeButton = nextBtn;
            _buttonOperation.setActiveObject(_activeButton);

            QVariant value;

            if (_activeButton == "setting1") {
                value = CATV_FREQUENCY_SETTING_1;
            } else if (_activeButton == "setting2") {
                value = CATV_FREQUENCY_SETTING_2;
            } else {
                // 何もしない
            }

            _model->setValue(VALUE_CATVCHANNEL_FREQ, value);
        }
    }
}

void CATVChannelFrequencyViewModel::onKeyStatus(ButtonId id)
{
    if (id == BUTTON_ENTER) {
        QObject *target = nullptr;
        if (_view) {
            target = _view->findChild<QObject *>(_activeButton);
        }
        if (target) {
            target->setProperty("press", false);
        }
        if (_model->isUpdate(VALUE_CATVCHANNEL_FREQ)) {
            emit requestToShowPopup(POPUP_SAVE_CONFIRMATION); // 保存確認
        } else {
            // 変更がなければ遷移元画面に遷移する
            emit back();
        }
    } else if (id == BUTTON_ESCAPE || id == BUTTON_HOME || id == BUTTON_USER) {
        if (_model->isUpdate(VALUE_CATVCHANNEL_FREQ)) {
            emit requestToShowPopup(POPUP_CANCEL_CONFIRMATION); // 破棄確認
        } else {
            onAccept(POPUP_CANCEL_CONFIRMATION, true);
        }
    } else {
        moveCursor(id);
    }
}

void CATVChannelFrequencyViewModel::onAccept(PopupId popupId, bool okOnly)
{
    Q_UNUSED(okOnly)

    AbstractViewModel::onAccept(popupId, okOnly);

    // CATV チャンネル周波数を設定
    if (popupId == POPUP_SAVE_CONFIRMATION) {
        // 設定データに対してコミットデータをコミットする。
        _model->commit(VALUE_CATVCHANNEL_FREQ);

        // チャンネル定義データを更新する
        updateChannelDefinitionData(LC70_BAND_CATV_ALL);
        updateChannelDefinitionData(LC70_BAND_CATV_90_470MHZ);

        // メニューに戻る
        emit back();

    } else if (popupId == POPUP_CANCEL_CONFIRMATION) {
        _model->rollback(VALUE_CATVCHANNEL_FREQ);

        // 押下されたボタンにより遷移先を変更する
        switch (_lastPressedButtonId) {
        case BUTTON_HOME:
            emit requestDirect(SCREEN_HOME, true);
            break;

        case BUTTON_ESCAPE:
            emit back();
            break;

        case BUTTON_USER:
#ifdef NEW_USER_SETTING
        emit requestDirect(SCREEN_USER_SETTING, true);
#else
        emit requestDirect(SCREEN_USER_DATA_LOGGER_MENU, true);
#endif
            break;

        default:
            break;
        }
    }
}

void CATVChannelFrequencyViewModel::onButtonPress(ButtonId id)
{
    if (id == BUTTON_ENTER) {
        QObject *target = nullptr;
        if (_view) {
            target = _view->findChild<QObject *>(_activeButton);
        }
        if (target) {
            target->setProperty("press", true);
        }
    }
}

void CATVChannelFrequencyViewModel::updateChannelDefinitionData(const LC70_BAND_T bandId)
{
    // モデルからCATV周波数の設定番号を取得
    QVariant value;
    _model->getValue(VALUE_CATVCHANNEL_FREQ, value);

    QList<ChannelDefinitionItem> channelDefinitionList;
    // チャンネル定義情報の取得を行う
    // ラッパー関数ライブラリ V2.00 対応
    _model->getChannelDefinitionList(bandId, channelDefinitionList);

    // チャンネルのリストインデックスを取得する。
    int channelIndexC24 = -1;
    int channelIndexC25 = -1;
    int channelIndexC26 = -1;
    int channelIndexC27 = -1;

    for (int i = 0; i < channelDefinitionList.length(); i++) {
        if (channelDefinitionList[i].channelNumber == "C24") {
            channelIndexC24 = i;
        } else if (channelDefinitionList[i].channelNumber == "C25") {
            channelIndexC25 = i;
        } else if (channelDefinitionList[i].channelNumber == "C26") {
            channelIndexC26 = i;
        } else if (channelDefinitionList[i].channelNumber == "C27") {
            channelIndexC27 = i;
        }
    }

    if (channelIndexC24 == -1 || channelIndexC25 == -1 || channelIndexC26 == -1 || channelIndexC27 == -1) {
        // 対象のチャンネルが１つも無い場合は後続処理を実施しない
        return;
    }

    if (value.toUInt() == CATV_FREQUENCY_SETTING_1) {
        // CATVチャンネル周波数設定が1の場合
        // [Memo]
        //  OFDM中心周波数(centerFrequency2)の値は、QAM + 143 [kHz]の値なので、設定時に算出する。

        // C24
        channelDefinitionList[channelIndexC24].centerFrequency1 = C24_QAM_FREQUENCY_SETTING_1;
        channelDefinitionList[channelIndexC24].centerFrequency2 = C24_QAM_FREQUENCY_SETTING_1 + 143;

        // C25
        channelDefinitionList[channelIndexC25].centerFrequency1 = C25_QAM_FREQUENCY_SETTING_1;
        channelDefinitionList[channelIndexC25].centerFrequency2 = C25_QAM_FREQUENCY_SETTING_1 + 143;

        // C26
        channelDefinitionList[channelIndexC26].centerFrequency1 = C26_QAM_FREQUENCY_SETTING_1;
        channelDefinitionList[channelIndexC26].centerFrequency2 = C26_QAM_FREQUENCY_SETTING_1 + 143;

        // C27
        channelDefinitionList[channelIndexC27].centerFrequency1 = C27_QAM_FREQUENCY_SETTING_1;
        channelDefinitionList[channelIndexC27].centerFrequency2 = C27_QAM_FREQUENCY_SETTING_1 + 143;;
    } else {
        // CATVチャンネル周波数設定が2の場合
        // C24
        channelDefinitionList[channelIndexC24].centerFrequency1 = C24_QAM_FREQUENCY_SETTING_2;
        channelDefinitionList[channelIndexC24].centerFrequency2 = C24_QAM_FREQUENCY_SETTING_2 + 143;

        // C25
        channelDefinitionList[channelIndexC25].centerFrequency1 = C25_QAM_FREQUENCY_SETTING_2;
        channelDefinitionList[channelIndexC25].centerFrequency2 = C25_QAM_FREQUENCY_SETTING_2 + 143;

        // C26
        channelDefinitionList[channelIndexC26].centerFrequency1 = C26_QAM_FREQUENCY_SETTING_2;
        channelDefinitionList[channelIndexC26].centerFrequency2 = C26_QAM_FREQUENCY_SETTING_2 + 143;

        // C27
        channelDefinitionList[channelIndexC27].centerFrequency1 = C27_QAM_FREQUENCY_SETTING_2;
        channelDefinitionList[channelIndexC27].centerFrequency2 = C27_QAM_FREQUENCY_SETTING_2 + 143;
    }

    // メモリで保持しているチャンネル定義データを更新
    // ラッパー関数ライブラリ V2.00 対応
    _model->setChannelDefinitionList(bandId, channelDefinitionList);

    // チャンネル定義データの設定ファイルを更新する。
    // ラッパー関数ライブラリ V2.00 対応
    _model->commitChannelDefinitionData(bandId);
}
