/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef CATVCHANNELFREQUENCYVIEWMODEL_H
#define CATVCHANNELFREQUENCYVIEWMODEL_H

#include "abstractviewmodel.h"
#include "buttonoperation.h"

/**
 * @brief CATVチャンネル周波数 ViewModel
 */
class CATVChannelFrequencyViewModel : public AbstractViewModel
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクター
     * @param screenId 画面 ID
     * @param model Model クラスのポインター
     * @param parent 親オブジェクト
     */
    explicit CATVChannelFrequencyViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent = nullptr);

    /**
     * @brief デストラクタ
     */
    virtual ~CATVChannelFrequencyViewModel();

    /**
     * @brief activate
     */
    virtual void activate(void) override;

    /**
     * @brief 画面を閉じるときに呼び出す表示な用の保存処理
     */
    virtual void deactivate(void) override;

signals:

protected:
    /**
     * @brief onKeyStatus
     * @param id
     */
    void onKeyStatus(ButtonId id);

protected slots:
    /**
     * @brief onAccept
     * @param popupId
     * @param okOnly
     */
    void onAccept(PopupId popupId, bool okOnly);

private:
    ButtonOperation _buttonOperation;
    QString         _activeButton;
    static const int BUTTON_COLUMN_NUMBER;
    static const int BUTTON_ROW_NUMBER;

    static const int CATV_FREQUENCY_SETTING_1;
    static const int CATV_FREQUENCY_SETTING_2;

    // [Memo]
    // OFDM中心周波数は、QAM中心周波数 + 143[kHz]なので覚えておく必要はない
    // 周波数設定に対応した QAM中心周波数[kHz]
    static const int C24_QAM_FREQUENCY_SETTING_1;
    static const int C24_QAM_FREQUENCY_SETTING_2;
    static const int C25_QAM_FREQUENCY_SETTING_1;
    static const int C25_QAM_FREQUENCY_SETTING_2;
    static const int C26_QAM_FREQUENCY_SETTING_1;
    static const int C26_QAM_FREQUENCY_SETTING_2;
    static const int C27_QAM_FREQUENCY_SETTING_1;
    static const int C27_QAM_FREQUENCY_SETTING_2;

    void onButtonPress(ButtonId id) override;

    /**
     * @brief moveCursor
     * @param buttonId
     */
    void moveCursor(ButtonId buttonId);

    /**
     * @brief チャンネル定義データを更新する
     * @param bandId 更新対象のバンド
     */
    void updateChannelDefinitionData(const LC70_BAND_T bandId);
};

#endif // CATVCHANNELFREQUENCYVIEWMODEL_H
