/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef CONSTELLATIONSETTINGVIEWMODEL_H
#define CONSTELLATIONSETTINGVIEWMODEL_H

#include "abstractviewmodel.h"
#include "buttonoperation.h"

/**
 * @brief コンスタレーション表示設定 ViewModel
 */
class ConstellationSettingViewModel : public AbstractViewModel
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクター
     * @param screenId 画面 ID
     * @param model Model クラスのポインター
     * @param parent 親オブジェクト
     */
    explicit ConstellationSettingViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent = nullptr);

    /**
     * @brief デストラクタ
     */
    virtual ~ConstellationSettingViewModel();

    /**
     * @brief 画面activate時処理
     */
    virtual void activate(void) override;

    /**
     * @brief 画面を閉じるときに呼び出す表示な用の保存処理
     */
    virtual void deactivate(void) override;

signals:

protected:
    /**
     * @brief onKeyStatus
     * @param id
     */
    void onKeyStatus(ButtonId id);

protected slots:
    /**
     * @brief accept受信時処理
     * @param popupId ポップアップID
     * @param okOnly OKボタンが押下されたか
     */
    void onAccept(PopupId popupId, bool okOnly);

private:
    ButtonOperation _buttonOperation;
    QString         _activeButton;
    static const int BUTTON_COLUMN_NUMBER;
    static const int BUTTON_ROW_NUMBER;

    void onButtonPress(ButtonId id) override;

    /**
     * @brief カーソル動作処理
     * @param buttonId ボタンID
     */
    void moveCursor(ButtonId buttonId);

    /**
     * @brief コンスタレーションの設定から対応するボタンインデックスの取得
     * @param constallationValue コンスタレーションの設定値
     * @return ボタンインデックス
     */
    int getButtonIndex(const int constallationValue);
};

#endif // CONSTELLATIONSETTINGVIEWMODEL_H
