/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "leveloffsetviewmodel.h"

QVector<QVector<QString>> levelOffsetButtonData = {
    {{"editList"}, {"register"}}
};
QVector<QVector<QString>> levelOffsetButtonDataEditMode = {
    {{"correctswitch"}, {"levelvalue1"}, {"levelvalue2"}, {"levelvalue3"}, {"levelvalue4"}}
};

const int LevelOffsetViewModel::BUTTON_COLUMN_NUMBER = 1;
const int LevelOffsetViewModel::BUTTON_ROW_NUMBER = 2;
const int LevelOffsetViewModel::BUTTON_ROW_NUMBER_EDITMODE = 5;

static const char *DISPLAY_FORMAT = "%1.1f dB";

LevelOffsetViewModel::LevelOffsetViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent)
    : AbstractViewModel(screenId, model, parent),
      _screenState(SELECT),
      _editmode(false)

{
    _buttonOperation.setButtonName(BUTTON_COLUMN_NUMBER, BUTTON_ROW_NUMBER, levelOffsetButtonData);

    _activeButton = levelOffsetButtonData[0][0];
    _buttonOperation.setActiveObject(_activeButton);
}

LevelOffsetViewModel::~LevelOffsetViewModel()
{

}

void LevelOffsetViewModel::activate()
{
    if (nullptr == _view) {
        qErrnoWarning("_view is null");
        return;
    }

    // ケーブルオフセット有効無効
    QVariant isEnableLevelOffset;

    if (_model->getValue(VALUE_LEVEL_OFFSET_ENABLE, isEnableLevelOffset)) {
        qDebug() << "LEVEL_CABLE_ENABLE : " << isEnableLevelOffset.toInt();

        QObject *item = nullptr;
        // 補正フラグ
        if (_view) {
            item = _view->findChild<QObject *>(levelOffsetButtonDataEditMode[0][0]);
        }
        if (item) {
            if (isEnableLevelOffset.toInt() < 0 || isEnableLevelOffset.toInt() >= 1) {
                // ラッパーから得られた値が範囲外の場合は、初期設定のONを設定する
                item->setProperty("message", "ON");
            } else {
                item->setProperty("message", "OFF");
            }
        }
    }


    // ボタン設定
    QVariant value;

    if (_model->getValue(VALUE_LEVEL_OFFSET, value)) {
        qDebug() << "CABLE_OFFSET : " << value.toList();
        QVariantList list = value.toList();

        QString itemname;
        QObject *item;

        // 10MHz
        itemname = levelOffsetButtonDataEditMode[0][1];
        item = nullptr;
        if (_view) {
            item = _view->findChild<QObject *>(itemname);
        }
        if (item) {
            double value;

            if (list[0].toInt() < 0 || list[0].toInt() > 300) {
                // ラッパーから得られた値が範囲外の場合初期値の0を設定する。
                value = 0.0;
            } else {
                value = list[0].toDouble() / 10.0;
            }

            QString stringValue;
            stringValue.sprintf(DISPLAY_FORMAT, value);

            item->setProperty("message", stringValue);
        }

        // 770MHz
        itemname = levelOffsetButtonDataEditMode[0][2];
        item = nullptr;
        if (_view) {
            item = _view->findChild<QObject *>(itemname);
        }
        if (item) {
            double value;

            if (list[1].toInt() < 0 || list[1].toInt() > 300) {
                // ラッパーから得られた値が範囲外の場合初期値の0を設定する。
                value = 0.0;
            } else {
                value = list[1].toDouble() / 10.0;
            }

            QString stringValue;
            stringValue.sprintf(DISPLAY_FORMAT, value);

            item->setProperty("message", stringValue);
        }

        // 950MHz
        itemname = levelOffsetButtonDataEditMode[0][3];
        item = nullptr;
        if (_view) {
            item = _view->findChild<QObject *>(itemname);
        }
        if (item) {
            double value;

            if (list[2].toInt() < 0 || list[2].toInt() > 300) {
                // ラッパーから得られた値が範囲外の場合初期値の0を設定する。
                value = 0.0;
            } else {
                value = list[2].toDouble() / 10.0;
            }

            QString stringValue;
            stringValue.sprintf(DISPLAY_FORMAT, value);

            item->setProperty("message", stringValue);
        }

        // 3224MHz
        itemname = levelOffsetButtonDataEditMode[0][4];
        item = nullptr;
        if (_view) {
            item = _view->findChild<QObject *>(itemname);
        }
        if (item) {

            double value;

            if (list[3].toInt() < 0 || list[3].toInt() > 300) {
                // ラッパーから得られた値が範囲外の場合初期値の0を設定する。
                value = 0.0;
            } else {
                value = list[3].toDouble() / 10.0;
            }

            QString stringValue;
            stringValue.sprintf(DISPLAY_FORMAT, value);

            item->setProperty("message", stringValue);
        }
    }

    // 画面遷移時は、選択状態から開始
    _screenState = SELECT;

    // ボタンオペレーションの設定
    _buttonOperation.setButtonName(BUTTON_COLUMN_NUMBER, BUTTON_ROW_NUMBER, levelOffsetButtonData);

    // Active にするボタンを設定
    QString itemname = levelOffsetButtonData[0][0];
    QObject *item = nullptr;
    if (_view) {
        item = _view->findChild<QObject *>(itemname);
    }
    if (item) {
        item->setProperty("active", true);
    }

    _activeButton = itemname;
    _buttonOperation.setActiveObject(_activeButton);
}

void LevelOffsetViewModel::deactivate()
{
    AbstractViewModel::deactivate();
    // 保存していなければ編集内容を破棄
    if (_model->isUpdate(VALUE_LEVEL_OFFSET_ENABLE)) {
        _model->rollback(VALUE_LEVEL_OFFSET_ENABLE);
    }
}

void LevelOffsetViewModel::onKeyStatus(ButtonId id)
{
    if (id == BUTTON_ENTER) {
        QObject *target = nullptr;
        if (_view) {
            target = _view->findChild<QObject *>(_activeButton);
        }
        if (target) {
            target->setProperty("press", false);
        }

        onKeyEnter();
    } else if (id == BUTTON_ESCAPE || id == BUTTON_HOME || id == BUTTON_USER) {
        if (_model->isUpdate(VALUE_LEVEL_OFFSET) || _model->isUpdate(VALUE_LEVEL_OFFSET_ENABLE)) {
            emit requestToShowPopup(POPUP_CANCEL_CONFIRMATION); // 破棄確認
        } else {
            onAccept(POPUP_CANCEL_CONFIRMATION, true);
        }
    } else {
        moveCursor(id);
    }
}

bool LevelOffsetViewModel::isValidSettings()
{
    QVariant isEnableLevelOffset;

    if (!_model->getValue(VALUE_LEVEL_OFFSET_ENABLE, isEnableLevelOffset)) {
        return false;
    }

    if (isEnableLevelOffset.toInt() == 0) {
        // 補正をしない場合は、設定値の関係性をチェックしない
        return true;
    }

    QVariant value;

    if (!_model->getValue(VALUE_LEVEL_OFFSET, value)) {
        return false;
    }

    QVariantList list = value.toList();

    if (list.size() != LEVEL_OFFSET_ITEM_COUNT) {
        return false;
    }

    // 設定値有効確認
    if ((list[0].toInt() <= list[1].toInt())             // 10MHzの設定値が 770MHzの設定値以下
            && (list[1].toInt() <= list[2].toInt())      // 770MHzの設定値が 950MHzの設定値以下
            && (list[2].toInt() <= list[3].toInt())) {   // 950MHzの設定値が 3224MHzの設定値以下
        return true;
    }

    return false;
}

void LevelOffsetViewModel::onKeyEnter()
{
    QObject *target = nullptr;

    if (_activeButton == "register") {
        // 保存ボタン押下時
        if (_model->isUpdate(VALUE_LEVEL_OFFSET) || _model->isUpdate(VALUE_LEVEL_OFFSET_ENABLE)) {
//            if (isValidSettings()) {
                emit requestToShowPopup(POPUP_SAVE_CONFIRMATION);
//            } else {
//                emit requestToShowPopup(POPUP_WRONG_INPUT_DATA);
//            }
        } else {
            // 変更がない場合は遷移元の画面に遷移する
            emit back();
        }
    } else {
        // 保存ボタン以外のボタン押下時
        _screenState = (_screenState == EDIT) ? SELECT : EDIT;

        if (_screenState == EDIT) {
            // EDIT状態の場合
            if (_view) {
                target = _view->findChild<QObject *>("editList");
            }
            if (target) {
                target->setProperty("edit", true);
            }
            // 編集用ボタンオペレーションに変更
            _editButtonOperation.setButtonName(BUTTON_COLUMN_NUMBER, BUTTON_ROW_NUMBER_EDITMODE, levelOffsetButtonDataEditMode);
            _activeEditButton = "correctswitch";
            _editButtonOperation.setActiveObject(_activeButton);
        } else {
            if (_view) {
                target = _view->findChild<QObject *>("editList");
            }
            if (target) {
                target->setProperty("edit", false);
            }
            _activeButton = "editList";
            _buttonOperation.setActiveObject(_activeButton);
        }
    }
}

void LevelOffsetViewModel::onAccept(PopupId popupId, bool okOnly)
{
    Q_UNUSED(okOnly)

    AbstractViewModel::onAccept(popupId, okOnly);

    if (popupId == POPUP_SAVE_CONFIRMATION) {
        _model->commit(VALUE_LEVEL_OFFSET_ENABLE);
        _model->commit(VALUE_LEVEL_OFFSET);
        // メニューに戻る
        emit back();

    } else if (popupId == POPUP_CANCEL_CONFIRMATION) {
        _model->rollback(VALUE_LEVEL_OFFSET_ENABLE);
        _model->rollback(VALUE_LEVEL_OFFSET);

        // 押下されたボタンにより遷移先を変更する
        switch (_lastPressedButtonId) {
        case BUTTON_HOME:
            emit requestDirect(SCREEN_HOME, true);
            break;

        case BUTTON_ESCAPE:
            emit back();
            break;

        case BUTTON_USER:
#ifdef NEW_USER_SETTING
        emit requestDirect(SCREEN_USER_SETTING, true);
#else
        emit requestDirect(SCREEN_USER_DATA_LOGGER_MENU, true);
#endif
            break;

        default:
            break;
        }
    }
}

void LevelOffsetViewModel::moveCursor(ButtonId buttonId)
{
    if ((buttonId == BUTTON_RIGHT) || (buttonId == BUTTON_LEFT) || (buttonId == BUTTON_UP) || (buttonId == BUTTON_DOWN)) {
        switch (_screenState) {
        case SELECT : {
            QString nextButton;
            bool ret = _buttonOperation.nextActiveObject(buttonId, nextButton);

            if (ret) {
                // inactivate
                QObject *target = nullptr;
                if (_view) {
                    target = _view->findChild<QObject *>(_activeButton);
                }
                if (target) {
                    target->setProperty("active", false);
                }

                // activate
                target = nullptr;
                if (_view) {
                    target = _view->findChild<QObject *>(nextButton);
                }
                if (target) {
                    target->setProperty("active", true);
                }

                _activeButton = nextButton;
                _buttonOperation.setActiveObject(_activeButton);
            }

            break;
        }

        case EDIT : {
            if (buttonId == BUTTON_LEFT || buttonId == BUTTON_RIGHT) {
                // 値の変更
                QString nextButton;
                bool ret = _editButtonOperation.nextActiveObject(buttonId, nextButton);

                if (ret) {
                    // 編集対象リストから対象のオブジェクトを取得する
                    QObject *targetbase = nullptr;
                    if (_view) {
                        targetbase = _view->findChild<QObject *>(_activeButton);
                    }
                    QObject *target = nullptr;
                    if (targetbase) {
                        // inactivate
                        target = targetbase->findChild<QObject *>(_activeEditButton);

                        if (target) {
                            target->setProperty("active", false);
                        }
                    }

                    // activate
                    target = nullptr;
                    if (targetbase) {
                        target = targetbase->findChild<QObject *>(nextButton);
                    }
                    if (target) {
                        target->setProperty("active", true);
                    }

                    _activeEditButton = nextButton;
                    _editButtonOperation.setActiveObject(_activeEditButton);
                }
            } else if ((buttonId == BUTTON_UP || buttonId == BUTTON_DOWN)) {
                if (_activeEditButton == levelOffsetButtonDataEditMode[0][0]) {
                    // activeボタンが補正の場合
                    // ケーブル損失有効かどうかを取得する
                    QVariant isEnableCableLose;

                    if (_model->getValue(VALUE_LEVEL_OFFSET_ENABLE, isEnableCableLose)) {
                        QString stringValue;

                        if (isEnableCableLose.toInt() == 0) {
                            // ON に設定
                            isEnableCableLose = "1";
                            stringValue = "ON";
                        } else {
                            isEnableCableLose = "0";
                            stringValue = "OFF";
                        }

                        QObject *targetbase = nullptr;
                        if (_view) {
                            targetbase = _view->findChild<QObject *>(_activeButton);
                        }
                        QObject *target = nullptr;
                        if (targetbase) {
                            target = targetbase->findChild<QObject *>(_activeEditButton);
                        }
                        if (target) {
                            target->setProperty("message", stringValue);
                        }
                        // ケーブル損失が有効かどうかを更新する
                        _model->setValue(VALUE_LEVEL_OFFSET_ENABLE, isEnableCableLose);
                    }
                } else {
                    // activeボタンが補正以外の場合
                    QVariant value;

                    if (_model->getValue(VALUE_LEVEL_OFFSET, value)) {
                        QVariantList list = value.toList();
                        QString stringValue;
                        int levelindex = -1;

                        if (_activeEditButton == levelOffsetButtonDataEditMode[0][1]) {
                            levelindex = 0;
                        } else if (_activeEditButton == levelOffsetButtonDataEditMode[0][2]) {
                            levelindex = 1;
                        } else if (_activeEditButton == levelOffsetButtonDataEditMode[0][3]) {
                            levelindex = 2;
                        } else if (_activeEditButton == levelOffsetButtonDataEditMode[0][4]) {
                            levelindex = 3;
                        } else {
                            // 処理なし
                        }

                        // 対象が数値変更
                        if (levelindex > -1 && levelindex <= 3) {
                            int v = list[levelindex].toInt();

                            if (buttonId == BUTTON_UP) {
                                v++;
                            } else if (buttonId == BUTTON_DOWN) {
                                v--;
                            }

                            // 最小 最大 を超えた場合の循環表示
                            if (v < 0) {
                                v = 300;
                            } else if (v > 300) {
                                v = 0;
                            }

                            stringValue.sprintf("%d", v);
                            list[levelindex] = stringValue;

                            stringValue.sprintf(DISPLAY_FORMAT, list[levelindex].toDouble() / 10.0);
                        }

                        QObject *targetbase = nullptr;
                        if (_view) {
                            targetbase = _view->findChild<QObject *>(_activeButton);
                        }
                        QObject *target = nullptr;
                        if (targetbase) {
                            target = targetbase->findChild<QObject *>(_activeEditButton);
                        }
                        if (target) {
                            target->setProperty("message", stringValue);
                        }
                        _model->setValue(VALUE_LEVEL_OFFSET, list);
                    }
                }
            }
        }
        }
    }
}

void LevelOffsetViewModel::onButtonPress(ButtonId id)
{
    if (id == BUTTON_ENTER) {
        QObject *target = nullptr;
        if (_view) {
            target = _view->findChild<QObject *>(_activeButton);
        }
        if (target) {
            target->setProperty("press", true);
        }
    }
}
