/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef CABLEATTENUATIONVIEWMODEL_H
#define CABLEATTENUATIONVIEWMODEL_H

#include "abstractviewmodel.h"
#include "buttonoperation.h"

/**
 * @brief ケーブルオフセット ViewModel
 */
class LevelOffsetViewModel : public AbstractViewModel
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクター
     * @param screenId 画面 ID
     * @param model Model クラスのポインター
     * @param parent 親オブジェクト
     */
    explicit LevelOffsetViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent = nullptr);

    /**
     * @brief デストラクタ
     */
    virtual ~LevelOffsetViewModel();

    /**
     * @brief activate
     */
    virtual void activate(void) override;

    /**
     * @brief 画面を閉じるときに呼び出す表示な用の保存処理
     */
    virtual void deactivate(void) override;

signals:

protected:
    /**
     * @brief onKeyStatus
     * @param id
     */
    void onKeyStatus(ButtonId id) override;

protected slots:
    /**
     * @brief onAccept
     * @param okOnly
     */
    void onAccept(PopupId popupId, bool okOnly) override;

private:
    ButtonOperation _buttonOperation;               //!< 選択モード中のボタンオペレーション
    ButtonOperation _editButtonOperation;           //!< 編集モード中のボタンオペレーション
    QString         _activeButton;                  //!< 選択モード中の選択ボタン
    QString         _activeEditButton;              //!< 編集モード中の選択ボタン
    static const int BUTTON_COLUMN_NUMBER;          //!< ボタン行数
    static const int BUTTON_ROW_NUMBER;             //!< 選択モード中のボタン列数
    static const int BUTTON_ROW_NUMBER_EDITMODE;    //!< 編集モード中のボタン列数

    enum state {
        SELECT = 0,
        EDIT
    };

    state _screenState;

    bool _editmode; // 選択している項目が編集モードがどうかを保持する

    void onButtonPress(ButtonId id) override;

    /**
     * @brief 設定値有効確認
     * @return 確認結果 true: 有効 false: 無効
     */
    bool isValidSettings();

    /**
     * @brief エンターキー押下時処理
     */
    void onKeyEnter();

    /**
     * @brief カーソル操作処理
     * @param buttonId ボタンID
     */
    void moveCursor(ButtonId buttonId);
};

#endif // CABLEATTENUATIONVIEWMODEL_H
