﻿/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef LOCALOSCILLATORVIEWMODEL_H
#define LOCALOSCILLATORVIEWMODEL_H

#include "abstractviewmodel.h"
#include "buttonid.h"
#include "buttonoperation.h"

/**
 * @brief 局部発振周波数 ViewModel
 */
class LocalOscillatorViewModel : public AbstractViewModel
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクター
     * @param screenId 画面 ID
     * @param model Model クラスのポインター
     * @param parent 親オブジェクト
     */
    explicit LocalOscillatorViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent = nullptr);

    /**
     * @brief デストラクタ
     */
    virtual ~LocalOscillatorViewModel();

    /**
     * @brief 画面を開くときに呼び出す表示内容の復元処理
     */
    virtual void activate(void) override;

    /**
     * @brief 画面を開くときに呼び出す表示内容の復元処理
     */
    virtual void deactivate(void) override;

signals:
    void requestSetTakeOver(QVariant, QVariant);

protected:
    /**
     * @brief キーステータス受診時
     * @param id ボタンId
     */
    void onKeyStatus(ButtonId id) override;

protected slots:
    void onAccept(PopupId popupId, bool okOnly) override;
    void onReject(PopupId popupId) override;

private:
    static const int BUTTON_COLUMN_NUMBER;
    static const int BUTTON_ROW_NUMBER;
    static const int EDIT_BUTTON_COLUMN_NUMBER;
    static const int EDIT_BUTTON_ROW_NUMBER;
    static const int EDIT_LOCAL_FREQUENCY_INDEX;
    static const uint LOCAL_FREQ_MIN;
    static const uint LOCAL_FREQ_MAX;

    ButtonOperation _editButtonOperation;
    QString _activeEditButton;
    ButtonOperation _buttonOperation;
    QString         _selectItem;

    enum state {
        SELECT = 0,
        EDIT
    };

    state _screenState;

    /**
     * @brief カーソル操作
     * @param buttonId ボタンId
     */
    void moveCursor(ButtonId buttonId);

    /**
     * @brief editNumber 番号編集時の処理
     * @param buttonId ボタンId
     */
    void editNumber(ButtonId buttonId);

    /**
     * @brief エンターキー押下時の処理
     */
    void onKeyEnter(void);

    /**
     * @brief 局発周波数設定処理
     */
    void setLocalFrequencyData();

    /**
     * @brief 入力値のチェックを行う
     * @return チェック結果 true: OK false: NG
     */
    bool checkValue(void);

    /**
     * @brief 局部発振周波数のチェック実施
     * @param localFrequency 局部発振周波数の設定値
     * @return チェック結果 true: OK false: NG
     */
    bool checkLocalFrequency(uint localFrequency);

};

#endif // LOCALOSCILLATORVIEWMODEL_H
