/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "measurementsettingmenuviewmodel.h"

// {"func2"},{"func3"},  を欠番とする
QVector<QVector<QString>> measurementMenuButtonData = {
    { {"func1"}, {"func4"}, {"func5"}},
    { {"func6"}, {"func7"}, {""}, {""}},
};
const int MeasurementSettingMenuViewModel::BUTTON_COLUMN_NUMBER = 2;
const int MeasurementSettingMenuViewModel::BUTTON_ROW_NUMBER    = 3;


MeasurementSettingMenuViewModel::MeasurementSettingMenuViewModel(ScreenId screenId, LevelCheckerModel *&model,
        QObject *parent)
    : AbstractViewModel(screenId, model, parent)
{
    _buttonOperation.setButtonName(BUTTON_COLUMN_NUMBER, BUTTON_ROW_NUMBER, measurementMenuButtonData);
    _activeButton = measurementMenuButtonData[0][0];
    _buttonOperation.setActiveObject(_activeButton);
}

MeasurementSettingMenuViewModel::~MeasurementSettingMenuViewModel()
{

}

void MeasurementSettingMenuViewModel::activate()
{
    if (nullptr == _view) {
        qErrnoWarning("_view is null");
        return;
    }

    // ヘッダメニュー表示
    _model->replaceMenuList(MenuListIconIndex::FUNCTION_ICON, "icon_menu_sokutei.png");

    // 先頭のボタンをアクティブにする
    resetToInitialButtonState(measurementMenuButtonData[0][0], _activeButton, _buttonOperation);
}

void MeasurementSettingMenuViewModel::onRequest(int condition)
{
    emit request(_screenId, condition);
}

void MeasurementSettingMenuViewModel::moveCursor(ButtonId buttonId)
{
    if ((buttonId == BUTTON_RIGHT) || (buttonId == BUTTON_LEFT) || (buttonId == BUTTON_UP) || (buttonId == BUTTON_DOWN)) {

        QString nextBtn;
        bool ret = _buttonOperation.nextActiveObject(buttonId, nextBtn);

        if (ret) {

            // inactive
            QObject *target = _view->findChild<QObject *>(_activeButton);

            if (target) {
                target->setProperty("active", false);
            }

            // active
            target = nullptr;
            if (_view) {
                target = _view->findChild<QObject *>(nextBtn);
            }
            if (target) {
                target->setProperty("active", true);
            }

            _activeButton = nextBtn;
            _buttonOperation.setActiveObject(_activeButton);
        }
    }
}

void MeasurementSettingMenuViewModel::onKeyStatus(ButtonId id)
{
    // 電源 ボタン押下は、HOME画面と同様の処理を行う
    // HOME ボタン押下で本画面を消去し、HOME画面に遷移する
    // USER ボタン押下で本画面を消去し、USER画面に遷移する
    // ESCAPE ボタン押下で本画面を消去し、HOME画面に戻る

    if (id == BUTTON_ENTER) {
        // 決定ボタン押下で選択中の画面を表示する
        int button_index = _activeButton.mid(4).toInt() - 1; // ”func" 文字列を削除して数字を取り出す
        onRequest(button_index);
    } else if (id == BUTTON_ESCAPE) {
        emit back();
    } else if (id == BUTTON_HOME) {
        emit requestDirect(SCREEN_HOME, true);
    } else if (id == BUTTON_USER) {
#ifdef NEW_USER_SETTING
        emit requestDirect(SCREEN_USER_SETTING, true);
#else
        emit requestDirect(SCREEN_USER_DATA_LOGGER_MENU, true);
#endif
    } else {
        // LEFT ボタン押下では選択している波長選択を左に移動する
        // RIGHTボタン押下では選択している波長選択を右に移動する
        moveCursor(id);
    }
}

void MeasurementSettingMenuViewModel::onButtonPress(ButtonId id)
{
    if (id == BUTTON_ENTER) {
        QObject *target = nullptr;
        if (_view) {
            target = _view->findChild<QObject *>(_activeButton);
        }
        if (target) {
            target->setProperty("press", true);
        }
    }
}
