/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef MEASUREMENTSETTINGMENUVIEWMODEL_H
#define MEASUREMENTSETTINGMENUVIEWMODEL_H

#include "abstractviewmodel.h"
#include "buttonoperation.h"

/**
 * @brief 測定設定メニュー ViewModel
 */
class MeasurementSettingMenuViewModel : public AbstractViewModel
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクター
     * @param screenId 画面 ID
     * @param model Model クラスのポインター
     * @param parent 親オブジェクト
     */
    explicit MeasurementSettingMenuViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent = nullptr);

    /**
     * @brief デストラクタ
     */
    virtual ~MeasurementSettingMenuViewModel();

    /**
     * @brief 画面Active 時の処理
     */
    void activate() override;

signals:


public slots:
    /**
     * @brief onRequest
     * @param condition
     */
    void onRequest(int condition) override;

protected:
    /**
     * @brief onKeyStatus
     * @param id
     */
    void onKeyStatus(ButtonId id) override;
private:
    ButtonOperation _buttonOperation;
    QString         _activeButton;
    static const int BUTTON_COLUMN_NUMBER;
    static const int BUTTON_ROW_NUMBER;

    void onButtonPress(ButtonId id) override;

    /**
     * @brief moveCursor
     * @param buttonId
     */
    void moveCursor(ButtonId buttonId);
};

#endif // MEASUREMENTSETTINGMENUVIEWMODEL_H
