/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SWITCHMERCNRVIEWMODEL_H
#define SWITCHMERCNRVIEWMODEL_H

#include "abstractviewmodel.h"
#include "buttonoperation.h"

/**
 * @brief MER/CN切り替え ViewModel
 */
class SwitchMERCNViewModel : public AbstractViewModel
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクター
     * @param screenId 画面 ID
     * @param model Model クラスのポインター
     * @param parent 親オブジェクト
     */
    explicit SwitchMERCNViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent = nullptr);

    /**
     * @brief デストラクタ
     */
    virtual ~SwitchMERCNViewModel();

    /**
     * @brief activate
     */
    void activate() override;

signals:

protected:
    /**
     * @brief onKeyStatus
     * @param id
     */
    void onKeyStatus(ButtonId id) override;

protected slots:
    /**
     * @brief onAccept
     * @param popupId
     * @param okOnly
     */
    void onAccept(PopupId popupId, bool okOnly) override;

private:
    ButtonOperation _buttonOperation;
    QString         _activeButton;
    static const int BUTTON_COLUMN_NUMBER;
    static const int BUTTON_ROW_NUMBER;
    static const int MER;
    static const int CN;
    /**
     * @brief moveCursor
     * @param buttonId
     */
    void moveCursor(ButtonId buttonId);
};

#endif // SWITCHMERCNRVIEWMODEL_H
