/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SWITCHOPTICALCOAXIALCABLEVIEWMODEL_H
#define SWITCHOPTICALCOAXIALCABLEVIEWMODEL_H

#include "abstractviewmodel.h"
#include "buttonoperation.h"

/**
 * @brief 光同軸切替え設定 ViewModel
 */
class SwitchOpticalCoaxialCableViewModel : public AbstractViewModel
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクター
     * @param screenId 画面 ID
     * @param model Model クラスのポインター
     * @param parent 親オブジェクト
     */
    explicit SwitchOpticalCoaxialCableViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent = nullptr);

    /**
     * @brief デストラクタ
     */
    virtual ~SwitchOpticalCoaxialCableViewModel();

    /**
     * @brief activate
     */
    virtual void activate(void) override;

    /**
     * @brief 画面を閉じるときに呼び出す表示な用の保存処理
     */
    virtual void deactivate(void) override;

signals:

protected:
    /**
     * @brief ボタン押下時処理
     * @param id ボタンID
     */
    void onKeyStatus(ButtonId id);

protected slots:
    /**
     * @brief ポップアップでAcceptボタン押下時処理
     * @param popupId ポップアップID
     * @param okOnly
     */
    void onAccept(PopupId popupId, bool okOnly);
private:
    ButtonOperation _buttonOperation;        // ボタンオペレーション
    QString         _activeButton;           // 活性中ボタン名
    static const int BUTTON_COLUMN_NUMBER;   // ボタンの列数
    static const int BUTTON_ROW_NUMBER;      // ボタンの行数
    static const int COAX_CABLE_NUMBER;      // 同軸ケーブル値
    static const int OPTICAL_CABLE_NUMBER;   // 光ケーブル値

    void onButtonPress(ButtonId id) override;

    /**
     * @brief カーソル移動処理
     * @param buttonId ボタンID
     */
    void moveCursor(ButtonId buttonId);

    /**
     * @brief 同軸/光アイコンを更新する
     */
    void updateRfOpticalIcon(void);
};

#endif // SWITCHOPTICALCOAXIALCABLEVIEWMODEL_H
