/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef THRESHOLDSETTINGVIEWMODEL_H
#define THRESHOLDSETTINGVIEWMODEL_H

#include "abstractviewmodel.h"
#include "buttonoperation.h"

/**
 * @brief 閾値設定 ViewModel
 */
class ThresholdSettingViewModel : public AbstractViewModel
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクター
     * @param screenId 画面 ID
     * @param model Model クラスのポインター
     * @param parent 親オブジェクト
     */
    explicit ThresholdSettingViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent = nullptr);

    /**
     * @brief デストラクタ
     */
    virtual ~ThresholdSettingViewModel();

    /**
     * @brief activate
     */
    virtual void activate(void) override;

    /**
     * @brief 画面を閉じるときに呼び出す表示な用の保存処理
     */
    virtual void deactivate(void) override;

public slots:

signals:
    void requestSetTakeOver(QVariant, QVariant);
    void requestGetTakeOver();


protected:
    /**
     * @brief onKeyStatus
     * @param id
     */
    void onKeyStatus(ButtonId id) override;

protected slots:
    void onAccept(PopupId popupId, bool okOnly) override;
    void onReject(PopupId popupId) override;

private:
    static const int LEVELMIN;
    static const int LEVELMAX;
    static const int MER_ADJUST;
    static const double BERMIN;
    static const double BERMAX;

    ButtonOperation _buttonOperation;                 //!< 選択モード中のボタンオペレーション
    QString         _selectButton;                    //!< 選択モード中の選択ボタン
    static const int BUTTON_COLUMN_NUMBER;            //!< BAND 全ての項目が選択可BAND用 選択時 選択モード中のボタン行数
    static const int BUTTON_ROW_NUMBER;               //!< BAND 全ての項目が選択可BAND用 選択モード中のボタン列数
    static const int BUTTON_COLUMN_NUMBER_LEVEL_ONLY; //!< BAND LEVELのみの項目が選択可BAND用 選択モード中のボタン行列
    static const int BUTTON_ROW_NUMBER_LEVEL_ONLY;    //!< BAND LEVELのみの項目が選択可BAND用 選択モード中のボタン列数

    ButtonOperation _editButtonOperation;        //!< 編集モード中のボタンオペレーション
    QString         _activeEditButton;           //!< 編集モード中の選択ボタン
    static const int EDIT_BUTTON_COLUMN_NUMBER;  //!< 編集モード中ボタン行数
    static const int EDIT_BUTTON_ROW_NUMBER;     //!< 編集モード中ボタン列数

    int     _selectedBand;          // 選択されたバンド
    QString _selectedModulation;    // 選択された変調方式
    QString _selectedBroadcasting;  // 選択された通信方式
    QPair<int, int> _merRange;                   //!< MERの値域(first:最小値、second:最大値)
    enum state {
        SELECT = 0,
        EDIT
    };

    state _screenState;

    void onButtonPress(ButtonId id) override;

    /**
     * @brief moveCursor
     * @param buttonId
     */
    void moveCursor(ButtonId buttonId);

    /**
     * @brief editNumber
     * @param buttonId
     */
    void editNumber(ButtonId buttonId);

    /**
     * @brief 閾値データを一時保存する。
     * @param dataList 閾値データ
     */
    void temporariliySaveThresholdData(QVariantList dataList);

    /**
     * @brief onKeyEnter
     */
    void onKeyEnter();

    /**
     * @brief setBandMessage
     */
    void setBandMessage();

    /**
     * @brief setThresholdData
     */
    void setThresholdData();

    /**
     * @brief checkValue
     * LEVEL MER/CN BER の入力値の範囲チェックを行う
     * @return true...チェックOK　false...チェックNG
     */
    bool checkValue();

    /**
     * @brief 設定に適応した閾値データリストの取得
     * @param デフォルト値から取得するか否か True: デフォルト値から取得する False: 設定値から取得する
     * @return 閾値データリスト
     * @note useDefaultValueは初期値表示ボタンが押された場合のみtrueに設定する
     */
    QVariantList thresholdData(bool useDefaultValue = false);

    /**
     * @brief ボタン操作の設定を行う
     */
    void setButtonOperation(void);
};

#endif // THRESHOLDSETTINGVIEWMODEL_H
