/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "opticalmeasurementviewmodel.h"
#include "correcter.h"

QVector<QVector<QString>> wavelengthsettingButtonData = {
    {{"wl0"},{"wl1"},{"wl2"},{"wl3"},{"wl4"}}
};

const int OpticalMeasurementViewModel::BUTTON_COLUMN_NUMBER = 1;
const int OpticalMeasurementViewModel::BUTTON_ROW_NUMBER = 5;

OpticalMeasurementViewModel::OpticalMeasurementViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent)
    : AbstractViewModel(screenId, model, parent)
    , _timer(nullptr)
{

    _buttonOperation.setButtonName(BUTTON_COLUMN_NUMBER, BUTTON_ROW_NUMBER, wavelengthsettingButtonData);
    _activeButton = wavelengthsettingButtonData[0][0];
    _buttonOperation.setActiveObject(_activeButton);

}

OpticalMeasurementViewModel::~OpticalMeasurementViewModel()
{
}

void OpticalMeasurementViewModel::activate()
{

//    _model->requestStandBy(1);
//    _model->wakeUp(1);
//    _model->readyToMeasure();

    // DC/光測定はスタンバイしてからウェイクアップしないと動作しない
    if (!_model->wakeUpRequested()) {
        _model->requestStandBy(1);
        _model->setWakeUpRequested(true);
        _model->wakeUp(1);
        _model->setWakeUpRequested(false);
    }
    _model->readyToMeasure();

    if (nullptr == _timer) {
        // タイマーがnullptrの場合生成する
        _timer = new QTimer;
    }

    QString itemname;
    itemname = "wl3";

    QObject *item = nullptr;
    if (_view) {
        item = _view->findChild<QObject *>(itemname);
        if (item) {
            item->setProperty("active", true);
        }
    }

    _activeButton = itemname;
    _buttonOperation.setActiveObject(_activeButton);

    // ヘッダメニュー表示
    _model->replaceMenuList(MenuListIconIndex::FUNCTION_ICON, "icon_menu_hikari.png");

    // コネクションを生成する
    connect(_timer, SIGNAL(timeout()), this, SLOT(onNotifyTimeOut()));

    if (nullptr == _view) {
        qErrnoWarning("_view is null");
        return;
    }

    propertyChange("wvval", "text", QString::number(OPTICAL_MEASUREMENT_WAVE_LENGTH_1550));

    // 光測定を開始
    if (!_model->startOpticalMeasurement(OPTICAL_MEASUREMENT_WAVE_LENGTH_1550)) {
        qDebug() << "Optical Measurement start Error";
        return;
    }

    timerStart();
}

void OpticalMeasurementViewModel::moveCursor(ButtonId buttonId){
    if((buttonId == BUTTON_RIGHT) || (buttonId == BUTTON_LEFT)){

        QString nextBtn;
        bool ret = _buttonOperation.nextActiveObject(buttonId, nextBtn);

        if (!_model->stopOpticalMeasurement()) {
            qDebug() << "Optical Measurement stop Error";
        }

//            _model->requestStandBy(1);
//            _model->wakeUp(1);
//            _model->readyToMeasure();

        // 波長切り替え時もスタンバイしてからウェイクアップする
        if (!_model->wakeUpRequested()) {
            _model->requestStandBy(1);
            _model->setWakeUpRequested(true);
            _model->wakeUp(1);
            _model->setWakeUpRequested(false);
        }
        _model->readyToMeasure();

            propertyChange("opvalue", "text", "---");
        if (ret) {

            // inactive
            QObject *target = nullptr;
            if (_view) {
                target = _view->findChild<QObject *>(_activeButton);
            }

            if (target) {
                target->setProperty("active", false);
            }

            // active
            target = nullptr;
            if (_view) {
                target = _view->findChild<QObject *>(nextBtn);
            }

            if (target) {
                target->setProperty("active", true);
            }

            _activeButton = nextBtn;
            _buttonOperation.setActiveObject(_activeButton);

            //-------------------------------------------------------------------------------------
            if(_activeButton == "wl0"){

                propertyChange("wvvalue", "text", QString::number(OPTICAL_MEASUREMENT_WAVE_LENGTH_1300));


                // 光測定を開始
                if (!_model->startOpticalMeasurement(OPTICAL_MEASUREMENT_WAVE_LENGTH_1300)) {
                    qDebug() << "Optical Measurement start Error";
                    return;
                }

            }else if(_activeButton == "wl1"){

                propertyChange("wvvalue", "text", QString::number(OPTICAL_MEASUREMENT_WAVE_LENGTH_1310));

                // 光測定を開始
                if (!_model->startOpticalMeasurement(OPTICAL_MEASUREMENT_WAVE_LENGTH_1310)) {
                    qDebug() << "Optical Measurement start Error";
                    return;
                }

            }else if(_activeButton == "wl2"){

                propertyChange("wvvalue", "text", QString::number(OPTICAL_MEASUREMENT_WAVE_LENGTH_1490));

                // 光測定を開始
                if (!_model->startOpticalMeasurement(OPTICAL_MEASUREMENT_WAVE_LENGTH_1490)) {
                    qDebug() << "Optical Measurement start Error";
                    return;
                }

            }else if(_activeButton == "wl3"){

                propertyChange("wvvalue", "text", QString::number(OPTICAL_MEASUREMENT_WAVE_LENGTH_1550));

                // 光測定を開始
                if (!_model->startOpticalMeasurement(OPTICAL_MEASUREMENT_WAVE_LENGTH_1550)) {
                    qDebug() << "Optical Measurement start Error";
                    return;
                }

            }else if(_activeButton == "wl4"){

                propertyChange("wvvalue", "text", QString::number(OPTICAL_MEASUREMENT_WAVE_LENGTH_1625));

                // 光測定を開始
                if (!_model->startOpticalMeasurement(OPTICAL_MEASUREMENT_WAVE_LENGTH_1625)) {
                    qDebug() << "Optical Measurement start Error";
                    return;
                }
                //---------------------------------------------------------------------------------------

            }else{

            }

        }
    }
}

void OpticalMeasurementViewModel::deactivate()
{
    AbstractViewModel::deactivate();
    disconnect(_timer, SIGNAL(timeout()), this, SLOT(onNotifyTimeOut()));
}

void OpticalMeasurementViewModel::suspend()
{
    // タイマーを止める
    if (_timer->isActive()) {
        _timer->stop();
    }

    // 光測定を終了
    if (!_model->stopOpticalMeasurement()) {
        qDebug() << "Optical Measurement stop Error";
    }

    // サブ CPU をスタンバイにする
    _model->setWakeUpRequested(false);
    _model->requestStandBy(1);

    AbstractViewModel::suspend();

    qDebug() << QString("[Leave] OpticalMeasurementViewmodel::suspend()");
}

void OpticalMeasurementViewModel::onKeyStatus(ButtonId id)
{
    // 電源 ボタン押下は、HOME画面と同様の処理を行う
    // HOME ボタン押下で本画面を消去し、HOME画面に遷移する
    // USER ボタン押下で本画面を消去し、USER画面に遷移する
    // ESCAPE ボタン押下で本画面を消去し、ホーム画面に遷移する

    switch (id) {
    case BUTTON_HOME:
        emit requestDirect(SCREEN_HOME, true);
        break;

    case BUTTON_ESCAPE:
        emit back();
        break;

    case BUTTON_USER:
#ifdef NEW_USER_SETTING
        emit requestDirect(SCREEN_USER_SETTING, true);
#else
        emit requestDirect(SCREEN_USER_DATA_LOGGER_MENU, true);
#endif
        break;

    default:
        moveCursor(id);
        break;
    }
}

void OpticalMeasurementViewModel::propertyChange(QString buttonName, QString propertyName, QString value)
{
    QObject *target = nullptr;
    if (_view) {
        target = _view->findChild<QObject *>(buttonName);
    }
    if (target) {
        if (propertyName == "text") {
            target->setProperty(propertyName.toUtf8().constData(), value);
        }
    }
}

void OpticalMeasurementViewModel::timerStart()
{
    // 光測定を行う周期毎にTimeOutするタイマーを起動する
    _timer->setInterval(_model->applicationSetting()->pollingIntervalOpticalMeasurement());
    _timer->start();
}

void OpticalMeasurementViewModel::onNotifyTimeOut()
{
    // 光測定の結果を取得する。
    QVariant measurementOpticalValue;

    if (!_model->getOpticalMeasurementResult(measurementOpticalValue)) {
        // エラー発生時
        qDebug() << "Optical Measurement result get Error";
    } else {
        // 正常終了時
        propertyChange("opvalue", "text", Correcter::displayOpticalValue(measurementOpticalValue.toInt()));
    }

    // 再度タイマーを動作させる
    _timer->start();
}
