/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef OPTICALMEASUREMENTVIEWMODEL_H
#define OPTICALMEASUREMENTVIEWMODEL_H

#include "abstractviewmodel.h"
#include "buttonoperation.h"
#include <QTimer>

/**
 * @brief 光測定 ViewModel
 */
class OpticalMeasurementViewModel : public AbstractViewModel
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクター
     * @param screenId 画面 ID
     * @param model Model クラスのポインター
     * @param parent 親オブジェクト
     */
    explicit OpticalMeasurementViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent = nullptr);

    /**
     * @brief デストラクタ
     */
    virtual ~OpticalMeasurementViewModel();

    /**
     * @brief 画面 閉じる時に呼び出されるメソッド
     */
    virtual void suspend() override;

    /**
     * @brief 画面Active 時の処理
     * 波長データと光パワー を表示する
     */
    void activate() override;

    /**
     * @brief 画面deactivate 時の処理
     */
    void deactivate() override;

public slots:
    /**
     * @brief タイムアウト受信時処理
     */
    void onNotifyTimeOut();

protected:
    /**
     * @brief 押下ボタンを受信
     * @param id ...押下ボタンのID
     */
    virtual void onKeyStatus(ButtonId id) override;

private:
    /**
     * @brief プロパティ変更
     * @param buttonName   オブジェクト名
     * @param propertyName プロパティ名
     * @param value        プロパティ値
     */
    void propertyChange(QString buttonName, QString propertyName, QString value);

    /**
     * @brief タイマーを開始する
     */
    void timerStart(void);
    void moveCursor(ButtonId buttonId);
private:
    QTimer *_timer;             //!< タイマー
    ButtonOperation _buttonOperation;
    QString         _activeButton;
    static const int BUTTON_COLUMN_NUMBER;
    static const int BUTTON_ROW_NUMBER;


};

#endif // OPTICALMEASUREMENTVIEWMODEL_H
