/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "wavelengthselectviewmodel.h"

QVector<QVector<QString>> opticalButtonData = {
    { {"wave0"}, {"wave1"},  {"wave2"} }
};
const int WaveLengthSelectViewModel::BUTTON_COLUMN_NUMBER = 1;
const int WaveLengthSelectViewModel::BUTTON_ROW_NUMBER    = 3;

WaveLengthSelectViewModel::WaveLengthSelectViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent)
    : AbstractViewModel(screenId, model, parent)
{
    _buttonOperation.setButtonName(BUTTON_COLUMN_NUMBER, BUTTON_ROW_NUMBER, opticalButtonData);

    _activeButton = opticalButtonData[0][0];
    _buttonOperation.setActiveObject(_activeButton);
}

WaveLengthSelectViewModel::~WaveLengthSelectViewModel()
{

}

void WaveLengthSelectViewModel::activate()
{
    if (nullptr == _view) {
        qErrnoWarning("_view is null");
        return;
    }

    connect(this, SIGNAL(requestSetTakeOver(QVariant, QVariant)), _view, SLOT(backup(QVariant, QVariant)));

    // Active ボタンの設定
    QObject *item = nullptr;
    if (_view) {
        item = _view->findChild<QObject *>(_activeButton);
    }
    if (item) {
        item->setProperty("active", true);
    }
    // ヘッダメニュー表示
    _model->replaceMenuList(MenuListIconIndex::FUNCTION_ICON, "icon_menu_hikari.png");
}

void WaveLengthSelectViewModel::setTakeOver()
{
    if (_activeButton == "wave0") {
        emit requestSetTakeOver("selectedWaveLength", "WaveLength1");
    } else if (_activeButton == "wave1") {
        emit requestSetTakeOver("selectedWaveLength", "WaveLength2");
    } else if (_activeButton == "wave2") {
        emit requestSetTakeOver("selectedWaveLength", "WaveLength3");
    }
}

void WaveLengthSelectViewModel::onRequest(int condition)
{
    qDebug("OpticalMeasurementViewModel::onRequest");

    emit request(_screenId, condition);
}

void WaveLengthSelectViewModel::moveCursor(ButtonId buttonId)
{
    if ((buttonId == BUTTON_RIGHT) || (buttonId == BUTTON_LEFT)) {
        // UP, DOWN なし

        QString nextBtn;
        bool ret = _buttonOperation.nextActiveObject(buttonId, nextBtn);

        if (ret) {

            // inactive
            QObject *target = nullptr;
            if (_view) {
                target = _view->findChild<QObject *>(_activeButton);
            }
            if (target) {
                target->setProperty("active", false);
            }

            // active
            target = nullptr;
            if (_view) {
                target = _view->findChild<QObject *>(nextBtn);
            }
            if (target) {
                target->setProperty("active", true);
            }

            _activeButton = nextBtn;
            _buttonOperation.setActiveObject(_activeButton);
        }
    }
}

void WaveLengthSelectViewModel::onKeyStatus(ButtonId id)
{
    // 電源 ボタン押下は、HOME画面と同様の処理を行う
    // HOME ボタン押下で本画面を消去し、HOME画面に遷移する
    // USER ボタン押下で本画面を消去し、USER画面に遷移する
    // ESCAPE ボタン押下で本画面を消去し、HOME画面に戻る

    if (id == BUTTON_ENTER) {
        // 決定ボタン押下で光測定画面を表示する
        // 遷移先は１つ
        onRequest(0);
    } else if (id == BUTTON_ESCAPE) {
        emit back();
    } else if (id == BUTTON_HOME) {
        emit requestDirect(SCREEN_HOME, true);
    } else if (id == BUTTON_USER) {
#ifdef NEW_USER_SETTING
        emit requestDirect(SCREEN_USER_SETTING, true);
#else
        emit requestDirect(SCREEN_USER_DATA_LOGGER_MENU, true);
#endif
    } else {
        // LEFT ボタン押下では選択している波長選択を左に移動する
        // RIGHTボタン押下では選択している波長選択を右に移動する
        moveCursor(id);
    }
}
