/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef WAVELENGTHSELECTVIEWMODEL_H
#define WAVELENGTHSELECTVIEWMODEL_H

#include "abstractviewmodel.h"
#include "buttonid.h"
#include "buttonoperation.h"

/**
 * @brief 波長選択 ViewModel
 */
class WaveLengthSelectViewModel : public AbstractViewModel
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクター
     * @param screenId 画面 ID
     * @param model Model クラスのポインター
     * @param parent 親オブジェクト
     */
    explicit WaveLengthSelectViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent = nullptr);

    /**
     * @brief デストラクタ
     */
    virtual ~WaveLengthSelectViewModel();

    /**
     * @brief 画面Active 時の処理
     *
     * 波長データを取得して画面に表示する
     */
    void activate() override;

    /**
     * @brief 遷移先画面で参照する遷移前画面のデータ設定
     */
    virtual void setTakeOver() override;

signals:
    void requestSetTakeOver(QVariant, QVariant);

public slots:
    void onRequest(int condition) override;

protected:
    /**
     * @brief 押下ボタンを受信
     * @param id ...押下ボタンのID
     */
    virtual void onKeyStatus(ButtonId id) override;

private:
    /**
     * @brief カーソル移動
     * @param buttonId 押下ボタンのID
     */
    void moveCursor(ButtonId buttonId);


private:
    ButtonOperation _buttonOperation;
    QString         _activeButton;
    static const int BUTTON_COLUMN_NUMBER;
    static const int BUTTON_ROW_NUMBER;
};

#endif // WAVELENGTHSELECTVIEWMODEL_H
