/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef COMPASSVIEWMODEL_H
#define COMPASSVIEWMODEL_H

#include "abstractviewmodel.h"

/**
 * @brief コンパス画面 ViewModel
 */
class CompassViewModel : public AbstractViewModel
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクター
     * @param screenId 画面 ID
     * @param model Model クラスのポインター
     * @param parent 親オブジェクト
     */
    explicit CompassViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent = nullptr);

    /**
     * @brief デストラクタ
     */
    virtual ~CompassViewModel();

    /**
     * @brief 画面を開くときに呼び出すスレッドの開始、再開処理
     */
    virtual void resume(void) override;

    /**
     * @brief 画面を閉じるときに呼び出すスレッドの停止処理
     */
    virtual void suspend(void) override;

    /**
     * @brief 画面を開くときに呼び出す qml との接続処理
     * @param qml qml のオブジェクトのポインター
     * @param mainFrame MainFrameViewModel のポインター
     */
    virtual void createConnection(QObject *qml, QObject *mainFrame) override;

    /**
     * @brief 画面を開くときに呼び出す表示内容の復元処理
     */
    virtual void activate() override;

    /**
     * @brief 画面を閉じるときに呼び出す表示用の保存処理
     */
    virtual void deactivate(void) override;
signals:

protected:
    /**
     * @brief onKeyStatus
     * @param id
     */
    void onKeyStatus(ButtonId id);

private slots:
    /**
     * @brief コンパス有効状態変化通知受信
     * @param enabled true：有効に変化、false：無効に変化
     */
    void onNotifyChangeCompassEnabled(bool enabled);

    /**
     * @brief 方位角を受信
     * @param azimuth 方位角
     */
    void onNotifyAzimuth(uint16_t azimuth);

private:
    bool _isEnabledCompass;                         //!< コンパス有効フラグ

};

#endif // COMPASSVIEWMODEL_H
