/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef DCMEASUREMENTVIEWMODEL_H
#define DCMEASUREMENTVIEWMODEL_H

#include "abstractviewmodel.h"
#include <QTimer>

/**
 * @brief DC測定 ViewModel
 */
class DCMeasurementViewModel : public AbstractViewModel
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクター
     * @param screenId 画面 ID
     * @param model Model クラスのポインター
     * @param parent 親オブジェクト
     */
    explicit DCMeasurementViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent = nullptr);

    /**
     * @brief デストラクタ
     */
    virtual ~DCMeasurementViewModel();

    /**
     * @brief 画面Resume時に呼び出されるメソッド
     */
    virtual void resume() override;

    /**
     * @brief 画面Suspend時に呼び出されるメソッド
     */
    virtual void suspend() override;

    /**
     * @brief 画面Active 時の処理
     *
     * 電圧値を取得して画面に表示する
     */
    void activate() override;

    /**
     * @brief 画面deactivate 時の処理
     */
    void deactivate() override;

public slots:
    /**
     * @brief タイムアウト受信時処理
     */
    void onNotifyTimeOut();
signals:

protected:
    /**
     * @brief onKeyStatus
     * @param id
     */
    void onKeyStatus(ButtonId id);

    /**
     * @brief 必要に応じて View を指すポインターを付け替えた後の復帰処理を行う
     */
    virtual void recover(void) override;

private:
    QObject *_voltage_msg;  //!< 電圧値メッセージ部品
    QTimer *_timer;         //!< タイマー

    /**
     * @brief タイマーを開始する
     */
    void timerStart(void);

};

#endif // DCMEASUREMENTVIEWMODEL_H
