/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "otherviewmodel.h"


QVector<QVector<QString>> otherButtonData = {
    {{"a1"},{"a2"},{"a3"}}
};

QVector<QVector<QString>> selectedCoaxialCableotherButtonData = {
    {{"a1"},{""},{"a3"}}
};

QVector<QVector<QString>> otherButtonDataWithNoCompass = {
    {{"a1"},{"a2"},{""}}
};

QVector<QVector<QString>> selectedCoaxialCableotherButtonDataWithNoCompass = {
    {{"a1"},{""},{""}}
};

const int OtherViewModel::BUTTON_COLUMN_NUMBER = 1;
const int OtherViewModel::BUTTON_ROW_NUMBER = 3;

constexpr const char *VISIBLE_COMPASS_OPTION_ID = "8001";   // コンパスを表示するオプション ID

OtherViewModel::OtherViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent)
    : AbstractViewModel(screenId, model, parent)
    , _visibleCompass(false)
{
    setObjectName("otherViewModel");
    _buttonOperationa.setButtonName(BUTTON_COLUMN_NUMBER, BUTTON_ROW_NUMBER, otherButtonData);
    _buttonOperationa.setActiveObject(otherButtonData[0][0]);
    _activeButton = otherButtonData[0][0];
}

void OtherViewModel::activate()
{
    if (nullptr == _view) {
        qErrnoWarning("_view is null");
        return;
    }

    // ヘッダメニュー表示
    _model->replaceMenuList(MenuListIconIndex::FUNCTION_ICON, "icon_menu_other.png");

    // 機種情報の取得を行う
    LC70_PRODUCT_INFO_T productionInfo;
    memset(&productionInfo, 0, sizeof(LC70_PRODUCT_INFO_T));
    _model->getModelInformation(productionInfo);

    // オプション ID
    QString optionInfo;
    for (int i = 0; i < LC70_OPTINFO_SIZE; ++i) {
        QChar code = QChar(productionInfo.cOptInfo[i]);
        if (code == '\0') {
            break;
        }
        optionInfo += code;
    }

    if (optionInfo == QString(VISIBLE_COMPASS_OPTION_ID)) {
        _visibleCompass = true;
    }

    if (_view) {
        _view->setProperty("visibleCompass", _visibleCompass);
    }

    // ボタンActive設定
    QVariant value;
    int measInput = 0;

    int rfOptical = 0;
    _model->getValue(VALUE_RF_OPTICAL, value);
    rfOptical = value.toInt();

    switch (rfOptical) {
    case 0:
    {
        if (_visibleCompass) {
            _buttonOperationa.setButtonName(BUTTON_COLUMN_NUMBER, BUTTON_ROW_NUMBER, selectedCoaxialCableotherButtonData);
            _buttonOperationa.setActiveObject(selectedCoaxialCableotherButtonData[0][0]);
            _activeButton = selectedCoaxialCableotherButtonData[0][0];

            _model->replaceMenuList(MenuListIconIndex::RF_OPTICAL_ICON, "icon_hikari_rf.png");
        } else {
            _buttonOperationa.setButtonName(BUTTON_COLUMN_NUMBER, BUTTON_ROW_NUMBER, selectedCoaxialCableotherButtonDataWithNoCompass);
            _buttonOperationa.setActiveObject(selectedCoaxialCableotherButtonDataWithNoCompass[0][0]);
            _activeButton = selectedCoaxialCableotherButtonDataWithNoCompass[0][0];

            _model->replaceMenuList(MenuListIconIndex::RF_OPTICAL_ICON, "icon_hikari_rf.png");
        }
    }
        break;

    case 1:
    {
        if (_visibleCompass) {
            _buttonOperationa.setButtonName(BUTTON_COLUMN_NUMBER, BUTTON_ROW_NUMBER, otherButtonData);
            _model->replaceMenuList(MenuListIconIndex::RF_OPTICAL_ICON, "icon_hikari_opt.png");
        } else {
            _buttonOperationa.setButtonName(BUTTON_COLUMN_NUMBER, BUTTON_ROW_NUMBER, otherButtonDataWithNoCompass);
            _model->replaceMenuList(MenuListIconIndex::RF_OPTICAL_ICON, "icon_hikari_opt.png");
        }
    }
        break;

    default:
        break;
    }

    bool opticalDisableState = false;

    switch (rfOptical) {
    case 0: // 同軸選択
        opticalDisableState = true;
        break;
    case 1: // 光選択
        opticalDisableState = false;
        break;
    default:
        break;
    }

    if (_view) {
        QObject *target = _view->findChild<QObject *>("a2");

        if (target) {
            target->setProperty("disable", opticalDisableState);
        }
    }

    int buttonIndex = 0;

    buttonIndex = measInput + 1;

    // Active にするボタンを設定
    QString itemname("a");
    itemname += QString().sprintf("%d", buttonIndex);

    QObject *item = nullptr;
    if (_view) {
        item = _view->findChild<QObject *>(itemname);
    }
    if (item) {
        item->setProperty("active", true);
    }

    _activeButton = itemname;
    _buttonOperationa.setActiveObject(_activeButton);
}

void OtherViewModel::moveCursor(ButtonId buttonId)
{
    if ((buttonId == BUTTON_RIGHT) || (buttonId == BUTTON_LEFT)) {
        // UP, DOWN なし

        QString nextBtn;
        bool ret = _buttonOperationa.nextActiveObject(buttonId, nextBtn);

        if (ret) {

            // inactive
            QObject *target = nullptr;
            if (_view) {
                target = _view->findChild<QObject *>(_activeButton);
            }
            if (target) {
                target->setProperty("active", false);
            }

            // active
            target = nullptr;
            if (_view) {
                target = _view->findChild<QObject *>(nextBtn);
            }
            if (target) {
                target->setProperty("active", true);
            }

            _activeButton = nextBtn;
            _buttonOperationa.setActiveObject(_activeButton);

            QVariant value;

            if (_activeButton == "a1") {
                value = 0;
            } else if (_activeButton == "a2") {
                value = 1;
            } else {
                // 何もしない
            }
        }
    }
}


void OtherViewModel::onKeyStatus(ButtonId id)
{
    if (id == BUTTON_ENTER) {
        int button_index = _activeButton.mid(1).toInt()-1;
        onRequest(button_index);
    } else if (id == BUTTON_USER) {
        //emit requestDirect(SCREEN_USER_DATA_LOGGER_MENU, true);
        emit requestDirect(SCREEN_USER_SETTING, true);
    }else if(id == BUTTON_ESCAPE || id == BUTTON_HOME){
        emit back();
    } else {
        moveCursor(id);
    }

}

void OtherViewModel::onButtonPress(ButtonId id)
{
    if (id == BUTTON_ENTER) {
        QObject *target = nullptr;
        if (_view) {
            target = _view->findChild<QObject *>(_activeButton);
        }
        if (target) {
            target->setProperty("press", true);
        }
    }
}
