/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef AUTOPOWEROFFSETTINGVIEWMODEL_H
#define AUTOPOWEROFFSETTINGVIEWMODEL_H

#include "abstractviewmodel.h"
#include "buttonoperation.h"

/**
 * @brief オートパワーオフ設定 ViewModel
 */
class AutoPowerOffSettingViewModel : public AbstractViewModel
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクター
     * @param screenId 画面 ID
     * @param model Model クラスのポインター
     * @param parent 親オブジェクト
     */
    explicit AutoPowerOffSettingViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent = nullptr);

    /**
     * @brief デストラクタ
     */
    virtual ~AutoPowerOffSettingViewModel();

    /**
     * @brief activate
     */
    void activate() override;

public slots:
    /**
     * @brief onRequest
     * @param condition
     */
    void onRequest(int condition) override;

protected:
    /**
     * @brief onKeyStatus
     * @param id
     */
    void onKeyStatus(ButtonId id) override;

protected slots:
    void onAccept(PopupId popupId, bool okOnly) override;
    void onReject(PopupId popupId) override;

private:
    ButtonOperation _buttonOperation;
    QString         _activeButton;
    static const int BUTTON_COLUMN_NUMBER;
    static const int BUTTON_ROW_NUMBER;

    void onButtonPress(ButtonId id) override;

    /**
     * @brief moveCursor
     * @param buttonId
     */
    void moveCursor(ButtonId buttonId);
};

#endif // AUTOPOWEROFFSETTINGVIEWMODEL_H
