/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "batteryinformationviewmodel.h"
#include "mainframeviewmodel.h"

BatteryInformationViewModel::BatteryInformationViewModel(ScreenId screenId, LevelCheckerModel *model,
       QObject *parent)
    : AbstractViewModel(screenId, model, parent)
{
    setObjectName("batteryInformation");
}

BatteryInformationViewModel::~BatteryInformationViewModel()
{

}

void BatteryInformationViewModel::createConnection(QObject *qml, QObject *mainFrame)
{
    AbstractViewModel::createConnection(qml, mainFrame);

    connect(mainFrame, SIGNAL(notifyBatteryCharge(uint8_t, uint8_t, uint8_t)), this, SLOT(onNotifyBatteryCharge(uint8_t, uint8_t, uint8_t)));
}

void BatteryInformationViewModel::activate()
{
    if (nullptr == _view) {
        qErrnoWarning("_view is null");
        return;
    }
}

void BatteryInformationViewModel::deactivate()
{
    AbstractViewModel::deactivate();

    disconnect(_mainFrame, SIGNAL(notifyBatteryCharge(uint8_t, uint8_t, uint8_t)), this, SLOT(onNotifyBatteryCharge(uint8_t, uint8_t, uint8_t)));
}

void BatteryInformationViewModel::onNotifyBatteryCharge(uint8_t battery, uint8_t batempH, uint8_t batempM)
{
    // バッテリー使用可能時間
    if( (batempH != 0xFF) && (batempM != 0xFF) )
    {
         // 充電中
        if( (battery & LC70_BATT_STS_MSK) == LC70_BATT_STS_MSK_CHGING) {
            if (_view) {
                _view->setProperty("acBattery", true);
            }
        } else {
            if (_view) {
                _view->setProperty("acBattery", false);
            }
        }

        // 正常
        if (_view) {
            _view->setProperty("availableTime", QString("%1時間%2分").arg(batempH).arg(batempM));
        }
        if (_view) {
            _view->setProperty("availbleNormal", true);
        }
    } else {
        // 異常
        if (_view) {
            _view->setProperty("availableTime", QString("--時間--分"));
        }
        if (_view) {
            _view->setProperty("availbleNormal", false);
        }
    }
}

void BatteryInformationViewModel::onKeyStatus(ButtonId id)
{
    if(id == BUTTON_ESCAPE) {
        emit back();
    } else if(id == BUTTON_HOME) {
        emit requestDirect(SCREEN_HOME, true);
    } else if(id == BUTTON_USER) {
#ifdef NEW_USER_SETTING
        emit requestDirect(SCREEN_USER_SETTING, true);
#else
        emit requestDirect(SCREEN_USER_DATA_LOGGER_MENU, true);
#endif
    }
}
