/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef BATTERYINFORMATIONVIEWMODEL_H
#define BATTERYINFORMATIONVIEWMODEL_H

#include "abstractviewmodel.h"

/**
 * @brief バッテリー情報 ViewModel クラス
 */
class BatteryInformationViewModel: public AbstractViewModel
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクタ
     */
    explicit BatteryInformationViewModel(ScreenId screenId, LevelCheckerModel *model, QObject *parent);

    /**
     * @brief デストラクタ
     */
    virtual ~BatteryInformationViewModel();

    /**
     * @brief 画面を開くときに呼び出す qml との接続処理
     * @param qml qml のオブジェクトのポインター
     * @param mainFrame MainFrameViewModel のポインター
     */
    virtual void createConnection(QObject *qml, QObject *mainFrame) override;

    /**
     * @brief activate
     */
    virtual void activate() override;

    /**
     * @brief 画面を閉じるときに呼び出す表示用の保存処理
     */
    virtual void deactivate(void) override;

public slots:

signals:

protected:
    /**
     * @brief onKeyStatus
     * @param id
     */
    void onKeyStatus(ButtonId id) override;

protected slots:

private slots:
    /**
     * @brief バッテリー使用可能時間を受信
     * @param battery バッテリー状態
     *        batempH 時間
     *        batempM 分
     */
    void onNotifyBatteryCharge(uint8_t battery, uint8_t batempH, uint8_t batempM);

private:

};

#endif // BATTERYINFORMATIONVIEWMODEL_H
