/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef BRIGHTNESSSETTINGVIEWMODEL_H
#define BRIGHTNESSSETTINGVIEWMODEL_H

#include "abstractviewmodel.h"
#include "buttonoperation.h"

/**
 * @brief 明るさ設定 ViewModel クラス
 */
class brightnessSettingViewModel: public AbstractViewModel
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクタ
     */
    brightnessSettingViewModel(ScreenId screenId, LevelCheckerModel *model, QObject *parent);

    /**
     * @brief デストラクタ
     */
    ~brightnessSettingViewModel();

    /**
     * @brief activate
     */
    void activate() override;

    void onKeyEnter();
public slots:
    /**
     * @brief onRequest
     * @param condition
     */
    void onRequest(int condition) override;

signals:

protected:
    /**
     * @brief onKeyStatus
     * @param id
     */
    void onKeyStatus(ButtonId id) override;

    /**
     * @brief 必要に応じて View を指すポインターを付け替えた後の復帰処理を行う
     */
    virtual void recover(void) override;

protected slots:
    /**
     * @brief onAccept
     * @param popupId
     * @param okOnly
     */
    void onAccept(PopupId popupId, bool okOnly) override;

    /**
     * @brief onReject
     * @param popupId
     */
    void onReject(PopupId popupId) override;


private:
    ButtonOperation _buttonOperation;
    QString         _activeButton;
    static const int BUTTON_COLUMN_NUMBER;
    static const int BUTTON_ROW_NUMBER;

    static const int INITIAL_BRIGHTNESS_VALUE;
    int _currentBrightness;

    QObject *_selectedBrightness;

    /**
     * @brief moveCursor
     * @param buttonId
     */
    void moveCursor(ButtonId buttonId);
    void onButtonPress(ButtonId id) override;
};

#endif // BRIGHTNESSSETTINGVIEWMODEL_H
