/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "datetimesettingviewmodel.h"

QVector<QVector<QString>> dateTimeButtonData = {
    {{"editDate"}, {"register"}}
};

QVector<QVector<QString>> dateTimeButtonDataEditMode = {
    {{"yeardata"}, {"monthdata"}, {"daydata"}, {"hourdata"}, {"minutesdata"}}
};

const int DateTimeSettingViewModel::BUTTON_COLUMN_NUMBER = 1;
const int DateTimeSettingViewModel::BUTTON_ROW_NUMBER = 2;
const int DateTimeSettingViewModel::BUTTON_ROW_NUMBER_EDITMODE = 5;

DateTimeSettingViewModel::DateTimeSettingViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent)
    : AbstractViewModel(screenId, model, parent),
      _screenState(SELECT)
{
    _buttonOperation.setButtonName(BUTTON_COLUMN_NUMBER, BUTTON_ROW_NUMBER, dateTimeButtonData);

    _activeButton = dateTimeButtonData[0][0];
    _buttonOperation.setActiveObject(_activeButton);
}

DateTimeSettingViewModel::~DateTimeSettingViewModel()
{

}

void DateTimeSettingViewModel::activate()
{
    // 現在時刻を取得
    QDateTime currentdatetime = QDateTime::currentDateTime();

    QString val;
    val = currentdatetime.toString("yyyy");
    _yyyy = val.toInt();

    val = currentdatetime.toString("MM");
    _mm = val.toInt();

    val = currentdatetime.toString("dd");
    _dd = val.toInt();

    val = currentdatetime.toString("HH");
    _HH = val.toInt();

    val = currentdatetime.toString("mm");
    _MM = val.toInt();

    // 初期表示
    updateYear(BUTTON_UNKNOWN);
    updateMonth(BUTTON_UNKNOWN);
    updateDay(BUTTON_UNKNOWN);
    updateHour(BUTTON_UNKNOWN);
    updateMinutes(BUTTON_UNKNOWN);

    // 選択状態から開始
    _screenState = SELECT;

    // ボタンオペレーションの設定
    _buttonOperation.setButtonName(BUTTON_COLUMN_NUMBER, BUTTON_ROW_NUMBER, dateTimeButtonData);

    // activeボタンの設定
    _activeButton = dateTimeButtonData[0][0];
    _buttonOperation.setActiveObject(_activeButton);
    QObject *target = nullptr;
    if (_view) {
        target = _view->findChild<QObject *>(_activeButton);
    }
    if (target) {
        target->setProperty("active", true);
    }

}

void DateTimeSettingViewModel::moveCursor(ButtonId buttonId)
{
    if ((buttonId == BUTTON_RIGHT) || (buttonId == BUTTON_LEFT) || (buttonId == BUTTON_UP) || (buttonId == BUTTON_DOWN)) {
        switch (_screenState) {
        case SELECT: {
            QString nextButton;
            bool ret = _buttonOperation.nextActiveObject(buttonId, nextButton);

            if (ret) {
                // inactivate
                QObject *target = nullptr;
                if (_view) {
                    target = _view->findChild<QObject *>(_activeButton);
                }
                if (target) {
                    target->setProperty("active", false);
                }

                // activate
                target = nullptr;
                if (_view) {
                    target = _view->findChild<QObject *>(nextButton);
                }
                if (target) {
                    target->setProperty("active", true);
                }

                _activeButton = nextButton;
                _buttonOperation.setActiveObject(_activeButton);
            }

            break;
        }

        case EDIT : {
            if (buttonId == BUTTON_LEFT || buttonId == BUTTON_RIGHT) {
                // 値の変更
                QString nextButton;
                bool ret = _editButtonOperation.nextActiveObject(buttonId, nextButton);

                if (ret) {
                    // 時間リストから対象のオブジェクトを取得する
                    QObject *targetbase = nullptr;
                    if (_view) {
                        targetbase = _view->findChild<QObject *>(_activeButton);
                    }
                    // inactivate
                    QObject *target = nullptr;
                    if (targetbase) {
                        target = targetbase->findChild<QObject *>(_activeEditButton);
                    }
                    if (target) {
                        target->setProperty("active", false);
                    }

                    // activate
                    target = nullptr;
                    if (targetbase) {
                        target = targetbase->findChild<QObject *>(nextButton);
                    }
                    if (target) {
                        target->setProperty("active", true);
                    }

                    _activeEditButton = nextButton;
                    _editButtonOperation.setActiveObject(_activeEditButton);
                }
            } else if (buttonId == BUTTON_UP || buttonId == BUTTON_DOWN) {
                updateDateTime(buttonId);
            }
        }
        }
    } else {
        // nothing to do
    }
}

void DateTimeSettingViewModel::updateDateTime(ButtonId buttonId)
{
    // active ボタンから対象フィールドを特定
    if (_activeEditButton == "yeardata") {
        updateYear(buttonId);
    } else if (_activeEditButton == "monthdata") {
        updateMonth(buttonId);
    } else if (_activeEditButton == "daydata") {
        updateDay(buttonId);
    } else if (_activeEditButton == "hourdata") {
        updateHour(buttonId);
    } else if (_activeEditButton == "minutesdata") {
        updateMinutes(buttonId);
    } else {
        return;
    }

    // データ更新
    QDate date(_yyyy, _mm, _dd);
    QList<QVariant> datetime = {_yyyy, _mm, _dd, date.dayOfWeek(), _HH, _MM};
    QVariant value(datetime);

    _model->setValue(VALUE_DATETIME, datetime);
}

void DateTimeSettingViewModel::onKeyStatus(ButtonId id)
{
    if (id == BUTTON_ENTER) {
        onKeyEnter();
    } else if (id == BUTTON_ESCAPE || id == BUTTON_HOME || id == BUTTON_USER) {
        if (_model->isUpdate(VALUE_DATETIME) == true) {
            // 変更されていれば破棄の確認
            onRequestPopup(POPUP_CANCEL_CONFIRMATION);
        } else {
            onAccept(POPUP_CANCEL_CONFIRMATION, true);
        }
    } else {
        moveCursor(id);
    }
}

void DateTimeSettingViewModel::onButtonPress(ButtonId id)
{
    if (id == BUTTON_ENTER) {
        QObject *target = nullptr;
        if (_view) {
            target = _view->findChild<QObject *>(_activeButton);
        }
        if (target) {
            target->setProperty("press", true);
        }
    }
}

void DateTimeSettingViewModel::updateYear(ButtonId id)
{
    if (id == BUTTON_UP) {
        _yyyy++;
    } else if (id == BUTTON_DOWN) {
        _yyyy--;
    } else {
        // nothing to do
    }

    // 上限下限の判定
    if (_yyyy < 2020) {
        _yyyy = 2020;
    } else if (_yyyy > 2037) {
        _yyyy = 2037;
    } else {
        // nothing to do
    }

    // 閏年などで月の日数が減る場合の調整
    while (!QDate::isValid(_yyyy, _mm, _dd)) {
        // 有効な日付になるまで日を減らす
        _dd--;
    }

    updateDateComponents();
}

void DateTimeSettingViewModel::updateMonth(ButtonId id)
{
    QDate date(_yyyy, _mm, _dd);

    if (id == BUTTON_UP) {
        date = date.addMonths(1);
    } else if (id == BUTTON_DOWN) {
        date = date.addMonths(-1);
    } else {
        // nothing to do
    }

    _mm = date.month();

    // 月末日付の調整
    int day = date.day();

    if (_dd != day) {
        _dd = day;
    }

    updateDateComponents();
}

void DateTimeSettingViewModel::updateDay(ButtonId id)
{
    QDate date(_yyyy, _mm, _dd);

    if (id == BUTTON_UP) {
        _dd++;
    } else if (id == BUTTON_DOWN) {
        _dd--;
    } else {
        // nothing to do
    }

    // 月末日付の調整
    int daysInMonth = date.daysInMonth();
    _dd = (_dd + daysInMonth) % daysInMonth;

    if (_dd == 0) {
        _dd = daysInMonth;
    }

    updateDateComponents();
}

void DateTimeSettingViewModel::updateDateComponents()
{
    QObject *btn = nullptr;

    // 年の更新
    if (_view) {
        btn = _view->findChild<QObject *>("yeardata");
    }

    if (btn) {
        btn->setProperty("message", QString().sprintf("%d年", _yyyy));
    }

    // 月の更新
    btn = nullptr;
    if (_view) {
        btn = _view->findChild<QObject *>("monthdata");
    }
    if (btn) {
        btn->setProperty("message", QString().sprintf("%d月", _mm));
    }

    // 日の更新
    btn = nullptr;
    if (_view) {
        btn = _view->findChild<QObject *>("daydata");
    }
    if (btn) {
        btn->setProperty("message", QString().sprintf("%d日", _dd));
    }
}


void DateTimeSettingViewModel::updateHour(ButtonId id)
{
    if (id == BUTTON_UP) {
        _HH++;
    } else if (id == BUTTON_DOWN) {
        _HH--;
    } else {
        // nothing to do.
    }

    _HH = (_HH + 24) % 24;

    QObject *btn = nullptr;
    if (_view) {
        btn = _view->findChild<QObject *>("hourdata");
    }
    if (btn) {
        btn->setProperty("message", QString().sprintf("%d", _HH));
    }

}

void DateTimeSettingViewModel::updateMinutes(ButtonId id)
{
    if (id == BUTTON_UP) {
        _MM++;
    } else if (id == BUTTON_DOWN) {
        _MM--;
    } else {
        // nothing to do.
    }

    _MM = (_MM + 60) % 60;

    QObject *btn = nullptr;
    if (_view) {
        btn = _view->findChild<QObject *>("minutesdata");
    }
    if (btn) {
        btn->setProperty("message", QString().sprintf("%d", _MM));
    }

}

void DateTimeSettingViewModel::onRequestPopup(PopupId id)
{
    emit requestToShowPopup(id);
}

void DateTimeSettingViewModel::onAccept(PopupId popupId, bool okOnly)
{
    Q_UNUSED(okOnly);

    AbstractViewModel::onAccept(popupId, okOnly);

    if (popupId == POPUP_CANCEL_CONFIRMATION) {
        _model->rollback(VALUE_DATETIME);

        switch (_lastPressedButtonId) {
        case BUTTON_HOME:
            // HOMEに戻る
            emit requestDirect(SCREEN_HOME, true);
            break;

        case BUTTON_ESCAPE:
            // システム設定メニューに戻る
            emit back();
            break;

        case BUTTON_USER:
            // ユーザ画面に遷移
#ifdef NEW_USER_SETTING
        emit requestDirect(SCREEN_USER_SETTING, true);
#else
        emit requestDirect(SCREEN_USER_DATA_LOGGER_MENU, true);
#endif

        default:
            break;
        }
    } else if (popupId == POPUP_FAILURE_DATE_SETTING) {
        emit requestDirect(SCREEN_HOME, true);
    }
}

void DateTimeSettingViewModel::onReject(PopupId popupId)
{
    if (popupId == POPUP_FAILURE_DATE_SETTING) {
        emit requestDirect(SCREEN_HOME, true);
    }
}

void DateTimeSettingViewModel::onKeyEnter()
{
    QObject *target = nullptr;
    if (_view) {
        target = _view->findChild<QObject *>(_activeButton);
    }
    if (target) {
        if (_activeButton == "register") {

            // データ更新
            QDate date(_yyyy, _mm, _dd);
            QList<QVariant> datetime = {_yyyy, _mm, _dd, date.dayOfWeek(), _HH, _MM};
            _model->setValue(VALUE_DATETIME, datetime);

            // 保存ボタン押下時
            if(_model->commit(VALUE_DATETIME)){
                // 保存失敗
                emit requestToShowPopup(POPUP_FAILURE_DATE_SETTING);
            }else{
                // 保存成功時はシステム設定メニューに戻る
                emit back();
            }
        } else {
            // 保存ボタン以外のボタン押下時
            _screenState = (_screenState == EDIT) ? SELECT : EDIT;

            if (_screenState == EDIT) {
                target = nullptr;
                if (_view) {
                    target = _view->findChild<QObject *>("editDate");
                }
                if (target) {
                    target->setProperty("edit", true);
                }

                // 編集用のボタンオペレーションに変更
                _editButtonOperation.setButtonName(BUTTON_COLUMN_NUMBER, BUTTON_ROW_NUMBER_EDITMODE, dateTimeButtonDataEditMode);
                _activeEditButton = "yeardata";
                _editButtonOperation.setActiveObject(_activeButton);
            } else {
                target = nullptr;
                if (_view) {
                    target = _view->findChild<QObject *>("editDate");
                }
                if (target) {
                    target->setProperty("edit", false);
                }
                _activeButton = "editDate";
                _buttonOperation.setActiveObject(_activeButton);
            }
        }
    }
}
