/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef DATETIMESETTINGVIEWMODEL_H
#define DATETIMESETTINGVIEWMODEL_H

#include "abstractviewmodel.h"
#include "buttonoperation.h"

/**
 * @brief 日時設定 ViewModel
 */
class DateTimeSettingViewModel : public AbstractViewModel
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクター
     * @param screenId 画面 ID
     * @param model Model クラスのポインター
     * @param parent 親オブジェクト
     */
    explicit DateTimeSettingViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent = nullptr);

    /**
     * @brief デストラクタ
     */
    virtual ~DateTimeSettingViewModel();

    /**
     * @brief activate
     */
    void activate() override;
signals:

protected:
    /**
     * @brief onKeyStatus
     * @param id
     */
    void onKeyStatus(ButtonId id) override;
protected slots:
    /**
     * @brief onRequestPopup
     * @param id
     */
    void onRequestPopup(PopupId id);

    /**
     * @brief onAccept
     * @param okOnly
     */
    void onAccept(PopupId popupId, bool okOnly) override;

    /**
     * @brief ポップアップから拒否の通知を受信
     */
    void onReject(PopupId popupId) override;

private:
    ButtonOperation _buttonOperation;              //!< 選択モード中のボタンオペレーション
    ButtonOperation _editButtonOperation;          //!< 編集モード中のボタンオペレーション
    QString         _activeButton;                 //!< 選択モード中の選択ボタン
    QString         _activeEditButton;             //!< 編集モード中の選択ボタン

    static const int BUTTON_COLUMN_NUMBER;         //!< ボタン行数
    static const int BUTTON_ROW_NUMBER;            //!< 選択モード中のボタン列数
    static const int BUTTON_ROW_NUMBER_EDITMODE;   //!< 編集モード中のボタン列数

    int _yyyy;
    int _mm;
    int _dd;
    int _HH;
    int _MM;

    enum state {
        SELECT = 0,
        EDIT
    };

    state _screenState;

    void onButtonPress(ButtonId id) override;

    /**
     * @brief onKeyEnter
     */
    void onKeyEnter();

    /**
     * @brief moveCursor
     * @param buttonId
     */
    void moveCursor(ButtonId buttonId);

    /**
     * @brief udpateDateTime
     * @param buttonId
     */
    void updateDateTime(ButtonId buttonId);

    /**
     * @brief upateYear
     * @param id
     */
    void updateYear(ButtonId id);

    /**
     * @brief updateMonth
     * @param id
     */
    void updateMonth(ButtonId id);

    /**
     * @brief updateDay
     * @param id
     */
    void updateDay(ButtonId id);

    /**
     * @brief updateHour
     * @param id
     */
    void updateHour(ButtonId id);

    /**
     * @brief updateMinutes
     * @param id
     */
    void updateMinutes(ButtonId id);

    /**
     * @brief updateDateComponent
     */
    void updateDateComponents();
};

#endif // DATETIMESETTINGVIEWMODEL_H
