/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "initializationviewmodel.h"

QVector<QVector<QString>> initializeButtonData = {
    {{"yes"}, {"no"}}
};

const int InitializationViewModel::BUTTON_COLUMN_NUMBER = 1;
const int InitializationViewModel::BUTTON_ROW_NUMBER = 2;

InitializationViewModel::InitializationViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent)
    : AbstractViewModel(screenId, model, parent)
{
    setObjectName(QString("initializationViewModel"));
    _buttonOperation.setButtonName(BUTTON_COLUMN_NUMBER, BUTTON_ROW_NUMBER, initializeButtonData);
}

InitializationViewModel::~InitializationViewModel()
{

}

void InitializationViewModel::activate()
{
    _activeButton = initializeButtonData[0][1];
    _buttonOperation.setActiveObject(_activeButton);
    QObject *target = nullptr;
    if (_view) {
        target = _view->findChild<QObject *>(_activeButton);
    }
    if (target) {
        target->setProperty("active", true);
    }

}

void InitializationViewModel::moveCursor(ButtonId buttonId)
{
    if ((buttonId == BUTTON_RIGHT) || (buttonId == BUTTON_LEFT)) {
        // UP, DOWN なし

        QString nextBtn;
        bool ret = _buttonOperation.nextActiveObject(buttonId, nextBtn);

        if (ret) {

            // inactive
            QObject *target = nullptr;
            if (_view) {
                target = _view->findChild<QObject *>(_activeButton);
            }
            if (target) {
                target->setProperty("active", false);
            }

            // active
            target = nullptr;
            if (_view) {
                target = _view->findChild<QObject *>(nextBtn);
            }
            if (target) {
                target->setProperty("active", true);
            }

            _activeButton = nextBtn;
            _buttonOperation.setActiveObject(_activeButton);
        }
    }
}

void InitializationViewModel::onKeyStatus(ButtonId id)
{
    if (id == BUTTON_LEFT || id == BUTTON_RIGHT || id == BUTTON_UP || id == BUTTON_DOWN) {
        moveCursor(id);
    } else if (id == BUTTON_ENTER) {
        QObject *target = nullptr;
        if (_view) {
            target = _view->findChild<QObject *>(_activeButton);
        }
        if (target) {
            target->setProperty("press", false);
        }
        if (_activeButton == "yes") {
            // 初期化処理確認
            emit requestToShowPopup(POPUP_INITIALIZE_CONFIRMATION);
        } else {
            emit back();
        }
    } else if (id == BUTTON_ESCAPE) {
        emit back();
    } else if (id == BUTTON_HOME) {
        emit requestDirect(SCREEN_HOME, true);
    } else if (id == BUTTON_USER) {
#ifdef NEW_USER_SETTING
        emit requestDirect(SCREEN_USER_SETTING, true);
#else
        emit requestDirect(SCREEN_USER_DATA_LOGGER_MENU, true);
#endif
    }
}

void InitializationViewModel::onAccept(PopupId popupId, bool okOnly)
{
    Q_UNUSED(okOnly)

    AbstractViewModel::onAccept(popupId, okOnly);

    if (popupId == POPUP_INITIALIZE_CONFIRMATION) {
        // 工場出荷状態初期化要求
        _model->initializeFactoryDefault();
    }
}

void InitializationViewModel::onButtonPress(ButtonId id)
{
    if (id == BUTTON_ENTER) {
        QObject *target = nullptr;
        target = _view->findChild<QObject *>(_activeButton);
        if (target) {
            target->setProperty("press", true);
        }
    }
}
