/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "manualviewmodel.h"
#include "mainframeviewmodel.h"
#include <QDebug>



QVector<QVector<QString>> indexbutton = {
    { {"manu1"}, {"manu2"}, {"manu3"},{"manu4"} },
    { {"manu5"}, {"manu6"}, {"manu7"},{"manu8"} }
};


const int Manualviewmodel::BUTTON_COLUMN_NUMBER = 2;
const int Manualviewmodel::BUTTON_ROW_NUMBER    = 4;

Manualviewmodel::Manualviewmodel(ScreenId screenId, LevelCheckerModel *&model,
                                 QObject *parent)
    : AbstractViewModel(screenId, model, parent)
{
    setObjectName("systemSettingMenuViewModel");
    _buttonOperation.setButtonName(BUTTON_COLUMN_NUMBER, BUTTON_ROW_NUMBER, indexbutton);

    _activeButton = indexbutton[0][0];
    _buttonOperation.setActiveObject(_activeButton);

}

void Manualviewmodel::activate()
{
    AbstractViewModel::activate();

    if (nullptr == _view) {
        qErrnoWarning("_view is null");
        return;
    }
   // _model->replaceMenuList(MenuListIconIndex::FUNCTION_ICON, "icon_menu_speana.png");
    _model->changeDeviceStatusInterval(true);

    //MainFrameViewModel *mainFrame = static_cast<MainFrameViewModel *>(_mainFrame);

    // 先頭のボタンをアクティブにする
    resetToInitialButtonState(indexbutton[0][0], _activeButton, _buttonOperation);

    _activepage = "indexp";
    _view->setProperty("indexp",true);
}

void Manualviewmodel::moveCursor(ButtonId buttonId)
{
    if ((buttonId == BUTTON_RIGHT) || (buttonId == BUTTON_LEFT) || (buttonId == BUTTON_UP) || (buttonId == BUTTON_DOWN)) {
        // UP, DOWN なし

        QString nextBtn;
        bool ret = _buttonOperation.nextActiveObject(buttonId, nextBtn);

        if (ret) {

            // inactive
            QObject *target = _view->findChild<QObject *>(_activeButton);

            if (target) {
                target->setProperty("active", false);
            }

            // active
            target = _view->findChild<QObject *>(nextBtn);

            if (target) {
                target->setProperty("active", true);
            }

            _activeButton = nextBtn;
            _buttonOperation.setActiveObject(_activeButton);
        }
    }

}

void Manualviewmodel::changepage(int valupage)
{
    _view->setProperty("indexp",false);
    switch(valupage){
    case 0:
        _activepage = "manuals1";
        _view->setProperty("manual_page","file:///usr/local/bin/manual_main/manuals1.png");
        _view->setProperty("manual1",true);
        count = 0;
        break;
    case 1:
        _activepage = "manualm1";
        _view->setProperty("manual_page","file:///usr/local/bin/manual_main/manualm1.png");
        _view->setProperty("manual1",true);
        count = 1;
        break;
    case 2:
        _activepage = "manuall1";
        _view->setProperty("manual_page","file:///usr/local/bin/manual_main/manuall1.png");
        _view->setProperty("manual1",true);
        count = 2;
        break;
    case 3:
        _activepage = "manualo1";
        _view->setProperty("manual_page","file:///usr/local/bin/manual_main/manualo1.png");
        _view->setProperty("manual1",true);
        count = 3;
        break;
    case 4:
        _activepage = "manualu1";
        _view->setProperty("manual_page","file:///usr/local/bin/manual_main/manualu1.png");
        _view->setProperty("manual1",true);
        count = 4;
        break;
    case 5:
        _activepage = "manualf1";
        _view->setProperty("manual_page","file:///usr/local/bin/manual_main/manualf1.png");
        _view->setProperty("manual1",true);
        count = 5;
        break;
    case 6:
        _activepage = "manualg1";
        _view->setProperty("manual_page","file:///usr/local/bin/manual_main/manualg1.png");
        _view->setProperty("manual1",true);
        count = 6;
        break;
    case 7:
        _activepage = "manuald1";
        _view->setProperty("manual_page","file:///usr/local/bin/manual_main/manuald1.png");
        _view->setProperty("manual1",true);
        count = 7;
        break;

    }

    if(count == 0){
        _manual_page = 14;
    }else if(count == 1){
        _manual_page = 12;
    }else if(count == 2){
        _manual_page = 5;
    }else if(count == 3){
        _manual_page = 3;
    }else if(count == 4){
        _manual_page = 4;
    }else if(count == 5){
        _manual_page = 4;
    }else if(count == 6){
        _manual_page = 5;
    }else{
        _manual_page = 2;
    }


}
void Manualviewmodel::movepage(ButtonId buttonId)
{
    int valu_page=0;
    QString next_page = "";
    QString page_name = "";


    if((buttonId == BUTTON_RIGHT) || (buttonId == BUTTON_LEFT) || (buttonId == BUTTON_CHANNEL_UP) || (buttonId == BUTTON_CHANNEL_DOWN)) {
        if((buttonId == BUTTON_RIGHT) || (buttonId == BUTTON_CHANNEL_UP)){
            _view->setProperty("manual1",false);



            valu_page = _activepage.mid(7).toInt();
            if(valu_page>=_manual_page){
               valu_page = 0;
            }

            if(count == 0){
                next_page += QString().sprintf("manuals%d",valu_page+1);
                page_name += QString().sprintf("file:///usr/local/bin/manual_main/manuals%d.png",valu_page+1);

            }else if(count == 1){
                next_page += QString().sprintf("manualm%d",valu_page+1);
                page_name += QString().sprintf("file:///usr/local/bin/manual_main/manualm%d.png",valu_page+1);

            }else if(count == 2){
                next_page += QString().sprintf("manuall%d",valu_page+1);
                page_name += QString().sprintf("file:///usr/local/bin/manual_main/manuall%d.png",valu_page+1);

            }else if(count == 3){
                next_page += QString().sprintf("manualo%d",valu_page+1);
                page_name += QString().sprintf("file:///usr/local/bin/manual_main/manualo%d.png",valu_page+1);

            } else if(count == 4){
                next_page += QString().sprintf("manualu%d",valu_page+1);
                page_name += QString().sprintf("file:///usr/local/bin/manual_main/manualu%d.png",valu_page+1);

            }else if(count == 5){
                next_page += QString().sprintf("manualf%d",valu_page+1);
                page_name += QString().sprintf("file:///usr/local/bin/manual_main/manualf%d.png",valu_page+1);

            }else if(count == 6){
                next_page += QString().sprintf("manualg%d",valu_page+1);
                page_name += QString().sprintf("file:///usr/local/bin/manual_main/manualg%d.png",valu_page+1);

            }else if(count == 7){
                next_page += QString().sprintf("manuald%d",valu_page+1);
                page_name += QString().sprintf("file:///usr/local/bin/manual_main/manuald%d.png",valu_page+1);
            }



            _view->setProperty("manual_page",page_name);
            _view->setProperty("manual1",true);
            _activepage = next_page;
        }else{


            _view->setProperty("manual1",false);
            valu_page = _activepage.mid(7).toInt()-1;
            if(valu_page==0){
                valu_page = _manual_page;
            }

            if(count == 0){
                next_page += QString().sprintf("manuals%d",valu_page);
                page_name += QString().sprintf("file:///usr/local/bin/manual_main/manuals%d.png",valu_page);

            }else if(count == 1){
                next_page += QString().sprintf("manualm%d",valu_page);
                page_name += QString().sprintf("file:///usr/local/bin/manual_main/manualm%d.png",valu_page);

            }else if(count == 2){
                next_page += QString().sprintf("manuall%d",valu_page);
                page_name += QString().sprintf("file:///usr/local/bin/manual_main/manuall%d.png",valu_page);

            }else if(count == 3){
                next_page += QString().sprintf("manualo%d",valu_page);
                page_name += QString().sprintf("file:///usr/local/bin/manual_main/manualo%d.png",valu_page);

            } else if(count == 4){
                next_page += QString().sprintf("manualu%d",valu_page);
                page_name += QString().sprintf("file:///usr/local/bin/manual_main/manualu%d.png",valu_page);

            }else if(count == 5){
                next_page += QString().sprintf("manualf%d",valu_page);
                page_name += QString().sprintf("file:///usr/local/bin/manual_main/manualf%d.png",valu_page);

            }else if(count == 6){
                next_page += QString().sprintf("manualg%d",valu_page);
                page_name += QString().sprintf("file:///usr/local/bin/manual_main/manualg%d.png",valu_page);

            }else if(count == 7){
                next_page += QString().sprintf("manuald%d",valu_page);
                page_name += QString().sprintf("file:///usr/local/bin/manual_main/manuald%d.png",valu_page);
            }else{

            }



            /*if(count == 0){
                next_page += QString().sprintf("manuals%d", valu_page);
                page_name += QString().sprintf("file:///usr/local/bin/manual_main/manuals%d.png",valu_page);

            }else{


            }*/

            _view->setProperty("manual_page",page_name);
            _view->setProperty("manual1",true);
            _activepage = next_page;

        }


    }


}


void Manualviewmodel::onKeyStatus(ButtonId id)
{
    if(_activepage == "indexp"){
        AbstractViewModel::onKeyStatus(id);
    }

    if(id == BUTTON_HOME){
        AbstractViewModel::onKeyStatus(id);
    }
    if(id == BUTTON_ESCAPE){
        _view->setProperty("manual1",false);
        _view->setProperty("indexp",true);
        _activepage = "indexp";
        // 先頭のボタンをアクティブにする
        resetToInitialButtonState(indexbutton[0][0], _activeButton, _buttonOperation);
    }
    if (id == BUTTON_USER) {
        emit requestDirect(SCREEN_USER_SETTING, true);
    }

    if (id == BUTTON_ENTER) {
        if(_activepage == "indexp"){
            int value = _activeButton.mid(4).toInt()-1;
            changepage(value);
        }
    }
    if(_activepage != "indexp"){
        if((id == BUTTON_RIGHT) || (id == BUTTON_LEFT) ){
            if(_activepage == "indexp"){
                _view->setProperty("indexp",false);
            }
            movepage(id);
        }

    }else{
        moveCursor(id);
    }
}
