/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef MODELINFORMATIONVIEWMODEL_H
#define MODELINFORMATIONVIEWMODEL_H

#include "abstractviewmodel.h"
#include "buttonoperation.h"

class ModelInformationViewModel : public AbstractViewModel
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクター
     * @param screenId 画面 ID
     * @param model Modelクラスのポインター
     * @param parent 親オブジェクト
     */
    explicit ModelInformationViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent = nullptr);

    /**
     * @brief デストラクタ
     */
    virtual ~ModelInformationViewModel(void);

    /**
     * @brief 画面を開くときに呼び出す qml との接続処理
     * @param qml qml のオブジェクトのポインター
     * @param mainFrame MainFrameViewModel のポインター
     */
    virtual void createConnection(QObject *qml, QObject *mainFrame) override;

    /**
     * @brief 画面を開くときに呼び出す表示内容の復元処理
     */
    virtual void activate(void) override;

    /**
     * @brief 画面を閉じるときに呼び出すスレッドの停止処理
     */
    virtual void suspend(void) override;

    /**
     * @brief 画面を閉じるときに呼び出す表示な用の保存処理
     */
    virtual void deactivate(void) override;

    /**
     * @brief 画面に機種情報を設定
     */
    void setModelInformation(void);

signals:
    /**
     * @brief アップデート中のインジケーターの表示を通知
     * @param show 表示/非表示
     */
    void showIndicator(bool show);

protected:
    /**
     * @brief onKeyStatus ボタン押下通知受信時処理
     * @param id 押下したボタンID
     */
    void onKeyStatus(ButtonId id) override;

    /**
     * @brief 必要に応じて View を指すポインターを付け替えた後の復帰処理を行う
     */
    virtual void recover(void) override;

protected slots:
    /**
     * @brief ポップアップから受諾の通知を受信
     * @param okOnly OK のみの場合 true
     */
    virtual void onAccept(PopupId popupId, bool okOnly) override;

private:
    ButtonOperation _buttonOpration;
    LC70_PRODUCT_INFO_T _productionInfo;
    QObject * _updateButton;
    bool _acquiring;                    //!< 機種情報取得中

    void onButtonPress(ButtonId id) override;

private slots:
    /**
     * @brief バージョンアップ可否を受信
     * @param versionUpReady バージョンアップ可否
     */
    void onNotifyVersionUpReady(bool versionUpReady);

    /**
     * @brief アップデートの完了を通知を受信
     * @param success アップデート成否
     */
    void onNotifySoftwareUpdateCompleted(bool success);
};

#endif // MODELINFORMATIONVIEWMODEL_H
