/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef VOLUMESETTINGVIEWMODEL_H
#define VOLUMESETTINGVIEWMODEL_H

#include "abstractviewmodel.h"
#include "buttonoperation.h"
/**
 * @brief 音量設定 ViewModel
 */
class VolumeSettingViewModel : public AbstractViewModel
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクター
     * @param screenId 画面 ID
     * @param model Model クラスのポインター
     * @param parent 親オブジェクト
     */
    explicit VolumeSettingViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent = nullptr);

    /**
     * @brief デストラクタ
     */
    virtual ~VolumeSettingViewModel();

    /**
     * @brief activate
     */
    void activate() override;

public slots:
    /**
     * @brief onRequest
     * @param condition
     */
    void onRequest(int condition) override;
signals:

protected:
    /**
     * @brief onKeyStatus
     * @param id
     */
    void onKeyStatus(ButtonId id) override;

    /**
     * @brief onButtonPress
     * @param id
     */
    void onButtonPress(ButtonId id) override;

    /**
     * @brief 必要に応じて View を指すポインターを付け替えた後の復帰処理を行う
     */
    virtual void recover(void) override;

protected slots:
    /**
     * @brief onAccept
     * @param popupId
     * @param okOnly
     */
    void onAccept(PopupId popupId, bool okOnly) override;
    /**
     * @brief onReject
     * @param popupId
     */
    void onReject(PopupId popupId) override;
private:
    ButtonOperation _buttonOperation;
    QString         _activeButton;
    static const int BUTTON_COLUMN_NUMBER;
    static const int BUTTON_ROW_NUMBER;

    QString         _activeIcon;    //< Press 時に置き換わるActiveIconの退避用

    int _currentVolume;

    QObject *_selectedVolume;


    /**
     * @brief moveCursor
     * @param buttonId
     */
    void moveCursor(ButtonId buttonId);

    /**
     * @brief onKeyEnter
     */
    void onKeyEnter();
};

#endif // VOLUMESETTINGVIEWMODEL_H
