/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef FILESELECTIONVIEWMODEL_H
#define FILESELECTIONVIEWMODEL_H

#include "abstractviewmodel.h"
#include "buttonoperation.h"

/**
 * @brief 登録ファイル選択 ViewModel
 */
class FileSelectionViewModel : public AbstractViewModel
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクター
     * @param screenId 画面 ID
     * @param model Model クラスのポインター
     * @param parent 親オブジェクト
     */
    explicit FileSelectionViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent = nullptr);

    /**
     * @brief デストラクタ
     */
    virtual ~FileSelectionViewModel();
    /**
     * @brief 画面Active 時の処理
     *
     * ユーザリストデータを取得して画面に表示する
     */
    void activate() override;

    /**
     * @brief 遷移先画面で参照する遷移前画面のデータ設定
     */
    virtual void setTakeOver() override;

signals:
    void requestSetTakeOver(QVariant, QVariant);
    void requestGetTakeOver();

protected:
    /**
     * @brief onKeyStatus
     * @param id
     */
    virtual void onKeyStatus(ButtonId id) override;

    /**
     * @brief onButtonPress
     * @param id
     */
    void onButtonPress(ButtonId id) override;

private slots:
    virtual void onRequest(int condition) override;

private:
    static const char *EMPTY_VALUE;

    // ユーザリストの操作用
    static const int USER_LIST_COLUMN_NUMBER;
    static const int USER_LIST_ROW_NUMBER;

    QVector< QVector<QString> > _dataLoggerFileListButtonData;
    ButtonOperation _fileSaveListButtonOperation;   //<
    QString _fileSaveListActiveButton;
    QString _reserveUserListActivebg;

    // チャンネル設定リストの操作用
    static const int CHANNEL_LIST_COLUMN_NUMBER;
    static const int CHANNEL_LIST_ROW_NUMBER;

    // 設定値編集の操作用
    static const int CHANNEL_EDIT_COLUMN_NUMBER;
    static const int CHANNEL_EDIT_ROW_NUMBER;

    // 選択不可 データに対してのメッセージ
    static const QString CANNOT_SELECTION_MESSAGE;

    QVector<QVector<QString> > dataLoggerChannelEditButtonData;
    ButtonOperation _channelEditButtonOperation;   //<
    QString _channelEditActiveButton;

    // 動作ボタンの操作用
    static const int ACTION_COLUMN_NUMBER;
    static const int ACTION_ROW_NUMBER;

    QVector<QVector<QString> > _dataLoggerActionButtonData;
    ButtonOperation _actionButtonOperation;   //<
    QString _actionButtonActiveButton;

    int _fileSaveListCurrentPage;   //< ファイル保存先リストの現在ページ
    int _displayInfoCurrentPage;    //< 表示情報の現在ページ

    int _filemixState;

    // 操作対象のエリア定義
    enum SelectArea {
        USERLIST_AREA = 1,  // ユーザリスト
        // CHANNEL_AREA  = 2,  // チャンネルリスト
        ACTION_AREA   = 4,  // 動作ボタン部
    };

    SelectArea _selectArea; //< 選択している操作対象エリア

    /**
     * @brief onKeyStatusUserListArea
     * @param id
     */
    void onKeyStatusUserListArea(ButtonId id);

    /**
     * @brief moveCursor
     * @param id
     */
    void moveCursorUserListArea(ButtonId id);

    /**
     * @brief onKeyStatusActionButtonArea
     * @param id
     */
    void onKeyStatusActionButtonArea(ButtonId id);

    /**
     * @brief moveCursorActionButtonArea
     * @param id
     */
    void moveCursorActionButtonArea(ButtonId id);

    /**
     * @brief ユーザ設定リストの取り込み
     * @param activeButton 選択されているユーザリストのボタン名称 (userlistxx.csv が前提)
     */
    void getUserSettingList();

    /**
     * @brief showUserSettingList
     * ユーザ設定リストの表示
     *
     */
    int showUserSettingList();

    /**
     * @brief からのユーザ設定リストを表示
     * @note  「- 設定不可 -」 を選択時のユーザ設定リスト
     */
    void showEmptyUserSettingList();

    /**
     * @brief Activeなユーザリスト部品からデータ上のインデックスを返す
     * @return
     */
    int getSelectedUserListIndex();

    /**
     * @brief ユーザファルリストを表示する
     */
    void showUserFileList();


};

#endif // FILESELECTIONVIEWMODEL_H
