/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef USERMENUVIEWMODEL_H
#define USERMENUVIEWMODEL_H

#include "abstractviewmodel.h"
#include "buttonoperation.h"

/**
 * @brief ユーザメニュー ViewModel
 */
class UserDataLoggerMenuViewModel : public AbstractViewModel
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクター
     * @param screenId 画面 ID
     * @param model Model クラスのポインター
     * @param parent 親オブジェクト
     */
    explicit UserDataLoggerMenuViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent = nullptr);

    /**
     * @brief デストラクタ
     */
    virtual ~UserDataLoggerMenuViewModel();

    /**
     * @brief 画面Active 時の処理
     *
     * 波長データを取得して画面に表示する
     */
    void activate() override;

    /**
     * @brief 画面を閉じるときに呼び出す表示な用の保存処理
     */
    virtual void deactivate(void) override;

    /**
     * @brief 遷移先画面で参照する遷移前画面のデータ設定
     */
    virtual void setTakeOver() override;

signals:
    void requestSetTakeOver(QVariant, QVariant);

protected:
    /**
     * @brief onKeyStatus
     * @param id
     */
    virtual void onKeyStatus(ButtonId id) override;

    /**
     * @brief onButtonPress
     * @param id
     */
    void onButtonPress(ButtonId id) override;

private slots:
    /**
     * @brief 画面遷移要求の受信時処理
     * @param condition 画面IDリストのインデックス
     */
    virtual void onRequest(int condition) override;

    /**
     * @brief USB挿抜変更通知受信時処理
     * @param usbStatus USB挿抜状態 LC70_STRAGE_Tの値
     */
private:
    static const int BUTTON_COLUMN_NUMBER;
    static const int BUTTON_ROW_NUMBER;

    ButtonOperation _buttonOperation;   //!< ボタン操作情報
    QString _activeButton;              //!< 活性ボタンID

    /**
     * @brief moveCursor
     * @param id
     */
    void moveCursor(ButtonId id);

    /**
     * @brief USB状態エラー発生チェック
     * @return true: USB状態エラーが発生している、false: 発生していない
     */
    bool isErrorUsbStatus(void);

    /**
     * @brief プロパティに Bool 値を設定
     * @param objectName オブジェクト名
     * @param propertyName プロパティ名
     * @param value 設定する Bool 値
     */
    void setBoolProperty(QString objectName, QString propertyName, bool value);

};

#endif // USERMENUVIEWMODEL_H
