/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "usermeasurementselectionviewmodel.h"

static const int BUTTON_COLUMN_NUMBER = 1;
static const int BUTTON_ROW_NUMBER = 2;

QVector<QVector<QString>> userMeasurementSelectionButtonLayout = {
    { {"single"}, {"multi"} },
};

UserMeasurementSelectionViewModel::UserMeasurementSelectionViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent)
    : AbstractViewModel(screenId, model, parent)
{
    setObjectName("userMeasurementSelectionViewModel");
    _buttonOperation.setButtonName(BUTTON_COLUMN_NUMBER, BUTTON_ROW_NUMBER, userMeasurementSelectionButtonLayout);
    _buttonOperation.setActiveObject(userMeasurementSelectionButtonLayout[0][0]);
    _activeButton = userMeasurementSelectionButtonLayout[0][0];
}

UserMeasurementSelectionViewModel::~UserMeasurementSelectionViewModel()
{

}

void UserMeasurementSelectionViewModel::activate()
{
    if (nullptr == _view) {
        qErrnoWarning("_view is null");
        return;
    }

    connect(this, SIGNAL(requestSetTakeOver(QVariant, QVariant)), _view, SLOT(backup(QVariant, QVariant)));
    connect(this, SIGNAL(removeAttribute(QString)), _mainFrame, SLOT(onRemoveAttribute(QString)));

    // 先頭のボタンをアクティブにする
    resetToInitialButtonState(userMeasurementSelectionButtonLayout[0][0], _activeButton, _buttonOperation);

    // リスト測定のアイコン表示
    if (_takeOver["hasMultiBandsInUserSetting"].toBool()) {
        if (_view) {
            _view->setProperty("useListMeasurement", true);
        }
    }

    // 測定する Band アイコンをクリアー
    _model->replaceMenuList(MenuListIconIndex::BAND_ICON, QString(""));
}

void UserMeasurementSelectionViewModel::deactivate()
{
    AbstractViewModel::deactivate();
    disconnect(this, SIGNAL(requestSetTakeOver(QVariant, QVariant)), _view, SLOT(backup(QVariant, QVariant)));
    disconnect(this, SIGNAL(removeAttribute(QString)), _mainFrame, SLOT(onRemoveAttribute(QString)));
}

void UserMeasurementSelectionViewModel::setTakeOver()
{

}

void UserMeasurementSelectionViewModel::onKeyStatus(ButtonId id)
{
    AbstractViewModel::onKeyStatus(id);

    if (id == BUTTON_ENTER) {
        if (_activeButton == "single") {
            emit requestSetTakeOver("fromUserSetting", true);
            onRequest(0);
        } else if (_activeButton == "multi") {
            emit requestSetTakeOver("fromUserSetting", true);
            onRequest(1);
        }
    } else {
        moveCursor(id);
    }
}

void UserMeasurementSelectionViewModel::onButtonPress(ButtonId id)
{
    Q_UNUSED(id);
    // 画面遷移するので、押した際のボタン画像更新はなし
}

void UserMeasurementSelectionViewModel::onRequest(int condition)
{
    emit request(_screenId, condition);
}

void UserMeasurementSelectionViewModel::moveCursor(ButtonId id)
{
    if ((id == BUTTON_UP) || (id == BUTTON_DOWN) || (id == BUTTON_RIGHT) || (id == BUTTON_LEFT)) {

        QString nextBtn;
        bool ret = _buttonOperation.nextActiveObject(id, nextBtn);

        if (ret) {
            // inactive
            setBoolProperty(_activeButton, "active", false);

            // active
            setBoolProperty(nextBtn, "active", true);

            _activeButton = nextBtn;
            _buttonOperation.setActiveObject(_activeButton);
        }
    }
}

void UserMeasurementSelectionViewModel::setBoolProperty(QString objectName, QString propertyName, bool value)
{
    QObject *target = nullptr;
    if (_view) {
        target = _view->findChild<QObject *>(objectName);
    }
    if (target) {
        target->setProperty(propertyName.toUtf8().constData(), value);
    }
}
