/*
 * This file is part of pdisp. Copyright (c) 2021 DX ANTENNA CO.,LTD.
 *
 * pdisp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef USERMEASUREMENTSELECTION_H
#define USERMEASUREMENTSELECTION_H

#include "abstractviewmodel.h"
#include "buttonoperation.h"

/**
 * @brief 測定メニュー選択 ViewModel
 */
class UserMeasurementSelectionViewModel : public AbstractViewModel
{
    Q_OBJECT
public:
    /**
     * @brief コンストラクター
     * @param screenId 画面 ID
     * @param model Model クラスのポインター
     * @param parent 親オブジェクト
     */
    explicit UserMeasurementSelectionViewModel(ScreenId screenId, LevelCheckerModel *&model, QObject *parent = nullptr);

    /**
     * @brief デストラクタ
     */
    virtual ~UserMeasurementSelectionViewModel();

    /**
     * @brief 画面Active 時の処理
     */
    virtual void activate() override;

    /**
     * @brief 画面を閉じるときに呼び出す表示な用の保存処理
     */
    virtual void deactivate(void) override;

    /**
     * @brief 遷移先画面で参照する遷移前画面のデータ設定
     */
    virtual void setTakeOver() override;

signals:
    void requestSetTakeOver(QVariant, QVariant);

protected:
    /**
     * @brief onKeyStatus
     * @param id
     */
    virtual void onKeyStatus(ButtonId id) override;

    /**
     * @brief onButtonPress
     * @param id
     */
    virtual void onButtonPress(ButtonId id) override;

private slots:
    /**
     * @brief 画面遷移要求の受信時処理
     * @param condition 画面IDリストのインデックス
     */
    virtual void onRequest(int condition) override;

private:
    ButtonOperation _buttonOperation;   //!< ボタン操作情報
    QString _activeButton;              //!< 活性ボタンID

    /**
     * @brief moveCursor
     * @param id
     */
    void moveCursor(ButtonId id);

    /**
     * @brief プロパティに Bool 値を設定
     * @param objectName オブジェクト名
     * @param propertyName プロパティ名
     * @param value 設定する Bool 値
     */
    void setBoolProperty(QString objectName, QString propertyName, bool value);
};

#endif // USERMEASUREMENTSELECTION_H
